#include <cstring>
#include <limits>

#include "CompletionModel.h"
#include "Quality.h"
#include "clang/Sema/CodeCompleteConsumer.h"
#include "llvm/ADT/bit.h"

#define BIT(X) (1 << X)

namespace clang {
namespace clangd {

using SymbolCategory_type = clang::clangd::SymbolQualitySignals::SymbolCategory;
using ContextKind_type = clang::CodeCompletionContext::Kind;
using Scope_type = clang::clangd::SymbolRelevanceSignals::AccessibleScope;

uint32_t Example::OrderEncode(float F) {
  static_assert(std::numeric_limits<float>::is_iec559, "");
  constexpr uint32_t TopBit = ~(~uint32_t{0} >> 1);

  // Get the bits of the float. Endianness is the same as for integers.
  uint32_t U = llvm::bit_cast<uint32_t>(F);
  std::memcpy(&U, &F, sizeof(U));
  // IEEE 754 floats compare like sign-magnitude integers.
  if (U & TopBit)    // Negative float.
    return 0 - U;    // Map onto the low half of integers, order reversed.
  return U + TopBit; // Positive floats map onto the high half of integers.
}

namespace {
LLVM_ATTRIBUTE_NOINLINE float EvaluateTree0(const Example& E) {
  t0_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t0_n232;
  t0_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t0_n199;
  t0_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t0_n124;
  t0_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t0_n57;
  t0_n4: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t0_n26;
  t0_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t0_n7;
  t0_n6: return -0.12079951167106628f;
  t0_n7: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t0_n9;
  t0_n8: return 0.061142247170209885f;
  t0_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t0_n13;
  t0_n10: if (E.getNumReferences() >= 3272572928 /*143.5*/) goto t0_n12;
  t0_n11: return -0.12391144037246704f;
  t0_n12: return -0.026990002021193504f;
  t0_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t0_n15;
  t0_n14: return 0.018572721630334854f;
  t0_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t0_n17;
  t0_n16: return 0.15703141689300537f;
  t0_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t0_n19;
  t0_n18: return 0.1773659735918045f;
  t0_n19: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n25;
  t0_n20: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t0_n24;
  t0_n21: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t0_n23;
  t0_n22: return 0.20000000298023224f;
  t0_n23: return 0.20000000298023224f;
  t0_n24: return 0.14621421694755554f;
  t0_n25: return 0.19240888953208923f;
  t0_n26: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n30;
  t0_n27: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n29;
  t0_n28: return 0.06444863229990005f;
  t0_n29: return 0.1855955868959427f;
  t0_n30: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t0_n40;
  t0_n31: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n37;
  t0_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t0_n34;
  t0_n33: return 0.17781588435173035f;
  t0_n34: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t0_n36;
  t0_n35: return 0.17779812216758728f;
  t0_n36: return 0.19931510090827942f;
  t0_n37: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t0_n39;
  t0_n38: return 0.1787724494934082f;
  t0_n39: return 0.19916342198848724f;
  t0_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t0_n42;
  t0_n41: return 0.17418637871742249f;
  t0_n42: if (E.getNumReferences() >= 3341246080 /*42846.5*/) goto t0_n46;
  t0_n43: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n45;
  t0_n44: return 0.1877955049276352f;
  t0_n45: return 0.19817236065864563f;
  t0_n46: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t0_n56;
  t0_n47: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t0_n49;
  t0_n48: return 0.20000000298023224f;
  t0_n49: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t0_n55;
  t0_n50: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t0_n54;
  t0_n51: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t0_n53;
  t0_n52: return 0.1981440782546997f;
  t0_n53: return 0.20000000298023224f;
  t0_n54: return 0.19614481925964355f;
  t0_n55: return 0.19921576976776123f;
  t0_n56: return 0.19941894710063934f;
  t0_n57: if (E.getFileProximityDistance() >= 3255173120 /*33.5*/) goto t0_n117;
  t0_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t0_n74;
  t0_n59: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t0_n61;
  t0_n60: return 0.11802919209003448f;
  t0_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t0_n65;
  t0_n62: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t0_n64;
  t0_n63: return 0.12647944688796997f;
  t0_n64: return 0.17280472815036774f;
  t0_n65: if (E.getNumReferences() >= 3347567040 /*69539.5*/) goto t0_n67;
  t0_n66: return 0.17839567363262177f;
  t0_n67: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t0_n69;
  t0_n68: return 0.1969286948442459f;
  t0_n69: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t0_n71;
  t0_n70: return 0.20000000298023224f;
  t0_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t0_n73;
  t0_n72: return 0.20000000298023224f;
  t0_n73: return 0.20000000298023224f;
  t0_n74: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t0_n76;
  t0_n75: return 0.16014410555362701f;
  t0_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t0_n80;
  t0_n77: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t0_n79;
  t0_n78: return 0.10176723450422287f;
  t0_n79: return 0.1980476826429367f;
  t0_n80: if (E.getNumReferences() >= 3335188480 /*25976.0*/) goto t0_n94;
  t0_n81: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t0_n89;
  t0_n82: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t0_n88;
  t0_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t0_n85;
  t0_n84: return 0.17472603917121887f;
  t0_n85: if (E.getNumReferences() >= 3331445760 /*18666.0*/) goto t0_n87;
  t0_n86: return 0.1908876597881317f;
  t0_n87: return 0.20000000298023224f;
  t0_n88: return 0.17501217126846313f;
  t0_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t0_n91;
  t0_n90: return 0.17833831906318665f;
  t0_n91: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t0_n93;
  t0_n92: return 0.187881201505661f;
  t0_n93: return 0.19937188923358917f;
  t0_n94: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t0_n98;
  t0_n95: if (E.getNumReferences() >= 3357991456 /*170888.5*/) goto t0_n97;
  t0_n96: return 0.1930556446313858f;
  t0_n97: return 0.17461903393268585f;
  t0_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t0_n100;
  t0_n99: return 0.19675719738006592f;
  t0_n100: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n112;
  t0_n101: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t0_n111;
  t0_n102: if (E.getNumReferences() >= 3347866752 /*71881.0*/) goto t0_n104;
  t0_n103: return 0.20000000298023224f;
  t0_n104: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t0_n106;
  t0_n105: return 0.20000000298023224f;
  t0_n106: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t0_n108;
  t0_n107: return 0.16305941343307495f;
  t0_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t0_n110;
  t0_n109: return 0.20000000298023224f;
  t0_n110: return 0.20000000298023224f;
  t0_n111: return 0.20000000298023224f;
  t0_n112: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t0_n114;
  t0_n113: return 0.19862937927246094f;
  t0_n114: if (E.getNumReferences() >= 3339920000 /*37666.5*/) goto t0_n116;
  t0_n115: return 0.20000000298023224f;
  t0_n116: return 0.20000000298023224f;
  t0_n117: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n119;
  t0_n118: return -0.027393395081162453f;
  t0_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t0_n121;
  t0_n120: return 0.06317751854658127f;
  t0_n121: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t0_n123;
  t0_n122: return 0.07462543994188309f;
  t0_n123: return 0.1521744430065155f;
  t0_n124: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t0_n160;
  t0_n125: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n147;
  t0_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t0_n132;
  t0_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t0_n129;
  t0_n128: return -0.02582113817334175f;
  t0_n129: if (E.getNumReferences() >= 3306979328 /*2504.0*/) goto t0_n131;
  t0_n130: return 0.1625605672597885f;
  t0_n131: return 0.20000000298023224f;
  t0_n132: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t0_n134;
  t0_n133: return 0.13989154994487762f;
  t0_n134: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t0_n140;
  t0_n135: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t0_n137;
  t0_n136: return 0.12005230039358139f;
  t0_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t0_n139;
  t0_n138: return 0.18763314187526703f;
  t0_n139: return 0.19849012792110443f;
  t0_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t0_n144;
  t0_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t0_n143;
  t0_n142: return 0.06016721948981285f;
  t0_n143: return 0.1677456796169281f;
  t0_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t0_n146;
  t0_n145: return -0.013765337876975536f;
  t0_n146: return 0.18368329107761383f;
  t0_n147: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t0_n149;
  t0_n148: return 0.17693720757961273f;
  t0_n149: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t0_n151;
  t0_n150: return 0.1785055547952652f;
  t0_n151: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n159;
  t0_n152: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t0_n158;
  t0_n153: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t0_n155;
  t0_n154: return 0.18721753358840942f;
  t0_n155: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t0_n157;
  t0_n156: return 0.1538866013288498f;
  t0_n157: return 0.19920213520526886f;
  t0_n158: return 0.19387505948543549f;
  t0_n159: return 0.1912827491760254f;
  t0_n160: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t0_n162;
  t0_n161: return 0.15168944001197815f;
  t0_n162: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t0_n188;
  t0_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t0_n165;
  t0_n164: return 0.012881728820502758f;
  t0_n165: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t0_n181;
  t0_n166: if (E.getNumReferences() >= 3332027904 /*19803.0*/) goto t0_n170;
  t0_n167: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t0_n169;
  t0_n168: return 0.18983542919158936f;
  t0_n169: return 0.16867470741271973f;
  t0_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t0_n174;
  t0_n171: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t0_n173;
  t0_n172: return 0.19392213225364685f;
  t0_n173: return 0.20000000298023224f;
  t0_n174: if (E.getNumReferences() >= 3333710848 /*23090.0*/) goto t0_n178;
  t0_n175: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n177;
  t0_n176: return 0.1994200497865677f;
  t0_n177: return 0.20000000298023224f;
  t0_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t0_n180;
  t0_n179: return 0.20000000298023224f;
  t0_n180: return 0.19904161989688873f;
  t0_n181: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n183;
  t0_n182: return 0.1641821414232254f;
  t0_n183: if (E.getNumReferences() >= 3314309120 /*4491.0*/) goto t0_n185;
  t0_n184: return 0.18643628060817719f;
  t0_n185: if (E.getNumReferences() >= 3319552000 /*7051.0*/) goto t0_n187;
  t0_n186: return 0.20000000298023224f;
  t0_n187: return 0.19677825272083282f;
  t0_n188: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t0_n198;
  t0_n189: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t0_n197;
  t0_n190: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t0_n196;
  t0_n191: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t0_n193;
  t0_n192: return 0.20000000298023224f;
  t0_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t0_n195;
  t0_n194: return 0.20000000298023224f;
  t0_n195: return 0.20000000298023224f;
  t0_n196: return 0.20000000298023224f;
  t0_n197: return 0.19828557968139648f;
  t0_n198: return 0.18800073862075806f;
  t0_n199: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t0_n207;
  t0_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t0_n204;
  t0_n201: if (E.getFileProximityDistance() >= 3252682752 /*28.0*/) goto t0_n203;
  t0_n202: return 0.18233279883861542f;
  t0_n203: return 0.20000000298023224f;
  t0_n204: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t0_n206;
  t0_n205: return 0.18986621499061584f;
  t0_n206: return 0.19835087656974792f;
  t0_n207: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t0_n215;
  t0_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t0_n212;
  t0_n209: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t0_n211;
  t0_n210: return 0.18936631083488464f;
  t0_n211: return 0.19875085353851318f;
  t0_n212: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t0_n214;
  t0_n213: return 0.20000000298023224f;
  t0_n214: return 0.20000000298023224f;
  t0_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t0_n223;
  t0_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t0_n222;
  t0_n217: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t0_n219;
  t0_n218: return 0.20000000298023224f;
  t0_n219: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n221;
  t0_n220: return 0.20000000298023224f;
  t0_n221: return 0.20000000298023224f;
  t0_n222: return 0.20000000298023224f;
  t0_n223: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n225;
  t0_n224: return 0.19947533309459686f;
  t0_n225: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t0_n231;
  t0_n226: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t0_n230;
  t0_n227: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t0_n229;
  t0_n228: return 0.20000000298023224f;
  t0_n229: return 0.20000000298023224f;
  t0_n230: return 0.19799521565437317f;
  t0_n231: return 0.20000000298023224f;
  t0_n232: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t0_n238;
  t0_n233: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n237;
  t0_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t0_n236;
  t0_n235: return 0.18191476166248322f;
  t0_n236: return 0.19283226132392883f;
  t0_n237: return 0.19608449935913086f;
  t0_n238: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n252;
  t0_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t0_n245;
  t0_n240: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t0_n242;
  t0_n241: return 0.19304229319095612f;
  t0_n242: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t0_n244;
  t0_n243: return 0.19672870635986328f;
  t0_n244: return 0.19354674220085144f;
  t0_n245: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t0_n251;
  t0_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t0_n248;
  t0_n247: return 0.0008015634957700968f;
  t0_n248: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t0_n250;
  t0_n249: return 0.19255712628364563f;
  t0_n250: return -0.038249850273132324f;
  t0_n251: return 0.1875191479921341f;
  t0_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t0_n254;
  t0_n253: return 0.19669055938720703f;
  t0_n254: return 0.19533346593379974f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree1(const Example& E) {
  t1_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t1_n200;
  t1_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t1_n163;
  t1_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t1_n100;
  t1_n3: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t1_n41;
  t1_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t1_n6;
  t1_n5: return -0.15091364085674286f;
  t1_n6: if (E.getFileProximityDistance() >= 3255173120 /*33.5*/) goto t1_n30;
  t1_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t1_n19;
  t1_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t1_n16;
  t1_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n11;
  t1_n10: return 0.05477355793118477f;
  t1_n11: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t1_n15;
  t1_n12: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t1_n14;
  t1_n13: return 0.1500079184770584f;
  t1_n14: return 0.16085197031497955f;
  t1_n15: return 0.12589889764785767f;
  t1_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t1_n18;
  t1_n17: return 0.14148353040218353f;
  t1_n18: return 0.16466857492923737f;
  t1_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t1_n21;
  t1_n20: return 0.1660798341035843f;
  t1_n21: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t1_n27;
  t1_n22: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t1_n24;
  t1_n23: return 0.17266814410686493f;
  t1_n24: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t1_n26;
  t1_n25: return 0.17533309757709503f;
  t1_n26: return 0.1711902618408203f;
  t1_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t1_n29;
  t1_n28: return 0.12080799788236618f;
  t1_n29: return 0.16948175430297852f;
  t1_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t1_n32;
  t1_n31: return -0.152507945895195f;
  t1_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t1_n34;
  t1_n33: return 0.062293633818626404f;
  t1_n34: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t1_n36;
  t1_n35: return 0.05149541795253754f;
  t1_n36: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t1_n38;
  t1_n37: return 0.1726255863904953f;
  t1_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t1_n40;
  t1_n39: return 0.15064777433872223f;
  t1_n40: return 0.17015288770198822f;
  t1_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t1_n47;
  t1_n42: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t1_n46;
  t1_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t1_n45;
  t1_n44: return -0.0333033986389637f;
  t1_n45: return 0.17266905307769775f;
  t1_n46: return 0.1643076390028f;
  t1_n47: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t1_n91;
  t1_n48: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t1_n84;
  t1_n49: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t1_n75;
  t1_n50: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t1_n64;
  t1_n51: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t1_n53;
  t1_n52: return 0.15230365097522736f;
  t1_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t1_n55;
  t1_n54: return 0.15409699082374573f;
  t1_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t1_n57;
  t1_n56: return 0.15844541788101196f;
  t1_n57: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t1_n59;
  t1_n58: return 0.16402532160282135f;
  t1_n59: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t1_n61;
  t1_n60: return 0.1747535616159439f;
  t1_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t1_n63;
  t1_n62: return 0.1657407134771347f;
  t1_n63: return 0.1731444001197815f;
  t1_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t1_n66;
  t1_n65: return 0.16987277567386627f;
  t1_n66: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t1_n70;
  t1_n67: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t1_n69;
  t1_n68: return 0.17380395531654358f;
  t1_n69: return 0.1460210531949997f;
  t1_n70: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t1_n74;
  t1_n71: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t1_n73;
  t1_n72: return 0.1738666445016861f;
  t1_n73: return 0.17415137588977814f;
  t1_n74: return 0.17075440287590027f;
  t1_n75: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t1_n79;
  t1_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t1_n78;
  t1_n77: return 0.17766523361206055f;
  t1_n78: return 0.17750349640846252f;
  t1_n79: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t1_n81;
  t1_n80: return 0.14760884642601013f;
  t1_n81: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t1_n83;
  t1_n82: return 0.17773769795894623f;
  t1_n83: return 0.16723182797431946f;
  t1_n84: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t1_n86;
  t1_n85: return 0.16861175000667572f;
  t1_n86: if (E.getNumReferences() >= 3341684224 /*44558.0*/) goto t1_n88;
  t1_n87: return 0.16913868486881256f;
  t1_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t1_n90;
  t1_n89: return 0.17053745687007904f;
  t1_n90: return 0.17202283442020416f;
  t1_n91: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t1_n93;
  t1_n92: return 0.17003630101680756f;
  t1_n93: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t1_n97;
  t1_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t1_n96;
  t1_n95: return 0.15597844123840332f;
  t1_n96: return 0.17304491996765137f;
  t1_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t1_n99;
  t1_n98: return 0.17289558053016663f;
  t1_n99: return 0.17391082644462585f;
  t1_n100: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t1_n158;
  t1_n101: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t1_n125;
  t1_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t1_n118;
  t1_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t1_n105;
  t1_n104: return -0.14724932610988617f;
  t1_n105: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n107;
  t1_n106: return -0.01228698343038559f;
  t1_n107: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t1_n117;
  t1_n108: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t1_n112;
  t1_n109: if (E.getNumReferences() >= 3299139584 /*1319.0*/) goto t1_n111;
  t1_n110: return 0.12740346789360046f;
  t1_n111: return 0.17001742124557495f;
  t1_n112: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t1_n114;
  t1_n113: return 0.10638996958732605f;
  t1_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t1_n116;
  t1_n115: return -0.00790400430560112f;
  t1_n116: return 0.17062979936599731f;
  t1_n117: return 0.16796031594276428f;
  t1_n118: if (E.getNumReferences() >= 3270770688 /*122.0*/) goto t1_n122;
  t1_n119: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t1_n121;
  t1_n120: return 0.16088688373565674f;
  t1_n121: return -0.1807948499917984f;
  t1_n122: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t1_n124;
  t1_n123: return 0.17053326964378357f;
  t1_n124: return 0.1730729192495346f;
  t1_n125: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n127;
  t1_n126: return 0.07471071928739548f;
  t1_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t1_n153;
  t1_n128: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t1_n140;
  t1_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t1_n131;
  t1_n130: return 0.04588872194290161f;
  t1_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t1_n139;
  t1_n132: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t1_n134;
  t1_n133: return 0.16948504745960236f;
  t1_n134: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t1_n136;
  t1_n135: return 0.1631210446357727f;
  t1_n136: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t1_n138;
  t1_n137: return 0.14138923585414886f;
  t1_n138: return 0.18068403005599976f;
  t1_n139: return 0.15891848504543304f;
  t1_n140: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t1_n142;
  t1_n141: return 0.16755996644496918f;
  t1_n142: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t1_n150;
  t1_n143: if (E.getNumReferences() >= 3350889856 /*95499.0*/) goto t1_n149;
  t1_n144: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t1_n146;
  t1_n145: return 0.17185594141483307f;
  t1_n146: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t1_n148;
  t1_n147: return 0.17316903173923492f;
  t1_n148: return 0.1699805110692978f;
  t1_n149: return 0.12834183871746063f;
  t1_n150: if (E.getNumReferences() >= 3361046624 /*218625.5*/) goto t1_n152;
  t1_n151: return 0.17364922165870667f;
  t1_n152: return 0.17049680650234222f;
  t1_n153: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t1_n155;
  t1_n154: return 0.17084209620952606f;
  t1_n155: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t1_n157;
  t1_n156: return 0.1738344430923462f;
  t1_n157: return 0.1729537546634674f;
  t1_n158: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t1_n162;
  t1_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t1_n161;
  t1_n160: return 0.1625131517648697f;
  t1_n161: return 0.17122158408164978f;
  t1_n162: return 0.1756647527217865f;
  t1_n163: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t1_n179;
  t1_n164: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n168;
  t1_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t1_n167;
  t1_n166: return 0.043860942125320435f;
  t1_n167: return 0.17042915523052216f;
  t1_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t1_n176;
  t1_n169: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t1_n171;
  t1_n170: return 0.16159118711948395f;
  t1_n171: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t1_n173;
  t1_n172: return 0.17422351241111755f;
  t1_n173: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t1_n175;
  t1_n174: return 0.17429384589195251f;
  t1_n175: return 0.15205422043800354f;
  t1_n176: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t1_n178;
  t1_n177: return 0.17339584231376648f;
  t1_n178: return 0.17394539713859558f;
  t1_n179: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t1_n187;
  t1_n180: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t1_n186;
  t1_n181: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t1_n185;
  t1_n182: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t1_n184;
  t1_n183: return 0.17305228114128113f;
  t1_n184: return 0.17637899518013f;
  t1_n185: return 0.17330048978328705f;
  t1_n186: return 0.1749802976846695f;
  t1_n187: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t1_n195;
  t1_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t1_n192;
  t1_n189: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t1_n191;
  t1_n190: return 0.17090068757534027f;
  t1_n191: return 0.1732286959886551f;
  t1_n192: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t1_n194;
  t1_n193: return 0.17361842095851898f;
  t1_n194: return 0.17327235639095306f;
  t1_n195: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t1_n197;
  t1_n196: return 0.1735181212425232f;
  t1_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t1_n199;
  t1_n198: return 0.17096033692359924f;
  t1_n199: return 0.1762663573026657f;
  t1_n200: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t1_n232;
  t1_n201: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t1_n209;
  t1_n202: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n204;
  t1_n203: return 0.1645682454109192f;
  t1_n204: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t1_n208;
  t1_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t1_n207;
  t1_n206: return 0.17240653932094574f;
  t1_n207: return 0.17337630689144135f;
  t1_n208: return -0.1254286766052246f;
  t1_n209: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t1_n223;
  t1_n210: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t1_n222;
  t1_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t1_n215;
  t1_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t1_n214;
  t1_n213: return -0.030446210876107216f;
  t1_n214: return 0.1743224859237671f;
  t1_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t1_n217;
  t1_n216: return 0.15891949832439423f;
  t1_n217: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t1_n221;
  t1_n218: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n220;
  t1_n219: return 0.17585204541683197f;
  t1_n220: return 0.1754288375377655f;
  t1_n221: return -0.20791785418987274f;
  t1_n222: return 0.1737327128648758f;
  t1_n223: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t1_n229;
  t1_n224: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t1_n228;
  t1_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t1_n227;
  t1_n226: return -0.018497085198760033f;
  t1_n227: return 0.17353105545043945f;
  t1_n228: return 0.1728522926568985f;
  t1_n229: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t1_n231;
  t1_n230: return 0.1719209849834442f;
  t1_n231: return 0.17153580486774445f;
  t1_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t1_n244;
  t1_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t1_n239;
  t1_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t1_n236;
  t1_n235: return 0.16320472955703735f;
  t1_n236: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t1_n238;
  t1_n237: return 0.1761353611946106f;
  t1_n238: return -0.001039095688611269f;
  t1_n239: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n243;
  t1_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t1_n242;
  t1_n241: return 0.17092837393283844f;
  t1_n242: return 0.17707902193069458f;
  t1_n243: return 0.17628850042819977f;
  t1_n244: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t1_n252;
  t1_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t1_n247;
  t1_n246: return 0.17169058322906494f;
  t1_n247: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t1_n249;
  t1_n248: return 0.1748499721288681f;
  t1_n249: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t1_n251;
  t1_n250: return 0.17445120215415955f;
  t1_n251: return 0.17385268211364746f;
  t1_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t1_n254;
  t1_n253: return 0.1731099635362625f;
  t1_n254: return 0.1733504682779312f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree2(const Example& E) {
  t2_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t2_n208;
  t2_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t2_n175;
  t2_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t2_n106;
  t2_n3: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t2_n41;
  t2_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t2_n6;
  t2_n5: return -0.133283793926239f;
  t2_n6: if (E.getFileProximityDistance() >= 3255173120 /*33.5*/) goto t2_n30;
  t2_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t2_n19;
  t2_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t2_n16;
  t2_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n11;
  t2_n10: return 0.07656025886535645f;
  t2_n11: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t2_n15;
  t2_n12: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t2_n14;
  t2_n13: return 0.13152086734771729f;
  t2_n14: return 0.1417326182126999f;
  t2_n15: return 0.10664967447519302f;
  t2_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t2_n18;
  t2_n17: return 0.12508608400821686f;
  t2_n18: return 0.14405442774295807f;
  t2_n19: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t2_n21;
  t2_n20: return 0.1429975926876068f;
  t2_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t2_n23;
  t2_n22: return 0.14844773709774017f;
  t2_n23: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t2_n27;
  t2_n24: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t2_n26;
  t2_n25: return 0.15496468544006348f;
  t2_n26: return 0.1491556018590927f;
  t2_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t2_n29;
  t2_n28: return 0.11798620223999023f;
  t2_n29: return 0.15261682868003845f;
  t2_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t2_n32;
  t2_n31: return -0.13154757022857666f;
  t2_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t2_n34;
  t2_n33: return 0.05591406673192978f;
  t2_n34: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t2_n36;
  t2_n35: return 0.044244393706321716f;
  t2_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n38;
  t2_n37: return 0.1516924500465393f;
  t2_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t2_n40;
  t2_n39: return 0.13413147628307343f;
  t2_n40: return 0.15042981505393982f;
  t2_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t2_n49;
  t2_n42: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t2_n48;
  t2_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t2_n45;
  t2_n44: return -0.039107292890548706f;
  t2_n45: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t2_n47;
  t2_n46: return 0.1497890204191208f;
  t2_n47: return 0.15605702996253967f;
  t2_n48: return 0.14486345648765564f;
  t2_n49: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t2_n97;
  t2_n50: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t2_n88;
  t2_n51: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t2_n73;
  t2_n52: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t2_n62;
  t2_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t2_n55;
  t2_n54: return 0.1279214322566986f;
  t2_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t2_n57;
  t2_n56: return 0.12952971458435059f;
  t2_n57: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t2_n59;
  t2_n58: return 0.1426417976617813f;
  t2_n59: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t2_n61;
  t2_n60: return 0.1562812775373459f;
  t2_n61: return 0.15334844589233398f;
  t2_n62: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t2_n64;
  t2_n63: return 0.14401467144489288f;
  t2_n64: if (E.getNumReferences() >= 3341684224 /*44558.0*/) goto t2_n66;
  t2_n65: return 0.14768342673778534f;
  t2_n66: if (E.getNumReferences() >= 3364158080 /*272340.0*/) goto t2_n72;
  t2_n67: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t2_n69;
  t2_n68: return 0.15198349952697754f;
  t2_n69: if (E.getNumReferences() >= 3356454464 /*146873.0*/) goto t2_n71;
  t2_n70: return 0.15132135152816772f;
  t2_n71: return 0.14691652357578278f;
  t2_n72: return -0.23428891599178314f;
  t2_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t2_n75;
  t2_n74: return 0.14979501068592072f;
  t2_n75: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t2_n79;
  t2_n76: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t2_n78;
  t2_n77: return 0.1529514640569687f;
  t2_n78: return 0.13581416010856628f;
  t2_n79: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t2_n87;
  t2_n80: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t2_n84;
  t2_n81: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t2_n83;
  t2_n82: return 0.15381106734275818f;
  t2_n83: return -0.2077629417181015f;
  t2_n84: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t2_n86;
  t2_n85: return 0.1538122594356537f;
  t2_n86: return 0.15379232168197632f;
  t2_n87: return 0.15146464109420776f;
  t2_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t2_n92;
  t2_n89: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t2_n91;
  t2_n90: return 0.14640307426452637f;
  t2_n91: return 0.15305066108703613f;
  t2_n92: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t2_n96;
  t2_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t2_n95;
  t2_n94: return 0.1561584621667862f;
  t2_n95: return 0.15588101744651794f;
  t2_n96: return -0.20534925162792206f;
  t2_n97: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t2_n99;
  t2_n98: return 0.1506338119506836f;
  t2_n99: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t2_n103;
  t2_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t2_n102;
  t2_n101: return 0.1336551457643509f;
  t2_n102: return 0.15281569957733154f;
  t2_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t2_n105;
  t2_n104: return 0.1526758372783661f;
  t2_n105: return 0.1535707414150238f;
  t2_n106: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t2_n164;
  t2_n107: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t2_n133;
  t2_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t2_n124;
  t2_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t2_n111;
  t2_n110: return -0.12758612632751465f;
  t2_n111: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n113;
  t2_n112: return -0.06837106496095657f;
  t2_n113: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t2_n123;
  t2_n114: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t2_n118;
  t2_n115: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t2_n117;
  t2_n116: return 0.10928419977426529f;
  t2_n117: return 0.151849627494812f;
  t2_n118: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t2_n120;
  t2_n119: return 0.0870794951915741f;
  t2_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t2_n122;
  t2_n121: return -0.004111700225621462f;
  t2_n122: return 0.15054772794246674f;
  t2_n123: return 0.14818798005580902f;
  t2_n124: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t2_n130;
  t2_n125: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t2_n129;
  t2_n126: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t2_n128;
  t2_n127: return 0.13847200572490692f;
  t2_n128: return 0.15455810725688934f;
  t2_n129: return -0.15978623926639557f;
  t2_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t2_n132;
  t2_n131: return 0.1426544338464737f;
  t2_n132: return 0.15348438918590546f;
  t2_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n135;
  t2_n134: return 0.05193212255835533f;
  t2_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t2_n161;
  t2_n136: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t2_n148;
  t2_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t2_n139;
  t2_n138: return 0.02436218596994877f;
  t2_n139: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t2_n147;
  t2_n140: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t2_n142;
  t2_n141: return 0.14910759031772614f;
  t2_n142: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t2_n144;
  t2_n143: return 0.14314158260822296f;
  t2_n144: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t2_n146;
  t2_n145: return 0.1194673553109169f;
  t2_n146: return 0.15822046995162964f;
  t2_n147: return 0.1404583901166916f;
  t2_n148: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t2_n150;
  t2_n149: return 0.14690779149532318f;
  t2_n150: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t2_n158;
  t2_n151: if (E.getNumReferences() >= 3350889856 /*95499.0*/) goto t2_n157;
  t2_n152: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t2_n154;
  t2_n153: return 0.15155918896198273f;
  t2_n154: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t2_n156;
  t2_n155: return 0.1530529260635376f;
  t2_n156: return 0.1498764008283615f;
  t2_n157: return 0.09187895059585571f;
  t2_n158: if (E.getNumReferences() >= 3361046624 /*218625.5*/) goto t2_n160;
  t2_n159: return 0.1537080556154251f;
  t2_n160: return 0.15092475712299347f;
  t2_n161: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t2_n163;
  t2_n162: return 0.1504388153553009f;
  t2_n163: return 0.1531168818473816f;
  t2_n164: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t2_n172;
  t2_n165: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t2_n167;
  t2_n166: return 0.14124099910259247f;
  t2_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n171;
  t2_n168: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t2_n170;
  t2_n169: return 0.14913100004196167f;
  t2_n170: return 0.15464331209659576f;
  t2_n171: return 0.15086820721626282f;
  t2_n172: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t2_n174;
  t2_n173: return 0.1553458422422409f;
  t2_n174: return 0.15285758674144745f;
  t2_n175: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t2_n191;
  t2_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n180;
  t2_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t2_n179;
  t2_n178: return -0.022871391847729683f;
  t2_n179: return 0.1508995145559311f;
  t2_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t2_n188;
  t2_n181: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t2_n183;
  t2_n182: return 0.1381033957004547f;
  t2_n183: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t2_n185;
  t2_n184: return 0.15351207554340363f;
  t2_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t2_n187;
  t2_n186: return 0.1538107991218567f;
  t2_n187: return 0.12698757648468018f;
  t2_n188: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t2_n190;
  t2_n189: return 0.15297596156597137f;
  t2_n190: return 0.15336363017559052f;
  t2_n191: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t2_n197;
  t2_n192: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t2_n196;
  t2_n193: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t2_n195;
  t2_n194: return 0.1531568467617035f;
  t2_n195: return 0.15304860472679138f;
  t2_n196: return 0.15437668561935425f;
  t2_n197: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t2_n205;
  t2_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t2_n202;
  t2_n199: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t2_n201;
  t2_n200: return 0.1497684270143509f;
  t2_n201: return 0.15299098193645477f;
  t2_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t2_n204;
  t2_n203: return 0.15331102907657623f;
  t2_n204: return 0.1530337929725647f;
  t2_n205: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t2_n207;
  t2_n206: return 0.15416307747364044f;
  t2_n207: return 0.15337632596492767f;
  t2_n208: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t2_n238;
  t2_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t2_n219;
  t2_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n212;
  t2_n211: return 0.1440243422985077f;
  t2_n212: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t2_n218;
  t2_n213: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t2_n215;
  t2_n214: return 0.15269339084625244f;
  t2_n215: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t2_n217;
  t2_n216: return 0.1529308706521988f;
  t2_n217: return 0.1522054225206375f;
  t2_n218: return -0.10300616174936295f;
  t2_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t2_n231;
  t2_n220: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t2_n230;
  t2_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t2_n225;
  t2_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t2_n224;
  t2_n223: return -0.08178834617137909f;
  t2_n224: return 0.15332281589508057f;
  t2_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t2_n227;
  t2_n226: return 0.1412745714187622f;
  t2_n227: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t2_n229;
  t2_n228: return 0.15475565195083618f;
  t2_n229: return -0.17009080946445465f;
  t2_n230: return 0.15295350551605225f;
  t2_n231: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t2_n235;
  t2_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t2_n234;
  t2_n233: return 0.15320010483264923f;
  t2_n234: return 0.1525789499282837f;
  t2_n235: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t2_n237;
  t2_n236: return 0.15172122418880463f;
  t2_n237: return 0.15143021941184998f;
  t2_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t2_n248;
  t2_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t2_n243;
  t2_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t2_n242;
  t2_n241: return 0.14508500695228577f;
  t2_n242: return 0.15544523298740387f;
  t2_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n247;
  t2_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t2_n246;
  t2_n245: return 0.15400546789169312f;
  t2_n246: return 0.1562241017818451f;
  t2_n247: return 0.15588527917861938f;
  t2_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t2_n252;
  t2_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t2_n251;
  t2_n250: return 0.15181264281272888f;
  t2_n251: return 0.15424948930740356f;
  t2_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t2_n254;
  t2_n253: return 0.1531326323747635f;
  t2_n254: return 0.15396717190742493f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree3(const Example& E) {
  t3_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t3_n208;
  t3_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t3_n175;
  t3_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t3_n110;
  t3_n3: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t3_n41;
  t3_n4: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t3_n6;
  t3_n5: return -0.1204330176115036f;
  t3_n6: if (E.getFileProximityDistance() >= 3254910976 /*32.5*/) goto t3_n30;
  t3_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t3_n19;
  t3_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t3_n16;
  t3_n9: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t3_n15;
  t3_n10: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n12;
  t3_n11: return 0.08824971318244934f;
  t3_n12: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t3_n14;
  t3_n13: return 0.11693461984395981f;
  t3_n14: return 0.1275223046541214f;
  t3_n15: return 0.08346706628799438f;
  t3_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t3_n18;
  t3_n17: return 0.11292148381471634f;
  t3_n18: return 0.12999244034290314f;
  t3_n19: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t3_n21;
  t3_n20: return 0.12903906404972076f;
  t3_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t3_n23;
  t3_n22: return 0.1344074010848999f;
  t3_n23: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t3_n27;
  t3_n24: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t3_n26;
  t3_n25: return 0.14141340553760529f;
  t3_n26: return 0.13674995303153992f;
  t3_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t3_n29;
  t3_n28: return 0.10628057271242142f;
  t3_n29: return 0.13875740766525269f;
  t3_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t3_n32;
  t3_n31: return -0.11721540242433548f;
  t3_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t3_n34;
  t3_n33: return 0.06393055617809296f;
  t3_n34: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t3_n36;
  t3_n35: return -0.00043427685159258544f;
  t3_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t3_n40;
  t3_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n39;
  t3_n38: return 0.13770294189453125f;
  t3_n39: return 0.12343572080135345f;
  t3_n40: return 0.13588464260101318f;
  t3_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t3_n49;
  t3_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t3_n46;
  t3_n43: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t3_n45;
  t3_n44: return -0.034344382584095f;
  t3_n45: return 0.13136006891727448f;
  t3_n46: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t3_n48;
  t3_n47: return 0.1344141662120819f;
  t3_n48: return 0.14192871749401093f;
  t3_n49: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t3_n101;
  t3_n50: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t3_n90;
  t3_n51: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t3_n75;
  t3_n52: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t3_n64;
  t3_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t3_n55;
  t3_n54: return 0.11161486804485321f;
  t3_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t3_n57;
  t3_n56: return 0.1155828982591629f;
  t3_n57: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t3_n59;
  t3_n58: return 0.12801359593868256f;
  t3_n59: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t3_n61;
  t3_n60: return 0.1425664722919464f;
  t3_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol))) goto t3_n63;
  t3_n62: return 0.13518792390823364f;
  t3_n63: return 0.14209319651126862f;
  t3_n64: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t3_n66;
  t3_n65: return 0.13083583116531372f;
  t3_n66: if (E.getNumReferences() >= 3341246080 /*42846.5*/) goto t3_n68;
  t3_n67: return 0.1338840126991272f;
  t3_n68: if (E.getNumReferences() >= 3364158080 /*272340.0*/) goto t3_n74;
  t3_n69: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t3_n71;
  t3_n70: return 0.13880455493927002f;
  t3_n71: if (E.getNumReferences() >= 3356454464 /*146873.0*/) goto t3_n73;
  t3_n72: return 0.13821831345558167f;
  t3_n73: return 0.13438640534877777f;
  t3_n74: return -0.19527609646320343f;
  t3_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t3_n77;
  t3_n76: return 0.13634338974952698f;
  t3_n77: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t3_n81;
  t3_n78: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t3_n80;
  t3_n79: return 0.13949155807495117f;
  t3_n80: return 0.12266673892736435f;
  t3_n81: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t3_n89;
  t3_n82: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t3_n86;
  t3_n83: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t3_n85;
  t3_n84: return 0.1404382884502411f;
  t3_n85: return -0.17007437348365784f;
  t3_n86: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t3_n88;
  t3_n87: return 0.14041678607463837f;
  t3_n88: return 0.14080794155597687f;
  t3_n89: return 0.1385136842727661f;
  t3_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t3_n96;
  t3_n91: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t3_n95;
  t3_n92: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t3_n94;
  t3_n93: return 0.14224322140216827f;
  t3_n94: return 0.13457348942756653f;
  t3_n95: return 0.13982658088207245f;
  t3_n96: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t3_n100;
  t3_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t3_n99;
  t3_n98: return 0.1419159173965454f;
  t3_n99: return 0.14184363186359406f;
  t3_n100: return -0.18263313174247742f;
  t3_n101: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t3_n103;
  t3_n102: return 0.1371743530035019f;
  t3_n103: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t3_n107;
  t3_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t3_n106;
  t3_n105: return 0.1212882250547409f;
  t3_n106: return 0.13973192870616913f;
  t3_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t3_n109;
  t3_n108: return 0.1392742246389389f;
  t3_n109: return 0.14037735760211945f;
  t3_n110: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t3_n166;
  t3_n111: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t3_n137;
  t3_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t3_n128;
  t3_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t3_n115;
  t3_n114: return -0.11261919885873795f;
  t3_n115: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n117;
  t3_n116: return -0.06276673823595047f;
  t3_n117: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t3_n127;
  t3_n118: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t3_n122;
  t3_n119: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t3_n121;
  t3_n120: return 0.09549877792596817f;
  t3_n121: return 0.1385771930217743f;
  t3_n122: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t3_n124;
  t3_n123: return 0.07433127611875534f;
  t3_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t3_n126;
  t3_n125: return -0.0031157447956502438f;
  t3_n126: return 0.13701224327087402f;
  t3_n127: return 0.13425131142139435f;
  t3_n128: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t3_n134;
  t3_n129: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t3_n133;
  t3_n130: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t3_n132;
  t3_n131: return 0.12487947940826416f;
  t3_n132: return 0.13906612992286682f;
  t3_n133: return -0.14553101360797882f;
  t3_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t3_n136;
  t3_n135: return 0.12794062495231628f;
  t3_n136: return 0.13959991931915283f;
  t3_n137: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n139;
  t3_n138: return 0.06500580906867981f;
  t3_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t3_n163;
  t3_n140: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t3_n152;
  t3_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t3_n143;
  t3_n142: return 0.009600312449038029f;
  t3_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t3_n151;
  t3_n144: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t3_n146;
  t3_n145: return 0.13542282581329346f;
  t3_n146: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t3_n148;
  t3_n147: return 0.12905986607074738f;
  t3_n148: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t3_n150;
  t3_n149: return 0.11207016557455063f;
  t3_n150: return 0.14389507472515106f;
  t3_n151: return 0.1273270547389984f;
  t3_n152: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t3_n154;
  t3_n153: return 0.13303056359291077f;
  t3_n154: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t3_n162;
  t3_n155: if (E.getNumReferences() >= 3350889856 /*95499.0*/) goto t3_n161;
  t3_n156: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t3_n158;
  t3_n157: return 0.13820381462574005f;
  t3_n158: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t3_n160;
  t3_n159: return 0.13991540670394897f;
  t3_n160: return 0.13560201227664948f;
  t3_n161: return 0.08063444495201111f;
  t3_n162: return 0.1405167132616043f;
  t3_n163: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t3_n165;
  t3_n164: return 0.13715477287769318f;
  t3_n165: return 0.13972711563110352f;
  t3_n166: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t3_n174;
  t3_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t3_n169;
  t3_n168: return 0.12713909149169922f;
  t3_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n173;
  t3_n170: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t3_n172;
  t3_n171: return 0.13620653748512268f;
  t3_n172: return 0.1407044529914856f;
  t3_n173: return 0.13742958009243011f;
  t3_n174: return 0.14127114415168762f;
  t3_n175: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t3_n191;
  t3_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n180;
  t3_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t3_n179;
  t3_n178: return -0.01099332980811596f;
  t3_n179: return 0.1373530626296997f;
  t3_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t3_n188;
  t3_n181: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t3_n183;
  t3_n182: return 0.12371889501810074f;
  t3_n183: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t3_n185;
  t3_n184: return 0.13992975652217865f;
  t3_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t3_n187;
  t3_n186: return 0.14004194736480713f;
  t3_n187: return 0.1134493425488472f;
  t3_n188: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t3_n190;
  t3_n189: return 0.13938522338867188f;
  t3_n190: return 0.13996073603630066f;
  t3_n191: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t3_n197;
  t3_n192: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t3_n196;
  t3_n193: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t3_n195;
  t3_n194: return 0.14001934230327606f;
  t3_n195: return 0.13988569378852844f;
  t3_n196: return 0.14103291928768158f;
  t3_n197: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t3_n205;
  t3_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t3_n202;
  t3_n199: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t3_n201;
  t3_n200: return 0.13570933043956757f;
  t3_n201: return 0.13970209658145905f;
  t3_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t3_n204;
  t3_n203: return 0.14017435908317566f;
  t3_n204: return 0.13984468579292297f;
  t3_n205: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t3_n207;
  t3_n206: return 0.14031049609184265f;
  t3_n207: return 0.14106346666812897f;
  t3_n208: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t3_n238;
  t3_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t3_n217;
  t3_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n212;
  t3_n211: return 0.1298855096101761f;
  t3_n212: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t3_n216;
  t3_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t3_n215;
  t3_n214: return 0.13843801617622375f;
  t3_n215: return 0.139500692486763f;
  t3_n216: return -0.09115998446941376f;
  t3_n217: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t3_n231;
  t3_n218: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t3_n230;
  t3_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t3_n223;
  t3_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t3_n222;
  t3_n221: return -0.04582589119672775f;
  t3_n222: return 0.1396026909351349f;
  t3_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t3_n225;
  t3_n224: return 0.12141555547714233f;
  t3_n225: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n229;
  t3_n226: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t3_n228;
  t3_n227: return 0.14089390635490417f;
  t3_n228: return -0.15300801396369934f;
  t3_n229: return 0.14157257974147797f;
  t3_n230: return 0.13919265568256378f;
  t3_n231: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t3_n235;
  t3_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t3_n234;
  t3_n233: return 0.1399143785238266f;
  t3_n234: return 0.13935180008411407f;
  t3_n235: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t3_n237;
  t3_n236: return 0.13858456909656525f;
  t3_n237: return 0.1381283849477768f;
  t3_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t3_n248;
  t3_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t3_n243;
  t3_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t3_n242;
  t3_n241: return 0.13119500875473022f;
  t3_n242: return 0.14192305505275726f;
  t3_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n247;
  t3_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t3_n246;
  t3_n245: return 0.1411043107509613f;
  t3_n246: return 0.14264418184757233f;
  t3_n247: return 0.14277209341526031f;
  t3_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t3_n252;
  t3_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t3_n251;
  t3_n250: return 0.13855332136154175f;
  t3_n251: return 0.14121687412261963f;
  t3_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t3_n254;
  t3_n253: return 0.14014697074890137f;
  t3_n254: return 0.14132735133171082f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree4(const Example& E) {
  t4_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t4_n208;
  t4_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t4_n181;
  t4_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t4_n118;
  t4_n3: if (E.getNumReferences() >= 3334835456 /*25286.5*/) goto t4_n53;
  t4_n4: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t4_n14;
  t4_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t4_n11;
  t4_n6: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t4_n8;
  t4_n7: return -0.00011980631097685546f;
  t4_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n10;
  t4_n9: return -0.13037718832492828f;
  t4_n10: return -0.12400064617395401f;
  t4_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t4_n13;
  t4_n12: return 0.02150256559252739f;
  t4_n13: return 0.1516893357038498f;
  t4_n14: if (E.getFileProximityDistance() >= 3255173120 /*33.5*/) goto t4_n42;
  t4_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t4_n31;
  t4_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t4_n26;
  t4_n17: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t4_n25;
  t4_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n20;
  t4_n19: return 0.08278460055589676f;
  t4_n20: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t4_n22;
  t4_n21: return 0.105562724173069f;
  t4_n22: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t4_n24;
  t4_n23: return 0.1159939169883728f;
  t4_n24: return 0.12627074122428894f;
  t4_n25: return 0.06974900513887405f;
  t4_n26: if (E.getNumReferences() >= 3280060416 /*259.5*/) goto t4_n30;
  t4_n27: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t4_n29;
  t4_n28: return 0.09180619567632675f;
  t4_n29: return 0.1179983913898468f;
  t4_n30: return 0.12673504650592804f;
  t4_n31: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t4_n33;
  t4_n32: return 0.1182960495352745f;
  t4_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t4_n35;
  t4_n34: return 0.12410110980272293f;
  t4_n35: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t4_n39;
  t4_n36: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t4_n38;
  t4_n37: return 0.1321878731250763f;
  t4_n38: return 0.1260734647512436f;
  t4_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t4_n41;
  t4_n40: return 0.09228869527578354f;
  t4_n41: return 0.12924227118492126f;
  t4_n42: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t4_n44;
  t4_n43: return -0.10240945965051651f;
  t4_n44: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t4_n46;
  t4_n45: return 0.05783577263355255f;
  t4_n46: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t4_n48;
  t4_n47: return 0.007513059303164482f;
  t4_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t4_n52;
  t4_n49: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n51;
  t4_n50: return 0.12745356559753418f;
  t4_n51: return 0.11066359281539917f;
  t4_n52: return 0.12579523026943207f;
  t4_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t4_n61;
  t4_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t4_n58;
  t4_n55: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t4_n57;
  t4_n56: return -0.022672263905405998f;
  t4_n57: return 0.12118544429540634f;
  t4_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t4_n60;
  t4_n59: return 0.12299049645662308f;
  t4_n60: return 0.13208577036857605f;
  t4_n61: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t4_n109;
  t4_n62: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t4_n100;
  t4_n63: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t4_n85;
  t4_n64: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t4_n74;
  t4_n65: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t4_n67;
  t4_n66: return 0.10073628276586533f;
  t4_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t4_n69;
  t4_n68: return 0.10787418484687805f;
  t4_n69: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t4_n71;
  t4_n70: return 0.11826545745134354f;
  t4_n71: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t4_n73;
  t4_n72: return 0.1327129304409027f;
  t4_n73: return 0.1297278106212616f;
  t4_n74: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t4_n76;
  t4_n75: return 0.12161669135093689f;
  t4_n76: if (E.getNumReferences() >= 3341246080 /*42846.5*/) goto t4_n78;
  t4_n77: return 0.1254672110080719f;
  t4_n78: if (E.getNumReferences() >= 3364158080 /*272340.0*/) goto t4_n84;
  t4_n79: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t4_n81;
  t4_n80: return 0.12968407571315765f;
  t4_n81: if (E.getNumReferences() >= 3356454464 /*146873.0*/) goto t4_n83;
  t4_n82: return 0.12899793684482574f;
  t4_n83: return 0.12471718341112137f;
  t4_n84: return -0.18162168562412262f;
  t4_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t4_n87;
  t4_n86: return 0.1273355633020401f;
  t4_n87: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t4_n91;
  t4_n88: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t4_n90;
  t4_n89: return 0.13142964243888855f;
  t4_n90: return 0.12226037681102753f;
  t4_n91: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t4_n99;
  t4_n92: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t4_n96;
  t4_n93: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t4_n95;
  t4_n94: return 0.13121187686920166f;
  t4_n95: return -0.15203113853931427f;
  t4_n96: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t4_n98;
  t4_n97: return 0.13116788864135742f;
  t4_n98: return 0.1318351775407791f;
  t4_n99: return 0.12939037382602692f;
  t4_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t4_n104;
  t4_n101: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t4_n103;
  t4_n102: return 0.12765207886695862f;
  t4_n103: return 0.13061551749706268f;
  t4_n104: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t4_n108;
  t4_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t4_n107;
  t4_n106: return 0.13202622532844543f;
  t4_n107: return 0.1321810781955719f;
  t4_n108: return -0.16530804336071014f;
  t4_n109: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t4_n113;
  t4_n110: if (E.getNumReferences() >= 3360228064 /*205835.5*/) goto t4_n112;
  t4_n111: return 0.12507092952728271f;
  t4_n112: return 0.13102613389492035f;
  t4_n113: if (E.getNumReferences() >= 3346571264 /*63648.0*/) goto t4_n115;
  t4_n114: return 0.12814205884933472f;
  t4_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t4_n117;
  t4_n116: return 0.1298857033252716f;
  t4_n117: return 0.1312725692987442f;
  t4_n118: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t4_n168;
  t4_n119: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t4_n145;
  t4_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t4_n136;
  t4_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t4_n123;
  t4_n122: return -0.0990992933511734f;
  t4_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n125;
  t4_n124: return -0.04187201336026192f;
  t4_n125: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t4_n135;
  t4_n126: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t4_n130;
  t4_n127: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t4_n129;
  t4_n128: return 0.08492990583181381f;
  t4_n129: return 0.1289561539888382f;
  t4_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t4_n132;
  t4_n131: return 0.05860279127955437f;
  t4_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t4_n134;
  t4_n133: return -0.0040860529989004135f;
  t4_n134: return 0.12704111635684967f;
  t4_n135: return 0.12396207451820374f;
  t4_n136: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t4_n142;
  t4_n137: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t4_n141;
  t4_n138: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t4_n140;
  t4_n139: return 0.11355147510766983f;
  t4_n140: return 0.12945899367332458f;
  t4_n141: return -0.1311863362789154f;
  t4_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t4_n144;
  t4_n143: return 0.11862269788980484f;
  t4_n144: return 0.12997157871723175f;
  t4_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n147;
  t4_n146: return 0.06020234897732735f;
  t4_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t4_n165;
  t4_n148: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t4_n154;
  t4_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t4_n151;
  t4_n150: return 0.014503761194646358f;
  t4_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t4_n153;
  t4_n152: return 0.12471770495176315f;
  t4_n153: return 0.11718671768903732f;
  t4_n154: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t4_n156;
  t4_n155: return 0.12273207306861877f;
  t4_n156: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t4_n164;
  t4_n157: if (E.getNumReferences() >= 3350889856 /*95499.0*/) goto t4_n163;
  t4_n158: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t4_n160;
  t4_n159: return 0.12865211069583893f;
  t4_n160: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t4_n162;
  t4_n161: return 0.13085277378559113f;
  t4_n162: return 0.12587197124958038f;
  t4_n163: return 0.07199150323867798f;
  t4_n164: return 0.1315421760082245f;
  t4_n165: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t4_n167;
  t4_n166: return 0.1275501847267151f;
  t4_n167: return 0.13041375577449799f;
  t4_n168: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t4_n180;
  t4_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t4_n171;
  t4_n170: return 0.11771033704280853f;
  t4_n171: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n175;
  t4_n172: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t4_n174;
  t4_n173: return 0.12486705929040909f;
  t4_n174: return 0.13076971471309662f;
  t4_n175: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t4_n177;
  t4_n176: return 0.12794850766658783f;
  t4_n177: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t4_n179;
  t4_n178: return 0.1687382161617279f;
  t4_n179: return 0.048748381435871124f;
  t4_n180: return 0.13170671463012695f;
  t4_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t4_n193;
  t4_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n186;
  t4_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t4_n185;
  t4_n184: return -0.023818938061594963f;
  t4_n185: return 0.12835869193077087f;
  t4_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t4_n190;
  t4_n187: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t4_n189;
  t4_n188: return 0.11277836561203003f;
  t4_n189: return 0.128361314535141f;
  t4_n190: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t4_n192;
  t4_n191: return 0.12976807355880737f;
  t4_n192: return 0.1306358128786087f;
  t4_n193: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t4_n197;
  t4_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t4_n196;
  t4_n195: return 0.13084447383880615f;
  t4_n196: return 0.13187165558338165f;
  t4_n197: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t4_n205;
  t4_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t4_n202;
  t4_n199: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t4_n201;
  t4_n200: return 0.12571308016777039f;
  t4_n201: return 0.13053598999977112f;
  t4_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t4_n204;
  t4_n203: return 0.13111430406570435f;
  t4_n204: return 0.13072632253170013f;
  t4_n205: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t4_n207;
  t4_n206: return 0.13192588090896606f;
  t4_n207: return 0.13129131495952606f;
  t4_n208: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t4_n238;
  t4_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t4_n217;
  t4_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n212;
  t4_n211: return 0.11941647529602051f;
  t4_n212: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t4_n216;
  t4_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t4_n215;
  t4_n214: return 0.12906840443611145f;
  t4_n215: return 0.1302323192358017f;
  t4_n216: return -0.10368392616510391f;
  t4_n217: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t4_n231;
  t4_n218: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t4_n230;
  t4_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t4_n223;
  t4_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t4_n222;
  t4_n221: return -0.040684185922145844f;
  t4_n222: return 0.12997625768184662f;
  t4_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t4_n225;
  t4_n224: return 0.1016077995300293f;
  t4_n225: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t4_n229;
  t4_n226: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n228;
  t4_n227: return 0.13122738897800446f;
  t4_n228: return 0.13243570923805237f;
  t4_n229: return -0.14311252534389496f;
  t4_n230: return 0.12940353155136108f;
  t4_n231: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t4_n235;
  t4_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t4_n234;
  t4_n233: return 0.13074102997779846f;
  t4_n234: return 0.13013486564159393f;
  t4_n235: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t4_n237;
  t4_n236: return 0.12941282987594604f;
  t4_n237: return 0.1288728266954422f;
  t4_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t4_n248;
  t4_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t4_n243;
  t4_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t4_n242;
  t4_n241: return 0.11836336553096771f;
  t4_n242: return 0.13269884884357452f;
  t4_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n247;
  t4_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t4_n246;
  t4_n245: return 0.13222922384738922f;
  t4_n246: return 0.13333725929260254f;
  t4_n247: return 0.13374334573745728f;
  t4_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t4_n252;
  t4_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t4_n251;
  t4_n250: return 0.12952646613121033f;
  t4_n251: return 0.13223955035209656f;
  t4_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t4_n254;
  t4_n253: return 0.13121181726455688f;
  t4_n254: return 0.13238316774368286f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree5(const Example& E) {
  t5_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t5_n210;
  t5_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t5_n183;
  t5_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t5_n116;
  t5_n3: if (E.getNumReferences() >= 3334835456 /*25286.5*/) goto t5_n59;
  t5_n4: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t5_n22;
  t5_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t5_n17;
  t5_n6: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t5_n14;
  t5_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t5_n9;
  t5_n8: return -0.08246518671512604f;
  t5_n9: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t5_n13;
  t5_n10: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t5_n12;
  t5_n11: return 0.10485164821147919f;
  t5_n12: return 0.16447512805461884f;
  t5_n13: return 0.022166235372424126f;
  t5_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n16;
  t5_n15: return -0.12325362116098404f;
  t5_n16: return -0.11497645825147629f;
  t5_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t5_n19;
  t5_n18: return 0.02503075823187828f;
  t5_n19: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t5_n21;
  t5_n20: return 0.1555223912000656f;
  t5_n21: return 0.12956663966178894f;
  t5_n22: if (E.getFileProximityDistance() >= 3255173120 /*33.5*/) goto t5_n48;
  t5_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t5_n37;
  t5_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t5_n32;
  t5_n25: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t5_n31;
  t5_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n28;
  t5_n27: return 0.07328794151544571f;
  t5_n28: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t5_n30;
  t5_n29: return 0.09581243246793747f;
  t5_n30: return 0.10851171612739563f;
  t5_n31: return 0.06038171425461769f;
  t5_n32: if (E.getNumReferences() >= 3280060416 /*259.5*/) goto t5_n36;
  t5_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t5_n35;
  t5_n34: return 0.08210990577936172f;
  t5_n35: return 0.10952675342559814f;
  t5_n36: return 0.11901907622814178f;
  t5_n37: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t5_n39;
  t5_n38: return 0.11047732830047607f;
  t5_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t5_n41;
  t5_n40: return 0.11634153127670288f;
  t5_n41: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t5_n45;
  t5_n42: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t5_n44;
  t5_n43: return 0.12574072182178497f;
  t5_n44: return 0.11729124188423157f;
  t5_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t5_n47;
  t5_n46: return 0.07906555384397507f;
  t5_n47: return 0.12265865504741669f;
  t5_n48: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t5_n50;
  t5_n49: return -0.09572849422693253f;
  t5_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t5_n52;
  t5_n51: return 0.05296313017606735f;
  t5_n52: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t5_n54;
  t5_n53: return 0.0028017389122396708f;
  t5_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t5_n58;
  t5_n55: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n57;
  t5_n56: return 0.1196630671620369f;
  t5_n57: return 0.10264015942811966f;
  t5_n58: return 0.11838161200284958f;
  t5_n59: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t5_n67;
  t5_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t5_n64;
  t5_n61: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t5_n63;
  t5_n62: return -0.01760932244360447f;
  t5_n63: return 0.1132378950715065f;
  t5_n64: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t5_n66;
  t5_n65: return 0.11439701169729233f;
  t5_n66: return 0.12489776313304901f;
  t5_n67: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t5_n107;
  t5_n68: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t5_n98;
  t5_n69: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t5_n89;
  t5_n70: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t5_n80;
  t5_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t5_n73;
  t5_n72: return 0.09204074740409851f;
  t5_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t5_n75;
  t5_n74: return 0.09913092106580734f;
  t5_n75: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t5_n77;
  t5_n76: return 0.1091567799448967f;
  t5_n77: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t5_n79;
  t5_n78: return 0.1254485845565796f;
  t5_n79: return 0.12214037775993347f;
  t5_n80: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t5_n82;
  t5_n81: return 0.11407013982534409f;
  t5_n82: if (E.getNumReferences() >= 3341246080 /*42846.5*/) goto t5_n84;
  t5_n83: return 0.11826757341623306f;
  t5_n84: if (E.getNumReferences() >= 3364158080 /*272340.0*/) goto t5_n88;
  t5_n85: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t5_n87;
  t5_n86: return 0.12276632338762283f;
  t5_n87: return 0.12125788629055023f;
  t5_n88: return -0.16854263842105865f;
  t5_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t5_n91;
  t5_n90: return 0.11965116113424301f;
  t5_n91: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t5_n95;
  t5_n92: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t5_n94;
  t5_n93: return 0.12440533190965652f;
  t5_n94: return 0.1150340884923935f;
  t5_n95: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t5_n97;
  t5_n96: return 0.12405123561620712f;
  t5_n97: return 0.12227573245763779f;
  t5_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t5_n102;
  t5_n99: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t5_n101;
  t5_n100: return 0.1196770966053009f;
  t5_n101: return 0.12369400262832642f;
  t5_n102: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t5_n106;
  t5_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t5_n105;
  t5_n104: return 0.12485748529434204f;
  t5_n105: return 0.12493136525154114f;
  t5_n106: return -0.15667559206485748f;
  t5_n107: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t5_n111;
  t5_n108: if (E.getNumReferences() >= 3360228064 /*205835.5*/) goto t5_n110;
  t5_n109: return 0.11714440584182739f;
  t5_n110: return 0.12430502474308014f;
  t5_n111: if (E.getNumReferences() >= 3346571264 /*63648.0*/) goto t5_n113;
  t5_n112: return 0.12104270607233047f;
  t5_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t5_n115;
  t5_n114: return 0.1230480819940567f;
  t5_n115: return 0.12465094774961472f;
  t5_n116: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t5_n170;
  t5_n117: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t5_n147;
  t5_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t5_n138;
  t5_n119: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t5_n133;
  t5_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t5_n122;
  t5_n121: return -0.08983761072158813f;
  t5_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t5_n124;
  t5_n123: return 0.008554327301681042f;
  t5_n124: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t5_n128;
  t5_n125: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t5_n127;
  t5_n126: return 0.08926698565483093f;
  t5_n127: return 0.12172023952007294f;
  t5_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t5_n130;
  t5_n129: return 0.07259354740381241f;
  t5_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t5_n132;
  t5_n131: return -0.01041330210864544f;
  t5_n132: return 0.11994793266057968f;
  t5_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n135;
  t5_n134: return 0.05254447087645531f;
  t5_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t5_n137;
  t5_n136: return -0.11969910562038422f;
  t5_n137: return 0.11612097173929214f;
  t5_n138: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t5_n144;
  t5_n139: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t5_n143;
  t5_n140: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t5_n142;
  t5_n141: return 0.10364782065153122f;
  t5_n142: return 0.12190599739551544f;
  t5_n143: return -0.13495953381061554f;
  t5_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t5_n146;
  t5_n145: return 0.10960251092910767f;
  t5_n146: return 0.12294292449951172f;
  t5_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n149;
  t5_n148: return 0.010330276563763618f;
  t5_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t5_n167;
  t5_n150: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t5_n156;
  t5_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t5_n153;
  t5_n152: return -0.001054544234648347f;
  t5_n153: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t5_n155;
  t5_n154: return 0.11708949506282806f;
  t5_n155: return 0.10950405895709991f;
  t5_n156: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t5_n158;
  t5_n157: return 0.11517553776502609f;
  t5_n158: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t5_n166;
  t5_n159: if (E.getNumReferences() >= 3350339968 /*91203.0*/) goto t5_n165;
  t5_n160: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t5_n162;
  t5_n161: return 0.12148863822221756f;
  t5_n162: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t5_n164;
  t5_n163: return 0.12410426884889603f;
  t5_n164: return 0.12050491571426392f;
  t5_n165: return 0.0866250991821289f;
  t5_n166: return 0.1248498484492302f;
  t5_n167: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t5_n169;
  t5_n168: return 0.12020380795001984f;
  t5_n169: return 0.12339581549167633f;
  t5_n170: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t5_n182;
  t5_n171: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t5_n173;
  t5_n172: return 0.10954398661851883f;
  t5_n173: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n177;
  t5_n174: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t5_n176;
  t5_n175: return 0.1173727810382843f;
  t5_n176: return 0.12380734086036682f;
  t5_n177: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t5_n179;
  t5_n178: return 0.12081331759691238f;
  t5_n179: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t5_n181;
  t5_n180: return 0.1632082611322403f;
  t5_n181: return 0.03827841207385063f;
  t5_n182: return 0.12498895078897476f;
  t5_n183: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t5_n195;
  t5_n184: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n188;
  t5_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t5_n187;
  t5_n186: return -0.00734816724434495f;
  t5_n187: return 0.12085331976413727f;
  t5_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t5_n192;
  t5_n189: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t5_n191;
  t5_n190: return 0.10164695233106613f;
  t5_n191: return 0.12107010185718536f;
  t5_n192: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t5_n194;
  t5_n193: return 0.12263202667236328f;
  t5_n194: return 0.12363939732313156f;
  t5_n195: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t5_n199;
  t5_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t5_n198;
  t5_n197: return 0.12404220551252365f;
  t5_n198: return 0.12517571449279785f;
  t5_n199: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t5_n207;
  t5_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t5_n204;
  t5_n201: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t5_n203;
  t5_n202: return 0.11891496181488037f;
  t5_n203: return 0.12356136739253998f;
  t5_n204: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t5_n206;
  t5_n205: return 0.12440799176692963f;
  t5_n206: return 0.12419634312391281f;
  t5_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t5_n209;
  t5_n208: return 0.12518806755542755f;
  t5_n209: return 0.1245139092206955f;
  t5_n210: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t5_n238;
  t5_n211: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t5_n219;
  t5_n212: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n214;
  t5_n213: return 0.1115230917930603f;
  t5_n214: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t5_n218;
  t5_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t5_n217;
  t5_n216: return 0.12214123457670212f;
  t5_n217: return 0.12336272746324539f;
  t5_n218: return -0.09089649468660355f;
  t5_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t5_n231;
  t5_n220: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t5_n230;
  t5_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t5_n225;
  t5_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t5_n224;
  t5_n223: return -0.044322870671749115f;
  t5_n224: return 0.1228397861123085f;
  t5_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t5_n227;
  t5_n226: return 0.09020587056875229f;
  t5_n227: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t5_n229;
  t5_n228: return 0.12455291301012039f;
  t5_n229: return -0.13367854058742523f;
  t5_n230: return 0.1221235990524292f;
  t5_n231: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t5_n235;
  t5_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t5_n234;
  t5_n233: return 0.12399512529373169f;
  t5_n234: return 0.12328121066093445f;
  t5_n235: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t5_n237;
  t5_n236: return 0.1225079894065857f;
  t5_n237: return 0.12186058610677719f;
  t5_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t5_n248;
  t5_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t5_n243;
  t5_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t5_n242;
  t5_n241: return 0.11127940565347672f;
  t5_n242: return 0.12598751485347748f;
  t5_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n247;
  t5_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t5_n246;
  t5_n245: return 0.12638694047927856f;
  t5_n246: return 0.12666495144367218f;
  t5_n247: return 0.1272842437028885f;
  t5_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t5_n252;
  t5_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t5_n251;
  t5_n250: return 0.12263109534978867f;
  t5_n251: return 0.12573689222335815f;
  t5_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t5_n254;
  t5_n253: return 0.12447214126586914f;
  t5_n254: return 0.12587770819664001f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree6(const Example& E) {
  t6_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t6_n210;
  t6_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t6_n181;
  t6_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t6_n116;
  t6_n3: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t6_n53;
  t6_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t6_n40;
  t6_n5: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t6_n25;
  t6_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t6_n18;
  t6_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t6_n9;
  t6_n8: return -0.07694527506828308f;
  t6_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t6_n15;
  t6_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t6_n14;
  t6_n11: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t6_n13;
  t6_n12: return 0.09366220235824585f;
  t6_n13: return 0.148265540599823f;
  t6_n14: return 0.019576098769903183f;
  t6_n15: if (E.getNumReferences() >= 3274047488 /*166.0*/) goto t6_n17;
  t6_n16: return 0.15084686875343323f;
  t6_n17: return 0.16081175208091736f;
  t6_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t6_n20;
  t6_n19: return 0.08417658507823944f;
  t6_n20: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t6_n22;
  t6_n21: return 0.11901114881038666f;
  t6_n22: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t6_n24;
  t6_n23: return 0.12081567943096161f;
  t6_n24: return 0.11749343574047089f;
  t6_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t6_n29;
  t6_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n28;
  t6_n27: return -0.11381218582391739f;
  t6_n28: return -0.10071047395467758f;
  t6_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t6_n31;
  t6_n30: return -0.010966906324028969f;
  t6_n31: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t6_n33;
  t6_n32: return 0.08624853193759918f;
  t6_n33: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t6_n37;
  t6_n34: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t6_n36;
  t6_n35: return 0.13918271660804749f;
  t6_n36: return 0.11404117196798325f;
  t6_n37: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t6_n39;
  t6_n38: return 0.11902166903018951f;
  t6_n39: return 0.09488772600889206f;
  t6_n40: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t6_n42;
  t6_n41: return -0.01503479853272438f;
  t6_n42: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t6_n44;
  t6_n43: return 0.054352983832359314f;
  t6_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t6_n50;
  t6_n45: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n49;
  t6_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t6_n48;
  t6_n47: return 0.12691329419612885f;
  t6_n48: return 0.11438445746898651f;
  t6_n49: return 0.09642253071069717f;
  t6_n50: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t6_n52;
  t6_n51: return 0.10210377722978592f;
  t6_n52: return 0.11493503302335739f;
  t6_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t6_n61;
  t6_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t6_n58;
  t6_n55: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t6_n57;
  t6_n56: return -0.019194869324564934f;
  t6_n57: return 0.10730741918087006f;
  t6_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t6_n60;
  t6_n59: return 0.1076255738735199f;
  t6_n60: return 0.11946488171815872f;
  t6_n61: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t6_n107;
  t6_n62: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t6_n98;
  t6_n63: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t6_n83;
  t6_n64: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t6_n74;
  t6_n65: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t6_n67;
  t6_n66: return 0.08718814700841904f;
  t6_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t6_n69;
  t6_n68: return 0.08843041956424713f;
  t6_n69: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t6_n71;
  t6_n70: return 0.10282241553068161f;
  t6_n71: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t6_n73;
  t6_n72: return 0.12006963789463043f;
  t6_n73: return 0.11652491986751556f;
  t6_n74: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t6_n76;
  t6_n75: return 0.10999485850334167f;
  t6_n76: if (E.getNumReferences() >= 3341246080 /*42846.5*/) goto t6_n78;
  t6_n77: return 0.11575620621442795f;
  t6_n78: if (E.getNumReferences() >= 3364158080 /*272340.0*/) goto t6_n82;
  t6_n79: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t6_n81;
  t6_n80: return 0.11759170144796371f;
  t6_n81: return 0.11575504392385483f;
  t6_n82: return -0.14012761414051056f;
  t6_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t6_n85;
  t6_n84: return 0.11453889310359955f;
  t6_n85: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t6_n89;
  t6_n86: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t6_n88;
  t6_n87: return 0.12215220928192139f;
  t6_n88: return 0.10887303948402405f;
  t6_n89: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t6_n97;
  t6_n90: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t6_n94;
  t6_n91: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t6_n93;
  t6_n92: return 0.1190926730632782f;
  t6_n93: return -0.14053958654403687f;
  t6_n94: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t6_n96;
  t6_n95: return 0.1193011924624443f;
  t6_n96: return 0.12044071406126022f;
  t6_n97: return 0.11722931265830994f;
  t6_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t6_n102;
  t6_n99: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t6_n101;
  t6_n100: return 0.11341708898544312f;
  t6_n101: return 0.11863100528717041f;
  t6_n102: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t6_n106;
  t6_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t6_n105;
  t6_n104: return 0.11966031044721603f;
  t6_n105: return 0.11959598958492279f;
  t6_n106: return -0.14092107117176056f;
  t6_n107: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t6_n109;
  t6_n108: return 0.11486894637346268f;
  t6_n109: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t6_n113;
  t6_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t6_n112;
  t6_n111: return 0.09547129273414612f;
  t6_n112: return 0.11884362995624542f;
  t6_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t6_n115;
  t6_n114: return 0.11788350343704224f;
  t6_n115: return 0.11981629580259323f;
  t6_n116: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t6_n168;
  t6_n117: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t6_n145;
  t6_n118: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t6_n140;
  t6_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t6_n133;
  t6_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t6_n122;
  t6_n121: return -0.0817423090338707f;
  t6_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t6_n124;
  t6_n123: return 0.004224621690809727f;
  t6_n124: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t6_n128;
  t6_n125: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t6_n127;
  t6_n126: return 0.08264568448066711f;
  t6_n127: return 0.11623498052358627f;
  t6_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t6_n130;
  t6_n129: return 0.06518735736608505f;
  t6_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t6_n132;
  t6_n131: return -0.01168738678097725f;
  t6_n132: return 0.11409099400043488f;
  t6_n133: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t6_n137;
  t6_n134: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t6_n136;
  t6_n135: return 0.088108591735363f;
  t6_n136: return 0.1156032383441925f;
  t6_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t6_n139;
  t6_n138: return 0.10262138396501541f;
  t6_n139: return 0.11700879037380219f;
  t6_n140: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n142;
  t6_n141: return 0.08917643874883652f;
  t6_n142: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t6_n144;
  t6_n143: return -0.07815256714820862f;
  t6_n144: return 0.10972098261117935f;
  t6_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n147;
  t6_n146: return 0.007304436527192593f;
  t6_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t6_n165;
  t6_n148: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t6_n154;
  t6_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t6_n151;
  t6_n150: return -0.007949978113174438f;
  t6_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t6_n153;
  t6_n152: return 0.11108005046844482f;
  t6_n153: return 0.10171493142843246f;
  t6_n154: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t6_n156;
  t6_n155: return 0.10885337740182877f;
  t6_n156: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t6_n164;
  t6_n157: if (E.getNumReferences() >= 3350339968 /*91203.0*/) goto t6_n163;
  t6_n158: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t6_n160;
  t6_n159: return 0.11590472608804703f;
  t6_n160: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t6_n162;
  t6_n161: return 0.11909585446119308f;
  t6_n162: return 0.11455501616001129f;
  t6_n163: return 0.07241708785295486f;
  t6_n164: return 0.12002451717853546f;
  t6_n165: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t6_n167;
  t6_n166: return 0.11472001671791077f;
  t6_n167: return 0.11811206489801407f;
  t6_n168: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t6_n180;
  t6_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t6_n171;
  t6_n170: return 0.10293734818696976f;
  t6_n171: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n175;
  t6_n172: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t6_n174;
  t6_n173: return 0.11301813274621964f;
  t6_n174: return 0.1183653250336647f;
  t6_n175: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t6_n177;
  t6_n176: return 0.11532328277826309f;
  t6_n177: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t6_n179;
  t6_n178: return 0.1577204167842865f;
  t6_n179: return 0.06319843232631683f;
  t6_n180: return 0.11995402723550797f;
  t6_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t6_n193;
  t6_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n186;
  t6_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t6_n185;
  t6_n184: return -0.024076901376247406f;
  t6_n185: return 0.11487280577421188f;
  t6_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t6_n190;
  t6_n187: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t6_n189;
  t6_n188: return 0.09653716534376144f;
  t6_n189: return 0.11526694148778915f;
  t6_n190: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t6_n192;
  t6_n191: return 0.1169799193739891f;
  t6_n192: return 0.11845660209655762f;
  t6_n193: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t6_n197;
  t6_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t6_n196;
  t6_n195: return 0.11907438188791275f;
  t6_n196: return 0.12033944576978683f;
  t6_n197: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t6_n205;
  t6_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t6_n202;
  t6_n199: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t6_n201;
  t6_n200: return 0.11376825720071793f;
  t6_n201: return 0.11842282861471176f;
  t6_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t6_n204;
  t6_n203: return 0.11952733993530273f;
  t6_n204: return 0.11944061517715454f;
  t6_n205: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t6_n207;
  t6_n206: return 0.11956767737865448f;
  t6_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t6_n209;
  t6_n208: return 0.11413019895553589f;
  t6_n209: return 0.12293189764022827f;
  t6_n210: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t6_n238;
  t6_n211: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t6_n219;
  t6_n212: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n214;
  t6_n213: return 0.10403391718864441f;
  t6_n214: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t6_n218;
  t6_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t6_n217;
  t6_n216: return 0.1162342056632042f;
  t6_n217: return 0.11813230812549591f;
  t6_n218: return 0.01899571903049946f;
  t6_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t6_n231;
  t6_n220: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t6_n230;
  t6_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t6_n225;
  t6_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t6_n224;
  t6_n223: return -0.030664870515465736f;
  t6_n224: return 0.11728805303573608f;
  t6_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t6_n227;
  t6_n226: return 0.07740702480077744f;
  t6_n227: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t6_n229;
  t6_n228: return 0.11929808557033539f;
  t6_n229: return -0.12399277836084366f;
  t6_n230: return 0.1167450025677681f;
  t6_n231: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t6_n235;
  t6_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t6_n234;
  t6_n233: return 0.11898418515920639f;
  t6_n234: return 0.11821065843105316f;
  t6_n235: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t6_n237;
  t6_n236: return 0.11734418570995331f;
  t6_n237: return 0.11662206798791885f;
  t6_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t6_n248;
  t6_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t6_n243;
  t6_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t6_n242;
  t6_n241: return 0.10602554678916931f;
  t6_n242: return 0.12102727591991425f;
  t6_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n247;
  t6_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t6_n246;
  t6_n245: return 0.1215435341000557f;
  t6_n246: return 0.1217925027012825f;
  t6_n247: return 0.12241791933774948f;
  t6_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t6_n252;
  t6_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t6_n251;
  t6_n250: return 0.11682932823896408f;
  t6_n251: return 0.12104137241840363f;
  t6_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t6_n254;
  t6_n253: return 0.1197219043970108f;
  t6_n254: return 0.12119611352682114f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree7(const Example& E) {
  t7_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t7_n212;
  t7_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t7_n187;
  t7_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t7_n130;
  t7_n3: if (E.getNumReferences() >= 3337711104 /*30903.0*/) goto t7_n67;
  t7_n4: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t7_n24;
  t7_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t7_n19;
  t7_n6: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t7_n16;
  t7_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t7_n9;
  t7_n8: return -0.07651832699775696f;
  t7_n9: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t7_n11;
  t7_n10: return 0.03678275644779205f;
  t7_n11: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t7_n13;
  t7_n12: return 0.09451880306005478f;
  t7_n13: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t7_n15;
  t7_n14: return 0.13966608047485352f;
  t7_n15: return 0.1410679966211319f;
  t7_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n18;
  t7_n17: return -0.11414434760808945f;
  t7_n18: return -0.10379552841186523f;
  t7_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t7_n21;
  t7_n20: return 0.021868770942091942f;
  t7_n21: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t7_n23;
  t7_n22: return 0.13303282856941223f;
  t7_n23: return 0.10801086574792862f;
  t7_n24: if (E.getFileProximityDistance() >= 3255173120 /*33.5*/) goto t7_n54;
  t7_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t7_n45;
  t7_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t7_n40;
  t7_n27: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t7_n39;
  t7_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n30;
  t7_n29: return 0.061667975038290024f;
  t7_n30: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t7_n38;
  t7_n31: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t7_n33;
  t7_n32: return 0.08006995171308517f;
  t7_n33: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t7_n35;
  t7_n34: return 0.0987827256321907f;
  t7_n35: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t7_n37;
  t7_n36: return 0.11787135899066925f;
  t7_n37: return 0.11937885731458664f;
  t7_n38: return 0.10030659288167953f;
  t7_n39: return 0.05393628031015396f;
  t7_n40: if (E.getNumReferences() >= 3280060416 /*259.5*/) goto t7_n44;
  t7_n41: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t7_n43;
  t7_n42: return 0.067432701587677f;
  t7_n43: return 0.0999528244137764f;
  t7_n44: return 0.1096913293004036f;
  t7_n45: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t7_n47;
  t7_n46: return 0.10127498209476471f;
  t7_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t7_n49;
  t7_n48: return 0.10896171629428864f;
  t7_n49: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t7_n51;
  t7_n50: return 0.11702041327953339f;
  t7_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t7_n53;
  t7_n52: return 0.06855163723230362f;
  t7_n53: return 0.11374770849943161f;
  t7_n54: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t7_n56;
  t7_n55: return -0.07861299812793732f;
  t7_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t7_n58;
  t7_n57: return 0.044826820492744446f;
  t7_n58: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t7_n60;
  t7_n59: return 0.009964678436517715f;
  t7_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t7_n64;
  t7_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n63;
  t7_n62: return 0.10979517549276352f;
  t7_n63: return 0.09482519328594208f;
  t7_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t7_n66;
  t7_n65: return -0.3470112979412079f;
  t7_n66: return 0.11045931279659271f;
  t7_n67: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t7_n87;
  t7_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t7_n70;
  t7_n69: return -0.046384941786527634f;
  t7_n70: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t7_n82;
  t7_n71: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t7_n75;
  t7_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t7_n74;
  t7_n73: return 0.07555894553661346f;
  t7_n74: return 0.10914449393749237f;
  t7_n75: if (E.getNumReferences() >= 3337883136 /*31239.0*/) goto t7_n77;
  t7_n76: return 0.11636073887348175f;
  t7_n77: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t7_n79;
  t7_n78: return 0.10632868111133575f;
  t7_n79: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t7_n81;
  t7_n80: return 0.12015494704246521f;
  t7_n81: return 0.11594400554895401f;
  t7_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n84;
  t7_n83: return 0.12442126870155334f;
  t7_n84: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t7_n86;
  t7_n85: return 0.14177241921424866f;
  t7_n86: return 0.12350218743085861f;
  t7_n87: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t7_n119;
  t7_n88: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t7_n110;
  t7_n89: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t7_n103;
  t7_n90: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t7_n100;
  t7_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t7_n93;
  t7_n92: return 0.08010321855545044f;
  t7_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t7_n95;
  t7_n94: return 0.08414481580257416f;
  t7_n95: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t7_n97;
  t7_n96: return 0.09454834461212158f;
  t7_n97: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t7_n99;
  t7_n98: return 0.11624400317668915f;
  t7_n99: return 0.11206576228141785f;
  t7_n100: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t7_n102;
  t7_n101: return 0.10269846767187119f;
  t7_n102: return 0.11259423941373825f;
  t7_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t7_n105;
  t7_n104: return 0.10878776013851166f;
  t7_n105: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t7_n109;
  t7_n106: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t7_n108;
  t7_n107: return 0.11546321958303452f;
  t7_n108: return 0.1037277951836586f;
  t7_n109: return 0.11493141204118729f;
  t7_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t7_n114;
  t7_n111: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t7_n113;
  t7_n112: return 0.10894259810447693f;
  t7_n113: return 0.11489898711442947f;
  t7_n114: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t7_n118;
  t7_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t7_n117;
  t7_n116: return 0.11595240980386734f;
  t7_n117: return 0.11570192873477936f;
  t7_n118: return -0.13659068942070007f;
  t7_n119: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t7_n123;
  t7_n120: if (E.getNumReferences() >= 3360228064 /*205835.5*/) goto t7_n122;
  t7_n121: return 0.1083010584115982f;
  t7_n122: return 0.1158897876739502f;
  t7_n123: if (E.getNumReferences() >= 3346571264 /*63648.0*/) goto t7_n127;
  t7_n124: if (E.getNumReferences() >= 3338315520 /*32083.5*/) goto t7_n126;
  t7_n125: return 0.15177322924137115f;
  t7_n126: return 0.10818535089492798f;
  t7_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t7_n129;
  t7_n128: return 0.11396890133619308f;
  t7_n129: return 0.11622614413499832f;
  t7_n130: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t7_n174;
  t7_n131: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t7_n153;
  t7_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t7_n148;
  t7_n133: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t7_n143;
  t7_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t7_n136;
  t7_n135: return -0.017825448885560036f;
  t7_n136: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t7_n138;
  t7_n137: return 0.04682198911905289f;
  t7_n138: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n140;
  t7_n139: return 0.09786824882030487f;
  t7_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t7_n142;
  t7_n141: return -0.0028368905186653137f;
  t7_n142: return 0.11079441756010056f;
  t7_n143: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n145;
  t7_n144: return 0.0810122862458229f;
  t7_n145: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t7_n147;
  t7_n146: return -0.10663174837827682f;
  t7_n147: return 0.10410875082015991f;
  t7_n148: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t7_n152;
  t7_n149: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t7_n151;
  t7_n150: return 0.09043923765420914f;
  t7_n151: return -0.1289406418800354f;
  t7_n152: return 0.10844844579696655f;
  t7_n153: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n155;
  t7_n154: return 0.03135048598051071f;
  t7_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t7_n171;
  t7_n156: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t7_n160;
  t7_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t7_n159;
  t7_n158: return 0.003141457913443446f;
  t7_n159: return 0.10377974063158035f;
  t7_n160: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t7_n162;
  t7_n161: return 0.1031254306435585f;
  t7_n162: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t7_n170;
  t7_n163: if (E.getNumReferences() >= 3350339968 /*91203.0*/) goto t7_n169;
  t7_n164: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t7_n166;
  t7_n165: return 0.11135101318359375f;
  t7_n166: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t7_n168;
  t7_n167: return 0.11550747603178024f;
  t7_n168: return 0.10996823012828827f;
  t7_n169: return 0.06432437151670456f;
  t7_n170: return 0.11651279777288437f;
  t7_n171: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t7_n173;
  t7_n172: return 0.11025538295507431f;
  t7_n173: return 0.11423131823539734f;
  t7_n174: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t7_n186;
  t7_n175: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t7_n177;
  t7_n176: return 0.09669717401266098f;
  t7_n177: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n181;
  t7_n178: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t7_n180;
  t7_n179: return 0.1069055050611496f;
  t7_n180: return 0.11382551491260529f;
  t7_n181: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t7_n183;
  t7_n182: return 0.11099054664373398f;
  t7_n183: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t7_n185;
  t7_n184: return 0.1542593538761139f;
  t7_n185: return 0.08924993872642517f;
  t7_n186: return 0.11601562798023224f;
  t7_n187: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t7_n199;
  t7_n188: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n192;
  t7_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t7_n191;
  t7_n190: return -0.03711888939142227f;
  t7_n191: return 0.10977572202682495f;
  t7_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t7_n196;
  t7_n193: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t7_n195;
  t7_n194: return 0.0898740217089653f;
  t7_n195: return 0.11054060608148575f;
  t7_n196: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t7_n198;
  t7_n197: return 0.1125241219997406f;
  t7_n198: return 0.11462436616420746f;
  t7_n199: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t7_n203;
  t7_n200: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t7_n202;
  t7_n201: return 0.11548912525177002f;
  t7_n202: return 0.11691773682832718f;
  t7_n203: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t7_n209;
  t7_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t7_n208;
  t7_n205: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t7_n207;
  t7_n206: return 0.1095297783613205f;
  t7_n207: return 0.11462422460317612f;
  t7_n208: return 0.11616656929254532f;
  t7_n209: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t7_n211;
  t7_n210: return 0.1163925975561142f;
  t7_n211: return 0.11587662249803543f;
  t7_n212: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t7_n240;
  t7_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t7_n221;
  t7_n214: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n216;
  t7_n215: return 0.0990118607878685f;
  t7_n216: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t7_n220;
  t7_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t7_n219;
  t7_n218: return 0.11234888434410095f;
  t7_n219: return 0.11404508352279663f;
  t7_n220: return 0.00979738961905241f;
  t7_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t7_n233;
  t7_n222: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t7_n232;
  t7_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t7_n227;
  t7_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t7_n226;
  t7_n225: return -0.030750200152397156f;
  t7_n226: return 0.1128266453742981f;
  t7_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t7_n229;
  t7_n228: return 0.07501054555177689f;
  t7_n229: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t7_n231;
  t7_n230: return 0.11510385572910309f;
  t7_n231: return -0.11895431578159332f;
  t7_n232: return 0.11200570315122604f;
  t7_n233: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t7_n237;
  t7_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t7_n236;
  t7_n235: return 0.11515509337186813f;
  t7_n236: return 0.1142982542514801f;
  t7_n237: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t7_n239;
  t7_n238: return 0.11345380544662476f;
  t7_n239: return 0.11260415613651276f;
  t7_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t7_n250;
  t7_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t7_n245;
  t7_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t7_n244;
  t7_n243: return 0.09579700231552124f;
  t7_n244: return 0.11725304275751114f;
  t7_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n249;
  t7_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t7_n248;
  t7_n247: return 0.11788005381822586f;
  t7_n248: return 0.11799407750368118f;
  t7_n249: return 0.11875198036432266f;
  t7_n250: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t7_n254;
  t7_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t7_n253;
  t7_n252: return 0.11300672590732574f;
  t7_n253: return 0.11746147274971008f;
  t7_n254: return 0.11641047894954681f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree8(const Example& E) {
  t8_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t8_n214;
  t8_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t8_n191;
  t8_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t8_n128;
  t8_n3: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t8_n49;
  t8_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t8_n30;
  t8_n5: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t8_n21;
  t8_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t8_n16;
  t8_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t8_n9;
  t8_n8: return -0.06547743082046509f;
  t8_n9: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t8_n11;
  t8_n10: return 0.03532000631093979f;
  t8_n11: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t8_n13;
  t8_n12: return 0.09117697179317474f;
  t8_n13: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t8_n15;
  t8_n14: return 0.1301424503326416f;
  t8_n15: return 0.12945537269115448f;
  t8_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t8_n18;
  t8_n17: return 0.07200779765844345f;
  t8_n18: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t8_n20;
  t8_n19: return 0.11174715310335159f;
  t8_n20: return 0.11420679837465286f;
  t8_n21: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t8_n25;
  t8_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n24;
  t8_n23: return -0.10846680402755737f;
  t8_n24: return -0.09971440583467484f;
  t8_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t8_n27;
  t8_n26: return 0.0015377497766166925f;
  t8_n27: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t8_n29;
  t8_n28: return 0.12166021764278412f;
  t8_n29: return 0.09845957159996033f;
  t8_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t8_n38;
  t8_n31: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t8_n37;
  t8_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t8_n34;
  t8_n33: return 0.059349365532398224f;
  t8_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t8_n36;
  t8_n35: return 0.011213590390980244f;
  t8_n36: return 0.10559426248073578f;
  t8_n37: return -0.011112953536212444f;
  t8_n38: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t8_n40;
  t8_n39: return 0.0448327474296093f;
  t8_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t8_n46;
  t8_n41: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n45;
  t8_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t8_n44;
  t8_n43: return 0.11176303029060364f;
  t8_n44: return 0.10594355314970016f;
  t8_n45: return 0.08839324116706848f;
  t8_n46: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t8_n48;
  t8_n47: return 0.09425932168960571f;
  t8_n48: return 0.10637087374925613f;
  t8_n49: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t8_n101;
  t8_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t8_n88;
  t8_n51: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t8_n81;
  t8_n52: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t8_n62;
  t8_n53: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t8_n55;
  t8_n54: return -0.044328365474939346f;
  t8_n55: if (E.getNumReferences() >= 3332280320 /*20296.0*/) goto t8_n57;
  t8_n56: return 0.050923947244882584f;
  t8_n57: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t8_n59;
  t8_n58: return 0.09309293329715729f;
  t8_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t8_n61;
  t8_n60: return 0.10062727332115173f;
  t8_n61: return 0.11192172765731812f;
  t8_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t8_n76;
  t8_n63: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t8_n65;
  t8_n64: return -0.038678381592035294f;
  t8_n65: if (E.getNumReferences() >= 3337697792 /*30877.0*/) goto t8_n73;
  t8_n66: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t8_n72;
  t8_n67: if (E.getNumReferences() >= 3294748672 /*903.5*/) goto t8_n71;
  t8_n68: if (E.getNumReferences() >= 3294666752 /*898.5*/) goto t8_n70;
  t8_n69: return 0.10408595949411392f;
  t8_n70: return 0.16123764216899872f;
  t8_n71: return 0.10283596068620682f;
  t8_n72: return 0.07165191322565079f;
  t8_n73: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t8_n75;
  t8_n74: return 0.12342588603496552f;
  t8_n75: return 0.11476241052150726f;
  t8_n76: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n78;
  t8_n77: return 0.10061712563037872f;
  t8_n78: if (E.getNumReferences() >= 3344831744 /*56853.0*/) goto t8_n80;
  t8_n79: return 0.0995582640171051f;
  t8_n80: return 0.126464381814003f;
  t8_n81: if (E.getNumReferences() >= 3332623360 /*20966.0*/) goto t8_n83;
  t8_n82: return 0.11869504302740097f;
  t8_n83: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t8_n85;
  t8_n84: return 0.09879282861948013f;
  t8_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t8_n87;
  t8_n86: return 0.10661789029836655f;
  t8_n87: return 0.11118782311677933f;
  t8_n88: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t8_n92;
  t8_n89: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t8_n91;
  t8_n90: return 0.07970006763935089f;
  t8_n91: return 0.10395988821983337f;
  t8_n92: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t8_n98;
  t8_n93: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t8_n95;
  t8_n94: return 0.10644859820604324f;
  t8_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t8_n97;
  t8_n96: return 0.10919098556041718f;
  t8_n97: return 0.11378417164087296f;
  t8_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t8_n100;
  t8_n99: return 0.08550520241260529f;
  t8_n100: return 0.11729203164577484f;
  t8_n101: if (E.getNumReferences() >= 3316905984 /*5759.0*/) goto t8_n109;
  t8_n102: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t8_n104;
  t8_n103: return 0.1302957832813263f;
  t8_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t8_n106;
  t8_n105: return 0.15932682156562805f;
  t8_n106: if (E.getNumReferences() >= 3309508608 /*3121.5*/) goto t8_n108;
  t8_n107: return 0.16140031814575195f;
  t8_n108: return 0.16877815127372742f;
  t8_n109: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t8_n111;
  t8_n110: return 0.12127749621868134f;
  t8_n111: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t8_n127;
  t8_n112: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t8_n116;
  t8_n113: if (E.getNumReferences() >= 3337152512 /*29812.0*/) goto t8_n115;
  t8_n114: return 0.14036574959754944f;
  t8_n115: return 0.10967881232500076f;
  t8_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t8_n120;
  t8_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t8_n119;
  t8_n118: return 0.12818646430969238f;
  t8_n119: return 0.16637516021728516f;
  t8_n120: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t8_n122;
  t8_n121: return 0.11963826417922974f;
  t8_n122: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t8_n126;
  t8_n123: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t8_n125;
  t8_n124: return 0.17955699563026428f;
  t8_n125: return 0.18985846638679504f;
  t8_n126: return 0.11659557372331619f;
  t8_n127: return 0.14087316393852234f;
  t8_n128: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t8_n176;
  t8_n129: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t8_n155;
  t8_n130: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t8_n150;
  t8_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t8_n137;
  t8_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t8_n134;
  t8_n133: return -0.02350633591413498f;
  t8_n134: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t8_n136;
  t8_n135: return 0.09085749834775925f;
  t8_n136: return -0.09804926067590714f;
  t8_n137: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t8_n143;
  t8_n138: if (E.getNumReferences() >= 3316554752 /*5587.5*/) goto t8_n140;
  t8_n139: return 0.04247909039258957f;
  t8_n140: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t8_n142;
  t8_n141: return 0.10219305008649826f;
  t8_n142: return 0.112519770860672f;
  t8_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t8_n149;
  t8_n144: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n146;
  t8_n145: return 0.10158360749483109f;
  t8_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t8_n148;
  t8_n147: return -0.0020382446236908436f;
  t8_n148: return 0.10430170595645905f;
  t8_n149: return 0.12071332335472107f;
  t8_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n152;
  t8_n151: return 0.08259961009025574f;
  t8_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t8_n154;
  t8_n153: return -0.0674571767449379f;
  t8_n154: return 0.09947020560503006f;
  t8_n155: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n157;
  t8_n156: return 0.041217803955078125f;
  t8_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t8_n173;
  t8_n158: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t8_n162;
  t8_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t8_n161;
  t8_n160: return 0.0010269013000652194f;
  t8_n161: return 0.09941023588180542f;
  t8_n162: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t8_n164;
  t8_n163: return 0.09760589897632599f;
  t8_n164: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t8_n172;
  t8_n165: if (E.getNumReferences() >= 3350339968 /*91203.0*/) goto t8_n171;
  t8_n166: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t8_n168;
  t8_n167: return 0.10767178982496262f;
  t8_n168: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t8_n170;
  t8_n169: return 0.11259830743074417f;
  t8_n170: return 0.10641951858997345f;
  t8_n171: return 0.059029098600149155f;
  t8_n172: return 0.1137610375881195f;
  t8_n173: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t8_n175;
  t8_n174: return 0.10660836100578308f;
  t8_n175: return 0.1108003556728363f;
  t8_n176: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t8_n188;
  t8_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t8_n179;
  t8_n178: return 0.09269571304321289f;
  t8_n179: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n183;
  t8_n180: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t8_n182;
  t8_n181: return 0.10306692868471146f;
  t8_n182: return 0.11009225994348526f;
  t8_n183: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t8_n185;
  t8_n184: return 0.1070241779088974f;
  t8_n185: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t8_n187;
  t8_n186: return 0.14922408759593964f;
  t8_n187: return 0.05147448554635048f;
  t8_n188: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n190;
  t8_n189: return 0.11346691101789474f;
  t8_n190: return 0.11292967200279236f;
  t8_n191: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t8_n201;
  t8_n192: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n196;
  t8_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t8_n195;
  t8_n194: return -0.0362948402762413f;
  t8_n195: return 0.10571350157260895f;
  t8_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t8_n200;
  t8_n197: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t8_n199;
  t8_n198: return 0.0841469094157219f;
  t8_n199: return 0.10599817335605621f;
  t8_n200: return 0.10902093350887299f;
  t8_n201: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t8_n205;
  t8_n202: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t8_n204;
  t8_n203: return 0.11261291056871414f;
  t8_n204: return 0.11422496289014816f;
  t8_n205: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t8_n211;
  t8_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t8_n210;
  t8_n207: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t8_n209;
  t8_n208: return 0.10614977031946182f;
  t8_n209: return 0.11155606806278229f;
  t8_n210: return 0.11340656131505966f;
  t8_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t8_n213;
  t8_n212: return 0.11328229308128357f;
  t8_n213: return 0.11301282048225403f;
  t8_n214: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t8_n240;
  t8_n215: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t8_n221;
  t8_n216: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n218;
  t8_n217: return 0.09297329932451248f;
  t8_n218: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t8_n220;
  t8_n219: return 0.11021395772695541f;
  t8_n220: return 0.013255096040666103f;
  t8_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t8_n233;
  t8_n222: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t8_n232;
  t8_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t8_n227;
  t8_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t8_n226;
  t8_n225: return -0.01040442194789648f;
  t8_n226: return 0.10941698402166367f;
  t8_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t8_n229;
  t8_n228: return 0.06740029156208038f;
  t8_n229: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t8_n231;
  t8_n230: return 0.11191198229789734f;
  t8_n231: return -0.11607234179973602f;
  t8_n232: return 0.10851335525512695f;
  t8_n233: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t8_n237;
  t8_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t8_n236;
  t8_n235: return 0.11212385445833206f;
  t8_n236: return 0.11105799674987793f;
  t8_n237: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t8_n239;
  t8_n238: return 0.11012834310531616f;
  t8_n239: return 0.10928084701299667f;
  t8_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t8_n250;
  t8_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t8_n245;
  t8_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t8_n244;
  t8_n243: return 0.08945435285568237f;
  t8_n244: return 0.11415990442037582f;
  t8_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n249;
  t8_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t8_n248;
  t8_n247: return 0.11485791206359863f;
  t8_n248: return 0.1152067556977272f;
  t8_n249: return 0.11592748761177063f;
  t8_n250: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t8_n254;
  t8_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t8_n253;
  t8_n252: return 0.10827924311161041f;
  t8_n253: return 0.11478926241397858f;
  t8_n254: return 0.11369560658931732f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree9(const Example& E) {
  t9_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t9_n222;
  t9_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t9_n199;
  t9_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t9_n146;
  t9_n3: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t9_n67;
  t9_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t9_n40;
  t9_n5: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t9_n25;
  t9_n6: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t9_n18;
  t9_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t9_n9;
  t9_n8: return -0.06853244453668594f;
  t9_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t9_n17;
  t9_n10: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t9_n12;
  t9_n11: return 0.014664157293736935f;
  t9_n12: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n14;
  t9_n13: return 0.07626525312662125f;
  t9_n14: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t9_n16;
  t9_n15: return 0.12836135923862457f;
  t9_n16: return 0.123404361307621f;
  t9_n17: return 0.12466690689325333f;
  t9_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t9_n20;
  t9_n19: return 0.06838180124759674f;
  t9_n20: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t9_n22;
  t9_n21: return 0.10847064852714539f;
  t9_n22: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t9_n24;
  t9_n23: return 0.11218585819005966f;
  t9_n24: return 0.10261552780866623f;
  t9_n25: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n27;
  t9_n26: return -0.1022336557507515f;
  t9_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t9_n29;
  t9_n28: return -0.09916984289884567f;
  t9_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t9_n37;
  t9_n30: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t9_n32;
  t9_n31: return -0.0063174511305987835f;
  t9_n32: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t9_n34;
  t9_n33: return 0.07727540284395218f;
  t9_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t9_n36;
  t9_n35: return 0.08833754807710648f;
  t9_n36: return 0.11304349452257156f;
  t9_n37: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t9_n39;
  t9_n38: return 0.11535986512899399f;
  t9_n39: return 0.09239251166582108f;
  t9_n40: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n56;
  t9_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t9_n43;
  t9_n42: return -0.034604188054800034f;
  t9_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t9_n51;
  t9_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t9_n46;
  t9_n45: return 0.0062573933973908424f;
  t9_n46: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t9_n48;
  t9_n47: return 0.056136537343263626f;
  t9_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t9_n50;
  t9_n49: return 0.09645510464906693f;
  t9_n50: return 0.16783428192138672f;
  t9_n51: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t9_n55;
  t9_n52: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t9_n54;
  t9_n53: return 0.14581839740276337f;
  t9_n54: return 0.15345625579357147f;
  t9_n55: return -0.11681395024061203f;
  t9_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t9_n58;
  t9_n57: return 0.047244250774383545f;
  t9_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t9_n64;
  t9_n59: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n63;
  t9_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t9_n62;
  t9_n61: return 0.10968109965324402f;
  t9_n62: return 0.10323546081781387f;
  t9_n63: return 0.08427122980356216f;
  t9_n64: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t9_n66;
  t9_n65: return 0.08797973394393921f;
  t9_n66: return 0.10257167369127274f;
  t9_n67: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t9_n121;
  t9_n68: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t9_n106;
  t9_n69: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n91;
  t9_n70: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t9_n80;
  t9_n71: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t9_n73;
  t9_n72: return -0.03532494232058525f;
  t9_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t9_n75;
  t9_n74: return 0.029815077781677246f;
  t9_n75: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n77;
  t9_n76: return 0.09339139610528946f;
  t9_n77: if (E.getNumReferences() >= 3344831744 /*56853.0*/) goto t9_n79;
  t9_n78: return 0.09372197091579437f;
  t9_n79: return 0.1256445050239563f;
  t9_n80: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t9_n82;
  t9_n81: return 0.06578553467988968f;
  t9_n82: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t9_n88;
  t9_n83: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t9_n85;
  t9_n84: return 0.09656242281198502f;
  t9_n85: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t9_n87;
  t9_n86: return 0.09546219557523727f;
  t9_n87: return 0.11074887961149216f;
  t9_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t9_n90;
  t9_n89: return 0.10143651813268661f;
  t9_n90: return 0.10981237143278122f;
  t9_n91: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t9_n99;
  t9_n92: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t9_n96;
  t9_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t9_n95;
  t9_n94: return 0.0857071653008461f;
  t9_n95: return 0.14868102967739105f;
  t9_n96: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t9_n98;
  t9_n97: return 0.08117634057998657f;
  t9_n98: return 0.11107300966978073f;
  t9_n99: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t9_n101;
  t9_n100: return 0.12696416676044464f;
  t9_n101: if (E.getNumReferences() >= 3314670592 /*4667.5*/) goto t9_n103;
  t9_n102: return 0.15038248896598816f;
  t9_n103: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t9_n105;
  t9_n104: return 0.1523316204547882f;
  t9_n105: return 0.10626910626888275f;
  t9_n106: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t9_n112;
  t9_n107: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t9_n111;
  t9_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t9_n110;
  t9_n109: return 0.021774036809802055f;
  t9_n110: return 0.10641668736934662f;
  t9_n111: return 0.09974052011966705f;
  t9_n112: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t9_n118;
  t9_n113: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t9_n115;
  t9_n114: return 0.10275077819824219f;
  t9_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t9_n117;
  t9_n116: return 0.10636093467473984f;
  t9_n117: return 0.11149490624666214f;
  t9_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t9_n120;
  t9_n119: return 0.08102115988731384f;
  t9_n120: return 0.11682812124490738f;
  t9_n121: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t9_n123;
  t9_n122: return 0.12695525586605072f;
  t9_n123: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t9_n125;
  t9_n124: return 0.12007838487625122f;
  t9_n125: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t9_n129;
  t9_n126: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n128;
  t9_n127: return 0.12413899600505829f;
  t9_n128: return 0.13873377442359924f;
  t9_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t9_n137;
  t9_n130: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n136;
  t9_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t9_n133;
  t9_n132: return 0.12737759947776794f;
  t9_n133: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t9_n135;
  t9_n134: return 0.15666936337947845f;
  t9_n135: return 0.15686967968940735f;
  t9_n136: return 0.13967114686965942f;
  t9_n137: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t9_n139;
  t9_n138: return 0.11949263513088226f;
  t9_n139: if (E.getNumReferences() >= 3332047872 /*19842.0*/) goto t9_n145;
  t9_n140: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t9_n144;
  t9_n141: if (E.getNumReferences() >= 3318694912 /*6632.5*/) goto t9_n143;
  t9_n142: return 0.16278627514839172f;
  t9_n143: return 0.16207823157310486f;
  t9_n144: return 0.1669691652059555f;
  t9_n145: return 0.1123083159327507f;
  t9_n146: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n184;
  t9_n147: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t9_n165;
  t9_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t9_n154;
  t9_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t9_n151;
  t9_n150: return -0.010888531804084778f;
  t9_n151: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t9_n153;
  t9_n152: return 0.08725670725107193f;
  t9_n153: return -0.1270279437303543f;
  t9_n154: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t9_n160;
  t9_n155: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t9_n157;
  t9_n156: return 0.01755915954709053f;
  t9_n157: if (E.getNumReferences() >= 3277455360 /*218.0*/) goto t9_n159;
  t9_n158: return 0.07728233188390732f;
  t9_n159: return 0.10869486629962921f;
  t9_n160: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n162;
  t9_n161: return 0.09986427426338196f;
  t9_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t9_n164;
  t9_n163: return -0.0009319137898273766f;
  t9_n164: return 0.101384237408638f;
  t9_n165: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n167;
  t9_n166: return 0.02540426142513752f;
  t9_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t9_n181;
  t9_n168: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t9_n170;
  t9_n169: return 0.0926477238535881f;
  t9_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t9_n172;
  t9_n171: return 0.0933849886059761f;
  t9_n172: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t9_n180;
  t9_n173: if (E.getNumReferences() >= 3350339968 /*91203.0*/) goto t9_n179;
  t9_n174: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t9_n176;
  t9_n175: return 0.1049264594912529f;
  t9_n176: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t9_n178;
  t9_n177: return 0.1103455126285553f;
  t9_n178: return 0.1030270904302597f;
  t9_n179: return 0.05997699499130249f;
  t9_n180: return 0.11159674823284149f;
  t9_n181: if (E.getNumReferences() >= 3276111872 /*197.5*/) goto t9_n183;
  t9_n182: return 0.10308925807476044f;
  t9_n183: return 0.1081802099943161f;
  t9_n184: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t9_n196;
  t9_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t9_n187;
  t9_n186: return 0.08642741292715073f;
  t9_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n191;
  t9_n188: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t9_n190;
  t9_n189: return 0.10024666041135788f;
  t9_n190: return 0.10751419514417648f;
  t9_n191: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t9_n193;
  t9_n192: return 0.10404530167579651f;
  t9_n193: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t9_n195;
  t9_n194: return 0.14279907941818237f;
  t9_n195: return 0.0563400536775589f;
  t9_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n198;
  t9_n197: return 0.1109919622540474f;
  t9_n198: return 0.11049427837133408f;
  t9_n199: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t9_n209;
  t9_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n204;
  t9_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t9_n203;
  t9_n202: return -0.09902960062026978f;
  t9_n203: return 0.10273673385381699f;
  t9_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t9_n208;
  t9_n205: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t9_n207;
  t9_n206: return 0.07701864093542099f;
  t9_n207: return 0.10220222175121307f;
  t9_n208: return 0.10581668466329575f;
  t9_n209: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t9_n213;
  t9_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t9_n212;
  t9_n211: return 0.11033472418785095f;
  t9_n212: return 0.11246601492166519f;
  t9_n213: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t9_n219;
  t9_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t9_n218;
  t9_n215: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t9_n217;
  t9_n216: return 0.10279238224029541f;
  t9_n217: return 0.10918153822422028f;
  t9_n218: return 0.11122792959213257f;
  t9_n219: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t9_n221;
  t9_n220: return 0.11085425317287445f;
  t9_n221: return 0.11061243712902069f;
  t9_n222: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n240;
  t9_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t9_n229;
  t9_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n226;
  t9_n225: return 0.08910759538412094f;
  t9_n226: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t9_n228;
  t9_n227: return 0.10714796930551529f;
  t9_n228: return -0.06444110721349716f;
  t9_n229: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t9_n237;
  t9_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t9_n236;
  t9_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t9_n233;
  t9_n232: return 0.10619659721851349f;
  t9_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t9_n235;
  t9_n234: return 0.06257414817810059f;
  t9_n235: return 0.1091151311993599f;
  t9_n236: return 0.10513731092214584f;
  t9_n237: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t9_n239;
  t9_n238: return 0.1091422364115715f;
  t9_n239: return 0.10707225650548935f;
  t9_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t9_n250;
  t9_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t9_n245;
  t9_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t9_n244;
  t9_n243: return 0.08384349197149277f;
  t9_n244: return 0.11169914901256561f;
  t9_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n249;
  t9_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t9_n248;
  t9_n247: return 0.11316007375717163f;
  t9_n248: return 0.11295861750841141f;
  t9_n249: return 0.11372324079275131f;
  t9_n250: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t9_n254;
  t9_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t9_n253;
  t9_n252: return 0.10733778774738312f;
  t9_n253: return 0.11260776221752167f;
  t9_n254: return 0.11138442158699036f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree10(const Example& E) {
  t10_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t10_n222;
  t10_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t10_n199;
  t10_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t10_n146;
  t10_n3: if (E.getNumReferences() >= 3289784320 /*600.5*/) goto t10_n57;
  t10_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t10_n22;
  t10_n5: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t10_n19;
  t10_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t10_n8;
  t10_n7: return -0.06894181668758392f;
  t10_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t10_n18;
  t10_n9: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t10_n11;
  t10_n10: return 0.012452631257474422f;
  t10_n11: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n15;
  t10_n12: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t10_n14;
  t10_n13: return 0.08269309997558594f;
  t10_n14: return 0.03459428250789642f;
  t10_n15: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t10_n17;
  t10_n16: return 0.12227106839418411f;
  t10_n17: return 0.11711292713880539f;
  t10_n18: return 0.11693963408470154f;
  t10_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n21;
  t10_n20: return -0.10570283234119415f;
  t10_n21: return -0.09751439094543457f;
  t10_n22: if (E.getFileProximityDistance() >= 3254910976 /*32.5*/) goto t10_n44;
  t10_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t10_n37;
  t10_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n26;
  t10_n25: return 0.029324455186724663f;
  t10_n26: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t10_n36;
  t10_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t10_n35;
  t10_n28: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t10_n34;
  t10_n29: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t10_n31;
  t10_n30: return 0.06864874809980392f;
  t10_n31: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t10_n33;
  t10_n32: return 0.09322725981473923f;
  t10_n33: return 0.10988599807024002f;
  t10_n34: return 0.04464532434940338f;
  t10_n35: return 0.08172885328531265f;
  t10_n36: return 0.08956414461135864f;
  t10_n37: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t10_n39;
  t10_n38: return 0.08989109098911285f;
  t10_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t10_n41;
  t10_n40: return 0.10211652517318726f;
  t10_n41: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t10_n43;
  t10_n42: return 0.11002326756715775f;
  t10_n43: return 0.10216384381055832f;
  t10_n44: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n46;
  t10_n45: return -0.060805972665548325f;
  t10_n46: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t10_n48;
  t10_n47: return -0.08108234405517578f;
  t10_n48: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t10_n50;
  t10_n49: return 0.042658984661102295f;
  t10_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t10_n56;
  t10_n51: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n55;
  t10_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t10_n54;
  t10_n53: return 0.10525105148553848f;
  t10_n54: return 0.10112606734037399f;
  t10_n55: return 0.08229856938123703f;
  t10_n56: return 0.09999354183673859f;
  t10_n57: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t10_n117;
  t10_n58: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t10_n102;
  t10_n59: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n87;
  t10_n60: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t10_n72;
  t10_n61: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t10_n63;
  t10_n62: return -0.03083433397114277f;
  t10_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t10_n65;
  t10_n64: return 0.03034846857190132f;
  t10_n65: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t10_n67;
  t10_n66: return 0.08971010893583298f;
  t10_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t10_n71;
  t10_n68: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t10_n70;
  t10_n69: return 0.1252216100692749f;
  t10_n70: return 0.1006692424416542f;
  t10_n71: return 0.07417521625757217f;
  t10_n72: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t10_n74;
  t10_n73: return 0.056223221123218536f;
  t10_n74: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t10_n84;
  t10_n75: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t10_n81;
  t10_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t10_n78;
  t10_n77: return 0.0861545130610466f;
  t10_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t10_n80;
  t10_n79: return 0.06957665830850601f;
  t10_n80: return 0.10926280915737152f;
  t10_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t10_n83;
  t10_n82: return 0.09390223026275635f;
  t10_n83: return 0.10799024999141693f;
  t10_n84: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t10_n86;
  t10_n85: return 0.0903552919626236f;
  t10_n86: return 0.1086459532380104f;
  t10_n87: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t10_n95;
  t10_n88: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t10_n92;
  t10_n89: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t10_n91;
  t10_n90: return 0.07689394801855087f;
  t10_n91: return 0.1396564394235611f;
  t10_n92: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t10_n94;
  t10_n93: return 0.07230648398399353f;
  t10_n94: return 0.10940157622098923f;
  t10_n95: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t10_n97;
  t10_n96: return 0.1197822242975235f;
  t10_n97: if (E.getNumReferences() >= 3314670592 /*4667.5*/) goto t10_n99;
  t10_n98: return 0.13512660562992096f;
  t10_n99: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t10_n101;
  t10_n100: return 0.14311550557613373f;
  t10_n101: return 0.10401536524295807f;
  t10_n102: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t10_n108;
  t10_n103: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t10_n107;
  t10_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t10_n106;
  t10_n105: return 0.026601118966937065f;
  t10_n106: return 0.09735067188739777f;
  t10_n107: return 0.0959782674908638f;
  t10_n108: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t10_n114;
  t10_n109: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t10_n111;
  t10_n110: return 0.0988479033112526f;
  t10_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t10_n113;
  t10_n112: return 0.10345815867185593f;
  t10_n113: return 0.10959935188293457f;
  t10_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t10_n116;
  t10_n115: return 0.07534542679786682f;
  t10_n116: return 0.1155477836728096f;
  t10_n117: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t10_n121;
  t10_n118: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t10_n120;
  t10_n119: return 0.13385005295276642f;
  t10_n120: return 0.1141357272863388f;
  t10_n121: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t10_n123;
  t10_n122: return 0.11384086310863495f;
  t10_n123: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t10_n127;
  t10_n124: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n126;
  t10_n125: return 0.11808019131422043f;
  t10_n126: return 0.13269375264644623f;
  t10_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t10_n135;
  t10_n128: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n134;
  t10_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t10_n131;
  t10_n130: return 0.12207780033349991f;
  t10_n131: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t10_n133;
  t10_n132: return 0.14571928977966309f;
  t10_n133: return 0.1450662761926651f;
  t10_n134: return 0.13335147500038147f;
  t10_n135: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t10_n137;
  t10_n136: return 0.11515205353498459f;
  t10_n137: if (E.getNumReferences() >= 3332047872 /*19842.0*/) goto t10_n145;
  t10_n138: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t10_n144;
  t10_n139: if (E.getNumReferences() >= 3318694912 /*6632.5*/) goto t10_n141;
  t10_n140: return 0.14767928421497345f;
  t10_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t10_n143;
  t10_n142: return 0.14850039780139923f;
  t10_n143: return 0.14701487123966217f;
  t10_n144: return 0.1514456570148468f;
  t10_n145: return 0.10995613038539886f;
  t10_n146: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n184;
  t10_n147: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t10_n167;
  t10_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t10_n154;
  t10_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t10_n151;
  t10_n150: return -0.011554036289453506f;
  t10_n151: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t10_n153;
  t10_n152: return 0.08311271667480469f;
  t10_n153: return -0.12483438849449158f;
  t10_n154: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t10_n158;
  t10_n155: if (E.getNumReferences() >= 3316554752 /*5587.5*/) goto t10_n157;
  t10_n156: return 0.035072196274995804f;
  t10_n157: return 0.10248743742704391f;
  t10_n158: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n164;
  t10_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t10_n161;
  t10_n160: return 0.08550386875867844f;
  t10_n161: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t10_n163;
  t10_n162: return 0.12371379882097244f;
  t10_n163: return 0.08183826506137848f;
  t10_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t10_n166;
  t10_n165: return -0.0036435374058783054f;
  t10_n166: return 0.09796370565891266f;
  t10_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n169;
  t10_n168: return 0.026908719912171364f;
  t10_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t10_n181;
  t10_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t10_n172;
  t10_n171: return -0.01022934541106224f;
  t10_n172: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t10_n178;
  t10_n173: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t10_n175;
  t10_n174: return 0.09475945681333542f;
  t10_n175: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t10_n177;
  t10_n176: return 0.09824615716934204f;
  t10_n177: return 0.10859653353691101f;
  t10_n178: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t10_n180;
  t10_n179: return 0.07902844995260239f;
  t10_n180: return 0.10910018533468246f;
  t10_n181: if (E.getNumReferences() >= 3276111872 /*197.5*/) goto t10_n183;
  t10_n182: return 0.09969764202833176f;
  t10_n183: return 0.10577958077192307f;
  t10_n184: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t10_n196;
  t10_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t10_n187;
  t10_n186: return 0.08248349279165268f;
  t10_n187: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t10_n193;
  t10_n188: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n192;
  t10_n189: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t10_n191;
  t10_n190: return 0.09428401291370392f;
  t10_n191: return 0.1043204665184021f;
  t10_n192: return 0.10058761388063431f;
  t10_n193: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t10_n195;
  t10_n194: return 0.1400451809167862f;
  t10_n195: return 0.10396529734134674f;
  t10_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n198;
  t10_n197: return 0.10840704292058945f;
  t10_n198: return 0.10859359800815582f;
  t10_n199: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t10_n209;
  t10_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n204;
  t10_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t10_n203;
  t10_n202: return -0.08066617697477341f;
  t10_n203: return 0.0981026217341423f;
  t10_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t10_n208;
  t10_n205: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t10_n207;
  t10_n206: return 0.0712357833981514f;
  t10_n207: return 0.09864891320466995f;
  t10_n208: return 0.10276862233877182f;
  t10_n209: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t10_n213;
  t10_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t10_n212;
  t10_n211: return 0.10850802809000015f;
  t10_n212: return 0.11120191216468811f;
  t10_n213: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t10_n219;
  t10_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t10_n218;
  t10_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t10_n217;
  t10_n216: return 0.09979444742202759f;
  t10_n217: return 0.10726556181907654f;
  t10_n218: return 0.10950817912817001f;
  t10_n219: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t10_n221;
  t10_n220: return 0.10839203745126724f;
  t10_n221: return 0.10917434096336365f;
  t10_n222: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n240;
  t10_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t10_n229;
  t10_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n226;
  t10_n225: return 0.08369584381580353f;
  t10_n226: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t10_n228;
  t10_n227: return 0.10459012538194656f;
  t10_n228: return -0.05232534185051918f;
  t10_n229: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t10_n237;
  t10_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t10_n236;
  t10_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t10_n233;
  t10_n232: return 0.10309281945228577f;
  t10_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t10_n235;
  t10_n234: return 0.05460306629538536f;
  t10_n235: return 0.1066644936800003f;
  t10_n236: return 0.10218971967697144f;
  t10_n237: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t10_n239;
  t10_n238: return 0.1069466844201088f;
  t10_n239: return 0.1047702357172966f;
  t10_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t10_n250;
  t10_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t10_n245;
  t10_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t10_n244;
  t10_n243: return 0.08609756082296371f;
  t10_n244: return 0.10966736078262329f;
  t10_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n249;
  t10_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t10_n248;
  t10_n247: return 0.11006668955087662f;
  t10_n248: return 0.11116715520620346f;
  t10_n249: return 0.11201436817646027f;
  t10_n250: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t10_n254;
  t10_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t10_n253;
  t10_n252: return 0.10426368564367294f;
  t10_n253: return 0.11085938662290573f;
  t10_n254: return 0.1095844954252243f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree11(const Example& E) {
  t11_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t11_n222;
  t11_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t11_n203;
  t11_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t11_n152;
  t11_n3: if (E.getNumReferences() >= 3289554944 /*586.5*/) goto t11_n65;
  t11_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t11_n38;
  t11_n5: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t11_n25;
  t11_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t11_n20;
  t11_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t11_n9;
  t11_n8: return -0.06579383462667465f;
  t11_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t11_n17;
  t11_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t11_n16;
  t11_n11: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t11_n15;
  t11_n12: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t11_n14;
  t11_n13: return 0.04017297178506851f;
  t11_n14: return 0.08299686014652252f;
  t11_n15: return 0.1174796000123024f;
  t11_n16: return -0.0038561176043003798f;
  t11_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t11_n19;
  t11_n18: return 0.10800515115261078f;
  t11_n19: return 0.11587008833885193f;
  t11_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t11_n22;
  t11_n21: return 0.05759033188223839f;
  t11_n22: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t11_n24;
  t11_n23: return 0.10367309302091599f;
  t11_n24: return 0.10783699154853821f;
  t11_n25: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n27;
  t11_n26: return -0.0969264805316925f;
  t11_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t11_n29;
  t11_n28: return -0.09221488982439041f;
  t11_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t11_n35;
  t11_n30: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t11_n32;
  t11_n31: return -0.0001715273829177022f;
  t11_n32: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t11_n34;
  t11_n33: return 0.07902790606021881f;
  t11_n34: return 0.07958292961120605f;
  t11_n35: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t11_n37;
  t11_n36: return 0.11027774214744568f;
  t11_n37: return 0.08513261377811432f;
  t11_n38: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t11_n58;
  t11_n39: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t11_n41;
  t11_n40: return -0.02546115592122078f;
  t11_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t11_n49;
  t11_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t11_n44;
  t11_n43: return 0.0036681299097836018f;
  t11_n44: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t11_n46;
  t11_n45: return 0.056537892669439316f;
  t11_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t11_n48;
  t11_n47: return 0.08941182494163513f;
  t11_n48: return 0.1514987200498581f;
  t11_n49: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t11_n57;
  t11_n50: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t11_n52;
  t11_n51: return 0.13061915338039398f;
  t11_n52: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t11_n54;
  t11_n53: return 0.08946020156145096f;
  t11_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t11_n56;
  t11_n55: return -0.1444183886051178f;
  t11_n56: return 0.14999547600746155f;
  t11_n57: return -0.10993263125419617f;
  t11_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t11_n60;
  t11_n59: return 0.03400709852576256f;
  t11_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n62;
  t11_n61: return 0.09789445251226425f;
  t11_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t11_n64;
  t11_n63: return 0.07756313681602478f;
  t11_n64: return 0.09518016874790192f;
  t11_n65: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t11_n123;
  t11_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t11_n110;
  t11_n67: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t11_n95;
  t11_n68: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t11_n84;
  t11_n69: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t11_n83;
  t11_n70: if (E.getNumReferences() >= 3350478720 /*92287.0*/) goto t11_n72;
  t11_n71: return 0.04577914625406265f;
  t11_n72: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n74;
  t11_n73: return 0.0878198891878128f;
  t11_n74: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t11_n82;
  t11_n75: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t11_n81;
  t11_n76: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t11_n80;
  t11_n77: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t11_n79;
  t11_n78: return 0.12409322708845139f;
  t11_n79: return 0.09639009833335876f;
  t11_n80: return 0.10966116189956665f;
  t11_n81: return 0.128379687666893f;
  t11_n82: return 0.08490176498889923f;
  t11_n83: return -0.04484656825661659f;
  t11_n84: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t11_n86;
  t11_n85: return 0.05283517390489578f;
  t11_n86: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t11_n92;
  t11_n87: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t11_n89;
  t11_n88: return 0.08969519287347794f;
  t11_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t11_n91;
  t11_n90: return 0.09029529243707657f;
  t11_n91: return 0.10645601153373718f;
  t11_n92: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t11_n94;
  t11_n93: return 0.08639171719551086f;
  t11_n94: return 0.10729516297578812f;
  t11_n95: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t11_n103;
  t11_n96: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t11_n100;
  t11_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t11_n99;
  t11_n98: return 0.07307653874158859f;
  t11_n99: return 0.13108839094638824f;
  t11_n100: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t11_n102;
  t11_n101: return 0.06883018463850021f;
  t11_n102: return 0.10748856514692307f;
  t11_n103: if (E.getNumReferences() >= 3315311616 /*4980.5*/) goto t11_n105;
  t11_n104: return 0.11783990263938904f;
  t11_n105: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t11_n107;
  t11_n106: return 0.10788179188966751f;
  t11_n107: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t11_n109;
  t11_n108: return 0.1340516209602356f;
  t11_n109: return 0.1018492579460144f;
  t11_n110: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t11_n116;
  t11_n111: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t11_n115;
  t11_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t11_n114;
  t11_n113: return 0.021960949525237083f;
  t11_n114: return 0.091550812125206f;
  t11_n115: return 0.09238975495100021f;
  t11_n116: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t11_n122;
  t11_n117: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t11_n119;
  t11_n118: return 0.10051321238279343f;
  t11_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t11_n121;
  t11_n120: return 0.06525825709104538f;
  t11_n121: return 0.11404350399971008f;
  t11_n122: return 0.11024269461631775f;
  t11_n123: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t11_n129;
  t11_n124: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t11_n126;
  t11_n125: return 0.09535157680511475f;
  t11_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t11_n128;
  t11_n127: return 0.10553183406591415f;
  t11_n128: return 0.1307184398174286f;
  t11_n129: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t11_n131;
  t11_n130: return 0.10797587782144547f;
  t11_n131: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t11_n151;
  t11_n132: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t11_n134;
  t11_n133: return 0.11411508917808533f;
  t11_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t11_n140;
  t11_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t11_n137;
  t11_n136: return 0.11763742566108704f;
  t11_n137: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t11_n139;
  t11_n138: return 0.13391102850437164f;
  t11_n139: return 0.13618358969688416f;
  t11_n140: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t11_n142;
  t11_n141: return 0.11177453398704529f;
  t11_n142: if (E.getNumReferences() >= 3332047872 /*19842.0*/) goto t11_n150;
  t11_n143: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t11_n149;
  t11_n144: if (E.getNumReferences() >= 3318694912 /*6632.5*/) goto t11_n146;
  t11_n145: return 0.13571150600910187f;
  t11_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t11_n148;
  t11_n147: return 0.1369863897562027f;
  t11_n148: return 0.14310699701309204f;
  t11_n149: return 0.14013652503490448f;
  t11_n150: return 0.10788334906101227f;
  t11_n151: return 0.1277266889810562f;
  t11_n152: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t11_n190;
  t11_n153: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t11_n171;
  t11_n154: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t11_n166;
  t11_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t11_n157;
  t11_n156: return -0.11314450949430466f;
  t11_n157: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t11_n159;
  t11_n158: return 0.023062217980623245f;
  t11_n159: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t11_n165;
  t11_n160: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t11_n164;
  t11_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t11_n163;
  t11_n162: return 0.08018583804368973f;
  t11_n163: return 0.09493445605039597f;
  t11_n164: return 0.10489436239004135f;
  t11_n165: return 0.01943764090538025f;
  t11_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n168;
  t11_n167: return 0.07162822037935257f;
  t11_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t11_n170;
  t11_n169: return -0.11593618243932724f;
  t11_n170: return 0.09007140249013901f;
  t11_n171: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n173;
  t11_n172: return 0.013027012348175049f;
  t11_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t11_n187;
  t11_n174: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t11_n176;
  t11_n175: return 0.08392925560474396f;
  t11_n176: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t11_n178;
  t11_n177: return 0.08477269858121872f;
  t11_n178: if (E.getNumReferences() >= 3350339968 /*91203.0*/) goto t11_n184;
  t11_n179: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t11_n181;
  t11_n180: return 0.0991453304886818f;
  t11_n181: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t11_n183;
  t11_n182: return 0.10714035481214523f;
  t11_n183: return 0.09692596644163132f;
  t11_n184: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t11_n186;
  t11_n185: return 0.03907909244298935f;
  t11_n186: return 0.10883732885122299f;
  t11_n187: if (E.getNumReferences() >= 3276111872 /*197.5*/) goto t11_n189;
  t11_n188: return 0.09675264358520508f;
  t11_n189: return 0.10366126149892807f;
  t11_n190: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t11_n200;
  t11_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t11_n193;
  t11_n192: return 0.07715988159179688f;
  t11_n193: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t11_n197;
  t11_n194: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n196;
  t11_n195: return 0.09987743198871613f;
  t11_n196: return 0.0979619026184082f;
  t11_n197: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t11_n199;
  t11_n198: return 0.13522189855575562f;
  t11_n199: return 0.06470903754234314f;
  t11_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n202;
  t11_n201: return 0.10657093673944473f;
  t11_n202: return 0.10685867071151733f;
  t11_n203: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t11_n213;
  t11_n204: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n208;
  t11_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t11_n207;
  t11_n206: return -0.06793522089719772f;
  t11_n207: return 0.09491673111915588f;
  t11_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t11_n212;
  t11_n209: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t11_n211;
  t11_n210: return 0.06614193320274353f;
  t11_n211: return 0.0956873968243599f;
  t11_n212: return 0.10013145208358765f;
  t11_n213: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t11_n217;
  t11_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t11_n216;
  t11_n215: return 0.10699084401130676f;
  t11_n216: return 0.11019746959209442f;
  t11_n217: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t11_n221;
  t11_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t11_n220;
  t11_n219: return 0.10125678777694702f;
  t11_n220: return 0.107998788356781f;
  t11_n221: return 0.10777629911899567f;
  t11_n222: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t11_n240;
  t11_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t11_n229;
  t11_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n226;
  t11_n225: return 0.07922739535570145f;
  t11_n226: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t11_n228;
  t11_n227: return 0.10226548463106155f;
  t11_n228: return -0.07848593592643738f;
  t11_n229: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t11_n237;
  t11_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t11_n236;
  t11_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t11_n233;
  t11_n232: return 0.10044308751821518f;
  t11_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t11_n235;
  t11_n234: return 0.05074216052889824f;
  t11_n235: return 0.1045994982123375f;
  t11_n236: return 0.09937219321727753f;
  t11_n237: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t11_n239;
  t11_n238: return 0.10506173968315125f;
  t11_n239: return 0.10278452932834625f;
  t11_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t11_n250;
  t11_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t11_n245;
  t11_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t11_n244;
  t11_n243: return 0.07947266846895218f;
  t11_n244: return 0.1083064079284668f;
  t11_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n249;
  t11_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t11_n248;
  t11_n247: return 0.1094546690583229f;
  t11_n248: return 0.10977908223867416f;
  t11_n249: return 0.1106608584523201f;
  t11_n250: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t11_n254;
  t11_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t11_n253;
  t11_n252: return 0.10440175980329514f;
  t11_n253: return 0.10962507128715515f;
  t11_n254: return 0.10818728059530258f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree12(const Example& E) {
  t12_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t12_n222;
  t12_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t12_n203;
  t12_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t12_n160;
  t12_n3: if (E.getNumReferences() >= 3288932352 /*548.5*/) goto t12_n51;
  t12_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t12_n22;
  t12_n5: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t12_n19;
  t12_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t12_n8;
  t12_n7: return -0.05947907269001007f;
  t12_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t12_n16;
  t12_n9: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t12_n11;
  t12_n10: return 0.01679440774023533f;
  t12_n11: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t12_n15;
  t12_n12: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t12_n14;
  t12_n13: return 0.07828737050294876f;
  t12_n14: return 0.1147882267832756f;
  t12_n15: return 0.0455186702311039f;
  t12_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t12_n18;
  t12_n17: return 0.10257267951965332f;
  t12_n18: return 0.11297492682933807f;
  t12_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n21;
  t12_n20: return -0.10164188593626022f;
  t12_n21: return -0.09096655249595642f;
  t12_n22: if (E.getFileProximityDistance() >= 3254910976 /*32.5*/) goto t12_n40;
  t12_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t12_n33;
  t12_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n26;
  t12_n25: return 0.021478427574038506f;
  t12_n26: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t12_n30;
  t12_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t12_n29;
  t12_n28: return 0.05488815903663635f;
  t12_n29: return 0.06986016780138016f;
  t12_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t12_n32;
  t12_n31: return 0.08261949568986893f;
  t12_n32: return 0.10169872641563416f;
  t12_n33: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t12_n35;
  t12_n34: return 0.0815439447760582f;
  t12_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t12_n37;
  t12_n36: return 0.09710436314344406f;
  t12_n37: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t12_n39;
  t12_n38: return 0.10674409568309784f;
  t12_n39: return 0.09629680961370468f;
  t12_n40: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t12_n42;
  t12_n41: return -0.05082354322075844f;
  t12_n42: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t12_n44;
  t12_n43: return -0.08767537027597427f;
  t12_n44: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t12_n46;
  t12_n45: return 0.03543271869421005f;
  t12_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t12_n50;
  t12_n47: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n49;
  t12_n48: return 0.0947757139801979f;
  t12_n49: return 0.0722113698720932f;
  t12_n50: return 0.09369350969791412f;
  t12_n51: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t12_n131;
  t12_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t12_n118;
  t12_n53: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t12_n99;
  t12_n54: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t12_n82;
  t12_n55: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t12_n73;
  t12_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t12_n58;
  t12_n57: return -0.014107156544923782f;
  t12_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n60;
  t12_n59: return 0.04769973084330559f;
  t12_n60: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t12_n66;
  t12_n61: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t12_n63;
  t12_n62: return 0.10562342405319214f;
  t12_n63: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t12_n65;
  t12_n64: return 0.13425853848457336f;
  t12_n65: return 0.11512649059295654f;
  t12_n66: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t12_n70;
  t12_n67: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t12_n69;
  t12_n68: return 0.126725435256958f;
  t12_n69: return 0.10584300011396408f;
  t12_n70: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t12_n72;
  t12_n71: return 0.12121367454528809f;
  t12_n72: return -0.03515598177909851f;
  t12_n73: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n75;
  t12_n74: return 0.10159583389759064f;
  t12_n75: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t12_n81;
  t12_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t12_n78;
  t12_n77: return 0.10602238774299622f;
  t12_n78: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t12_n80;
  t12_n79: return 0.11973530799150467f;
  t12_n80: return 0.009303427301347256f;
  t12_n81: return 0.12315909564495087f;
  t12_n82: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t12_n84;
  t12_n83: return -0.04083368554711342f;
  t12_n84: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t12_n86;
  t12_n85: return 0.0295286625623703f;
  t12_n86: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t12_n94;
  t12_n87: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t12_n89;
  t12_n88: return 0.07591849565505981f;
  t12_n89: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t12_n91;
  t12_n90: return 0.04357365518808365f;
  t12_n91: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t12_n93;
  t12_n92: return 0.111052967607975f;
  t12_n93: return 0.10561221837997437f;
  t12_n94: if (E.getNumReferences() >= 3346550272 /*63566.0*/) goto t12_n98;
  t12_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t12_n97;
  t12_n96: return 0.08112434297800064f;
  t12_n97: return 0.11945769190788269f;
  t12_n98: return 0.1068475991487503f;
  t12_n99: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t12_n107;
  t12_n100: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t12_n106;
  t12_n101: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t12_n103;
  t12_n102: return 0.06679829210042953f;
  t12_n103: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t12_n105;
  t12_n104: return 0.06620751321315765f;
  t12_n105: return 0.10597112774848938f;
  t12_n106: return 0.12037666141986847f;
  t12_n107: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t12_n109;
  t12_n108: return 0.10831144452095032f;
  t12_n109: if (E.getNumReferences() >= 3314670592 /*4667.5*/) goto t12_n111;
  t12_n110: return 0.11807990819215775f;
  t12_n111: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t12_n117;
  t12_n112: if (E.getNumReferences() >= 3327652864 /*13821.0*/) goto t12_n116;
  t12_n113: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t12_n115;
  t12_n114: return 0.1372307389974594f;
  t12_n115: return 0.13534148037433624f;
  t12_n116: return 0.13778743147850037f;
  t12_n117: return 0.10356183350086212f;
  t12_n118: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t12_n128;
  t12_n119: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t12_n127;
  t12_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t12_n122;
  t12_n121: return 0.017148753628134727f;
  t12_n122: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t12_n126;
  t12_n123: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t12_n125;
  t12_n124: return 0.10889720171689987f;
  t12_n125: return 0.12185942381620407f;
  t12_n126: return 0.08184568583965302f;
  t12_n127: return 0.08938590437173843f;
  t12_n128: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t12_n130;
  t12_n129: return 0.09593269973993301f;
  t12_n130: return 0.1091126948595047f;
  t12_n131: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t12_n135;
  t12_n132: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t12_n134;
  t12_n133: return 0.12915223836898804f;
  t12_n134: return 0.0987958088517189f;
  t12_n135: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t12_n137;
  t12_n136: return 0.10399075597524643f;
  t12_n137: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t12_n155;
  t12_n138: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t12_n140;
  t12_n139: return 0.10977837443351746f;
  t12_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t12_n144;
  t12_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t12_n143;
  t12_n142: return 0.11288796365261078f;
  t12_n143: return 0.1285760998725891f;
  t12_n144: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t12_n146;
  t12_n145: return 0.10930103808641434f;
  t12_n146: if (E.getNumReferences() >= 3333289472 /*22267.0*/) goto t12_n154;
  t12_n147: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t12_n153;
  t12_n148: if (E.getNumReferences() >= 3318694912 /*6632.5*/) goto t12_n150;
  t12_n149: return 0.12692245841026306f;
  t12_n150: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t12_n152;
  t12_n151: return 0.1296205371618271f;
  t12_n152: return 0.13468678295612335f;
  t12_n153: return 0.1319226622581482f;
  t12_n154: return 0.10385016351938248f;
  t12_n155: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t12_n159;
  t12_n156: if (E.getNumReferences() >= 3319711744 /*7129.0*/) goto t12_n158;
  t12_n157: return 0.13379809260368347f;
  t12_n158: return 0.13472987711429596f;
  t12_n159: return 0.1068042516708374f;
  t12_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t12_n188;
  t12_n161: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t12_n181;
  t12_n162: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t12_n176;
  t12_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t12_n165;
  t12_n164: return -0.11084145307540894f;
  t12_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t12_n167;
  t12_n166: return 0.020866796374320984f;
  t12_n167: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t12_n175;
  t12_n168: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t12_n174;
  t12_n169: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t12_n173;
  t12_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t12_n172;
  t12_n171: return 0.07988076657056808f;
  t12_n172: return 0.09153573960065842f;
  t12_n173: return -0.11092475801706314f;
  t12_n174: return 0.10477197915315628f;
  t12_n175: return 0.01782882772386074f;
  t12_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n178;
  t12_n177: return 0.06900789588689804f;
  t12_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t12_n180;
  t12_n179: return -0.11438912153244019f;
  t12_n180: return 0.08628913760185242f;
  t12_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n183;
  t12_n182: return 0.0056274146772921085f;
  t12_n183: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t12_n185;
  t12_n184: return 0.08104356378316879f;
  t12_n185: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t12_n187;
  t12_n186: return 0.08256027847528458f;
  t12_n187: return 0.09834179282188416f;
  t12_n188: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t12_n200;
  t12_n189: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t12_n191;
  t12_n190: return 0.07307735830545425f;
  t12_n191: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t12_n197;
  t12_n192: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n196;
  t12_n193: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t12_n195;
  t12_n194: return 0.08648844808340073f;
  t12_n195: return 0.09963613748550415f;
  t12_n196: return 0.09567975252866745f;
  t12_n197: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t12_n199;
  t12_n198: return 0.13367284834384918f;
  t12_n199: return 0.06292009353637695f;
  t12_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n202;
  t12_n201: return 0.10490160435438156f;
  t12_n202: return 0.10516589879989624f;
  t12_n203: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t12_n213;
  t12_n204: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n208;
  t12_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t12_n207;
  t12_n206: return -0.044961556792259216f;
  t12_n207: return 0.09400244802236557f;
  t12_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t12_n212;
  t12_n209: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t12_n211;
  t12_n210: return 0.06021488830447197f;
  t12_n211: return 0.09227823466062546f;
  t12_n212: return 0.09770937263965607f;
  t12_n213: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t12_n217;
  t12_n214: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t12_n216;
  t12_n215: return 0.1072666198015213f;
  t12_n216: return 0.108050137758255f;
  t12_n217: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t12_n221;
  t12_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t12_n220;
  t12_n219: return 0.09929375350475311f;
  t12_n220: return 0.10693669319152832f;
  t12_n221: return 0.1066160798072815f;
  t12_n222: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t12_n240;
  t12_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t12_n229;
  t12_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n226;
  t12_n225: return 0.07508399337530136f;
  t12_n226: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t12_n228;
  t12_n227: return 0.10014152526855469f;
  t12_n228: return -0.07068818062543869f;
  t12_n229: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t12_n237;
  t12_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t12_n236;
  t12_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t12_n233;
  t12_n232: return 0.09780130535364151f;
  t12_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t12_n235;
  t12_n234: return 0.06326586753129959f;
  t12_n235: return 0.10243970155715942f;
  t12_n236: return 0.09666267037391663f;
  t12_n237: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t12_n239;
  t12_n238: return 0.10325590521097183f;
  t12_n239: return 0.1008005291223526f;
  t12_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t12_n250;
  t12_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t12_n245;
  t12_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t12_n244;
  t12_n243: return 0.07802943885326385f;
  t12_n244: return 0.10679663717746735f;
  t12_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n249;
  t12_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t12_n248;
  t12_n247: return 0.1070803627371788f;
  t12_n248: return 0.10863887518644333f;
  t12_n249: return 0.10961427539587021f;
  t12_n250: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t12_n254;
  t12_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t12_n253;
  t12_n252: return 0.10078494250774384f;
  t12_n253: return 0.10855970531702042f;
  t12_n254: return 0.10698916763067245f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree13(const Example& E) {
  t13_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t13_n226;
  t13_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t13_n211;
  t13_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t13_n160;
  t13_n3: if (E.getNumReferences() >= 3279650816 /*251.5*/) goto t13_n49;
  t13_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t13_n34;
  t13_n5: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t13_n23;
  t13_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t13_n12;
  t13_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t13_n9;
  t13_n8: return -0.00427229842171073f;
  t13_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t13_n11;
  t13_n10: return 0.09521917253732681f;
  t13_n11: return 0.11381188780069351f;
  t13_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t13_n20;
  t13_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n15;
  t13_n14: return 0.027293680235743523f;
  t13_n15: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t13_n17;
  t13_n16: return 0.05383661761879921f;
  t13_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t13_n19;
  t13_n18: return 0.0790724977850914f;
  t13_n19: return 0.09844401478767395f;
  t13_n20: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t13_n22;
  t13_n21: return 0.09962568432092667f;
  t13_n22: return 0.10442037880420685f;
  t13_n23: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n25;
  t13_n24: return -0.09410659223794937f;
  t13_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t13_n27;
  t13_n26: return -0.09123560041189194f;
  t13_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t13_n33;
  t13_n28: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t13_n30;
  t13_n29: return -0.0025724724400788546f;
  t13_n30: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t13_n32;
  t13_n31: return 0.07461866736412048f;
  t13_n32: return 0.06769025325775146f;
  t13_n33: return 0.08119551092386246f;
  t13_n34: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n36;
  t13_n35: return -0.01716025359928608f;
  t13_n36: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t13_n44;
  t13_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t13_n39;
  t13_n38: return 0.04946554824709892f;
  t13_n39: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t13_n41;
  t13_n40: return 0.12081724405288696f;
  t13_n41: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t13_n43;
  t13_n42: return 0.12968450784683228f;
  t13_n43: return -0.11721250414848328f;
  t13_n44: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t13_n46;
  t13_n45: return 0.08971454948186874f;
  t13_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t13_n48;
  t13_n47: return 0.06344039738178253f;
  t13_n48: return 0.0873006284236908f;
  t13_n49: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t13_n137;
  t13_n50: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t13_n114;
  t13_n51: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t13_n95;
  t13_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t13_n58;
  t13_n53: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t13_n55;
  t13_n54: return -0.04583188146352768f;
  t13_n55: if (E.getNumReferences() >= 3315905536 /*5270.5*/) goto t13_n57;
  t13_n56: return 0.03632405027747154f;
  t13_n57: return 0.08766630291938782f;
  t13_n58: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t13_n78;
  t13_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t13_n61;
  t13_n60: return -0.027221379801630974f;
  t13_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t13_n63;
  t13_n62: return 0.05622824653983116f;
  t13_n63: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t13_n77;
  t13_n64: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t13_n70;
  t13_n65: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t13_n69;
  t13_n66: if (E.getNumReferences() >= 3293249536 /*812.0*/) goto t13_n68;
  t13_n67: return 0.13330966234207153f;
  t13_n68: return 0.13060976564884186f;
  t13_n69: return 0.11177151650190353f;
  t13_n70: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t13_n74;
  t13_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t13_n73;
  t13_n72: return 0.12736395001411438f;
  t13_n73: return 0.11628518253564835f;
  t13_n74: if (E.getNumReferences() >= 3325332480 /*11555.0*/) goto t13_n76;
  t13_n75: return 0.023848554119467735f;
  t13_n76: return 0.0984242707490921f;
  t13_n77: return 0.11207287013530731f;
  t13_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n90;
  t13_n79: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t13_n89;
  t13_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n82;
  t13_n81: return 0.10108617693185806f;
  t13_n82: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t13_n84;
  t13_n83: return 0.11512497067451477f;
  t13_n84: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t13_n86;
  t13_n85: return 0.10110590606927872f;
  t13_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t13_n88;
  t13_n87: return 0.12114068120718002f;
  t13_n88: return 0.11139904707670212f;
  t13_n89: return 0.02827148325741291f;
  t13_n90: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t13_n94;
  t13_n91: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t13_n93;
  t13_n92: return 0.11909864842891693f;
  t13_n93: return 0.12972784042358398f;
  t13_n94: return 0.09964592009782791f;
  t13_n95: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t13_n103;
  t13_n96: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n102;
  t13_n97: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t13_n99;
  t13_n98: return 0.06146992743015289f;
  t13_n99: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t13_n101;
  t13_n100: return 0.0518890805542469f;
  t13_n101: return 0.10323052108287811f;
  t13_n102: return 0.12000031769275665f;
  t13_n103: if (E.getNumReferences() >= 3315342336 /*4995.5*/) goto t13_n105;
  t13_n104: return 0.11162035167217255f;
  t13_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t13_n107;
  t13_n106: return 0.10150875896215439f;
  t13_n107: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t13_n113;
  t13_n108: if (E.getNumReferences() >= 3327652864 /*13821.0*/) goto t13_n112;
  t13_n109: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t13_n111;
  t13_n110: return 0.13239659368991852f;
  t13_n111: return 0.1278836578130722f;
  t13_n112: return 0.13050876557826996f;
  t13_n113: return 0.10193446278572083f;
  t13_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t13_n122;
  t13_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t13_n117;
  t13_n116: return -0.012794425711035728f;
  t13_n117: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t13_n119;
  t13_n118: return 0.08069130778312683f;
  t13_n119: if (E.getNumReferences() >= 3360228064 /*205835.5*/) goto t13_n121;
  t13_n120: return 0.12366446852684021f;
  t13_n121: return 0.10537247359752655f;
  t13_n122: if (E.getNumReferences() >= 3337711104 /*30903.0*/) goto t13_n126;
  t13_n123: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t13_n125;
  t13_n124: return 0.10004632920026779f;
  t13_n125: return 0.06652258336544037f;
  t13_n126: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t13_n128;
  t13_n127: return 0.11082284152507782f;
  t13_n128: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t13_n136;
  t13_n129: if (E.getNumReferences() >= 3338301440 /*32056.0*/) goto t13_n131;
  t13_n130: return 0.13062338531017303f;
  t13_n131: if (E.getNumReferences() >= 3345968640 /*61294.0*/) goto t13_n133;
  t13_n132: return 0.08644653856754303f;
  t13_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t13_n135;
  t13_n134: return 0.10178505629301071f;
  t13_n135: return 0.10632220655679703f;
  t13_n136: return 0.07380237430334091f;
  t13_n137: if (E.getNumReferences() >= 3308636160 /*2908.5*/) goto t13_n141;
  t13_n138: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t13_n140;
  t13_n139: return 0.138036847114563f;
  t13_n140: return 0.11355844885110855f;
  t13_n141: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t13_n143;
  t13_n142: return 0.10048478096723557f;
  t13_n143: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t13_n149;
  t13_n144: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t13_n148;
  t13_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t13_n147;
  t13_n146: return 0.10967327654361725f;
  t13_n147: return 0.12279706448316574f;
  t13_n148: return 0.11932878941297531f;
  t13_n149: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t13_n151;
  t13_n150: return 0.10708080977201462f;
  t13_n151: if (E.getNumReferences() >= 3333289472 /*22267.0*/) goto t13_n159;
  t13_n152: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t13_n158;
  t13_n153: if (E.getNumReferences() >= 3318694912 /*6632.5*/) goto t13_n155;
  t13_n154: return 0.12040301412343979f;
  t13_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t13_n157;
  t13_n156: return 0.12343394011259079f;
  t13_n157: return 0.12834948301315308f;
  t13_n158: return 0.12567929923534393f;
  t13_n159: return 0.10259904712438583f;
  t13_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t13_n194;
  t13_n161: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t13_n179;
  t13_n162: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t13_n178;
  t13_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t13_n169;
  t13_n164: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t13_n166;
  t13_n165: return -0.005733537022024393f;
  t13_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t13_n168;
  t13_n167: return 0.07877806574106216f;
  t13_n168: return 0.10048748552799225f;
  t13_n169: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t13_n173;
  t13_n170: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n172;
  t13_n171: return -0.0417984202504158f;
  t13_n172: return 0.058724187314510345f;
  t13_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t13_n177;
  t13_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n176;
  t13_n175: return 0.05693957209587097f;
  t13_n176: return 0.09653718769550323f;
  t13_n177: return 0.1072884276509285f;
  t13_n178: return 0.07612177729606628f;
  t13_n179: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n181;
  t13_n180: return -0.009992293082177639f;
  t13_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t13_n193;
  t13_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t13_n184;
  t13_n183: return -0.040638260543346405f;
  t13_n184: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t13_n190;
  t13_n185: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t13_n187;
  t13_n186: return 0.08326543122529984f;
  t13_n187: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t13_n189;
  t13_n188: return 0.08935269713401794f;
  t13_n189: return 0.10498280823230743f;
  t13_n190: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t13_n192;
  t13_n191: return 0.06320104002952576f;
  t13_n192: return 0.10688306391239166f;
  t13_n193: return 0.09459489583969116f;
  t13_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n198;
  t13_n195: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t13_n197;
  t13_n196: return 0.06668178737163544f;
  t13_n197: return 0.10000945627689362f;
  t13_n198: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n204;
  t13_n199: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t13_n201;
  t13_n200: return 0.08334636688232422f;
  t13_n201: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t13_n203;
  t13_n202: return 0.10104721784591675f;
  t13_n203: return 0.10649557411670685f;
  t13_n204: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t13_n208;
  t13_n205: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t13_n207;
  t13_n206: return 0.09287883341312408f;
  t13_n207: return 0.10556674748659134f;
  t13_n208: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t13_n210;
  t13_n209: return 0.1260083019733429f;
  t13_n210: return 0.09959600120782852f;
  t13_n211: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t13_n219;
  t13_n212: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n216;
  t13_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t13_n215;
  t13_n214: return -0.041407469660043716f;
  t13_n215: return 0.08979424834251404f;
  t13_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t13_n218;
  t13_n217: return 0.09283924102783203f;
  t13_n218: return 0.06349675357341766f;
  t13_n219: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t13_n221;
  t13_n220: return 0.1071629524230957f;
  t13_n221: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t13_n225;
  t13_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t13_n224;
  t13_n223: return 0.09675222635269165f;
  t13_n224: return 0.10597708076238632f;
  t13_n225: return 0.1056610494852066f;
  t13_n226: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t13_n242;
  t13_n227: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n231;
  t13_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n230;
  t13_n229: return 0.07065246999263763f;
  t13_n230: return 0.09786402434110641f;
  t13_n231: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t13_n239;
  t13_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t13_n238;
  t13_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t13_n235;
  t13_n234: return 0.09542027115821838f;
  t13_n235: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t13_n237;
  t13_n236: return 0.04699840024113655f;
  t13_n237: return 0.10079647600650787f;
  t13_n238: return 0.09391700476408005f;
  t13_n239: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t13_n241;
  t13_n240: return 0.10168428719043732f;
  t13_n241: return 0.09906555712223053f;
  t13_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t13_n252;
  t13_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n247;
  t13_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t13_n246;
  t13_n245: return 0.07325878739356995f;
  t13_n246: return 0.10569486767053604f;
  t13_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n251;
  t13_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t13_n250;
  t13_n249: return 0.10560904443264008f;
  t13_n250: return 0.10772459954023361f;
  t13_n251: return 0.10860088467597961f;
  t13_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t13_n254;
  t13_n253: return 0.10770808160305023f;
  t13_n254: return 0.10632012784481049f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree14(const Example& E) {
  t14_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t14_n224;
  t14_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t14_n207;
  t14_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t14_n68;
  t14_n3: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t14_n27;
  t14_n4: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t14_n6;
  t14_n5: return -0.0651426762342453f;
  t14_n6: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t14_n24;
  t14_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t14_n21;
  t14_n8: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t14_n10;
  t14_n9: return -0.017711402848362923f;
  t14_n10: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t14_n20;
  t14_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t14_n13;
  t14_n12: return -0.1119973435997963f;
  t14_n13: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t14_n19;
  t14_n14: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t14_n18;
  t14_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t14_n17;
  t14_n16: return 0.07091665267944336f;
  t14_n17: return 0.11561950296163559f;
  t14_n18: return -0.11117683351039886f;
  t14_n19: return -0.05111325904726982f;
  t14_n20: return 0.10209978371858597f;
  t14_n21: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n23;
  t14_n22: return 0.07005593180656433f;
  t14_n23: return 0.09708401560783386f;
  t14_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n26;
  t14_n25: return 0.006223167758435011f;
  t14_n26: return 0.08124203234910965f;
  t14_n27: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t14_n47;
  t14_n28: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t14_n46;
  t14_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n35;
  t14_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n32;
  t14_n31: return 0.06993338465690613f;
  t14_n32: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t14_n34;
  t14_n33: return 0.10497727245092392f;
  t14_n34: return 0.11229278892278671f;
  t14_n35: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t14_n45;
  t14_n36: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t14_n38;
  t14_n37: return 0.0935264378786087f;
  t14_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n44;
  t14_n39: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t14_n41;
  t14_n40: return 0.11199841648340225f;
  t14_n41: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t14_n43;
  t14_n42: return 0.1196088045835495f;
  t14_n43: return 0.11882944405078888f;
  t14_n44: return 0.04071899503469467f;
  t14_n45: return 0.1190328374505043f;
  t14_n46: return -0.021808460354804993f;
  t14_n47: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t14_n61;
  t14_n48: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t14_n60;
  t14_n49: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t14_n59;
  t14_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t14_n56;
  t14_n51: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n53;
  t14_n52: return 0.07054976373910904f;
  t14_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t14_n55;
  t14_n54: return 0.10886835306882858f;
  t14_n55: return 0.10356344282627106f;
  t14_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t14_n58;
  t14_n57: return 0.07705479115247726f;
  t14_n58: return 0.1019461378455162f;
  t14_n59: return 0.01031743735074997f;
  t14_n60: return 0.10743779689073563f;
  t14_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t14_n63;
  t14_n62: return 0.09744227677583694f;
  t14_n63: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t14_n67;
  t14_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t14_n66;
  t14_n65: return 0.1048942357301712f;
  t14_n66: return 0.10727610439062119f;
  t14_n67: return 0.10024398565292358f;
  t14_n68: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t14_n142;
  t14_n69: if (E.getNumReferences() >= 3294633984 /*896.5*/) goto t14_n113;
  t14_n70: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t14_n82;
  t14_n71: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n79;
  t14_n72: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t14_n74;
  t14_n73: return 0.041878316551446915f;
  t14_n74: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n78;
  t14_n75: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t14_n77;
  t14_n76: return 0.054741375148296356f;
  t14_n77: return 0.08247809112071991f;
  t14_n78: return -0.00017354161536786705f;
  t14_n79: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t14_n81;
  t14_n80: return 0.11503197997808456f;
  t14_n81: return 0.11631883680820465f;
  t14_n82: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t14_n96;
  t14_n83: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t14_n85;
  t14_n84: return -0.056474316865205765f;
  t14_n85: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t14_n91;
  t14_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t14_n88;
  t14_n87: return -0.028664376586675644f;
  t14_n88: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n90;
  t14_n89: return 0.057680584490299225f;
  t14_n90: return 0.08783527463674545f;
  t14_n91: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n93;
  t14_n92: return 0.07568788528442383f;
  t14_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t14_n95;
  t14_n94: return 0.10817340016365051f;
  t14_n95: return 0.09564092755317688f;
  t14_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t14_n98;
  t14_n97: return 0.05566256120800972f;
  t14_n98: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t14_n106;
  t14_n99: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t14_n105;
  t14_n100: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t14_n102;
  t14_n101: return 0.0392170250415802f;
  t14_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t14_n104;
  t14_n103: return 0.09649576246738434f;
  t14_n104: return 0.11832375079393387f;
  t14_n105: return 0.09861258417367935f;
  t14_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t14_n108;
  t14_n107: return 0.15513412654399872f;
  t14_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n112;
  t14_n109: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n111;
  t14_n110: return 0.15510646998882294f;
  t14_n111: return 0.13178585469722748f;
  t14_n112: return 0.15143056213855743f;
  t14_n113: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t14_n135;
  t14_n114: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n134;
  t14_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t14_n123;
  t14_n116: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t14_n118;
  t14_n117: return 0.032777268439531326f;
  t14_n118: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t14_n122;
  t14_n119: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n121;
  t14_n120: return 0.12900102138519287f;
  t14_n121: return 0.12031852453947067f;
  t14_n122: return 0.11226537078619003f;
  t14_n123: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t14_n127;
  t14_n124: if (E.getNumReferences() >= 3294674944 /*899.0*/) goto t14_n126;
  t14_n125: return 0.14707466959953308f;
  t14_n126: return 0.10257268697023392f;
  t14_n127: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t14_n133;
  t14_n128: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t14_n130;
  t14_n129: return 0.11307501792907715f;
  t14_n130: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n132;
  t14_n131: return 0.13278938829898834f;
  t14_n132: return 0.11838682740926743f;
  t14_n133: return 0.09479658305644989f;
  t14_n134: return 0.11414322257041931f;
  t14_n135: if (E.getNumReferences() >= 3294699520 /*900.5*/) goto t14_n139;
  t14_n136: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t14_n138;
  t14_n137: return 0.12767460942268372f;
  t14_n138: return -0.1498386263847351f;
  t14_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t14_n141;
  t14_n140: return 0.08359793573617935f;
  t14_n141: return 0.09647728502750397f;
  t14_n142: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n190;
  t14_n143: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t14_n189;
  t14_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t14_n186;
  t14_n145: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n185;
  t14_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t14_n166;
  t14_n147: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t14_n151;
  t14_n148: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t14_n150;
  t14_n149: return 0.010868972167372704f;
  t14_n150: return 0.0832286924123764f;
  t14_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t14_n155;
  t14_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t14_n154;
  t14_n153: return -0.031010163947939873f;
  t14_n154: return 0.10228375345468521f;
  t14_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t14_n159;
  t14_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n158;
  t14_n157: return 0.14296415448188782f;
  t14_n158: return 0.13247358798980713f;
  t14_n159: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t14_n165;
  t14_n160: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n162;
  t14_n161: return 0.16496506333351135f;
  t14_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t14_n164;
  t14_n163: return 0.1408810168504715f;
  t14_n164: return 0.1453968584537506f;
  t14_n165: return 0.10052715241909027f;
  t14_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t14_n172;
  t14_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n169;
  t14_n168: return 0.08265627175569534f;
  t14_n169: if (E.getNumReferences() >= 3331838976 /*19434.0*/) goto t14_n171;
  t14_n170: return 0.10532116889953613f;
  t14_n171: return 0.11650216579437256f;
  t14_n172: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t14_n184;
  t14_n173: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t14_n175;
  t14_n174: return 0.10141593217849731f;
  t14_n175: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n181;
  t14_n176: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t14_n180;
  t14_n177: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t14_n179;
  t14_n178: return 0.22546294331550598f;
  t14_n179: return 0.1479322612285614f;
  t14_n180: return 0.09123296290636063f;
  t14_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n183;
  t14_n182: return 0.14474396407604218f;
  t14_n183: return 0.1029386967420578f;
  t14_n184: return 0.17527668178081512f;
  t14_n185: return 0.04543857276439667f;
  t14_n186: if (E.getNumReferences() >= 3339137920 /*34611.5*/) goto t14_n188;
  t14_n187: return 0.11094824224710464f;
  t14_n188: return 0.11925950646400452f;
  t14_n189: return -0.11490331590175629f;
  t14_n190: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t14_n196;
  t14_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n193;
  t14_n192: return 0.0878908559679985f;
  t14_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t14_n195;
  t14_n194: return 0.062295470386743546f;
  t14_n195: return 0.08339153230190277f;
  t14_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n200;
  t14_n197: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t14_n199;
  t14_n198: return 0.09901473671197891f;
  t14_n199: return 0.10573612153530121f;
  t14_n200: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t14_n204;
  t14_n201: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t14_n203;
  t14_n202: return 0.09179113805294037f;
  t14_n203: return 0.10441265255212784f;
  t14_n204: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t14_n206;
  t14_n205: return 0.1237359493970871f;
  t14_n206: return 0.10642862319946289f;
  t14_n207: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t14_n215;
  t14_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t14_n214;
  t14_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n211;
  t14_n210: return -0.03806758299469948f;
  t14_n211: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n213;
  t14_n212: return 0.08511682599782944f;
  t14_n213: return 0.0559593066573143f;
  t14_n214: return 0.09555428475141525f;
  t14_n215: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t14_n219;
  t14_n216: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t14_n218;
  t14_n217: return 0.1062157079577446f;
  t14_n218: return 0.10708757489919662f;
  t14_n219: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t14_n223;
  t14_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t14_n222;
  t14_n221: return 0.09477247297763824f;
  t14_n222: return 0.10529960691928864f;
  t14_n223: return 0.10482154786586761f;
  t14_n224: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n242;
  t14_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t14_n229;
  t14_n226: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n228;
  t14_n227: return 0.06545069813728333f;
  t14_n228: return 0.09558168798685074f;
  t14_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n239;
  t14_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n236;
  t14_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t14_n233;
  t14_n232: return 0.09244994074106216f;
  t14_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t14_n235;
  t14_n234: return 0.043373625725507736f;
  t14_n235: return 0.0989702120423317f;
  t14_n236: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t14_n238;
  t14_n237: return 0.10082586109638214f;
  t14_n238: return 0.09833516925573349f;
  t14_n239: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t14_n241;
  t14_n240: return 0.09305420517921448f;
  t14_n241: return 0.09628482908010483f;
  t14_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n252;
  t14_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t14_n247;
  t14_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t14_n246;
  t14_n245: return 0.06721276789903641f;
  t14_n246: return 0.10421966761350632f;
  t14_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n251;
  t14_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t14_n250;
  t14_n249: return 0.10197018831968307f;
  t14_n250: return 0.10692442953586578f;
  t14_n251: return 0.10801646113395691f;
  t14_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t14_n254;
  t14_n253: return 0.10688631236553192f;
  t14_n254: return 0.10538673400878906f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree15(const Example& E) {
  t15_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t15_n228;
  t15_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t15_n217;
  t15_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t15_n84;
  t15_n3: if (E.getNumReferences() >= 3279716352 /*252.5*/) goto t15_n21;
  t15_n4: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t15_n20;
  t15_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t15_n17;
  t15_n6: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t15_n8;
  t15_n7: return -0.07458433508872986f;
  t15_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t15_n10;
  t15_n9: return -0.04134067893028259f;
  t15_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t15_n16;
  t15_n11: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t15_n13;
  t15_n12: return 0.09624151140451431f;
  t15_n13: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t15_n15;
  t15_n14: return 0.15304921567440033f;
  t15_n15: return -0.27883991599082947f;
  t15_n16: return -0.0031900315079838037f;
  t15_n17: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t15_n19;
  t15_n18: return -0.062029335647821426f;
  t15_n19: return 0.04432067275047302f;
  t15_n20: return -0.08402161300182343f;
  t15_n21: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t15_n59;
  t15_n22: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n48;
  t15_n23: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t15_n33;
  t15_n24: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t15_n26;
  t15_n25: return -0.021411392837762833f;
  t15_n26: if (E.getNumReferences() >= 3319521280 /*7036.0*/) goto t15_n28;
  t15_n27: return 0.026076195761561394f;
  t15_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t15_n30;
  t15_n29: return 0.07508769631385803f;
  t15_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t15_n32;
  t15_n31: return 0.07091135531663895f;
  t15_n32: return 0.10107428580522537f;
  t15_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n39;
  t15_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t15_n36;
  t15_n35: return -0.008620675653219223f;
  t15_n36: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t15_n38;
  t15_n37: return 0.0641559436917305f;
  t15_n38: return 0.10113269835710526f;
  t15_n39: if (E.getNumReferences() >= 3334782720 /*25183.5*/) goto t15_n43;
  t15_n40: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t15_n42;
  t15_n41: return 0.06192973628640175f;
  t15_n42: return 0.09065695106983185f;
  t15_n43: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t15_n45;
  t15_n44: return 0.09432007372379303f;
  t15_n45: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t15_n47;
  t15_n46: return 0.09705395251512527f;
  t15_n47: return 0.07299456745386124f;
  t15_n48: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t15_n58;
  t15_n49: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t15_n51;
  t15_n50: return 0.06786078959703445f;
  t15_n51: if (E.getNumReferences() >= 3315311616 /*4980.5*/) goto t15_n53;
  t15_n52: return 0.10312062501907349f;
  t15_n53: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t15_n55;
  t15_n54: return 0.09036644548177719f;
  t15_n55: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t15_n57;
  t15_n56: return 0.11761315166950226f;
  t15_n57: return 0.06449182331562042f;
  t15_n58: return 0.09354879707098007f;
  t15_n59: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t15_n65;
  t15_n60: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t15_n64;
  t15_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t15_n63;
  t15_n62: return 0.1244569793343544f;
  t15_n63: return 0.13514560461044312f;
  t15_n64: return 0.08899008482694626f;
  t15_n65: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t15_n67;
  t15_n66: return 0.0953805148601532f;
  t15_n67: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n83;
  t15_n68: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t15_n72;
  t15_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t15_n71;
  t15_n70: return 0.10250407457351685f;
  t15_n71: return 0.11633191257715225f;
  t15_n72: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t15_n74;
  t15_n73: return 0.10359320789575577f;
  t15_n74: if (E.getNumReferences() >= 3333341184 /*22368.0*/) goto t15_n82;
  t15_n75: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t15_n77;
  t15_n76: return 0.1093168705701828f;
  t15_n77: if (E.getNumReferences() >= 3318611968 /*6592.0*/) goto t15_n79;
  t15_n78: return 0.11567235738039017f;
  t15_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t15_n81;
  t15_n80: return 0.11867634207010269f;
  t15_n81: return 0.12391141057014465f;
  t15_n82: return 0.0998341366648674f;
  t15_n83: return 0.11392863839864731f;
  t15_n84: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t15_n160;
  t15_n85: if (E.getNumReferences() >= 3294650368 /*897.5*/) goto t15_n127;
  t15_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t15_n104;
  t15_n87: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t15_n97;
  t15_n88: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n94;
  t15_n89: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t15_n91;
  t15_n90: return 0.026541123166680336f;
  t15_n91: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t15_n93;
  t15_n92: return 0.08519451320171356f;
  t15_n93: return 0.07003793120384216f;
  t15_n94: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t15_n96;
  t15_n95: return 0.11528033763170242f;
  t15_n96: return 0.11617103219032288f;
  t15_n97: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t15_n99;
  t15_n98: return -0.039221521466970444f;
  t15_n99: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t15_n103;
  t15_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t15_n102;
  t15_n101: return -0.031970977783203125f;
  t15_n102: return 0.062291473150253296f;
  t15_n103: return 0.07530064880847931f;
  t15_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t15_n106;
  t15_n105: return 0.056779421865940094f;
  t15_n106: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t15_n118;
  t15_n107: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t15_n117;
  t15_n108: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t15_n110;
  t15_n109: return 0.047768328338861465f;
  t15_n110: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t15_n114;
  t15_n111: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t15_n113;
  t15_n112: return 0.11203517764806747f;
  t15_n113: return 0.11764170974493027f;
  t15_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t15_n116;
  t15_n115: return 0.09224548190832138f;
  t15_n116: return 0.11508835107088089f;
  t15_n117: return 0.09530052542686462f;
  t15_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t15_n120;
  t15_n119: return 0.14231932163238525f;
  t15_n120: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t15_n126;
  t15_n121: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n125;
  t15_n122: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t15_n124;
  t15_n123: return 0.14959557354450226f;
  t15_n124: return 0.13104045391082764f;
  t15_n125: return 0.13465069234371185f;
  t15_n126: return 0.13280710577964783f;
  t15_n127: if (E.getNumReferences() >= 3294699520 /*900.5*/) goto t15_n133;
  t15_n128: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t15_n132;
  t15_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t15_n131;
  t15_n130: return 0.04015637934207916f;
  t15_n131: return 0.13871432840824127f;
  t15_n132: return 0.12287326157093048f;
  t15_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t15_n145;
  t15_n134: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t15_n144;
  t15_n135: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n143;
  t15_n136: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t15_n138;
  t15_n137: return 0.04201512783765793f;
  t15_n138: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t15_n142;
  t15_n139: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t15_n141;
  t15_n140: return 0.12524834275245667f;
  t15_n141: return 0.11688528954982758f;
  t15_n142: return 0.10865837335586548f;
  t15_n143: return 0.10800961405038834f;
  t15_n144: return 0.08658129721879959f;
  t15_n145: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t15_n155;
  t15_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t15_n150;
  t15_n147: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n149;
  t15_n148: return 0.07176510244607925f;
  t15_n149: return 0.11289148032665253f;
  t15_n150: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t15_n152;
  t15_n151: return 0.10112842172384262f;
  t15_n152: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t15_n154;
  t15_n153: return 0.13149258494377136f;
  t15_n154: return 0.10307790338993073f;
  t15_n155: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t15_n159;
  t15_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n158;
  t15_n157: return 0.12714722752571106f;
  t15_n158: return 0.11621872335672379f;
  t15_n159: return 0.09085364639759064f;
  t15_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n204;
  t15_n161: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t15_n203;
  t15_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t15_n178;
  t15_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t15_n167;
  t15_n164: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t15_n166;
  t15_n165: return 0.0795278325676918f;
  t15_n166: return 0.04169662296772003f;
  t15_n167: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t15_n177;
  t15_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t15_n170;
  t15_n169: return -0.12967337667942047f;
  t15_n170: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n172;
  t15_n171: return 0.10328757762908936f;
  t15_n172: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t15_n174;
  t15_n173: return 0.08037953823804855f;
  t15_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t15_n176;
  t15_n175: return 0.10772444307804108f;
  t15_n176: return 0.12282005697488785f;
  t15_n177: return -0.10292021185159683f;
  t15_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t15_n184;
  t15_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t15_n181;
  t15_n180: return 0.0784236341714859f;
  t15_n181: if (E.getNumReferences() >= 3339137920 /*34611.5*/) goto t15_n183;
  t15_n182: return 0.10603485256433487f;
  t15_n183: return 0.11721882224082947f;
  t15_n184: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t15_n202;
  t15_n185: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t15_n199;
  t15_n186: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t15_n188;
  t15_n187: return 0.06906413286924362f;
  t15_n188: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t15_n198;
  t15_n189: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t15_n195;
  t15_n190: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t15_n194;
  t15_n191: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t15_n193;
  t15_n192: return 0.22579325735569f;
  t15_n193: return 0.1680600941181183f;
  t15_n194: return 0.07476432621479034f;
  t15_n195: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t15_n197;
  t15_n196: return 0.11612097173929214f;
  t15_n197: return 0.13787171244621277f;
  t15_n198: return 0.10028191655874252f;
  t15_n199: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n201;
  t15_n200: return 0.1480880081653595f;
  t15_n201: return 0.14342980086803436f;
  t15_n202: return 0.053090911358594894f;
  t15_n203: return -0.09975038468837738f;
  t15_n204: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t15_n208;
  t15_n205: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n207;
  t15_n206: return 0.08228632062673569f;
  t15_n207: return 0.067634217441082f;
  t15_n208: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t15_n210;
  t15_n209: return 0.09731446206569672f;
  t15_n210: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t15_n214;
  t15_n211: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t15_n213;
  t15_n212: return 0.08946286141872406f;
  t15_n213: return 0.10296697169542313f;
  t15_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t15_n216;
  t15_n215: return 0.11929710954427719f;
  t15_n216: return 0.041948575526475906f;
  t15_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t15_n223;
  t15_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t15_n222;
  t15_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t15_n221;
  t15_n220: return -0.045569390058517456f;
  t15_n221: return 0.0759270116686821f;
  t15_n222: return 0.09310828149318695f;
  t15_n223: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t15_n225;
  t15_n224: return 0.1060977578163147f;
  t15_n225: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t15_n227;
  t15_n226: return 0.09761158376932144f;
  t15_n227: return 0.10398033261299133f;
  t15_n228: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n242;
  t15_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t15_n233;
  t15_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t15_n232;
  t15_n231: return 0.06207228824496269f;
  t15_n232: return 0.09303316473960876f;
  t15_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t15_n241;
  t15_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n238;
  t15_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t15_n237;
  t15_n236: return 0.09035370498895645f;
  t15_n237: return 0.09734134376049042f;
  t15_n238: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t15_n240;
  t15_n239: return 0.09940025955438614f;
  t15_n240: return 0.09682422876358032f;
  t15_n241: return 0.09091218560934067f;
  t15_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n252;
  t15_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t15_n247;
  t15_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t15_n246;
  t15_n245: return 0.054816555231809616f;
  t15_n246: return 0.10320450365543365f;
  t15_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t15_n251;
  t15_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t15_n250;
  t15_n249: return 0.10045668482780457f;
  t15_n250: return 0.10608786344528198f;
  t15_n251: return 0.10709629952907562f;
  t15_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t15_n254;
  t15_n253: return 0.10621697455644608f;
  t15_n254: return 0.10474418103694916f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree16(const Example& E) {
  t16_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t16_n228;
  t16_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t16_n217;
  t16_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t16_n70;
  t16_n3: if (E.getNumReferences() >= 3300909056 /*1535.0*/) goto t16_n21;
  t16_n4: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t16_n6;
  t16_n5: return -0.043929323554039f;
  t16_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Namespace))) goto t16_n12;
  t16_n7: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t16_n9;
  t16_n8: return -0.09273163974285126f;
  t16_n9: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t16_n11;
  t16_n10: return 0.028328407555818558f;
  t16_n11: return 0.07855052500963211f;
  t16_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t16_n14;
  t16_n13: return 0.0007161966641433537f;
  t16_n14: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t16_n16;
  t16_n15: return 0.10158178210258484f;
  t16_n16: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t16_n20;
  t16_n17: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t16_n19;
  t16_n18: return 0.1063777431845665f;
  t16_n19: return 0.06857730448246002f;
  t16_n20: return 0.008727574720978737f;
  t16_n21: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t16_n41;
  t16_n22: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n36;
  t16_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t16_n33;
  t16_n24: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t16_n26;
  t16_n25: return -0.02228308469057083f;
  t16_n26: if (E.getNumReferences() >= 3348207616 /*74544.0*/) goto t16_n28;
  t16_n27: return 0.04870791360735893f;
  t16_n28: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t16_n32;
  t16_n29: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t16_n31;
  t16_n30: return 0.08010875433683395f;
  t16_n31: return 0.10440400242805481f;
  t16_n32: return 0.10382455587387085f;
  t16_n33: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t16_n35;
  t16_n34: return 0.06288570165634155f;
  t16_n35: return 0.10472723841667175f;
  t16_n36: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t16_n38;
  t16_n37: return 0.07088177651166916f;
  t16_n38: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t16_n40;
  t16_n39: return 0.11090930551290512f;
  t16_n40: return -0.2111329436302185f;
  t16_n41: if (E.getNumReferences() >= 3319640064 /*7094.0*/) goto t16_n45;
  t16_n42: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t16_n44;
  t16_n43: return 0.06373985856771469f;
  t16_n44: return 0.0994240939617157f;
  t16_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t16_n59;
  t16_n46: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n52;
  t16_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t16_n49;
  t16_n48: return 0.03422550857067108f;
  t16_n49: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t16_n51;
  t16_n50: return 0.0806569829583168f;
  t16_n51: return 0.09992627799510956f;
  t16_n52: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t16_n54;
  t16_n53: return 0.08890819549560547f;
  t16_n54: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t16_n58;
  t16_n55: if (E.getNumReferences() >= 3327475712 /*13648.0*/) goto t16_n57;
  t16_n56: return 0.11793233454227448f;
  t16_n57: return 0.12080693244934082f;
  t16_n58: return 0.09929011017084122f;
  t16_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t16_n67;
  t16_n60: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t16_n62;
  t16_n61: return 0.07834476232528687f;
  t16_n62: if (E.getNumReferences() >= 3327415808 /*13589.5*/) goto t16_n66;
  t16_n63: if (E.getNumReferences() >= 3322781184 /*9063.5*/) goto t16_n65;
  t16_n64: return 0.10801836103200912f;
  t16_n65: return 0.1157984659075737f;
  t16_n66: return 0.09731516987085342f;
  t16_n67: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t16_n69;
  t16_n68: return 0.11619309335947037f;
  t16_n69: return 0.0995875671505928f;
  t16_n70: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t16_n158;
  t16_n71: if (E.getNumReferences() >= 3309346816 /*3082.0*/) goto t16_n129;
  t16_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t16_n112;
  t16_n73: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t16_n87;
  t16_n74: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n84;
  t16_n75: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t16_n77;
  t16_n76: return 0.024889592081308365f;
  t16_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t16_n79;
  t16_n78: return 0.05580703541636467f;
  t16_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t16_n81;
  t16_n80: return 0.07858147472143173f;
  t16_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t16_n83;
  t16_n82: return -0.1785253882408142f;
  t16_n83: return 0.11416144669055939f;
  t16_n84: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t16_n86;
  t16_n85: return 0.11276564002037048f;
  t16_n86: return 0.11254443228244781f;
  t16_n87: if (E.getNumReferences() >= 3272572928 /*143.5*/) goto t16_n103;
  t16_n88: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t16_n90;
  t16_n89: return -0.04636048525571823f;
  t16_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t16_n98;
  t16_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t16_n95;
  t16_n92: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t16_n94;
  t16_n93: return 0.0710248276591301f;
  t16_n94: return -0.03881388157606125f;
  t16_n95: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n97;
  t16_n96: return 0.0563608855009079f;
  t16_n97: return 0.08645347505807877f;
  t16_n98: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t16_n102;
  t16_n99: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n101;
  t16_n100: return 0.10133069008588791f;
  t16_n101: return 0.08640710264444351f;
  t16_n102: return -0.14164914190769196f;
  t16_n103: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t16_n107;
  t16_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t16_n106;
  t16_n105: return 0.059307169169187546f;
  t16_n106: return 0.12383387237787247f;
  t16_n107: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t16_n111;
  t16_n108: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t16_n110;
  t16_n109: return -0.0013380198506638408f;
  t16_n110: return 0.12643349170684814f;
  t16_n111: return 0.08656224608421326f;
  t16_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t16_n114;
  t16_n113: return 0.05504552274942398f;
  t16_n114: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t16_n120;
  t16_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t16_n119;
  t16_n116: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t16_n118;
  t16_n117: return 0.08587725460529327f;
  t16_n118: return 0.10082904249429703f;
  t16_n119: return 0.06621867418289185f;
  t16_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t16_n122;
  t16_n121: return 0.13331453502178192f;
  t16_n122: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t16_n128;
  t16_n123: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t16_n127;
  t16_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n126;
  t16_n125: return 0.14027516543865204f;
  t16_n126: return 0.1255120187997818f;
  t16_n127: return 0.12824268639087677f;
  t16_n128: return 0.12083341181278229f;
  t16_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t16_n139;
  t16_n130: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t16_n138;
  t16_n131: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n135;
  t16_n132: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t16_n134;
  t16_n133: return 0.048773907124996185f;
  t16_n134: return 0.10442424565553665f;
  t16_n135: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t16_n137;
  t16_n136: return 0.0969642847776413f;
  t16_n137: return 0.11296811699867249f;
  t16_n138: return 0.0847570151090622f;
  t16_n139: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t16_n153;
  t16_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t16_n144;
  t16_n141: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n143;
  t16_n142: return 0.07069218903779984f;
  t16_n143: return 0.11203036457300186f;
  t16_n144: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t16_n146;
  t16_n145: return 0.10042542964220047f;
  t16_n146: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t16_n152;
  t16_n147: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t16_n149;
  t16_n148: return 0.12134648859500885f;
  t16_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t16_n151;
  t16_n150: return 0.12979531288146973f;
  t16_n151: return 0.14782629907131195f;
  t16_n152: return 0.10206875205039978f;
  t16_n153: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t16_n157;
  t16_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t16_n156;
  t16_n155: return 0.12317453324794769f;
  t16_n156: return 0.1148969978094101f;
  t16_n157: return 0.09143218398094177f;
  t16_n158: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n202;
  t16_n159: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t16_n201;
  t16_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t16_n178;
  t16_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t16_n165;
  t16_n162: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t16_n164;
  t16_n163: return 0.07359911501407623f;
  t16_n164: return 0.03329899534583092f;
  t16_n165: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t16_n177;
  t16_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t16_n168;
  t16_n167: return -0.12478349357843399f;
  t16_n168: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n172;
  t16_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t16_n171;
  t16_n170: return 0.08454003185033798f;
  t16_n171: return 0.10709602385759354f;
  t16_n172: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t16_n174;
  t16_n173: return 0.08232142776250839f;
  t16_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t16_n176;
  t16_n175: return 0.10346034914255142f;
  t16_n176: return 0.11907084286212921f;
  t16_n177: return -0.10573814064264297f;
  t16_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t16_n184;
  t16_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t16_n181;
  t16_n180: return 0.07726706564426422f;
  t16_n181: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t16_n183;
  t16_n182: return 0.10256966948509216f;
  t16_n183: return 0.11552521586418152f;
  t16_n184: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t16_n200;
  t16_n185: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n197;
  t16_n186: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t16_n188;
  t16_n187: return 0.06320499628782272f;
  t16_n188: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t16_n196;
  t16_n189: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t16_n193;
  t16_n190: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t16_n192;
  t16_n191: return 0.15254457294940948f;
  t16_n192: return -0.002879087347537279f;
  t16_n193: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t16_n195;
  t16_n194: return 0.11371646821498871f;
  t16_n195: return 0.13025428354740143f;
  t16_n196: return 0.09082522988319397f;
  t16_n197: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t16_n199;
  t16_n198: return 0.14040787518024445f;
  t16_n199: return 0.13862812519073486f;
  t16_n200: return 0.08857335895299911f;
  t16_n201: return -0.10377553105354309f;
  t16_n202: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t16_n208;
  t16_n203: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n205;
  t16_n204: return 0.08248725533485413f;
  t16_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t16_n207;
  t16_n206: return 0.058404356241226196f;
  t16_n207: return 0.07972630858421326f;
  t16_n208: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n210;
  t16_n209: return 0.0955289974808693f;
  t16_n210: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t16_n214;
  t16_n211: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t16_n213;
  t16_n212: return 0.08647239953279495f;
  t16_n213: return 0.10172007232904434f;
  t16_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t16_n216;
  t16_n215: return 0.11803045123815536f;
  t16_n216: return 0.04968561604619026f;
  t16_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t16_n223;
  t16_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t16_n222;
  t16_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n221;
  t16_n220: return -0.03693278133869171f;
  t16_n221: return 0.0723537802696228f;
  t16_n222: return 0.09089160710573196f;
  t16_n223: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t16_n225;
  t16_n224: return 0.10584483295679092f;
  t16_n225: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t16_n227;
  t16_n226: return 0.0960618257522583f;
  t16_n227: return 0.10348790884017944f;
  t16_n228: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n242;
  t16_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t16_n233;
  t16_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n232;
  t16_n231: return 0.05729282274842262f;
  t16_n232: return 0.09074150025844574f;
  t16_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t16_n241;
  t16_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t16_n238;
  t16_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t16_n237;
  t16_n236: return 0.08725550025701523f;
  t16_n237: return 0.09516587108373642f;
  t16_n238: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t16_n240;
  t16_n239: return 0.09806624054908752f;
  t16_n240: return 0.09555763751268387f;
  t16_n241: return 0.08863522857427597f;
  t16_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t16_n252;
  t16_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t16_n247;
  t16_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t16_n246;
  t16_n245: return 0.055783480405807495f;
  t16_n246: return 0.10188669711351395f;
  t16_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n251;
  t16_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t16_n250;
  t16_n249: return 0.0962231382727623f;
  t16_n250: return 0.10527244955301285f;
  t16_n251: return 0.10628551244735718f;
  t16_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t16_n254;
  t16_n253: return 0.10557590425014496f;
  t16_n254: return 0.10425006598234177f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree17(const Example& E) {
  t17_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t17_n228;
  t17_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t17_n217;
  t17_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t17_n88;
  t17_n3: if (E.getNumReferences() >= 3279716352 /*252.5*/) goto t17_n47;
  t17_n4: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t17_n46;
  t17_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t17_n19;
  t17_n6: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t17_n8;
  t17_n7: return -0.06787480413913727f;
  t17_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t17_n10;
  t17_n9: return -0.03842611983418465f;
  t17_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t17_n18;
  t17_n11: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t17_n13;
  t17_n12: return 0.09285801649093628f;
  t17_n13: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n17;
  t17_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n16;
  t17_n15: return 0.14105795323848724f;
  t17_n16: return 0.14125332236289978f;
  t17_n17: return -0.2505941689014435f;
  t17_n18: return -0.026135042309761047f;
  t17_n19: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t17_n21;
  t17_n20: return -0.05627795681357384f;
  t17_n21: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t17_n35;
  t17_n22: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t17_n24;
  t17_n23: return 0.015537355095148087f;
  t17_n24: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t17_n28;
  t17_n25: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t17_n27;
  t17_n26: return 0.1279165893793106f;
  t17_n27: return 0.10089468955993652f;
  t17_n28: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t17_n32;
  t17_n29: if (E.getFileProximityDistance() >= 3250585600 /*24.0*/) goto t17_n31;
  t17_n30: return 0.14877505600452423f;
  t17_n31: return 0.182429239153862f;
  t17_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t17_n34;
  t17_n33: return 0.15457843244075775f;
  t17_n34: return 0.17129990458488464f;
  t17_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t17_n39;
  t17_n36: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t17_n38;
  t17_n37: return 0.0825614184141159f;
  t17_n38: return 0.09762369096279144f;
  t17_n39: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t17_n43;
  t17_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t17_n42;
  t17_n41: return 0.10442540049552917f;
  t17_n42: return 0.13090397417545319f;
  t17_n43: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n45;
  t17_n44: return 0.1337658017873764f;
  t17_n45: return 0.09161185473203659f;
  t17_n46: return -0.07933938503265381f;
  t17_n47: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t17_n79;
  t17_n48: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t17_n72;
  t17_n49: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t17_n61;
  t17_n50: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t17_n52;
  t17_n51: return -0.018528640270233154f;
  t17_n52: if (E.getNumReferences() >= 3319521280 /*7036.0*/) goto t17_n54;
  t17_n53: return 0.02609597146511078f;
  t17_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t17_n56;
  t17_n55: return 0.06462936848402023f;
  t17_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t17_n58;
  t17_n57: return 0.0656939223408699f;
  t17_n58: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t17_n60;
  t17_n59: return 0.12124847620725632f;
  t17_n60: return 0.09469275921583176f;
  t17_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n67;
  t17_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t17_n64;
  t17_n63: return -0.008768279105424881f;
  t17_n64: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t17_n66;
  t17_n65: return 0.05919089540839195f;
  t17_n66: return 0.09722638130187988f;
  t17_n67: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t17_n71;
  t17_n68: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n70;
  t17_n69: return 0.05464703217148781f;
  t17_n70: return 0.08652553707361221f;
  t17_n71: return 0.09203411638736725f;
  t17_n72: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t17_n76;
  t17_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t17_n75;
  t17_n74: return 0.06570228189229965f;
  t17_n75: return 0.09944029897451401f;
  t17_n76: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t17_n78;
  t17_n77: return 0.11068416386842728f;
  t17_n78: return -0.17918407917022705f;
  t17_n79: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t17_n85;
  t17_n80: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t17_n84;
  t17_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t17_n83;
  t17_n82: return 0.12240880727767944f;
  t17_n83: return 0.1290513426065445f;
  t17_n84: return 0.08224137872457504f;
  t17_n85: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t17_n87;
  t17_n86: return 0.08909645676612854f;
  t17_n87: return 0.10119274258613586f;
  t17_n88: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t17_n160;
  t17_n89: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t17_n137;
  t17_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t17_n122;
  t17_n91: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t17_n101;
  t17_n92: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t17_n98;
  t17_n93: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t17_n95;
  t17_n94: return 0.02417825721204281f;
  t17_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n97;
  t17_n96: return 0.05332084000110626f;
  t17_n97: return 0.08163303881883621f;
  t17_n98: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t17_n100;
  t17_n99: return 0.10607292503118515f;
  t17_n100: return 0.10990169644355774f;
  t17_n101: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t17_n115;
  t17_n102: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n104;
  t17_n103: return -0.041936542838811874f;
  t17_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t17_n110;
  t17_n105: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t17_n109;
  t17_n106: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t17_n108;
  t17_n107: return 0.07018512487411499f;
  t17_n108: return -0.034712836146354675f;
  t17_n109: return 0.056493062525987625f;
  t17_n110: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t17_n114;
  t17_n111: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n113;
  t17_n112: return 0.10033517330884933f;
  t17_n113: return 0.08163676410913467f;
  t17_n114: return -0.136590376496315f;
  t17_n115: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t17_n119;
  t17_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t17_n118;
  t17_n117: return 0.05833333358168602f;
  t17_n118: return 0.12094241380691528f;
  t17_n119: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t17_n121;
  t17_n120: return 0.01438909862190485f;
  t17_n121: return 0.08385226875543594f;
  t17_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t17_n124;
  t17_n123: return 0.05516565591096878f;
  t17_n124: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t17_n128;
  t17_n125: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t17_n127;
  t17_n126: return 0.09097940474748611f;
  t17_n127: return 0.06105718016624451f;
  t17_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t17_n130;
  t17_n129: return 0.1282411366701126f;
  t17_n130: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t17_n136;
  t17_n131: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n135;
  t17_n132: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n134;
  t17_n133: return 0.13311508297920227f;
  t17_n134: return 0.1211174875497818f;
  t17_n135: return 0.12262964248657227f;
  t17_n136: return 0.11157940328121185f;
  t17_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t17_n143;
  t17_n138: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t17_n142;
  t17_n139: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t17_n141;
  t17_n140: return 0.05048526078462601f;
  t17_n141: return 0.10129130631685257f;
  t17_n142: return 0.08184551447629929f;
  t17_n143: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t17_n155;
  t17_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t17_n146;
  t17_n145: return 0.08177092671394348f;
  t17_n146: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t17_n148;
  t17_n147: return 0.09712732583284378f;
  t17_n148: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t17_n154;
  t17_n149: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t17_n151;
  t17_n150: return 0.11772455275058746f;
  t17_n151: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t17_n153;
  t17_n152: return 0.14221228659152985f;
  t17_n153: return 0.12598338723182678f;
  t17_n154: return 0.09818112850189209f;
  t17_n155: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t17_n159;
  t17_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n158;
  t17_n157: return 0.12061285227537155f;
  t17_n158: return 0.11395056545734406f;
  t17_n159: return 0.08513856679201126f;
  t17_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t17_n202;
  t17_n161: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t17_n201;
  t17_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t17_n180;
  t17_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t17_n167;
  t17_n164: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t17_n166;
  t17_n165: return 0.06873799115419388f;
  t17_n166: return 0.03750455752015114f;
  t17_n167: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t17_n179;
  t17_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t17_n170;
  t17_n169: return -0.12246974557638168f;
  t17_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n172;
  t17_n171: return 0.09909835457801819f;
  t17_n172: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t17_n174;
  t17_n173: return 0.07550685852766037f;
  t17_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t17_n176;
  t17_n175: return 0.09904054552316666f;
  t17_n176: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n178;
  t17_n177: return 0.1298241913318634f;
  t17_n178: return 0.08444047719240189f;
  t17_n179: return -0.09726324677467346f;
  t17_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t17_n186;
  t17_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t17_n183;
  t17_n182: return 0.07223202288150787f;
  t17_n183: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t17_n185;
  t17_n184: return 0.09915608167648315f;
  t17_n185: return 0.11330397427082062f;
  t17_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t17_n200;
  t17_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n197;
  t17_n188: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t17_n190;
  t17_n189: return 0.0651857778429985f;
  t17_n190: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n196;
  t17_n191: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t17_n195;
  t17_n192: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t17_n194;
  t17_n193: return 0.14082995057106018f;
  t17_n194: return 0.013792723417282104f;
  t17_n195: return 0.12390189617872238f;
  t17_n196: return -0.03255408629775047f;
  t17_n197: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n199;
  t17_n198: return 0.13222751021385193f;
  t17_n199: return 0.13261456787586212f;
  t17_n200: return 0.07889794558286667f;
  t17_n201: return -0.10021496564149857f;
  t17_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t17_n206;
  t17_n203: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n205;
  t17_n204: return 0.07535311579704285f;
  t17_n205: return 0.04875481501221657f;
  t17_n206: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n210;
  t17_n207: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n209;
  t17_n208: return 0.07523921132087708f;
  t17_n209: return 0.09300398826599121f;
  t17_n210: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t17_n212;
  t17_n211: return 0.08492173999547958f;
  t17_n212: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n214;
  t17_n213: return -0.14231549203395844f;
  t17_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t17_n216;
  t17_n215: return 0.11559645086526871f;
  t17_n216: return 0.14281749725341797f;
  t17_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t17_n223;
  t17_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t17_n222;
  t17_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n221;
  t17_n220: return -0.02713131345808506f;
  t17_n221: return 0.06851441413164139f;
  t17_n222: return 0.08798515796661377f;
  t17_n223: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t17_n225;
  t17_n224: return 0.10569102317094803f;
  t17_n225: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t17_n227;
  t17_n226: return 0.09465999901294708f;
  t17_n227: return 0.10293618589639664f;
  t17_n228: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t17_n242;
  t17_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t17_n233;
  t17_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n232;
  t17_n231: return 0.05342940241098404f;
  t17_n232: return 0.08826317638158798f;
  t17_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t17_n241;
  t17_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n238;
  t17_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t17_n237;
  t17_n236: return 0.08446567505598068f;
  t17_n237: return 0.09334573894739151f;
  t17_n238: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t17_n240;
  t17_n239: return 0.09667423367500305f;
  t17_n240: return 0.09423716366291046f;
  t17_n241: return 0.08592279255390167f;
  t17_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n252;
  t17_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t17_n247;
  t17_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t17_n246;
  t17_n245: return 0.04786746948957443f;
  t17_n246: return 0.10083850473165512f;
  t17_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n251;
  t17_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t17_n250;
  t17_n249: return 0.0966801866889f;
  t17_n250: return 0.10472741723060608f;
  t17_n251: return 0.10577129572629929f;
  t17_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t17_n254;
  t17_n253: return 0.10493633896112442f;
  t17_n254: return 0.10368882864713669f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree18(const Example& E) {
  t18_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t18_n228;
  t18_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t18_n217;
  t18_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t18_n60;
  t18_n3: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t18_n23;
  t18_n4: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n8;
  t18_n5: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t18_n7;
  t18_n6: return -0.03803091496229172f;
  t18_n7: return -0.08662264794111252f;
  t18_n8: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t18_n22;
  t18_n9: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t18_n11;
  t18_n10: return 0.022465188056230545f;
  t18_n11: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t18_n13;
  t18_n12: return 0.061006393283605576f;
  t18_n13: if (E.getNumReferences() >= 3315736576 /*5188.0*/) goto t18_n15;
  t18_n14: return 0.09767300635576248f;
  t18_n15: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t18_n17;
  t18_n16: return 0.08664707839488983f;
  t18_n17: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t18_n21;
  t18_n18: if (E.getNumReferences() >= 3327475712 /*13648.0*/) goto t18_n20;
  t18_n19: return 0.11171255260705948f;
  t18_n20: return 0.11498711258172989f;
  t18_n21: return 0.09264931082725525f;
  t18_n22: return 0.06929314136505127f;
  t18_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t18_n43;
  t18_n24: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t18_n42;
  t18_n25: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n31;
  t18_n26: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n28;
  t18_n27: return 0.061326105147600174f;
  t18_n28: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t18_n30;
  t18_n29: return 0.08974531292915344f;
  t18_n30: return 0.10931236296892166f;
  t18_n31: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t18_n41;
  t18_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t18_n34;
  t18_n33: return 0.08861710876226425f;
  t18_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t18_n40;
  t18_n35: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t18_n37;
  t18_n36: return 0.10791963338851929f;
  t18_n37: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t18_n39;
  t18_n38: return 0.11500661820173264f;
  t18_n39: return 0.1137288361787796f;
  t18_n40: return 0.014876269735395908f;
  t18_n41: return 0.11480008065700531f;
  t18_n42: return -0.009165040217339993f;
  t18_n43: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t18_n55;
  t18_n44: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t18_n54;
  t18_n45: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t18_n53;
  t18_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t18_n50;
  t18_n47: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n49;
  t18_n48: return 0.05827334150671959f;
  t18_n49: return 0.10216585546731949f;
  t18_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t18_n52;
  t18_n51: return 0.05992761254310608f;
  t18_n52: return 0.09629028290510178f;
  t18_n53: return -0.031178178265690804f;
  t18_n54: return 0.10238134115934372f;
  t18_n55: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t18_n57;
  t18_n56: return 0.08781755715608597f;
  t18_n57: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t18_n59;
  t18_n58: return 0.10405620187520981f;
  t18_n59: return 0.09232895076274872f;
  t18_n60: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t18_n150;
  t18_n61: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t18_n123;
  t18_n62: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t18_n104;
  t18_n63: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t18_n83;
  t18_n64: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n74;
  t18_n65: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t18_n67;
  t18_n66: return 0.023334631696343422f;
  t18_n67: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n69;
  t18_n68: return 0.05092048645019531f;
  t18_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t18_n71;
  t18_n70: return 0.07206263393163681f;
  t18_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t18_n73;
  t18_n72: return -0.15889109671115875f;
  t18_n73: return 0.10672829300165176f;
  t18_n74: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t18_n76;
  t18_n75: return 0.10215650498867035f;
  t18_n76: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t18_n78;
  t18_n77: return 0.10608422756195068f;
  t18_n78: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t18_n82;
  t18_n79: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t18_n81;
  t18_n80: return 0.10052814334630966f;
  t18_n81: return 0.1295863389968872f;
  t18_n82: return 0.13220137357711792f;
  t18_n83: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t18_n97;
  t18_n84: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t18_n86;
  t18_n85: return -0.03705385699868202f;
  t18_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t18_n92;
  t18_n87: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t18_n91;
  t18_n88: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t18_n90;
  t18_n89: return 0.06619735807180405f;
  t18_n90: return -0.031808000057935715f;
  t18_n91: return 0.052962902933359146f;
  t18_n92: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t18_n96;
  t18_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n95;
  t18_n94: return 0.09777562320232391f;
  t18_n95: return 0.07867398113012314f;
  t18_n96: return -0.1382952630519867f;
  t18_n97: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t18_n101;
  t18_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t18_n100;
  t18_n99: return 0.05073346197605133f;
  t18_n100: return 0.11376345902681351f;
  t18_n101: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t18_n103;
  t18_n102: return 0.01571480557322502f;
  t18_n103: return 0.07981503754854202f;
  t18_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t18_n106;
  t18_n105: return 0.0513591468334198f;
  t18_n106: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t18_n114;
  t18_n107: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t18_n113;
  t18_n108: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t18_n110;
  t18_n109: return 0.03025796264410019f;
  t18_n110: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t18_n112;
  t18_n111: return 0.10855968296527863f;
  t18_n112: return 0.08532002568244934f;
  t18_n113: return 0.08892448246479034f;
  t18_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t18_n116;
  t18_n115: return 0.12145376205444336f;
  t18_n116: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t18_n122;
  t18_n117: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n121;
  t18_n118: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n120;
  t18_n119: return 0.1279468685388565f;
  t18_n120: return 0.11745796352624893f;
  t18_n121: return 0.1183212623000145f;
  t18_n122: return 0.10509228706359863f;
  t18_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t18_n131;
  t18_n124: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t18_n130;
  t18_n125: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t18_n129;
  t18_n126: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n128;
  t18_n127: return 0.048397619277238846f;
  t18_n128: return 0.09608625620603561f;
  t18_n129: return 0.102444589138031f;
  t18_n130: return 0.07770359516143799f;
  t18_n131: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t18_n145;
  t18_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t18_n136;
  t18_n133: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n135;
  t18_n134: return 0.06462275236845016f;
  t18_n135: return 0.10810758918523788f;
  t18_n136: if (E.getNumReferences() >= 3330029056 /*16141.5*/) goto t18_n138;
  t18_n137: return 0.09431582689285278f;
  t18_n138: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t18_n144;
  t18_n139: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t18_n141;
  t18_n140: return 0.1155514121055603f;
  t18_n141: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t18_n143;
  t18_n142: return 0.13791756331920624f;
  t18_n143: return 0.12707430124282837f;
  t18_n144: return 0.09594082832336426f;
  t18_n145: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t18_n149;
  t18_n146: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n148;
  t18_n147: return 0.11833721399307251f;
  t18_n148: return 0.11315073072910309f;
  t18_n149: return 0.08777209371328354f;
  t18_n150: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n208;
  t18_n151: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t18_n207;
  t18_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t18_n186;
  t18_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t18_n175;
  t18_n154: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t18_n156;
  t18_n155: return -0.1280006617307663f;
  t18_n156: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t18_n166;
  t18_n157: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t18_n161;
  t18_n158: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t18_n160;
  t18_n159: return -0.10116294771432877f;
  t18_n160: return 0.07306891679763794f;
  t18_n161: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t18_n165;
  t18_n162: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t18_n164;
  t18_n163: return 0.07848112285137177f;
  t18_n164: return -0.0038332385011017323f;
  t18_n165: return -0.11432473361492157f;
  t18_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t18_n168;
  t18_n167: return 0.03591925650835037f;
  t18_n168: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t18_n170;
  t18_n169: return 0.06743372231721878f;
  t18_n170: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t18_n174;
  t18_n171: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n173;
  t18_n172: return 0.0939590260386467f;
  t18_n173: return 0.07263316214084625f;
  t18_n174: return 0.061751510947942734f;
  t18_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t18_n177;
  t18_n176: return -0.11985090374946594f;
  t18_n177: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t18_n181;
  t18_n178: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t18_n180;
  t18_n179: return -0.026014555245637894f;
  t18_n180: return 0.08121920377016068f;
  t18_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t18_n185;
  t18_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n184;
  t18_n183: return 0.06476835161447525f;
  t18_n184: return 0.09653657674789429f;
  t18_n185: return 0.11034319549798965f;
  t18_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t18_n192;
  t18_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t18_n189;
  t18_n188: return 0.07056497037410736f;
  t18_n189: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t18_n191;
  t18_n190: return 0.09449733048677444f;
  t18_n191: return 0.11170969158411026f;
  t18_n192: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t18_n206;
  t18_n193: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n203;
  t18_n194: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t18_n196;
  t18_n195: return 0.06062910333275795f;
  t18_n196: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t18_n202;
  t18_n197: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t18_n201;
  t18_n198: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t18_n200;
  t18_n199: return 0.13280948996543884f;
  t18_n200: return -0.0013354640686884522f;
  t18_n201: return 0.11910200864076614f;
  t18_n202: return 0.08783616125583649f;
  t18_n203: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n205;
  t18_n204: return 0.12478920817375183f;
  t18_n205: return 0.1304868459701538f;
  t18_n206: return 0.07490529865026474f;
  t18_n207: return -0.10004983097314835f;
  t18_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t18_n210;
  t18_n209: return 0.06536269187927246f;
  t18_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n212;
  t18_n211: return 0.09105654805898666f;
  t18_n212: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t18_n214;
  t18_n213: return 0.08305097371339798f;
  t18_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t18_n216;
  t18_n215: return 0.11410412192344666f;
  t18_n216: return 0.049583010375499725f;
  t18_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t18_n223;
  t18_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t18_n222;
  t18_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n221;
  t18_n220: return -0.01864858716726303f;
  t18_n221: return 0.06425798684358597f;
  t18_n222: return 0.0859752967953682f;
  t18_n223: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t18_n225;
  t18_n224: return 0.10560378432273865f;
  t18_n225: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t18_n227;
  t18_n226: return 0.09313683211803436f;
  t18_n227: return 0.10257557779550552f;
  t18_n228: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n242;
  t18_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t18_n233;
  t18_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n232;
  t18_n231: return 0.05070669203996658f;
  t18_n232: return 0.08495151251554489f;
  t18_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t18_n241;
  t18_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n238;
  t18_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t18_n237;
  t18_n236: return 0.08133240044116974f;
  t18_n237: return 0.09119682013988495f;
  t18_n238: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t18_n240;
  t18_n239: return 0.0952216312289238f;
  t18_n240: return 0.0897068977355957f;
  t18_n241: return 0.08311630040407181f;
  t18_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n252;
  t18_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t18_n247;
  t18_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t18_n246;
  t18_n245: return 0.04281450808048248f;
  t18_n246: return 0.0992877408862114f;
  t18_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n251;
  t18_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t18_n250;
  t18_n249: return 0.09296120703220367f;
  t18_n250: return 0.10396013408899307f;
  t18_n251: return 0.10521509498357773f;
  t18_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t18_n254;
  t18_n253: return 0.10453527420759201f;
  t18_n254: return 0.10329734534025192f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree19(const Example& E) {
  t19_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t19_n224;
  t19_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t19_n89;
  t19_n2: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t19_n84;
  t19_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t19_n61;
  t19_n4: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t19_n60;
  t19_n5: if (E.getNumReferences() >= 3298328576 /*1220.0*/) goto t19_n7;
  t19_n6: return -0.041252631694078445f;
  t19_n7: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t19_n25;
  t19_n8: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t19_n24;
  t19_n9: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t19_n13;
  t19_n10: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n12;
  t19_n11: return 0.014680483378469944f;
  t19_n12: return 0.08482184261083603f;
  t19_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n15;
  t19_n14: return 0.08139672130346298f;
  t19_n15: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t19_n23;
  t19_n16: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t19_n18;
  t19_n17: return 0.1128191277384758f;
  t19_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t19_n22;
  t19_n19: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t19_n21;
  t19_n20: return 0.10882458090782166f;
  t19_n21: return 0.10391276329755783f;
  t19_n22: return 0.032587822526693344f;
  t19_n23: return 0.11219605058431625f;
  t19_n24: return -0.025440800935029984f;
  t19_n25: if (E.getNumReferences() >= 3319640064 /*7094.0*/) goto t19_n33;
  t19_n26: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t19_n30;
  t19_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t19_n29;
  t19_n28: return 0.03163371607661247f;
  t19_n29: return 0.11333060264587402f;
  t19_n30: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t19_n32;
  t19_n31: return 0.0320863239467144f;
  t19_n32: return 0.09745816141366959f;
  t19_n33: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t19_n57;
  t19_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t19_n40;
  t19_n35: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t19_n39;
  t19_n36: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t19_n38;
  t19_n37: return 0.06258900463581085f;
  t19_n38: return 0.0812964215874672f;
  t19_n39: return 0.09862139821052551f;
  t19_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t19_n42;
  t19_n41: return 0.07613325119018555f;
  t19_n42: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t19_n56;
  t19_n43: if (E.getNumReferences() >= 3328529408 /*14677.0*/) goto t19_n45;
  t19_n44: return 0.10779105871915817f;
  t19_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t19_n47;
  t19_n46: return 0.11426301300525665f;
  t19_n47: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t19_n49;
  t19_n48: return 0.11567050963640213f;
  t19_n49: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t19_n53;
  t19_n50: if (E.getNumReferences() >= 3332338944 /*20410.5*/) goto t19_n52;
  t19_n51: return 0.10576621443033218f;
  t19_n52: return 0.13324962556362152f;
  t19_n53: if (E.getNumReferences() >= 3331241984 /*18268.0*/) goto t19_n55;
  t19_n54: return 0.1284535974264145f;
  t19_n55: return 0.1290154755115509f;
  t19_n56: return 0.08514901995658875f;
  t19_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t19_n59;
  t19_n58: return 0.08796185255050659f;
  t19_n59: return 0.10337304323911667f;
  t19_n60: return -0.08277449756860733f;
  t19_n61: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t19_n65;
  t19_n62: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t19_n64;
  t19_n63: return 0.02871512994170189f;
  t19_n64: return 0.06479569524526596f;
  t19_n65: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t19_n81;
  t19_n66: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t19_n68;
  t19_n67: return 0.06468010693788528f;
  t19_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t19_n70;
  t19_n69: return 0.06053495779633522f;
  t19_n70: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t19_n72;
  t19_n71: return 0.15515775978565216f;
  t19_n72: if (E.getNumReferences() >= 3309828096 /*3199.5*/) goto t19_n74;
  t19_n73: return 0.11022049933671951f;
  t19_n74: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t19_n80;
  t19_n75: if (E.getNumReferences() >= 3325494272 /*11713.0*/) goto t19_n77;
  t19_n76: return 0.10766854882240295f;
  t19_n77: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t19_n79;
  t19_n78: return 0.11379656940698624f;
  t19_n79: return 0.11122222244739532f;
  t19_n80: return 0.09519150853157043f;
  t19_n81: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t19_n83;
  t19_n82: return 0.11010897159576416f;
  t19_n83: return -0.16601364314556122f;
  t19_n84: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t19_n86;
  t19_n85: return 0.06358295679092407f;
  t19_n86: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t19_n88;
  t19_n87: return 0.09419234097003937f;
  t19_n88: return 0.10250589996576309f;
  t19_n89: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t19_n153;
  t19_n90: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t19_n130;
  t19_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t19_n117;
  t19_n92: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t19_n108;
  t19_n93: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t19_n99;
  t19_n94: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t19_n96;
  t19_n95: return 0.025264175608754158f;
  t19_n96: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n98;
  t19_n97: return 0.036552440375089645f;
  t19_n98: return 0.07389792054891586f;
  t19_n99: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t19_n101;
  t19_n100: return 0.09892670810222626f;
  t19_n101: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t19_n103;
  t19_n102: return 0.10401519387960434f;
  t19_n103: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t19_n107;
  t19_n104: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t19_n106;
  t19_n105: return 0.08989930897951126f;
  t19_n106: return 0.12860901653766632f;
  t19_n107: return 0.12521573901176453f;
  t19_n108: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t19_n110;
  t19_n109: return -0.01958444155752659f;
  t19_n110: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t19_n114;
  t19_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t19_n113;
  t19_n112: return 0.04936930537223816f;
  t19_n113: return 0.10842178016901016f;
  t19_n114: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t19_n116;
  t19_n115: return 0.015748286619782448f;
  t19_n116: return 0.07740968465805054f;
  t19_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t19_n119;
  t19_n118: return 0.047171447426080704f;
  t19_n119: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t19_n123;
  t19_n120: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t19_n122;
  t19_n121: return 0.09292712807655334f;
  t19_n122: return 0.061091963201761246f;
  t19_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t19_n125;
  t19_n124: return 0.11665474623441696f;
  t19_n125: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t19_n129;
  t19_n126: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t19_n128;
  t19_n127: return 0.12078613042831421f;
  t19_n128: return 0.11390858888626099f;
  t19_n129: return 0.09795073419809341f;
  t19_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t19_n136;
  t19_n131: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t19_n135;
  t19_n132: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t19_n134;
  t19_n133: return 0.04717133939266205f;
  t19_n134: return 0.09506282210350037f;
  t19_n135: return 0.07849244773387909f;
  t19_n136: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t19_n148;
  t19_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t19_n139;
  t19_n138: return 0.07208787649869919f;
  t19_n139: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t19_n141;
  t19_n140: return 0.08923517167568207f;
  t19_n141: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t19_n147;
  t19_n142: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t19_n144;
  t19_n143: return 0.11471889913082123f;
  t19_n144: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t19_n146;
  t19_n145: return 0.13307107985019684f;
  t19_n146: return 0.1114005446434021f;
  t19_n147: return 0.09227467328310013f;
  t19_n148: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t19_n152;
  t19_n149: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t19_n151;
  t19_n150: return 0.11666318029165268f;
  t19_n151: return 0.11213172972202301f;
  t19_n152: return 0.08997370302677155f;
  t19_n153: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t19_n223;
  t19_n154: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t19_n202;
  t19_n155: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t19_n193;
  t19_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t19_n180;
  t19_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t19_n159;
  t19_n158: return -0.1230221539735794f;
  t19_n159: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t19_n163;
  t19_n160: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t19_n162;
  t19_n161: return 0.000353206938598305f;
  t19_n162: return 0.060949306935071945f;
  t19_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t19_n171;
  t19_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t19_n166;
  t19_n165: return -0.034136224538087845f;
  t19_n166: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t19_n170;
  t19_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t19_n169;
  t19_n168: return 0.09276311099529266f;
  t19_n169: return 0.03979102522134781f;
  t19_n170: return -0.06852495670318604f;
  t19_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t19_n175;
  t19_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t19_n174;
  t19_n173: return 0.08319224417209625f;
  t19_n174: return 0.09630633145570755f;
  t19_n175: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t19_n179;
  t19_n176: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t19_n178;
  t19_n177: return 0.1257074922323227f;
  t19_n178: return 0.10122671723365784f;
  t19_n179: return -0.04881294071674347f;
  t19_n180: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t19_n192;
  t19_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t19_n183;
  t19_n182: return -0.11804090440273285f;
  t19_n183: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n185;
  t19_n184: return 0.09014355391263962f;
  t19_n185: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t19_n187;
  t19_n186: return 0.0670701414346695f;
  t19_n187: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t19_n189;
  t19_n188: return 0.09211332350969315f;
  t19_n189: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t19_n191;
  t19_n190: return 0.12239458411931992f;
  t19_n191: return 0.07925587147474289f;
  t19_n192: return -0.0941106528043747f;
  t19_n193: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t19_n195;
  t19_n194: return 0.06237979605793953f;
  t19_n195: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n197;
  t19_n196: return 0.08972452580928802f;
  t19_n197: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t19_n199;
  t19_n198: return 0.07979388535022736f;
  t19_n199: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t19_n201;
  t19_n200: return 0.11198204755783081f;
  t19_n201: return 0.14513622224330902f;
  t19_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t19_n208;
  t19_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t19_n205;
  t19_n204: return 0.06523347645998001f;
  t19_n205: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t19_n207;
  t19_n206: return 0.09045501053333282f;
  t19_n207: return 0.11001641303300858f;
  t19_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t19_n222;
  t19_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n219;
  t19_n210: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t19_n212;
  t19_n211: return 0.07859555631875992f;
  t19_n212: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t19_n218;
  t19_n213: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t19_n217;
  t19_n214: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t19_n216;
  t19_n215: return 0.1256270855665207f;
  t19_n216: return 0.009016445837914944f;
  t19_n217: return 0.11626280844211578f;
  t19_n218: return -0.051587510854005814f;
  t19_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t19_n221;
  t19_n220: return 0.11743059754371643f;
  t19_n221: return 0.12235661596059799f;
  t19_n222: return 0.06924007833003998f;
  t19_n223: return -0.07991296052932739f;
  t19_n224: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t19_n238;
  t19_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t19_n229;
  t19_n226: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n228;
  t19_n227: return 0.04674442484974861f;
  t19_n228: return 0.08255256712436676f;
  t19_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t19_n237;
  t19_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t19_n234;
  t19_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t19_n233;
  t19_n232: return 0.07867465913295746f;
  t19_n233: return 0.08928316831588745f;
  t19_n234: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t19_n236;
  t19_n235: return 0.09371563047170639f;
  t19_n236: return 0.08842722326517105f;
  t19_n237: return 0.08022903650999069f;
  t19_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t19_n252;
  t19_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t19_n247;
  t19_n240: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t19_n244;
  t19_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t19_n243;
  t19_n242: return 0.046469200402498245f;
  t19_n243: return 0.09800243377685547f;
  t19_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n246;
  t19_n245: return 0.11265657842159271f;
  t19_n246: return -0.02423366717994213f;
  t19_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n251;
  t19_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t19_n250;
  t19_n249: return 0.09045221656560898f;
  t19_n250: return 0.10338488221168518f;
  t19_n251: return 0.1045740395784378f;
  t19_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t19_n254;
  t19_n253: return 0.1039339229464531f;
  t19_n254: return 0.1027916669845581f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree20(const Example& E) {
  t20_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t20_n224;
  t20_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t20_n65;
  t20_n2: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t20_n60;
  t20_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t20_n41;
  t20_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t20_n20;
  t20_n5: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t20_n13;
  t20_n6: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t20_n8;
  t20_n7: return -0.03750084713101387f;
  t20_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n10;
  t20_n9: return 0.08529295027256012f;
  t20_n10: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t20_n12;
  t20_n11: return 0.09898042678833008f;
  t20_n12: return 0.10908405482769012f;
  t20_n13: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n15;
  t20_n14: return -0.07610669732093811f;
  t20_n15: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t20_n19;
  t20_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n18;
  t20_n17: return -0.06505297869443893f;
  t20_n18: return 0.08237334340810776f;
  t20_n19: return 0.025482797995209694f;
  t20_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t20_n22;
  t20_n21: return 0.011446668766438961f;
  t20_n22: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t20_n28;
  t20_n23: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t20_n25;
  t20_n24: return 0.09755279868841171f;
  t20_n25: if (E.getNumReferences() >= 3267756032 /*99.0*/) goto t20_n27;
  t20_n26: return 0.10396908223628998f;
  t20_n27: return 0.11262358725070953f;
  t20_n28: if (E.getNumReferences() >= 3307687936 /*2677.0*/) goto t20_n40;
  t20_n29: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t20_n31;
  t20_n30: return 0.010836216621100903f;
  t20_n31: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t20_n35;
  t20_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t20_n34;
  t20_n33: return 0.060227490961551666f;
  t20_n34: return 0.1033381000161171f;
  t20_n35: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t20_n39;
  t20_n36: if (E.getNumReferences() >= 3302678528 /*1751.0*/) goto t20_n38;
  t20_n37: return 0.09863197058439255f;
  t20_n38: return 0.11495398730039597f;
  t20_n39: return 0.00845232605934143f;
  t20_n40: return 0.08163411170244217f;
  t20_n41: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t20_n45;
  t20_n42: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n44;
  t20_n43: return 0.029076993465423584f;
  t20_n44: return 0.06260780245065689f;
  t20_n45: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t20_n57;
  t20_n46: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t20_n48;
  t20_n47: return 0.0615314282476902f;
  t20_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t20_n50;
  t20_n49: return 0.05741335451602936f;
  t20_n50: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t20_n52;
  t20_n51: return 0.1454186737537384f;
  t20_n52: if (E.getNumReferences() >= 3309828096 /*3199.5*/) goto t20_n56;
  t20_n53: if (E.getNumReferences() >= 3272671232 /*145.0*/) goto t20_n55;
  t20_n54: return 0.14579588174819946f;
  t20_n55: return 0.1051219031214714f;
  t20_n56: return 0.10196232050657272f;
  t20_n57: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t20_n59;
  t20_n58: return 0.10918238759040833f;
  t20_n59: return -0.16168741881847382f;
  t20_n60: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t20_n62;
  t20_n61: return 0.059633709490299225f;
  t20_n62: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t20_n64;
  t20_n63: return 0.09252098947763443f;
  t20_n64: return 0.10208412259817123f;
  t20_n65: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t20_n155;
  t20_n66: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t20_n128;
  t20_n67: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t20_n87;
  t20_n68: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t20_n78;
  t20_n69: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t20_n71;
  t20_n70: return 0.021817702800035477f;
  t20_n71: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t20_n75;
  t20_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t20_n74;
  t20_n73: return 0.06205614283680916f;
  t20_n74: return 0.10868088155984879f;
  t20_n75: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t20_n77;
  t20_n76: return 0.070552758872509f;
  t20_n77: return 0.028483031317591667f;
  t20_n78: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t20_n80;
  t20_n79: return 0.1024247333407402f;
  t20_n80: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t20_n82;
  t20_n81: return 0.1042613610625267f;
  t20_n82: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t20_n86;
  t20_n83: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t20_n85;
  t20_n84: return 0.12382552027702332f;
  t20_n85: return 0.18502962589263916f;
  t20_n86: return 0.1292969286441803f;
  t20_n87: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t20_n117;
  t20_n88: if (E.getNumReferences() >= 3272572928 /*143.5*/) goto t20_n98;
  t20_n89: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n91;
  t20_n90: return -0.03790534287691116f;
  t20_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t20_n93;
  t20_n92: return -0.10149919241666794f;
  t20_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t20_n95;
  t20_n94: return 0.05271906033158302f;
  t20_n95: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t20_n97;
  t20_n96: return 0.08858192712068558f;
  t20_n97: return -0.13180451095104218f;
  t20_n98: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t20_n102;
  t20_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t20_n101;
  t20_n100: return 0.04814025014638901f;
  t20_n101: return 0.10316929221153259f;
  t20_n102: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t20_n108;
  t20_n103: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t20_n105;
  t20_n104: return -0.003604368306696415f;
  t20_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t20_n107;
  t20_n106: return 0.10444484651088715f;
  t20_n107: return 0.13006135821342468f;
  t20_n108: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t20_n116;
  t20_n109: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t20_n111;
  t20_n110: return 0.07842588424682617f;
  t20_n111: if (E.getNumReferences() >= 3294330880 /*878.0*/) goto t20_n113;
  t20_n112: return 0.08224945515394211f;
  t20_n113: if (E.getNumReferences() >= 3299852288 /*1406.0*/) goto t20_n115;
  t20_n114: return 0.1119329184293747f;
  t20_n115: return 0.005113099701702595f;
  t20_n116: return 0.06284986436367035f;
  t20_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t20_n119;
  t20_n118: return 0.04564015567302704f;
  t20_n119: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t20_n121;
  t20_n120: return 0.05746937915682793f;
  t20_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t20_n123;
  t20_n122: return 0.11097146570682526f;
  t20_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t20_n127;
  t20_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t20_n126;
  t20_n125: return 0.11841461062431335f;
  t20_n126: return 0.11233469098806381f;
  t20_n127: return 0.09241421520709991f;
  t20_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t20_n136;
  t20_n129: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t20_n133;
  t20_n130: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t20_n132;
  t20_n131: return 0.04417378455400467f;
  t20_n132: return 0.09255407005548477f;
  t20_n133: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t20_n135;
  t20_n134: return 0.06916038691997528f;
  t20_n135: return 0.09556686878204346f;
  t20_n136: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t20_n148;
  t20_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t20_n139;
  t20_n138: return 0.06786075979471207f;
  t20_n139: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t20_n141;
  t20_n140: return 0.0848383679986f;
  t20_n141: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t20_n147;
  t20_n142: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t20_n144;
  t20_n143: return 0.11297638714313507f;
  t20_n144: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t20_n146;
  t20_n145: return 0.1293671429157257f;
  t20_n146: return 0.11033894866704941f;
  t20_n147: return 0.08949806541204453f;
  t20_n148: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t20_n152;
  t20_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n151;
  t20_n150: return 0.11385606974363327f;
  t20_n151: return 0.11390956491231918f;
  t20_n152: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t20_n154;
  t20_n153: return 0.035163093358278275f;
  t20_n154: return 0.0942227691411972f;
  t20_n155: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t20_n223;
  t20_n156: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t20_n202;
  t20_n157: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t20_n193;
  t20_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t20_n180;
  t20_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t20_n161;
  t20_n160: return -0.12046770751476288f;
  t20_n161: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n179;
  t20_n162: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t20_n164;
  t20_n163: return 0.006793489679694176f;
  t20_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t20_n172;
  t20_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t20_n167;
  t20_n166: return -0.04034753143787384f;
  t20_n167: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t20_n171;
  t20_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t20_n170;
  t20_n169: return 0.08344151824712753f;
  t20_n170: return 0.03357525169849396f;
  t20_n171: return -0.059171728789806366f;
  t20_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t20_n176;
  t20_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t20_n175;
  t20_n174: return 0.08727708458900452f;
  t20_n175: return 0.12184564769268036f;
  t20_n176: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t20_n178;
  t20_n177: return 0.12288923561573029f;
  t20_n178: return -0.07432906329631805f;
  t20_n179: return 0.059088580310344696f;
  t20_n180: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t20_n192;
  t20_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t20_n183;
  t20_n182: return -0.11653995513916016f;
  t20_n183: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n185;
  t20_n184: return 0.0879327654838562f;
  t20_n185: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t20_n187;
  t20_n186: return 0.06075740605592728f;
  t20_n187: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t20_n189;
  t20_n188: return 0.08710499852895737f;
  t20_n189: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n191;
  t20_n190: return 0.11943497508764267f;
  t20_n191: return 0.07563497126102448f;
  t20_n192: return -0.09407338500022888f;
  t20_n193: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n195;
  t20_n194: return 0.06148038059473038f;
  t20_n195: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n197;
  t20_n196: return 0.08693090826272964f;
  t20_n197: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t20_n199;
  t20_n198: return 0.07810443639755249f;
  t20_n199: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t20_n201;
  t20_n200: return 0.11027955263853073f;
  t20_n201: return 0.14058806002140045f;
  t20_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t20_n208;
  t20_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t20_n205;
  t20_n204: return 0.06202095374464989f;
  t20_n205: if (E.getNumReferences() >= 3339137920 /*34611.5*/) goto t20_n207;
  t20_n206: return 0.08568938076496124f;
  t20_n207: return 0.10781590640544891f;
  t20_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t20_n222;
  t20_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n219;
  t20_n210: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t20_n212;
  t20_n211: return 0.07519925385713577f;
  t20_n212: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n218;
  t20_n213: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t20_n217;
  t20_n214: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t20_n216;
  t20_n215: return 0.1205364316701889f;
  t20_n216: return -0.00794061180204153f;
  t20_n217: return 0.11260874569416046f;
  t20_n218: return 0.08755996823310852f;
  t20_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t20_n221;
  t20_n220: return 0.11278398334980011f;
  t20_n221: return 0.11434684693813324f;
  t20_n222: return 0.05748733878135681f;
  t20_n223: return -0.07974559813737869f;
  t20_n224: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t20_n238;
  t20_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t20_n229;
  t20_n226: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n228;
  t20_n227: return 0.04277215152978897f;
  t20_n228: return 0.07950848340988159f;
  t20_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t20_n237;
  t20_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t20_n234;
  t20_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t20_n233;
  t20_n232: return 0.07539836317300797f;
  t20_n233: return 0.0871601477265358f;
  t20_n234: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t20_n236;
  t20_n235: return 0.09223172068595886f;
  t20_n236: return 0.08629985898733139f;
  t20_n237: return 0.07747206091880798f;
  t20_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t20_n252;
  t20_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t20_n247;
  t20_n240: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t20_n244;
  t20_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t20_n243;
  t20_n242: return 0.042327459901571274f;
  t20_n243: return 0.09685162454843521f;
  t20_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n246;
  t20_n245: return 0.11151184886693954f;
  t20_n246: return -0.021423742175102234f;
  t20_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n251;
  t20_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t20_n250;
  t20_n249: return 0.08955726027488708f;
  t20_n250: return 0.1027236357331276f;
  t20_n251: return 0.10389205813407898f;
  t20_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t20_n254;
  t20_n253: return 0.10314469784498215f;
  t20_n254: return 0.10211843997240067f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree21(const Example& E) {
  t21_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t21_n228;
  t21_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t21_n131;
  t21_n2: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t21_n126;
  t21_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t21_n117;
  t21_n4: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t21_n68;
  t21_n5: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t21_n57;
  t21_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t21_n20;
  t21_n7: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t21_n9;
  t21_n8: return -0.0637674406170845f;
  t21_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t21_n11;
  t21_n10: return -0.04174390062689781f;
  t21_n11: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t21_n19;
  t21_n12: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t21_n14;
  t21_n13: return 0.09015722572803497f;
  t21_n14: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t21_n18;
  t21_n15: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n17;
  t21_n16: return 0.1317012459039688f;
  t21_n17: return 0.13253383338451385f;
  t21_n18: return -0.16130219399929047f;
  t21_n19: return -0.02722049504518509f;
  t21_n20: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t21_n22;
  t21_n21: return -0.04842088371515274f;
  t21_n22: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t21_n44;
  t21_n23: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t21_n31;
  t21_n24: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t21_n28;
  t21_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t21_n27;
  t21_n26: return -0.004091278649866581f;
  t21_n27: return 0.07969820499420166f;
  t21_n28: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t21_n30;
  t21_n29: return 0.07513368129730225f;
  t21_n30: return 0.08150684088468552f;
  t21_n31: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t21_n35;
  t21_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t21_n34;
  t21_n33: return 0.12401089072227478f;
  t21_n34: return 0.09698754549026489f;
  t21_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t21_n37;
  t21_n36: return 0.13881467282772064f;
  t21_n37: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t21_n43;
  t21_n38: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t21_n40;
  t21_n39: return 0.12904152274131775f;
  t21_n40: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t21_n42;
  t21_n41: return 0.16046662628650665f;
  t21_n42: return -0.13312655687332153f;
  t21_n43: return 0.15988294780254364f;
  t21_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t21_n48;
  t21_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t21_n47;
  t21_n46: return 0.04440266638994217f;
  t21_n47: return 0.09535535424947739f;
  t21_n48: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t21_n52;
  t21_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t21_n51;
  t21_n50: return 0.10257643461227417f;
  t21_n51: return 0.12461967766284943f;
  t21_n52: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t21_n56;
  t21_n53: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t21_n55;
  t21_n54: return 0.13222043216228485f;
  t21_n55: return 0.12578855454921722f;
  t21_n56: return 0.08953901380300522f;
  t21_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Namespace))) goto t21_n65;
  t21_n58: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t21_n60;
  t21_n59: return -0.09332738071680069f;
  t21_n60: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t21_n64;
  t21_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n63;
  t21_n62: return -0.038348350673913956f;
  t21_n63: return 0.07887139916419983f;
  t21_n64: return 0.010339183732867241f;
  t21_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t21_n67;
  t21_n66: return 0.0030118965078145266f;
  t21_n67: return 0.0741790384054184f;
  t21_n68: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t21_n94;
  t21_n69: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t21_n85;
  t21_n70: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t21_n84;
  t21_n71: if (E.getNumReferences() >= 3354933440 /*127089.5*/) goto t21_n79;
  t21_n72: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t21_n74;
  t21_n73: return 0.013851573690772057f;
  t21_n74: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t21_n76;
  t21_n75: return 0.04516209661960602f;
  t21_n76: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t21_n78;
  t21_n77: return 0.12156503647565842f;
  t21_n78: return 0.09257543087005615f;
  t21_n79: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n81;
  t21_n80: return 0.07030769437551498f;
  t21_n81: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t21_n83;
  t21_n82: return 0.09221429377794266f;
  t21_n83: return 0.10753558576107025f;
  t21_n84: return -0.01949804462492466f;
  t21_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t21_n89;
  t21_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t21_n88;
  t21_n87: return -0.00038330498500727117f;
  t21_n88: return 0.0648307278752327f;
  t21_n89: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t21_n91;
  t21_n90: return 0.062046557664871216f;
  t21_n91: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t21_n93;
  t21_n92: return 0.13140814006328583f;
  t21_n93: return 0.08537527173757553f;
  t21_n94: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t21_n112;
  t21_n95: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t21_n111;
  t21_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t21_n98;
  t21_n97: return 0.11489829421043396f;
  t21_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t21_n108;
  t21_n99: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t21_n101;
  t21_n100: return 0.13147927820682526f;
  t21_n101: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t21_n107;
  t21_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t21_n104;
  t21_n103: return 0.13375723361968994f;
  t21_n104: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t21_n106;
  t21_n105: return 0.14942072331905365f;
  t21_n106: return 0.1555061787366867f;
  t21_n107: return 0.09745560586452484f;
  t21_n108: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t21_n110;
  t21_n109: return 0.15713223814964294f;
  t21_n110: return 0.1607862412929535f;
  t21_n111: return 0.12001683562994003f;
  t21_n112: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t21_n114;
  t21_n113: return 0.07633835077285767f;
  t21_n114: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t21_n116;
  t21_n115: return 0.08083406835794449f;
  t21_n116: return 0.09565266966819763f;
  t21_n117: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t21_n119;
  t21_n118: return 0.03863409161567688f;
  t21_n119: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t21_n123;
  t21_n120: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t21_n122;
  t21_n121: return 0.05635671690106392f;
  t21_n122: return 0.09324062615633011f;
  t21_n123: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t21_n125;
  t21_n124: return 0.10852286964654922f;
  t21_n125: return -0.15606990456581116f;
  t21_n126: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t21_n128;
  t21_n127: return 0.054902780801057816f;
  t21_n128: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t21_n130;
  t21_n129: return 0.09052251279354095f;
  t21_n130: return 0.10139475017786026f;
  t21_n131: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t21_n181;
  t21_n132: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t21_n168;
  t21_n133: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t21_n155;
  t21_n134: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t21_n144;
  t21_n135: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t21_n137;
  t21_n136: return 0.024295581504702568f;
  t21_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t21_n139;
  t21_n138: return 0.06562107056379318f;
  t21_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t21_n141;
  t21_n140: return 0.010576224885880947f;
  t21_n141: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t21_n143;
  t21_n142: return 0.09944246709346771f;
  t21_n143: return 0.1133391484618187f;
  t21_n144: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t21_n146;
  t21_n145: return 0.10058087110519409f;
  t21_n146: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t21_n148;
  t21_n147: return 0.10518155992031097f;
  t21_n148: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t21_n154;
  t21_n149: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t21_n153;
  t21_n150: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t21_n152;
  t21_n151: return 0.07950989902019501f;
  t21_n152: return 0.14054948091506958f;
  t21_n153: return 0.1316937357187271f;
  t21_n154: return 0.12374350428581238f;
  t21_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t21_n157;
  t21_n156: return -0.012066377326846123f;
  t21_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t21_n159;
  t21_n158: return 0.043897777795791626f;
  t21_n159: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t21_n161;
  t21_n160: return 0.05360548943281174f;
  t21_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t21_n163;
  t21_n162: return 0.10615114122629166f;
  t21_n163: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t21_n167;
  t21_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t21_n166;
  t21_n165: return 0.11573851108551025f;
  t21_n166: return 0.10717818140983582f;
  t21_n167: return 0.09254322201013565f;
  t21_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t21_n174;
  t21_n169: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t21_n173;
  t21_n170: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t21_n172;
  t21_n171: return 0.04275349900126457f;
  t21_n172: return 0.08913807570934296f;
  t21_n173: return 0.0736815333366394f;
  t21_n174: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t21_n176;
  t21_n175: return 0.07916736602783203f;
  t21_n176: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t21_n180;
  t21_n177: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n179;
  t21_n178: return 0.11209819465875626f;
  t21_n179: return 0.11317616701126099f;
  t21_n180: return 0.08438151329755783f;
  t21_n181: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t21_n227;
  t21_n182: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t21_n206;
  t21_n183: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t21_n199;
  t21_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t21_n186;
  t21_n185: return 0.04669920355081558f;
  t21_n186: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t21_n198;
  t21_n187: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t21_n189;
  t21_n188: return -0.11545996367931366f;
  t21_n189: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n191;
  t21_n190: return 0.0834159106016159f;
  t21_n191: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t21_n193;
  t21_n192: return 0.06066546216607094f;
  t21_n193: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t21_n197;
  t21_n194: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t21_n196;
  t21_n195: return 0.11389999091625214f;
  t21_n196: return 0.09542833268642426f;
  t21_n197: return 0.06279809027910233f;
  t21_n198: return -0.09391489624977112f;
  t21_n199: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t21_n201;
  t21_n200: return 0.05747269466519356f;
  t21_n201: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t21_n205;
  t21_n202: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n204;
  t21_n203: return 0.08465512841939926f;
  t21_n204: return 0.07489856332540512f;
  t21_n205: return 0.1146414503455162f;
  t21_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t21_n212;
  t21_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t21_n209;
  t21_n208: return 0.05867448076605797f;
  t21_n209: if (E.getNumReferences() >= 3339137920 /*34611.5*/) goto t21_n211;
  t21_n210: return 0.07906220108270645f;
  t21_n211: return 0.10698077827692032f;
  t21_n212: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t21_n226;
  t21_n213: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n223;
  t21_n214: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t21_n216;
  t21_n215: return 0.07148497551679611f;
  t21_n216: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t21_n222;
  t21_n217: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t21_n221;
  t21_n218: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t21_n220;
  t21_n219: return 0.11456239223480225f;
  t21_n220: return -0.016337504610419273f;
  t21_n221: return 0.1100461483001709f;
  t21_n222: return 0.08414001762866974f;
  t21_n223: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t21_n225;
  t21_n224: return 0.10954972356557846f;
  t21_n225: return 0.10943955183029175f;
  t21_n226: return 0.05786583572626114f;
  t21_n227: return -0.07162168622016907f;
  t21_n228: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t21_n242;
  t21_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t21_n233;
  t21_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n232;
  t21_n231: return 0.040314577519893646f;
  t21_n232: return 0.07652152329683304f;
  t21_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t21_n241;
  t21_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t21_n238;
  t21_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t21_n237;
  t21_n236: return 0.07177077233791351f;
  t21_n237: return 0.08507171273231506f;
  t21_n238: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t21_n240;
  t21_n239: return 0.09047505259513855f;
  t21_n240: return 0.08437895029783249f;
  t21_n241: return 0.07482842355966568f;
  t21_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t21_n252;
  t21_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t21_n247;
  t21_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t21_n246;
  t21_n245: return 0.03903985023498535f;
  t21_n246: return 0.09586634486913681f;
  t21_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n251;
  t21_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t21_n250;
  t21_n249: return 0.08556656539440155f;
  t21_n250: return 0.10212759673595428f;
  t21_n251: return 0.10329724848270416f;
  t21_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t21_n254;
  t21_n253: return 0.10267733782529831f;
  t21_n254: return 0.10194625705480576f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree22(const Example& E) {
  t22_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t22_n228;
  t22_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t22_n97;
  t22_n2: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t22_n92;
  t22_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t22_n75;
  t22_n4: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t22_n72;
  t22_n5: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t22_n23;
  t22_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t22_n8;
  t22_n7: return -0.04521164298057556f;
  t22_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t22_n10;
  t22_n9: return 0.014125242829322815f;
  t22_n10: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t22_n22;
  t22_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n19;
  t22_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n14;
  t22_n13: return -0.12007568031549454f;
  t22_n14: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t22_n16;
  t22_n15: return 0.06044100970029831f;
  t22_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t22_n18;
  t22_n17: return 0.05975402519106865f;
  t22_n18: return 0.08696945756673813f;
  t22_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t22_n21;
  t22_n20: return 0.08984199166297913f;
  t22_n21: return 0.05108078196644783f;
  t22_n22: return -0.12327039986848831f;
  t22_n23: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t22_n47;
  t22_n24: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t22_n42;
  t22_n25: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t22_n33;
  t22_n26: if (E.getNumReferences() >= 3350460992 /*92148.5*/) goto t22_n28;
  t22_n27: return 0.03241107985377312f;
  t22_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n30;
  t22_n29: return 0.07171054184436798f;
  t22_n30: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t22_n32;
  t22_n31: return 0.09304501861333847f;
  t22_n32: return 0.105484239757061f;
  t22_n33: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n35;
  t22_n34: return 0.052515801042318344f;
  t22_n35: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t22_n41;
  t22_n36: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t22_n40;
  t22_n37: if (E.getNumReferences() >= 3302604800 /*1742.0*/) goto t22_n39;
  t22_n38: return 0.08699925243854523f;
  t22_n39: return 0.10272364318370819f;
  t22_n40: return 0.11197648197412491f;
  t22_n41: return 0.07986811548471451f;
  t22_n42: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t22_n44;
  t22_n43: return -0.002336851553991437f;
  t22_n44: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n46;
  t22_n45: return -0.05142727121710777f;
  t22_n46: return 0.07428868860006332f;
  t22_n47: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t22_n57;
  t22_n48: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t22_n56;
  t22_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t22_n51;
  t22_n50: return 0.10515067726373672f;
  t22_n51: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t22_n53;
  t22_n52: return 0.14194530248641968f;
  t22_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t22_n55;
  t22_n54: return 0.1285526156425476f;
  t22_n55: return 0.14650051295757294f;
  t22_n56: return 0.10948926955461502f;
  t22_n57: if (E.getNumReferences() >= 3308660736 /*2914.5*/) goto t22_n69;
  t22_n58: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t22_n68;
  t22_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t22_n61;
  t22_n60: return 0.11238603293895721f;
  t22_n61: if (E.getNumReferences() >= 3276242944 /*199.5*/) goto t22_n65;
  t22_n62: if (E.getNumReferences() >= 3275063296 /*181.5*/) goto t22_n64;
  t22_n63: return 0.14315468072891235f;
  t22_n64: return 0.14810633659362793f;
  t22_n65: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t22_n67;
  t22_n66: return 0.11739278584718704f;
  t22_n67: return 0.13046082854270935f;
  t22_n68: return 0.06714363396167755f;
  t22_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t22_n71;
  t22_n70: return 0.090487040579319f;
  t22_n71: return 0.09604073315858841f;
  t22_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t22_n74;
  t22_n73: return -0.09322939813137054f;
  t22_n74: return -0.07009044289588928f;
  t22_n75: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t22_n89;
  t22_n76: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t22_n80;
  t22_n77: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t22_n79;
  t22_n78: return 0.035518746823072433f;
  t22_n79: return 0.05645189806818962f;
  t22_n80: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t22_n82;
  t22_n81: return 0.05552844703197479f;
  t22_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t22_n84;
  t22_n83: return 0.05218341201543808f;
  t22_n84: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t22_n86;
  t22_n85: return 0.13455405831336975f;
  t22_n86: if (E.getNumReferences() >= 3309828096 /*3199.5*/) goto t22_n88;
  t22_n87: return 0.09905225038528442f;
  t22_n88: return 0.09883066266775131f;
  t22_n89: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t22_n91;
  t22_n90: return 0.10744518041610718f;
  t22_n91: return -0.15405236184597015f;
  t22_n92: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t22_n94;
  t22_n93: return 0.05086821690201759f;
  t22_n94: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t22_n96;
  t22_n95: return 0.08856385946273804f;
  t22_n96: return 0.10102096945047379f;
  t22_n97: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t22_n185;
  t22_n98: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t22_n162;
  t22_n99: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t22_n125;
  t22_n100: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t22_n114;
  t22_n101: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t22_n103;
  t22_n102: return 0.023331349715590477f;
  t22_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t22_n109;
  t22_n104: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t22_n106;
  t22_n105: return 0.061724115163087845f;
  t22_n106: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t22_n108;
  t22_n107: return 0.09889163076877594f;
  t22_n108: return 0.12537674605846405f;
  t22_n109: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t22_n111;
  t22_n110: return 0.09102116525173187f;
  t22_n111: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t22_n113;
  t22_n112: return 0.1166694238781929f;
  t22_n113: return 0.10433409363031387f;
  t22_n114: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t22_n116;
  t22_n115: return 0.09792731702327728f;
  t22_n116: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t22_n118;
  t22_n117: return 0.1060355007648468f;
  t22_n118: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t22_n124;
  t22_n119: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t22_n123;
  t22_n120: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t22_n122;
  t22_n121: return 0.07620657980442047f;
  t22_n122: return 0.137957364320755f;
  t22_n123: return 0.12857386469841003f;
  t22_n124: return 0.11971444636583328f;
  t22_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t22_n151;
  t22_n126: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t22_n140;
  t22_n127: if (E.getNumReferences() >= 3272572928 /*143.5*/) goto t22_n129;
  t22_n128: return -0.03722847253084183f;
  t22_n129: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t22_n135;
  t22_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t22_n132;
  t22_n131: return 0.04914555698633194f;
  t22_n132: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t22_n134;
  t22_n133: return 0.13501620292663574f;
  t22_n134: return 0.09686993807554245f;
  t22_n135: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t22_n137;
  t22_n136: return 0.009274082258343697f;
  t22_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t22_n139;
  t22_n138: return 0.09701956808567047f;
  t22_n139: return 0.12201515585184097f;
  t22_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n142;
  t22_n141: return -0.09809672832489014f;
  t22_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t22_n146;
  t22_n143: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t22_n145;
  t22_n144: return 0.04865065589547157f;
  t22_n145: return 0.0788327008485794f;
  t22_n146: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t22_n150;
  t22_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n149;
  t22_n148: return 0.09272085875272751f;
  t22_n149: return 0.0718664601445198f;
  t22_n150: return -0.1320115476846695f;
  t22_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t22_n153;
  t22_n152: return 0.040096551179885864f;
  t22_n153: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t22_n155;
  t22_n154: return 0.04908088594675064f;
  t22_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t22_n157;
  t22_n156: return 0.10109912604093552f;
  t22_n157: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t22_n161;
  t22_n158: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t22_n160;
  t22_n159: return 0.11371567845344543f;
  t22_n160: return 0.10599197447299957f;
  t22_n161: return 0.08749158680438995f;
  t22_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t22_n168;
  t22_n163: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t22_n167;
  t22_n164: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t22_n166;
  t22_n165: return 0.040991950780153275f;
  t22_n166: return 0.09672246128320694f;
  t22_n167: return 0.07129731774330139f;
  t22_n168: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t22_n180;
  t22_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n171;
  t22_n170: return 0.06220857799053192f;
  t22_n171: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t22_n173;
  t22_n172: return 0.07652159035205841f;
  t22_n173: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t22_n179;
  t22_n174: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t22_n176;
  t22_n175: return 0.10936254262924194f;
  t22_n176: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t22_n178;
  t22_n177: return 0.12418550997972488f;
  t22_n178: return 0.10870133340358734f;
  t22_n179: return 0.08530250936746597f;
  t22_n180: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t22_n184;
  t22_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n183;
  t22_n182: return 0.11119940876960754f;
  t22_n183: return 0.11250545084476471f;
  t22_n184: return 0.08244796097278595f;
  t22_n185: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t22_n227;
  t22_n186: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n210;
  t22_n187: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t22_n201;
  t22_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t22_n190;
  t22_n189: return 0.043488435447216034f;
  t22_n190: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t22_n200;
  t22_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n193;
  t22_n192: return -0.11391264945268631f;
  t22_n193: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t22_n195;
  t22_n194: return 0.05983489751815796f;
  t22_n195: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t22_n199;
  t22_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n198;
  t22_n197: return 0.052188217639923096f;
  t22_n198: return 0.08017999678850174f;
  t22_n199: return 0.09964317828416824f;
  t22_n200: return -0.08470036089420319f;
  t22_n201: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t22_n203;
  t22_n202: return 0.05481072515249252f;
  t22_n203: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n205;
  t22_n204: return 0.08337461203336716f;
  t22_n205: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t22_n207;
  t22_n206: return 0.0726684182882309f;
  t22_n207: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t22_n209;
  t22_n208: return 0.10822884738445282f;
  t22_n209: return 0.12369024753570557f;
  t22_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t22_n214;
  t22_n211: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t22_n213;
  t22_n212: return 0.07813972234725952f;
  t22_n213: return -0.0462191142141819f;
  t22_n214: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t22_n226;
  t22_n215: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n223;
  t22_n216: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t22_n218;
  t22_n217: return 0.06743642687797546f;
  t22_n218: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t22_n222;
  t22_n219: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t22_n221;
  t22_n220: return 0.10931980609893799f;
  t22_n221: return 0.10747617483139038f;
  t22_n222: return 0.07936207950115204f;
  t22_n223: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t22_n225;
  t22_n224: return 0.10656165331602097f;
  t22_n225: return 0.10781911015510559f;
  t22_n226: return 0.05057692527770996f;
  t22_n227: return -0.06849317252635956f;
  t22_n228: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t22_n242;
  t22_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t22_n233;
  t22_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n232;
  t22_n231: return 0.03649128973484039f;
  t22_n232: return 0.07353859394788742f;
  t22_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t22_n241;
  t22_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t22_n238;
  t22_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t22_n237;
  t22_n236: return 0.068202443420887f;
  t22_n237: return 0.08225443959236145f;
  t22_n238: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t22_n240;
  t22_n239: return 0.08868706971406937f;
  t22_n240: return 0.08317942172288895f;
  t22_n241: return 0.07203096896409988f;
  t22_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t22_n252;
  t22_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t22_n247;
  t22_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t22_n246;
  t22_n245: return 0.04501327499747276f;
  t22_n246: return 0.09413398057222366f;
  t22_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n251;
  t22_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t22_n250;
  t22_n249: return 0.08418097347021103f;
  t22_n250: return 0.10141000151634216f;
  t22_n251: return 0.1030830591917038f;
  t22_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t22_n254;
  t22_n253: return 0.10221869498491287f;
  t22_n254: return 0.10103550553321838f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree23(const Example& E) {
  t23_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t23_n232;
  t23_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t23_n107;
  t23_n2: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t23_n104;
  t23_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t23_n93;
  t23_n4: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t23_n86;
  t23_n5: if (E.getNumReferences() >= 3350479168 /*92290.5*/) goto t23_n61;
  t23_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t23_n10;
  t23_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t23_n9;
  t23_n8: return -0.0670025423169136f;
  t23_n9: return -0.04367159679532051f;
  t23_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t23_n12;
  t23_n11: return -0.007504863664507866f;
  t23_n12: if (E.getNumReferences() >= 3273031680 /*150.5*/) goto t23_n44;
  t23_n13: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t23_n21;
  t23_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t23_n16;
  t23_n15: return 0.04749932885169983f;
  t23_n16: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t23_n18;
  t23_n17: return 0.0729912742972374f;
  t23_n18: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t23_n20;
  t23_n19: return 0.07764342427253723f;
  t23_n20: return 0.10017454624176025f;
  t23_n21: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t23_n41;
  t23_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t23_n34;
  t23_n23: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t23_n25;
  t23_n24: return -0.00810820609331131f;
  t23_n25: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t23_n33;
  t23_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t23_n30;
  t23_n27: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t23_n29;
  t23_n28: return 0.07503074407577515f;
  t23_n29: return 0.0973166674375534f;
  t23_n30: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t23_n32;
  t23_n31: return 0.08736281841993332f;
  t23_n32: return 0.10506746917963028f;
  t23_n33: return 0.005731381010264158f;
  t23_n34: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t23_n36;
  t23_n35: return 0.03968428075313568f;
  t23_n36: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t23_n40;
  t23_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t23_n39;
  t23_n38: return 0.06668933480978012f;
  t23_n39: return 0.1021733209490776f;
  t23_n40: return 0.034502483904361725f;
  t23_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t23_n43;
  t23_n42: return 0.11679862439632416f;
  t23_n43: return 0.1278681606054306f;
  t23_n44: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t23_n58;
  t23_n45: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t23_n47;
  t23_n46: return 0.09067565202713013f;
  t23_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t23_n51;
  t23_n48: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t23_n50;
  t23_n49: return 0.10746051371097565f;
  t23_n50: return 0.08371025323867798f;
  t23_n51: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t23_n57;
  t23_n52: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t23_n56;
  t23_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t23_n55;
  t23_n54: return 0.11729732155799866f;
  t23_n55: return 0.14320144057273865f;
  t23_n56: return 0.12095954269170761f;
  t23_n57: return 0.12725019454956055f;
  t23_n58: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t23_n60;
  t23_n59: return 0.03637876361608505f;
  t23_n60: return 0.07318583875894547f;
  t23_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n63;
  t23_n62: return 0.05078461021184921f;
  t23_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t23_n65;
  t23_n64: return 0.0077086882665753365f;
  t23_n65: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t23_n83;
  t23_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t23_n72;
  t23_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t23_n69;
  t23_n68: return 0.068008653819561f;
  t23_n69: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t23_n71;
  t23_n70: return 0.09798572957515717f;
  t23_n71: return -0.007992702536284924f;
  t23_n72: if (E.getNumReferences() >= 3354764736 /*125771.5*/) goto t23_n82;
  t23_n73: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t23_n79;
  t23_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t23_n76;
  t23_n75: return 0.14890994131565094f;
  t23_n76: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t23_n78;
  t23_n77: return 0.13075588643550873f;
  t23_n78: return -0.16752617061138153f;
  t23_n79: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t23_n81;
  t23_n80: return 0.1088843047618866f;
  t23_n81: return 0.10011031478643417f;
  t23_n82: return 0.10065103322267532f;
  t23_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t23_n85;
  t23_n84: return 0.09624484181404114f;
  t23_n85: return 0.10401970893144608f;
  t23_n86: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t23_n88;
  t23_n87: return -0.06536716222763062f;
  t23_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n90;
  t23_n89: return -0.04247163236141205f;
  t23_n90: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t23_n92;
  t23_n91: return 0.06530530750751495f;
  t23_n92: return -0.10781064629554749f;
  t23_n93: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t23_n99;
  t23_n94: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t23_n98;
  t23_n95: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t23_n97;
  t23_n96: return 0.030656760558485985f;
  t23_n97: return 0.05634601414203644f;
  t23_n98: return 0.06095041707158089f;
  t23_n99: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t23_n103;
  t23_n100: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t23_n102;
  t23_n101: return 0.0921257734298706f;
  t23_n102: return 0.11488429456949234f;
  t23_n103: return 0.082788847386837f;
  t23_n104: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t23_n106;
  t23_n105: return 0.04653044790029526f;
  t23_n106: return 0.09603098034858704f;
  t23_n107: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t23_n193;
  t23_n108: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t23_n158;
  t23_n109: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t23_n135;
  t23_n110: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t23_n126;
  t23_n111: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t23_n113;
  t23_n112: return 0.02209080196917057f;
  t23_n113: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t23_n115;
  t23_n114: return 0.0642714872956276f;
  t23_n115: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t23_n117;
  t23_n116: return 0.0909452959895134f;
  t23_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t23_n119;
  t23_n118: return 0.12030066549777985f;
  t23_n119: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t23_n121;
  t23_n120: return 0.1302683800458908f;
  t23_n121: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t23_n125;
  t23_n122: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t23_n124;
  t23_n123: return 0.07886702567338943f;
  t23_n124: return 0.1358511745929718f;
  t23_n125: return 0.1718037873506546f;
  t23_n126: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t23_n130;
  t23_n127: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t23_n129;
  t23_n128: return 0.09571295231580734f;
  t23_n129: return 0.10088285058736801f;
  t23_n130: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t23_n132;
  t23_n131: return -0.14675216376781464f;
  t23_n132: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t23_n134;
  t23_n133: return 0.12025311589241028f;
  t23_n134: return 0.15285837650299072f;
  t23_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t23_n147;
  t23_n136: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t23_n138;
  t23_n137: return -0.03379612788558006f;
  t23_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t23_n140;
  t23_n139: return -0.09711913764476776f;
  t23_n140: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t23_n144;
  t23_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t23_n143;
  t23_n142: return 0.06889687478542328f;
  t23_n143: return 0.08142505586147308f;
  t23_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t23_n146;
  t23_n145: return -0.12314438074827194f;
  t23_n146: return 0.04939870536327362f;
  t23_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t23_n149;
  t23_n148: return 0.040415145456790924f;
  t23_n149: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t23_n151;
  t23_n150: return 0.04732656851410866f;
  t23_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t23_n153;
  t23_n152: return 0.09690593928098679f;
  t23_n153: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t23_n157;
  t23_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t23_n156;
  t23_n155: return 0.11192294955253601f;
  t23_n156: return 0.10326255857944489f;
  t23_n157: return 0.08229685574769974f;
  t23_n158: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t23_n178;
  t23_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t23_n163;
  t23_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t23_n162;
  t23_n161: return 0.040678057819604874f;
  t23_n162: return 0.10093683004379272f;
  t23_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t23_n169;
  t23_n164: if (E.getNumReferences() >= 3342741376 /*48687.5*/) goto t23_n166;
  t23_n165: return 0.08897099643945694f;
  t23_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t23_n168;
  t23_n167: return 0.09720822423696518f;
  t23_n168: return -0.027462609112262726f;
  t23_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n171;
  t23_n170: return 0.061774082481861115f;
  t23_n171: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t23_n177;
  t23_n172: if (E.getNumReferences() >= 3281469440 /*302.5*/) goto t23_n176;
  t23_n173: if (E.getNumReferences() >= 3273195520 /*153.0*/) goto t23_n175;
  t23_n174: return 0.08478084951639175f;
  t23_n175: return 0.1251426339149475f;
  t23_n176: return 0.07488584518432617f;
  t23_n177: return 0.11764760315418243f;
  t23_n178: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t23_n190;
  t23_n179: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t23_n189;
  t23_n180: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t23_n184;
  t23_n181: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t23_n183;
  t23_n182: return 0.021210720762610435f;
  t23_n183: return 0.08484400063753128f;
  t23_n184: if (E.getNumReferences() >= 3290931200 /*670.5*/) goto t23_n186;
  t23_n185: return 0.10607680678367615f;
  t23_n186: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t23_n188;
  t23_n187: return 0.11376242339611053f;
  t23_n188: return 0.09373289346694946f;
  t23_n189: return 0.09723813831806183f;
  t23_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t23_n192;
  t23_n191: return 0.06723029166460037f;
  t23_n192: return 0.09830570966005325f;
  t23_n193: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t23_n195;
  t23_n194: return -0.11481451988220215f;
  t23_n195: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t23_n229;
  t23_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t23_n216;
  t23_n197: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t23_n215;
  t23_n198: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t23_n200;
  t23_n199: return 0.045046061277389526f;
  t23_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t23_n202;
  t23_n201: return 0.06082760542631149f;
  t23_n202: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n212;
  t23_n203: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t23_n205;
  t23_n204: return 0.06440615653991699f;
  t23_n205: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t23_n211;
  t23_n206: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t23_n210;
  t23_n207: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t23_n209;
  t23_n208: return 0.10648705810308456f;
  t23_n209: return -0.044152867048978806f;
  t23_n210: return 0.10545133054256439f;
  t23_n211: return -0.0684368759393692f;
  t23_n212: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t23_n214;
  t23_n213: return 0.10332600027322769f;
  t23_n214: return 0.10394494235515594f;
  t23_n215: return 0.027821049094200134f;
  t23_n216: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t23_n222;
  t23_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t23_n219;
  t23_n218: return 0.04733862355351448f;
  t23_n219: if (E.getNumReferences() >= 3339137920 /*34611.5*/) goto t23_n221;
  t23_n220: return 0.07448448240756989f;
  t23_n221: return 0.10401178896427155f;
  t23_n222: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t23_n226;
  t23_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n225;
  t23_n224: return 0.048937972635030746f;
  t23_n225: return 0.0768369808793068f;
  t23_n226: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t23_n228;
  t23_n227: return 0.10333514213562012f;
  t23_n228: return 0.059964071959257126f;
  t23_n229: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t23_n231;
  t23_n230: return 0.047398027032613754f;
  t23_n231: return 0.07459260523319244f;
  t23_n232: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t23_n244;
  t23_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t23_n237;
  t23_n234: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n236;
  t23_n235: return 0.03577946871519089f;
  t23_n236: return 0.07023951411247253f;
  t23_n237: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t23_n243;
  t23_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t23_n242;
  t23_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t23_n241;
  t23_n240: return 0.06545548141002655f;
  t23_n241: return 0.08028707653284073f;
  t23_n242: return 0.08669762313365936f;
  t23_n243: return 0.06957267224788666f;
  t23_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t23_n252;
  t23_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t23_n249;
  t23_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t23_n248;
  t23_n247: return 0.03744826838374138f;
  t23_n248: return 0.09255963563919067f;
  t23_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n251;
  t23_n250: return 0.10018783807754517f;
  t23_n251: return 0.10235167294740677f;
  t23_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t23_n254;
  t23_n253: return 0.10150332003831863f;
  t23_n254: return 0.10074210911989212f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree24(const Example& E) {
  t24_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t24_n234;
  t24_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t24_n105;
  t24_n2: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t24_n102;
  t24_n3: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t24_n61;
  t24_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t24_n26;
  t24_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n7;
  t24_n6: return -0.08898825943470001f;
  t24_n7: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t24_n25;
  t24_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t24_n22;
  t24_n9: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t24_n11;
  t24_n10: return -0.016563281416893005f;
  t24_n11: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t24_n13;
  t24_n12: return 0.05841028690338135f;
  t24_n13: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t24_n21;
  t24_n14: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t24_n16;
  t24_n15: return 0.10796554386615753f;
  t24_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t24_n18;
  t24_n17: return 0.06932752579450607f;
  t24_n18: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t24_n20;
  t24_n19: return 0.13711702823638916f;
  t24_n20: return 0.12914560735225677f;
  t24_n21: return 0.10033559054136276f;
  t24_n22: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t24_n24;
  t24_n23: return 0.08828029781579971f;
  t24_n24: return 0.10053598135709763f;
  t24_n25: return -0.07979728281497955f;
  t24_n26: if (E.getFileProximityDistance() >= 3254517760 /*31.5*/) goto t24_n60;
  t24_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n29;
  t24_n28: return 0.013146830722689629f;
  t24_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t24_n47;
  t24_n30: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t24_n46;
  t24_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t24_n33;
  t24_n32: return 0.03803709149360657f;
  t24_n33: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t24_n35;
  t24_n34: return 0.04975070804357529f;
  t24_n35: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t24_n45;
  t24_n36: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t24_n38;
  t24_n37: return 0.06198708340525627f;
  t24_n38: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t24_n40;
  t24_n39: return 0.014219434931874275f;
  t24_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t24_n44;
  t24_n41: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t24_n43;
  t24_n42: return 0.19257663190364838f;
  t24_n43: return 0.14516116678714752f;
  t24_n44: return -0.050409648567438126f;
  t24_n45: return 0.06801265478134155f;
  t24_n46: return 0.08109802007675171f;
  t24_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t24_n49;
  t24_n48: return 0.04121699184179306f;
  t24_n49: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t24_n59;
  t24_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t24_n58;
  t24_n51: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t24_n57;
  t24_n52: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t24_n54;
  t24_n53: return 0.08308743685483932f;
  t24_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t24_n56;
  t24_n55: return 0.07489126920700073f;
  t24_n56: return 0.09987715631723404f;
  t24_n57: return 0.10336194187402725f;
  t24_n58: return -0.009202755987644196f;
  t24_n59: return 0.051436856389045715f;
  t24_n60: return -0.02371092699468136f;
  t24_n61: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t24_n85;
  t24_n62: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t24_n82;
  t24_n63: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t24_n77;
  t24_n64: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t24_n66;
  t24_n65: return 0.02700420282781124f;
  t24_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t24_n68;
  t24_n67: return 0.0485927052795887f;
  t24_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t24_n70;
  t24_n69: return 0.10177362710237503f;
  t24_n70: if (E.getNumReferences() >= 3288547328 /*525.0*/) goto t24_n72;
  t24_n71: return 0.11534357070922852f;
  t24_n72: if (E.getNumReferences() >= 3289890816 /*607.0*/) goto t24_n76;
  t24_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t24_n75;
  t24_n74: return 0.13508744537830353f;
  t24_n75: return 0.13379782438278198f;
  t24_n76: return 0.11397166550159454f;
  t24_n77: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t24_n79;
  t24_n78: return 0.08018286526203156f;
  t24_n79: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n81;
  t24_n80: return 0.10714451223611832f;
  t24_n81: return 0.12361838668584824f;
  t24_n82: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t24_n84;
  t24_n83: return -0.005363681819289923f;
  t24_n84: return 0.05666632205247879f;
  t24_n85: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t24_n97;
  t24_n86: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t24_n96;
  t24_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t24_n89;
  t24_n88: return 0.09834462404251099f;
  t24_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t24_n93;
  t24_n90: if (E.getNumReferences() >= 3273687040 /*160.5*/) goto t24_n92;
  t24_n91: return 0.13782206177711487f;
  t24_n92: return 0.11919205635786057f;
  t24_n93: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t24_n95;
  t24_n94: return 0.13928453624248505f;
  t24_n95: return 0.14540995657444f;
  t24_n96: return 0.11259087920188904f;
  t24_n97: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t24_n99;
  t24_n98: return 0.06952771544456482f;
  t24_n99: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t24_n101;
  t24_n100: return 0.0775487944483757f;
  t24_n101: return 0.09234050661325455f;
  t24_n102: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t24_n104;
  t24_n103: return 0.04296475276350975f;
  t24_n104: return 0.09454330056905746f;
  t24_n105: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t24_n199;
  t24_n106: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t24_n170;
  t24_n107: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t24_n159;
  t24_n108: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t24_n110;
  t24_n109: return -0.02048930712044239f;
  t24_n110: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t24_n156;
  t24_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t24_n135;
  t24_n112: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t24_n126;
  t24_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t24_n115;
  t24_n114: return 0.03339335322380066f;
  t24_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t24_n117;
  t24_n116: return 0.06158693507313728f;
  t24_n117: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t24_n119;
  t24_n118: return 0.04026748985052109f;
  t24_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t24_n121;
  t24_n120: return 0.09177011251449585f;
  t24_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t24_n125;
  t24_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n124;
  t24_n123: return 0.10985642671585083f;
  t24_n124: return 0.09988368302583694f;
  t24_n125: return 0.07810868322849274f;
  t24_n126: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t24_n132;
  t24_n127: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t24_n129;
  t24_n128: return 0.083390973508358f;
  t24_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t24_n131;
  t24_n130: return 0.11016308516263962f;
  t24_n131: return 0.12278363108634949f;
  t24_n132: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t24_n134;
  t24_n133: return -3.087921504629776e-05f;
  t24_n134: return 0.09010626375675201f;
  t24_n135: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t24_n137;
  t24_n136: return 0.07815537601709366f;
  t24_n137: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n139;
  t24_n138: return 0.020399127155542374f;
  t24_n139: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t24_n153;
  t24_n140: if (E.getNumReferences() >= 3273031680 /*150.5*/) goto t24_n148;
  t24_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t24_n143;
  t24_n142: return 0.09614239633083344f;
  t24_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n147;
  t24_n144: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t24_n146;
  t24_n145: return 0.12703804671764374f;
  t24_n146: return 0.1265375316143036f;
  t24_n147: return 0.09174419194459915f;
  t24_n148: if (E.getNumReferences() >= 3275784192 /*192.5*/) goto t24_n152;
  t24_n149: if (E.getNumReferences() >= 3275096064 /*182.0*/) goto t24_n151;
  t24_n150: return 0.12119748443365097f;
  t24_n151: return 0.12632471323013306f;
  t24_n152: return 0.11633560061454773f;
  t24_n153: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t24_n155;
  t24_n154: return 0.12225674837827682f;
  t24_n155: return 0.0964503362774849f;
  t24_n156: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t24_n158;
  t24_n157: return -0.018611766397953033f;
  t24_n158: return 0.04718386381864548f;
  t24_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t24_n163;
  t24_n160: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t24_n162;
  t24_n161: return 0.035464879125356674f;
  t24_n162: return 0.0640779361128807f;
  t24_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t24_n165;
  t24_n164: return 0.03740580752491951f;
  t24_n165: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t24_n167;
  t24_n166: return 0.07280068844556808f;
  t24_n167: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t24_n169;
  t24_n168: return 0.09452009201049805f;
  t24_n169: return -0.0019600028172135353f;
  t24_n170: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t24_n198;
  t24_n171: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t24_n181;
  t24_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t24_n174;
  t24_n173: return 0.03610789403319359f;
  t24_n174: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t24_n178;
  t24_n175: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t24_n177;
  t24_n176: return -0.053355827927589417f;
  t24_n177: return 0.060116298496723175f;
  t24_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t24_n180;
  t24_n179: return 0.06453591585159302f;
  t24_n180: return 0.09586746245622635f;
  t24_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t24_n185;
  t24_n182: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t24_n184;
  t24_n183: return 0.07233692705631256f;
  t24_n184: return -0.042264241725206375f;
  t24_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t24_n197;
  t24_n186: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n194;
  t24_n187: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t24_n189;
  t24_n188: return 0.05925663560628891f;
  t24_n189: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t24_n193;
  t24_n190: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t24_n192;
  t24_n191: return 0.10186795890331268f;
  t24_n192: return 0.10303256660699844f;
  t24_n193: return 0.07281392812728882f;
  t24_n194: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n196;
  t24_n195: return 0.09934757649898529f;
  t24_n196: return 0.10123523324728012f;
  t24_n197: return 0.0478086955845356f;
  t24_n198: return -0.08318805694580078f;
  t24_n199: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t24_n227;
  t24_n200: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t24_n220;
  t24_n201: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t24_n217;
  t24_n202: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t24_n204;
  t24_n203: return 0.0953967496752739f;
  t24_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t24_n206;
  t24_n205: return 0.08693362772464752f;
  t24_n206: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n208;
  t24_n207: return 0.12883447110652924f;
  t24_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n210;
  t24_n209: return 0.12550878524780273f;
  t24_n210: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t24_n212;
  t24_n211: return 0.08172253519296646f;
  t24_n212: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t24_n216;
  t24_n213: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t24_n215;
  t24_n214: return 0.12283647060394287f;
  t24_n215: return 0.13682134449481964f;
  t24_n216: return 0.11658955365419388f;
  t24_n217: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t24_n219;
  t24_n218: return 0.055241625756025314f;
  t24_n219: return 0.04951534792780876f;
  t24_n220: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t24_n226;
  t24_n221: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t24_n223;
  t24_n222: return 0.08542577177286148f;
  t24_n223: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t24_n225;
  t24_n224: return 0.1191733330488205f;
  t24_n225: return 0.12775008380413055f;
  t24_n226: return 0.09852899610996246f;
  t24_n227: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t24_n231;
  t24_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n230;
  t24_n229: return 0.07449112832546234f;
  t24_n230: return 0.06461283564567566f;
  t24_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t24_n233;
  t24_n232: return -0.14111103117465973f;
  t24_n233: return 0.11162705719470978f;
  t24_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t24_n244;
  t24_n235: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t24_n239;
  t24_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n238;
  t24_n237: return 0.03161162883043289f;
  t24_n238: return 0.06761990487575531f;
  t24_n239: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t24_n243;
  t24_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n242;
  t24_n241: return 0.07330860942602158f;
  t24_n242: return 0.08467020094394684f;
  t24_n243: return 0.06621427834033966f;
  t24_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n252;
  t24_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t24_n249;
  t24_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t24_n248;
  t24_n247: return 0.03814175724983215f;
  t24_n248: return 0.09134194999933243f;
  t24_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n251;
  t24_n250: return 0.09978199005126953f;
  t24_n251: return 0.10179370641708374f;
  t24_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t24_n254;
  t24_n253: return 0.10085102915763855f;
  t24_n254: return 0.09998769313097f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree25(const Example& E) {
  t25_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t25_n236;
  t25_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t25_n139;
  t25_n2: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t25_n98;
  t25_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t25_n93;
  t25_n4: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t25_n82;
  t25_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t25_n7;
  t25_n6: return -0.03690199553966522f;
  t25_n7: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t25_n51;
  t25_n8: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t25_n14;
  t25_n9: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t25_n13;
  t25_n10: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t25_n12;
  t25_n11: return 0.0061548990197479725f;
  t25_n12: return 0.05696645379066467f;
  t25_n13: return -0.027868865057826042f;
  t25_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t25_n30;
  t25_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t25_n17;
  t25_n16: return -0.012633911333978176f;
  t25_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t25_n19;
  t25_n18: return 0.022943994030356407f;
  t25_n19: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t25_n21;
  t25_n20: return 0.058626383543014526f;
  t25_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t25_n27;
  t25_n22: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n26;
  t25_n23: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t25_n25;
  t25_n24: return 0.1283687800168991f;
  t25_n25: return 0.11855170875787735f;
  t25_n26: return 0.08548422157764435f;
  t25_n27: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n29;
  t25_n28: return 0.146471306681633f;
  t25_n29: return 0.1021866574883461f;
  t25_n30: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t25_n34;
  t25_n31: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t25_n33;
  t25_n32: return 0.0749087855219841f;
  t25_n33: return -0.14742225408554077f;
  t25_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t25_n38;
  t25_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t25_n37;
  t25_n36: return -0.16079933941364288f;
  t25_n37: return 0.09328688681125641f;
  t25_n38: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t25_n50;
  t25_n39: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n49;
  t25_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t25_n48;
  t25_n41: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t25_n45;
  t25_n42: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t25_n44;
  t25_n43: return 0.12928442656993866f;
  t25_n44: return 0.12612298130989075f;
  t25_n45: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t25_n47;
  t25_n46: return 0.010157212615013123f;
  t25_n47: return 0.12490243464708328f;
  t25_n48: return 0.12114982306957245f;
  t25_n49: return 0.08714230358600616f;
  t25_n50: return -0.10186692327260971f;
  t25_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t25_n63;
  t25_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t25_n54;
  t25_n53: return 0.030240565538406372f;
  t25_n54: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t25_n56;
  t25_n55: return 0.11595530062913895f;
  t25_n56: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t25_n58;
  t25_n57: return 0.1250377595424652f;
  t25_n58: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t25_n62;
  t25_n59: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t25_n61;
  t25_n60: return 0.13563720881938934f;
  t25_n61: return 0.07475613802671432f;
  t25_n62: return 0.14688166975975037f;
  t25_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t25_n67;
  t25_n64: if (E.getNumReferences() >= 3271720960 /*130.5*/) goto t25_n66;
  t25_n65: return 0.08852090686559677f;
  t25_n66: return 0.0983005240559578f;
  t25_n67: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t25_n71;
  t25_n68: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t25_n70;
  t25_n69: return 0.11016272753477097f;
  t25_n70: return 0.11654260754585266f;
  t25_n71: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t25_n79;
  t25_n72: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t25_n74;
  t25_n73: return 0.12736129760742188f;
  t25_n74: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t25_n78;
  t25_n75: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t25_n77;
  t25_n76: return 0.13435092568397522f;
  t25_n77: return 0.08711062371730804f;
  t25_n78: return 0.12021595984697342f;
  t25_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t25_n81;
  t25_n80: return 0.09724607318639755f;
  t25_n81: return 0.14048387110233307f;
  t25_n82: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Namespace))) goto t25_n88;
  t25_n83: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n85;
  t25_n84: return -0.07258697599172592f;
  t25_n85: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t25_n87;
  t25_n86: return 0.02026878297328949f;
  t25_n87: return 0.06009600684046745f;
  t25_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t25_n90;
  t25_n89: return 0.0026062980759888887f;
  t25_n90: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t25_n92;
  t25_n91: return 0.08895762264728546f;
  t25_n92: return 0.05852504447102547f;
  t25_n93: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n97;
  t25_n94: if (E.getNumReferences() >= 3271720960 /*130.5*/) goto t25_n96;
  t25_n95: return 0.032874103635549545f;
  t25_n96: return 0.05743447318673134f;
  t25_n97: return 0.05575476959347725f;
  t25_n98: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t25_n108;
  t25_n99: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t25_n105;
  t25_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n104;
  t25_n101: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t25_n103;
  t25_n102: return 0.04717090353369713f;
  t25_n103: return 0.09327362477779388f;
  t25_n104: return 0.08898892253637314f;
  t25_n105: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t25_n107;
  t25_n106: return -0.010259861126542091f;
  t25_n107: return 0.0645832046866417f;
  t25_n108: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t25_n136;
  t25_n109: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t25_n135;
  t25_n110: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t25_n134;
  t25_n111: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t25_n125;
  t25_n112: if (E.getNumReferences() >= 3356822208 /*152619.0*/) goto t25_n124;
  t25_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t25_n115;
  t25_n114: return 0.0654779002070427f;
  t25_n115: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t25_n121;
  t25_n116: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t25_n120;
  t25_n117: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t25_n119;
  t25_n118: return -0.334852397441864f;
  t25_n119: return 0.10761624574661255f;
  t25_n120: return 0.09377473592758179f;
  t25_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t25_n123;
  t25_n122: return 0.032746024429798126f;
  t25_n123: return 0.09606136381626129f;
  t25_n124: return -0.07916650176048279f;
  t25_n125: if (E.getNumReferences() >= 3360630592 /*212125.0*/) goto t25_n133;
  t25_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t25_n128;
  t25_n127: return 0.10178090631961823f;
  t25_n128: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t25_n130;
  t25_n129: return 0.01975713111460209f;
  t25_n130: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t25_n132;
  t25_n131: return 0.11206359416246414f;
  t25_n132: return 0.11374465376138687f;
  t25_n133: return 0.06619451940059662f;
  t25_n134: return -0.058774322271347046f;
  t25_n135: return 0.09961261600255966f;
  t25_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t25_n138;
  t25_n137: return 0.08585544675588608f;
  t25_n138: return 0.09133344888687134f;
  t25_n139: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t25_n215;
  t25_n140: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t25_n186;
  t25_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t25_n147;
  t25_n142: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t25_n144;
  t25_n143: return -0.020343076437711716f;
  t25_n144: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t25_n146;
  t25_n145: return 0.027253063395619392f;
  t25_n146: return 0.11778703331947327f;
  t25_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t25_n155;
  t25_n148: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t25_n150;
  t25_n149: return 0.0013152218889445066f;
  t25_n150: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t25_n152;
  t25_n151: return 0.047136612236499786f;
  t25_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n154;
  t25_n153: return 0.021842539310455322f;
  t25_n154: return 0.06967971473932266f;
  t25_n155: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t25_n185;
  t25_n156: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t25_n170;
  t25_n157: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t25_n161;
  t25_n158: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t25_n160;
  t25_n159: return 0.06722558289766312f;
  t25_n160: return 0.0176190584897995f;
  t25_n161: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t25_n169;
  t25_n162: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t25_n168;
  t25_n163: if (E.getNumReferences() >= 3270967296 /*123.5*/) goto t25_n165;
  t25_n164: return 0.13381488621234894f;
  t25_n165: if (E.getNumReferences() >= 3271098368 /*124.5*/) goto t25_n167;
  t25_n166: return 0.1665211170911789f;
  t25_n167: return 0.1173693835735321f;
  t25_n168: return 0.09761855751276016f;
  t25_n169: return 0.04609879106283188f;
  t25_n170: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t25_n174;
  t25_n171: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t25_n173;
  t25_n172: return 0.05168671905994415f;
  t25_n173: return 0.056092433631420135f;
  t25_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t25_n176;
  t25_n175: return 0.022372279316186905f;
  t25_n176: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t25_n178;
  t25_n177: return 0.07381711900234222f;
  t25_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t25_n180;
  t25_n179: return 0.08874266594648361f;
  t25_n180: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t25_n184;
  t25_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t25_n183;
  t25_n182: return 0.10851673036813736f;
  t25_n183: return 0.09729903936386108f;
  t25_n184: return 0.06980862468481064f;
  t25_n185: return 0.08450575917959213f;
  t25_n186: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t25_n188;
  t25_n187: return -0.1132279559969902f;
  t25_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t25_n204;
  t25_n189: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t25_n203;
  t25_n190: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t25_n192;
  t25_n191: return 0.038136012852191925f;
  t25_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t25_n194;
  t25_n193: return 0.05465397611260414f;
  t25_n194: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n202;
  t25_n195: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t25_n197;
  t25_n196: return 0.05599016696214676f;
  t25_n197: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n201;
  t25_n198: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t25_n200;
  t25_n199: return 0.09963186830282211f;
  t25_n200: return 0.10133979469537735f;
  t25_n201: return -0.0484488382935524f;
  t25_n202: return 0.0997401773929596f;
  t25_n203: return 0.02270159311592579f;
  t25_n204: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t25_n210;
  t25_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t25_n207;
  t25_n206: return 0.041113171726465225f;
  t25_n207: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n209;
  t25_n208: return 0.08522047102451324f;
  t25_n209: return 0.015087341889739037f;
  t25_n210: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t25_n214;
  t25_n211: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n213;
  t25_n212: return 0.029507754370570183f;
  t25_n213: return 0.07106882333755493f;
  t25_n214: return 0.0926426500082016f;
  t25_n215: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t25_n235;
  t25_n216: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n228;
  t25_n217: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t25_n225;
  t25_n218: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t25_n224;
  t25_n219: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t25_n221;
  t25_n220: return 0.056193456053733826f;
  t25_n221: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t25_n223;
  t25_n222: return 0.11200492829084396f;
  t25_n223: return 0.10369132459163666f;
  t25_n224: return 0.10372419655323029f;
  t25_n225: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t25_n227;
  t25_n226: return 0.06768085807561874f;
  t25_n227: return 0.0493784174323082f;
  t25_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n230;
  t25_n229: return 0.07372123003005981f;
  t25_n230: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t25_n232;
  t25_n231: return 0.06141049414873123f;
  t25_n232: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t25_n234;
  t25_n233: return 0.10208559781312943f;
  t25_n234: return 0.0862874761223793f;
  t25_n235: return 0.09926255792379379f;
  t25_n236: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t25_n246;
  t25_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t25_n241;
  t25_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n240;
  t25_n239: return 0.029646653681993484f;
  t25_n240: return 0.06433539092540741f;
  t25_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t25_n245;
  t25_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t25_n244;
  t25_n243: return 0.07058992236852646f;
  t25_n244: return 0.08285298198461533f;
  t25_n245: return 0.0635547786951065f;
  t25_n246: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t25_n252;
  t25_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t25_n249;
  t25_n248: return 0.0888437032699585f;
  t25_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n251;
  t25_n250: return 0.09870356321334839f;
  t25_n251: return 0.10092539340257645f;
  t25_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t25_n254;
  t25_n253: return 0.10004948824644089f;
  t25_n254: return 0.09932459890842438f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree26(const Example& E) {
  t26_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t26_n234;
  t26_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t26_n89;
  t26_n2: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t26_n54;
  t26_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t26_n47;
  t26_n4: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t26_n20;
  t26_n5: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t26_n17;
  t26_n6: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t26_n16;
  t26_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t26_n9;
  t26_n8: return 0.014405845664441586f;
  t26_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t26_n15;
  t26_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n12;
  t26_n11: return 0.08003503084182739f;
  t26_n12: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t26_n14;
  t26_n13: return 0.10005635768175125f;
  t26_n14: return 0.08272362500429153f;
  t26_n15: return 0.09879712760448456f;
  t26_n16: return -0.05046782270073891f;
  t26_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t26_n19;
  t26_n18: return -0.09682656079530716f;
  t26_n19: return -0.07741732895374298f;
  t26_n20: if (E.getFileProximityDistance() >= 3255435264 /*34.5*/) goto t26_n46;
  t26_n21: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n23;
  t26_n22: return -0.0014361203648149967f;
  t26_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t26_n31;
  t26_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n26;
  t26_n25: return 0.02398626320064068f;
  t26_n26: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t26_n28;
  t26_n27: return 0.043291885405778885f;
  t26_n28: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t26_n30;
  t26_n29: return 0.05907106399536133f;
  t26_n30: return 0.08178655058145523f;
  t26_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t26_n33;
  t26_n32: return 0.03764462471008301f;
  t26_n33: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t26_n43;
  t26_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n42;
  t26_n35: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t26_n41;
  t26_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag))) goto t26_n38;
  t26_n37: return 0.07390547543764114f;
  t26_n38: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t26_n40;
  t26_n39: return 0.08386719971895218f;
  t26_n40: return 0.09625855088233948f;
  t26_n41: return 0.09843553602695465f;
  t26_n42: return -0.007019375450909138f;
  t26_n43: if (E.getNumReferences() >= 3337742592 /*30964.5*/) goto t26_n45;
  t26_n44: return 0.03788790851831436f;
  t26_n45: return 0.1049976721405983f;
  t26_n46: return -0.025165744125843048f;
  t26_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n49;
  t26_n48: return 0.024968791753053665f;
  t26_n49: if (E.getNumReferences() >= 3301310464 /*1584.0*/) goto t26_n51;
  t26_n50: return 0.048295434564352036f;
  t26_n51: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t26_n53;
  t26_n52: return 0.04483024403452873f;
  t26_n53: return 0.0833570659160614f;
  t26_n54: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t26_n64;
  t26_n55: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t26_n61;
  t26_n56: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n60;
  t26_n57: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t26_n59;
  t26_n58: return 0.04560507833957672f;
  t26_n59: return 0.09152285009622574f;
  t26_n60: return 0.08583171665668488f;
  t26_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n63;
  t26_n62: return -0.011096643283963203f;
  t26_n63: return 0.060159213840961456f;
  t26_n64: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t26_n86;
  t26_n65: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t26_n85;
  t26_n66: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t26_n84;
  t26_n67: if (E.getNumReferences() >= 3359435680 /*193454.5*/) goto t26_n81;
  t26_n68: if (E.getNumReferences() >= 3355504736 /*132033.5*/) goto t26_n80;
  t26_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t26_n71;
  t26_n70: return 0.06546513736248016f;
  t26_n71: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t26_n77;
  t26_n72: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t26_n76;
  t26_n73: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t26_n75;
  t26_n74: return -0.29993537068367004f;
  t26_n75: return 0.1062079519033432f;
  t26_n76: return 0.09719296544790268f;
  t26_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t26_n79;
  t26_n78: return 0.08907850831747055f;
  t26_n79: return -0.1146119013428688f;
  t26_n80: return -0.027773112058639526f;
  t26_n81: if (E.getNumReferences() >= 3360630592 /*212125.0*/) goto t26_n83;
  t26_n82: return 0.10290336608886719f;
  t26_n83: return 0.05970387160778046f;
  t26_n84: return -0.051487091928720474f;
  t26_n85: return 0.09774709492921829f;
  t26_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t26_n88;
  t26_n87: return 0.08291012793779373f;
  t26_n88: return 0.08900907635688782f;
  t26_n89: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t26_n205;
  t26_n90: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t26_n174;
  t26_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t26_n101;
  t26_n92: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t26_n94;
  t26_n93: return -0.019237851724028587f;
  t26_n94: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n96;
  t26_n95: return 0.028570694848895073f;
  t26_n96: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n98;
  t26_n97: return 0.093368761241436f;
  t26_n98: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n100;
  t26_n99: return 0.12014514207839966f;
  t26_n100: return 0.11002354323863983f;
  t26_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t26_n111;
  t26_n102: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t26_n106;
  t26_n103: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t26_n105;
  t26_n104: return 0.049268562346696854f;
  t26_n105: return -0.023958448320627213f;
  t26_n106: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t26_n108;
  t26_n107: return 0.045336365699768066f;
  t26_n108: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n110;
  t26_n109: return 0.016995510086417198f;
  t26_n110: return 0.06684443354606628f;
  t26_n111: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t26_n155;
  t26_n112: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t26_n128;
  t26_n113: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t26_n117;
  t26_n114: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t26_n116;
  t26_n115: return 0.06801466643810272f;
  t26_n116: return 0.028500594198703766f;
  t26_n117: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t26_n119;
  t26_n118: return 0.04840678349137306f;
  t26_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t26_n121;
  t26_n120: return 0.040820397436618805f;
  t26_n121: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t26_n123;
  t26_n122: return 0.07591094076633453f;
  t26_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n127;
  t26_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n126;
  t26_n125: return 0.10747081786394119f;
  t26_n126: return 0.09468194097280502f;
  t26_n127: return 0.061911240220069885f;
  t26_n128: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t26_n146;
  t26_n129: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t26_n145;
  t26_n130: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n132;
  t26_n131: return 0.08416491001844406f;
  t26_n132: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t26_n142;
  t26_n133: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t26_n135;
  t26_n134: return 0.10643356293439865f;
  t26_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t26_n137;
  t26_n136: return 0.11771097034215927f;
  t26_n137: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t26_n141;
  t26_n138: if (E.getNumReferences() >= 3256352768 /*38.0*/) goto t26_n140;
  t26_n139: return 0.13736295700073242f;
  t26_n140: return 0.11816023290157318f;
  t26_n141: return 0.1675173044204712f;
  t26_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t26_n144;
  t26_n143: return 0.10991781949996948f;
  t26_n144: return 0.1226481944322586f;
  t26_n145: return 0.08255918323993683f;
  t26_n146: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t26_n154;
  t26_n147: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t26_n149;
  t26_n148: return 0.040628112852573395f;
  t26_n149: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t26_n151;
  t26_n150: return 0.1299315094947815f;
  t26_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t26_n153;
  t26_n152: return 0.09907563030719757f;
  t26_n153: return 0.11593476682901382f;
  t26_n154: return 0.07608336210250854f;
  t26_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n173;
  t26_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol))) goto t26_n160;
  t26_n157: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t26_n159;
  t26_n158: return 0.05432823300361633f;
  t26_n159: return 0.0997917652130127f;
  t26_n160: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t26_n166;
  t26_n161: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t26_n163;
  t26_n162: return 0.09979181736707687f;
  t26_n163: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t26_n165;
  t26_n164: return 0.12174098193645477f;
  t26_n165: return 0.10146904736757278f;
  t26_n166: if (E.getNumReferences() >= 3361098688 /*219439.0*/) goto t26_n168;
  t26_n167: return 0.07906590402126312f;
  t26_n168: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t26_n172;
  t26_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n171;
  t26_n170: return 0.10819828510284424f;
  t26_n171: return 0.11162833869457245f;
  t26_n172: return 0.08183406293392181f;
  t26_n173: return 0.008491222746670246f;
  t26_n174: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t26_n204;
  t26_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t26_n185;
  t26_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t26_n178;
  t26_n177: return 0.032524432986974716f;
  t26_n178: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t26_n180;
  t26_n179: return 0.032751958817243576f;
  t26_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t26_n182;
  t26_n181: return 0.060417987406253815f;
  t26_n182: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t26_n184;
  t26_n183: return 0.09682713449001312f;
  t26_n184: return 0.045387327671051025f;
  t26_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t26_n193;
  t26_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n192;
  t26_n187: if (E.getNumReferences() >= 3331838976 /*19434.0*/) goto t26_n189;
  t26_n188: return 0.06456196308135986f;
  t26_n189: if (E.getNumReferences() >= 3367232976 /*368430.5*/) goto t26_n191;
  t26_n190: return 0.10257193446159363f;
  t26_n191: return -0.029642047360539436f;
  t26_n192: return -0.03721177205443382f;
  t26_n193: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n203;
  t26_n194: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n202;
  t26_n195: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t26_n197;
  t26_n196: return 0.05364245921373367f;
  t26_n197: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t26_n201;
  t26_n198: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t26_n200;
  t26_n199: return 0.09765447676181793f;
  t26_n200: return 0.09899885952472687f;
  t26_n201: return 0.07114715129137039f;
  t26_n202: return 0.09499595314264297f;
  t26_n203: return 0.0463312529027462f;
  t26_n204: return -0.07984188944101334f;
  t26_n205: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t26_n227;
  t26_n206: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t26_n220;
  t26_n207: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t26_n215;
  t26_n208: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t26_n210;
  t26_n209: return 0.06798141449689865f;
  t26_n210: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t26_n214;
  t26_n211: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t26_n213;
  t26_n212: return 0.1070571169257164f;
  t26_n213: return 0.12837938964366913f;
  t26_n214: return 0.09846615791320801f;
  t26_n215: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t26_n217;
  t26_n216: return 0.057345516979694366f;
  t26_n217: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t26_n219;
  t26_n218: return 0.04918431118130684f;
  t26_n219: return -0.4464443624019623f;
  t26_n220: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n222;
  t26_n221: return 0.07045559585094452f;
  t26_n222: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t26_n224;
  t26_n223: return 0.058893147855997086f;
  t26_n224: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t26_n226;
  t26_n225: return 0.10119149088859558f;
  t26_n226: return 0.060545191168785095f;
  t26_n227: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t26_n233;
  t26_n228: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t26_n230;
  t26_n229: return 0.08277919143438339f;
  t26_n230: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t26_n232;
  t26_n231: return 0.11774390190839767f;
  t26_n232: return 0.12525182962417603f;
  t26_n233: return 0.0956396609544754f;
  t26_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t26_n246;
  t26_n235: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t26_n239;
  t26_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n238;
  t26_n237: return 0.02691120095551014f;
  t26_n238: return 0.06066697835922241f;
  t26_n239: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n245;
  t26_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n244;
  t26_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t26_n243;
  t26_n242: return 0.05355618894100189f;
  t26_n243: return 0.0720386803150177f;
  t26_n244: return 0.0805329978466034f;
  t26_n245: return 0.06060732528567314f;
  t26_n246: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n252;
  t26_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t26_n249;
  t26_n248: return 0.0865032747387886f;
  t26_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n251;
  t26_n250: return 0.09784076362848282f;
  t26_n251: return 0.10035522282123566f;
  t26_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t26_n254;
  t26_n253: return 0.09916064143180847f;
  t26_n254: return 0.09836581349372864f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree27(const Example& E) {
  t27_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t27_n234;
  t27_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t27_n103;
  t27_n2: if (E.getNumReferences() >= 3300909056 /*1535.0*/) goto t27_n30;
  t27_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t27_n17;
  t27_n4: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t27_n12;
  t27_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t27_n7;
  t27_n6: return -0.002250316319987178f;
  t27_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t27_n9;
  t27_n8: return 0.08175423741340637f;
  t27_n9: if (E.getNumReferences() >= 3266641920 /*90.5*/) goto t27_n11;
  t27_n10: return 0.09260950982570648f;
  t27_n11: return 0.10614252090454102f;
  t27_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n14;
  t27_n13: return -0.08366627991199493f;
  t27_n14: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t27_n16;
  t27_n15: return -0.07547459751367569f;
  t27_n16: return 0.031507354229688644f;
  t27_n17: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t27_n29;
  t27_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n20;
  t27_n19: return 0.009542238898575306f;
  t27_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t27_n24;
  t27_n21: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t27_n23;
  t27_n22: return 0.04284418001770973f;
  t27_n23: return 0.06509136408567429f;
  t27_n24: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t27_n26;
  t27_n25: return 0.05332379415631294f;
  t27_n26: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t27_n28;
  t27_n27: return 0.0935368686914444f;
  t27_n28: return 0.053418464958667755f;
  t27_n29: return -0.01649182289838791f;
  t27_n30: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t27_n46;
  t27_n31: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t27_n45;
  t27_n32: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t27_n42;
  t27_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n35;
  t27_n34: return 0.006141360383480787f;
  t27_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t27_n37;
  t27_n36: return 0.04069095849990845f;
  t27_n37: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t27_n41;
  t27_n38: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t27_n40;
  t27_n39: return 0.09493308514356613f;
  t27_n40: return 0.09985616058111191f;
  t27_n41: return -0.007883652113378048f;
  t27_n42: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t27_n44;
  t27_n43: return 0.06649854779243469f;
  t27_n44: return 0.10591664165258408f;
  t27_n45: return -0.02156270295381546f;
  t27_n46: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t27_n50;
  t27_n47: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t27_n49;
  t27_n48: return 0.04125131294131279f;
  t27_n49: return 0.07967223227024078f;
  t27_n50: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t27_n102;
  t27_n51: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t27_n75;
  t27_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t27_n56;
  t27_n53: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t27_n55;
  t27_n54: return 0.05694194510579109f;
  t27_n55: return 0.0909416675567627f;
  t27_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t27_n58;
  t27_n57: return 0.0712653398513794f;
  t27_n58: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t27_n74;
  t27_n59: if (E.getNumReferences() >= 3328529408 /*14677.0*/) goto t27_n61;
  t27_n60: return 0.09078636020421982f;
  t27_n61: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t27_n63;
  t27_n62: return 0.10290645807981491f;
  t27_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t27_n69;
  t27_n64: if (E.getNumReferences() >= 3331854592 /*19464.5*/) goto t27_n66;
  t27_n65: return 0.13163284957408905f;
  t27_n66: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t27_n68;
  t27_n67: return 0.13196611404418945f;
  t27_n68: return 0.10339105129241943f;
  t27_n69: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t27_n73;
  t27_n70: if (E.getNumReferences() >= 3332338944 /*20410.5*/) goto t27_n72;
  t27_n71: return 0.12263378500938416f;
  t27_n72: return 0.1372125893831253f;
  t27_n73: return 0.12189549952745438f;
  t27_n74: return 0.07118251174688339f;
  t27_n75: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t27_n77;
  t27_n76: return 0.06033502146601677f;
  t27_n77: if (E.getNumReferences() >= 3332389376 /*20509.0*/) goto t27_n101;
  t27_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t27_n88;
  t27_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t27_n83;
  t27_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t27_n82;
  t27_n81: return 0.031783781945705414f;
  t27_n82: return 0.1019834652543068f;
  t27_n83: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t27_n87;
  t27_n84: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t27_n86;
  t27_n85: return 0.11924794316291809f;
  t27_n86: return 0.11239280551671982f;
  t27_n87: return 0.11285277456045151f;
  t27_n88: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t27_n94;
  t27_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t27_n91;
  t27_n90: return 0.10655276477336884f;
  t27_n91: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t27_n93;
  t27_n92: return 0.11295586824417114f;
  t27_n93: return 0.11289377510547638f;
  t27_n94: if (E.getNumReferences() >= 3332047872 /*19842.0*/) goto t27_n98;
  t27_n95: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t27_n97;
  t27_n96: return 0.11348339170217514f;
  t27_n97: return 0.11483943462371826f;
  t27_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t27_n100;
  t27_n99: return 0.10529745370149612f;
  t27_n100: return 0.11073853820562363f;
  t27_n101: return 0.06336667388677597f;
  t27_n102: return 0.0836590901017189f;
  t27_n103: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t27_n213;
  t27_n104: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t27_n194;
  t27_n105: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t27_n149;
  t27_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t27_n108;
  t27_n107: return -0.10185298323631287f;
  t27_n108: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t27_n134;
  t27_n109: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t27_n113;
  t27_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t27_n112;
  t27_n111: return -0.07527177780866623f;
  t27_n112: return 0.09749510884284973f;
  t27_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t27_n131;
  t27_n114: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t27_n116;
  t27_n115: return 0.020543811842799187f;
  t27_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t27_n118;
  t27_n117: return 0.04278431460261345f;
  t27_n118: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t27_n124;
  t27_n119: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t27_n123;
  t27_n120: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t27_n122;
  t27_n121: return 0.06817318499088287f;
  t27_n122: return -0.12515026330947876f;
  t27_n123: return -0.1445506513118744f;
  t27_n124: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t27_n126;
  t27_n125: return 0.04412543401122093f;
  t27_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t27_n128;
  t27_n127: return 0.08207032829523087f;
  t27_n128: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t27_n130;
  t27_n129: return 0.10497482120990753f;
  t27_n130: return 0.056964632123708725f;
  t27_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t27_n133;
  t27_n132: return -0.1579478234052658f;
  t27_n133: return 0.06755433976650238f;
  t27_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t27_n138;
  t27_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t27_n137;
  t27_n136: return -0.01960107311606407f;
  t27_n137: return 0.038574106991291046f;
  t27_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t27_n146;
  t27_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t27_n141;
  t27_n140: return 0.048909012228250504f;
  t27_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n143;
  t27_n142: return 0.0763493999838829f;
  t27_n143: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t27_n145;
  t27_n144: return 0.11428479850292206f;
  t27_n145: return 0.05217314511537552f;
  t27_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t27_n148;
  t27_n147: return 0.11336711049079895f;
  t27_n148: return 0.09681560844182968f;
  t27_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t27_n181;
  t27_n150: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t27_n156;
  t27_n151: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t27_n153;
  t27_n152: return 0.05331927165389061f;
  t27_n153: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t27_n155;
  t27_n154: return 0.16469398140907288f;
  t27_n155: return -0.11179858446121216f;
  t27_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t27_n174;
  t27_n157: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t27_n159;
  t27_n158: return 0.07096464931964874f;
  t27_n159: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t27_n165;
  t27_n160: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t27_n162;
  t27_n161: return 0.11626150459051132f;
  t27_n162: if (E.getFilterLength() >= 3246653440 /*16.5*/) goto t27_n164;
  t27_n163: return 0.13258449733257294f;
  t27_n164: return 0.10530152916908264f;
  t27_n165: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t27_n169;
  t27_n166: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t27_n168;
  t27_n167: return 0.18532268702983856f;
  t27_n168: return 0.18019329011440277f;
  t27_n169: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t27_n173;
  t27_n170: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t27_n172;
  t27_n171: return 0.134942427277565f;
  t27_n172: return 0.13207806646823883f;
  t27_n173: return 0.12346258014440536f;
  t27_n174: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t27_n176;
  t27_n175: return 0.1062602698802948f;
  t27_n176: if (E.getNumReferences() >= 3341359232 /*43288.5*/) goto t27_n178;
  t27_n177: return 0.07957826554775238f;
  t27_n178: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t27_n180;
  t27_n179: return 0.08813734352588654f;
  t27_n180: return -0.05292808264493942f;
  t27_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n183;
  t27_n182: return 0.00472661666572094f;
  t27_n183: if (E.getNumReferences() >= 3271360512 /*126.5*/) goto t27_n193;
  t27_n184: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t27_n186;
  t27_n185: return 0.10558247566223145f;
  t27_n186: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t27_n188;
  t27_n187: return 0.11705932766199112f;
  t27_n188: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t27_n190;
  t27_n189: return 0.13552039861679077f;
  t27_n190: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t27_n192;
  t27_n191: return 0.11851337552070618f;
  t27_n192: return 0.14436441659927368f;
  t27_n193: return 0.10974132269620895f;
  t27_n194: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t27_n198;
  t27_n195: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t27_n197;
  t27_n196: return -0.02867922931909561f;
  t27_n197: return 0.07844355702400208f;
  t27_n198: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t27_n202;
  t27_n199: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t27_n201;
  t27_n200: return 0.04181888327002525f;
  t27_n201: return -0.11062851548194885f;
  t27_n202: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t27_n208;
  t27_n203: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t27_n205;
  t27_n204: return 0.03879576548933983f;
  t27_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t27_n207;
  t27_n206: return 0.05773795768618584f;
  t27_n207: return 0.09160872548818588f;
  t27_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t27_n212;
  t27_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n211;
  t27_n210: return 0.09366068989038467f;
  t27_n211: return 0.10056722909212112f;
  t27_n212: return 0.07204980403184891f;
  t27_n213: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t27_n229;
  t27_n214: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t27_n222;
  t27_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t27_n217;
  t27_n216: return 0.03919835388660431f;
  t27_n217: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t27_n221;
  t27_n218: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t27_n220;
  t27_n219: return 0.10484211146831512f;
  t27_n220: return 0.09291033446788788f;
  t27_n221: return 0.05861171334981918f;
  t27_n222: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t27_n226;
  t27_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n225;
  t27_n224: return 0.06753937900066376f;
  t27_n225: return 0.056757740676403046f;
  t27_n226: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t27_n228;
  t27_n227: return -0.18442082405090332f;
  t27_n228: return 0.10957329720258713f;
  t27_n229: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t27_n231;
  t27_n230: return 0.10683280974626541f;
  t27_n231: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t27_n233;
  t27_n232: return 0.08790922164916992f;
  t27_n233: return 0.09217962622642517f;
  t27_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t27_n248;
  t27_n235: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t27_n239;
  t27_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n238;
  t27_n237: return 0.02626214176416397f;
  t27_n238: return 0.056954458355903625f;
  t27_n239: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t27_n247;
  t27_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t27_n244;
  t27_n241: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t27_n243;
  t27_n242: return 0.05560321360826492f;
  t27_n243: return 0.09685510396957397f;
  t27_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t27_n246;
  t27_n245: return 0.06945163011550903f;
  t27_n246: return 0.08205331861972809f;
  t27_n247: return 0.05784423649311066f;
  t27_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t27_n254;
  t27_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t27_n251;
  t27_n250: return 0.08464425802230835f;
  t27_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n253;
  t27_n252: return 0.09648414701223373f;
  t27_n253: return 0.09941785782575607f;
  t27_n254: return 0.09814776480197906f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree28(const Example& E) {
  t28_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t28_n236;
  t28_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t28_n123;
  t28_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t28_n112;
  t28_n3: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t28_n73;
  t28_n4: if (E.getNumReferences() >= 3350479168 /*92290.5*/) goto t28_n60;
  t28_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t28_n9;
  t28_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t28_n8;
  t28_n7: return -0.07319080829620361f;
  t28_n8: return -0.034655600786209106f;
  t28_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t28_n11;
  t28_n10: return 0.004125924315303564f;
  t28_n11: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t28_n31;
  t28_n12: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t28_n28;
  t28_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t28_n27;
  t28_n14: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t28_n18;
  t28_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t28_n17;
  t28_n16: return 0.02764684334397316f;
  t28_n17: return 0.06906145811080933f;
  t28_n18: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t28_n20;
  t28_n19: return 0.0007923730299808085f;
  t28_n20: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t28_n26;
  t28_n21: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t28_n25;
  t28_n22: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t28_n24;
  t28_n23: return 0.0845867320895195f;
  t28_n24: return 0.10380563884973526f;
  t28_n25: return -0.01781434379518032f;
  t28_n26: return -0.14093796908855438f;
  t28_n27: return 0.055923204869031906f;
  t28_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t28_n30;
  t28_n29: return 0.11047772318124771f;
  t28_n30: return 0.12354728579521179f;
  t28_n31: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t28_n57;
  t28_n32: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t28_n40;
  t28_n33: if (E.getNumReferences() >= 3273031680 /*150.5*/) goto t28_n35;
  t28_n34: return 0.09117015451192856f;
  t28_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t28_n37;
  t28_n36: return 0.09104929864406586f;
  t28_n37: if (E.getNumReferences() >= 3288662016 /*532.0*/) goto t28_n39;
  t28_n38: return 0.10903242975473404f;
  t28_n39: return 0.11665262281894684f;
  t28_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t28_n44;
  t28_n41: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t28_n43;
  t28_n42: return 0.11676470935344696f;
  t28_n43: return 0.10730163007974625f;
  t28_n44: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t28_n48;
  t28_n45: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t28_n47;
  t28_n46: return 0.11589714139699936f;
  t28_n47: return 0.12234698981046677f;
  t28_n48: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t28_n54;
  t28_n49: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t28_n53;
  t28_n50: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t28_n52;
  t28_n51: return 0.13078458607196808f;
  t28_n52: return 0.14318498969078064f;
  t28_n53: return 0.13347768783569336f;
  t28_n54: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t28_n56;
  t28_n55: return 0.12436038255691528f;
  t28_n56: return 0.11671070754528046f;
  t28_n57: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t28_n59;
  t28_n58: return 0.01793665997684002f;
  t28_n59: return 0.07287955284118652f;
  t28_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n62;
  t28_n61: return 0.036084383726119995f;
  t28_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t28_n64;
  t28_n63: return 0.07390078157186508f;
  t28_n64: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t28_n72;
  t28_n65: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t28_n71;
  t28_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t28_n68;
  t28_n67: return -0.051693227142095566f;
  t28_n68: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t28_n70;
  t28_n69: return 0.1231718435883522f;
  t28_n70: return 0.09190519899129868f;
  t28_n71: return 0.059616170823574066f;
  t28_n72: return 0.12006671726703644f;
  t28_n73: if (E.getNumReferences() >= 3302551552 /*1735.5*/) goto t28_n75;
  t28_n74: return -0.07020708173513412f;
  t28_n75: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t28_n77;
  t28_n76: return -0.014188935048878193f;
  t28_n77: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t28_n83;
  t28_n78: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t28_n80;
  t28_n79: return -0.023351827636361122f;
  t28_n80: if (E.getNumReferences() >= 3346571264 /*63648.0*/) goto t28_n82;
  t28_n81: return 0.031273212283849716f;
  t28_n82: return 0.08856521546840668f;
  t28_n83: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t28_n87;
  t28_n84: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t28_n86;
  t28_n85: return 0.05735853686928749f;
  t28_n86: return 0.08539588004350662f;
  t28_n87: if (E.getNumReferences() >= 3322022400 /*8322.5*/) goto t28_n89;
  t28_n88: return 0.08893360942602158f;
  t28_n89: if (E.getNumReferences() >= 3332892672 /*21492.0*/) goto t28_n111;
  t28_n90: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t28_n100;
  t28_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t28_n95;
  t28_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t28_n94;
  t28_n93: return 0.09601203352212906f;
  t28_n94: return 0.11779074370861053f;
  t28_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t28_n97;
  t28_n96: return 0.09584145247936249f;
  t28_n97: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t28_n99;
  t28_n98: return 0.11194667965173721f;
  t28_n99: return 0.12073103338479996f;
  t28_n100: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t28_n110;
  t28_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t28_n107;
  t28_n102: if (E.getNumReferences() >= 3332280320 /*20296.0*/) goto t28_n106;
  t28_n103: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t28_n105;
  t28_n104: return 0.12021433562040329f;
  t28_n105: return 0.054349951446056366f;
  t28_n106: return 0.1137055903673172f;
  t28_n107: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t28_n109;
  t28_n108: return 0.1125812977552414f;
  t28_n109: return 0.10768667608499527f;
  t28_n110: return 0.12094046175479889f;
  t28_n111: return 0.08027283102273941f;
  t28_n112: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t28_n118;
  t28_n113: if (E.getNumReferences() >= 3266772992 /*91.5*/) goto t28_n117;
  t28_n114: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t28_n116;
  t28_n115: return 0.029525483027100563f;
  t28_n116: return 0.052279382944107056f;
  t28_n117: return 0.05336284637451172f;
  t28_n118: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t28_n122;
  t28_n119: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t28_n121;
  t28_n120: return 0.09209723770618439f;
  t28_n121: return 0.11341874301433563f;
  t28_n122: return 0.07904698699712753f;
  t28_n123: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t28_n211;
  t28_n124: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t28_n188;
  t28_n125: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t28_n165;
  t28_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t28_n128;
  t28_n127: return -0.09893183410167694f;
  t28_n128: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t28_n150;
  t28_n129: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t28_n133;
  t28_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t28_n132;
  t28_n131: return -0.07029975950717926f;
  t28_n132: return 0.09692507982254028f;
  t28_n133: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t28_n149;
  t28_n134: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t28_n148;
  t28_n135: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t28_n139;
  t28_n136: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t28_n138;
  t28_n137: return 0.04518013820052147f;
  t28_n138: return -0.024235466495156288f;
  t28_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t28_n141;
  t28_n140: return 0.04706069082021713f;
  t28_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t28_n143;
  t28_n142: return 0.05309688299894333f;
  t28_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t28_n145;
  t28_n144: return 0.06559275090694427f;
  t28_n145: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t28_n147;
  t28_n146: return 0.0474921390414238f;
  t28_n147: return 0.10299462080001831f;
  t28_n148: return 0.06512492150068283f;
  t28_n149: return 0.01391737349331379f;
  t28_n150: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t28_n152;
  t28_n151: return 0.03082091547548771f;
  t28_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t28_n162;
  t28_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t28_n155;
  t28_n154: return 0.04736173897981644f;
  t28_n155: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n159;
  t28_n156: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t28_n158;
  t28_n157: return 0.08003383129835129f;
  t28_n158: return 0.06252841651439667f;
  t28_n159: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t28_n161;
  t28_n160: return 0.11143464595079422f;
  t28_n161: return 0.05032835528254509f;
  t28_n162: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t28_n164;
  t28_n163: return 0.11182516068220139f;
  t28_n164: return 0.0966302752494812f;
  t28_n165: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n167;
  t28_n166: return 0.05253740772604942f;
  t28_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t28_n183;
  t28_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t28_n170;
  t28_n169: return 0.060715384781360626f;
  t28_n170: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t28_n178;
  t28_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t28_n173;
  t28_n172: return 0.08585411310195923f;
  t28_n173: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t28_n177;
  t28_n174: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t28_n176;
  t28_n175: return 0.11497923731803894f;
  t28_n176: return 0.10477931052446365f;
  t28_n177: return 0.0887206494808197f;
  t28_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t28_n180;
  t28_n179: return 0.11148922890424728f;
  t28_n180: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t28_n182;
  t28_n181: return 0.11767596751451492f;
  t28_n182: return 0.1345542073249817f;
  t28_n183: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t28_n185;
  t28_n184: return 0.1041170284152031f;
  t28_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t28_n187;
  t28_n186: return 0.04511601850390434f;
  t28_n187: return 0.1129213273525238f;
  t28_n188: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t28_n196;
  t28_n189: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t28_n195;
  t28_n190: if (E.getNumReferences() >= 3300749312 /*1515.5*/) goto t28_n192;
  t28_n191: return -0.03517380356788635f;
  t28_n192: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t28_n194;
  t28_n193: return 0.03208289295434952f;
  t28_n194: return 0.09019894152879715f;
  t28_n195: return 0.07574383914470673f;
  t28_n196: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t28_n200;
  t28_n197: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t28_n199;
  t28_n198: return 0.04015159234404564f;
  t28_n199: return -0.09610975533723831f;
  t28_n200: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t28_n206;
  t28_n201: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t28_n203;
  t28_n202: return 0.03590346500277519f;
  t28_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t28_n205;
  t28_n204: return 0.055153779685497284f;
  t28_n205: return 0.08987389504909515f;
  t28_n206: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t28_n210;
  t28_n207: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n209;
  t28_n208: return 0.08958028256893158f;
  t28_n209: return 0.09639377146959305f;
  t28_n210: return 0.06609519571065903f;
  t28_n211: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t28_n231;
  t28_n212: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t28_n222;
  t28_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t28_n217;
  t28_n214: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t28_n216;
  t28_n215: return 0.01606987603008747f;
  t28_n216: return 0.059487007558345795f;
  t28_n217: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t28_n221;
  t28_n218: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t28_n220;
  t28_n219: return 0.10172253847122192f;
  t28_n220: return 0.09002453833818436f;
  t28_n221: return 0.05638539791107178f;
  t28_n222: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t28_n230;
  t28_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n225;
  t28_n224: return 0.06888460367918015f;
  t28_n225: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t28_n227;
  t28_n226: return 0.061818260699510574f;
  t28_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t28_n229;
  t28_n228: return 0.10328233987092972f;
  t28_n229: return 0.05090958997607231f;
  t28_n230: return -0.06752050668001175f;
  t28_n231: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t28_n233;
  t28_n232: return 0.10481748729944229f;
  t28_n233: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t28_n235;
  t28_n234: return 0.08940485119819641f;
  t28_n235: return 0.0902535542845726f;
  t28_n236: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t28_n248;
  t28_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t28_n241;
  t28_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n240;
  t28_n239: return 0.023753339424729347f;
  t28_n240: return 0.05417478457093239f;
  t28_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t28_n247;
  t28_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t28_n244;
  t28_n243: return 0.053186748176813126f;
  t28_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t28_n246;
  t28_n245: return 0.0661201924085617f;
  t28_n246: return 0.07971949875354767f;
  t28_n247: return 0.0549158938229084f;
  t28_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t28_n254;
  t28_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t28_n251;
  t28_n250: return 0.08245819061994553f;
  t28_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n253;
  t28_n252: return 0.09542493522167206f;
  t28_n253: return 0.09814881533384323f;
  t28_n254: return 0.09708111733198166f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree29(const Example& E) {
  t29_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t29_n236;
  t29_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t29_n123;
  t29_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t29_n116;
  t29_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t29_n93;
  t29_n4: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t29_n84;
  t29_n5: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t29_n83;
  t29_n6: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t29_n50;
  t29_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t29_n21;
  t29_n8: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t29_n10;
  t29_n9: return -0.046342816203832626f;
  t29_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t29_n12;
  t29_n11: return -0.06902772933244705f;
  t29_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t29_n20;
  t29_n13: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t29_n15;
  t29_n14: return 0.07261911034584045f;
  t29_n15: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n19;
  t29_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t29_n18;
  t29_n17: return 0.11989691853523254f;
  t29_n18: return 0.031202232465147972f;
  t29_n19: return -0.1987142115831375f;
  t29_n20: return -0.06657100468873978f;
  t29_n21: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t29_n23;
  t29_n22: return -0.03819447383284569f;
  t29_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t29_n35;
  t29_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t29_n26;
  t29_n25: return -0.009936257265508175f;
  t29_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n28;
  t29_n27: return 0.10028426349163055f;
  t29_n28: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t29_n30;
  t29_n29: return -0.019022764638066292f;
  t29_n30: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t29_n34;
  t29_n31: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n33;
  t29_n32: return 0.21282723546028137f;
  t29_n33: return 0.08435684442520142f;
  t29_n34: return 0.12594260275363922f;
  t29_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t29_n41;
  t29_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t29_n38;
  t29_n37: return 0.04876156151294708f;
  t29_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t29_n40;
  t29_n39: return -0.15646661818027496f;
  t29_n40: return 0.0873827412724495f;
  t29_n41: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t29_n45;
  t29_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t29_n44;
  t29_n43: return 0.08962169289588928f;
  t29_n44: return 0.1135420873761177f;
  t29_n45: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n49;
  t29_n46: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t29_n48;
  t29_n47: return 0.12668254971504211f;
  t29_n48: return 0.11957183480262756f;
  t29_n49: return 0.08459299057722092f;
  t29_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t29_n52;
  t29_n51: return 0.01874445751309395f;
  t29_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t29_n70;
  t29_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t29_n61;
  t29_n54: if (E.getNumReferences() >= 3322526208 /*8814.5*/) goto t29_n56;
  t29_n55: return -0.00755287054926157f;
  t29_n56: if (E.getNumReferences() >= 3322619392 /*8905.5*/) goto t29_n60;
  t29_n57: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t29_n59;
  t29_n58: return 0.12436193227767944f;
  t29_n59: return 0.13846561312675476f;
  t29_n60: return 0.07065743207931519f;
  t29_n61: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t29_n63;
  t29_n62: return 0.11110251396894455f;
  t29_n63: if (E.getNumReferences() >= 3274440704 /*172.0*/) goto t29_n65;
  t29_n64: return 0.11706472933292389f;
  t29_n65: if (E.getNumReferences() >= 3283369984 /*360.5*/) goto t29_n69;
  t29_n66: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t29_n68;
  t29_n67: return 0.12824293971061707f;
  t29_n68: return 0.13060955703258514f;
  t29_n69: return 0.1376085877418518f;
  t29_n70: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t29_n76;
  t29_n71: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t29_n73;
  t29_n72: return 0.09456486999988556f;
  t29_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t29_n75;
  t29_n74: return 0.09248660504817963f;
  t29_n75: return 0.11247477680444717f;
  t29_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t29_n78;
  t29_n77: return 0.10990148037672043f;
  t29_n78: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t29_n82;
  t29_n79: if (E.getNumReferences() >= 3268870144 /*107.5*/) goto t29_n81;
  t29_n80: return 0.11561852693557739f;
  t29_n81: return 0.11510325223207474f;
  t29_n82: return 0.14070595800876617f;
  t29_n83: return 0.06530718505382538f;
  t29_n84: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n86;
  t29_n85: return -0.05977655202150345f;
  t29_n86: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t29_n92;
  t29_n87: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n89;
  t29_n88: return -0.04638363793492317f;
  t29_n89: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t29_n91;
  t29_n90: return 0.11303608864545822f;
  t29_n91: return 0.05235430970788002f;
  t29_n92: return 0.005024287384003401f;
  t29_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n95;
  t29_n94: return 0.003358637448400259f;
  t29_n95: if (E.getNumReferences() >= 3345992448 /*61387.0*/) goto t29_n115;
  t29_n96: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t29_n102;
  t29_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t29_n99;
  t29_n98: return 0.06009771302342415f;
  t29_n99: if (E.getNumReferences() >= 3266641920 /*90.5*/) goto t29_n101;
  t29_n100: return 0.07708510756492615f;
  t29_n101: return 0.09892570972442627f;
  t29_n102: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t29_n110;
  t29_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t29_n105;
  t29_n104: return -0.009806705638766289f;
  t29_n105: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t29_n109;
  t29_n106: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t29_n108;
  t29_n107: return 0.088361956179142f;
  t29_n108: return -0.028381850570440292f;
  t29_n109: return 0.06623093783855438f;
  t29_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t29_n114;
  t29_n111: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t29_n113;
  t29_n112: return 0.050270453095436096f;
  t29_n113: return 0.09959348291158676f;
  t29_n114: return 0.07924217730760574f;
  t29_n115: return 0.05385678634047508f;
  t29_n116: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t29_n120;
  t29_n117: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t29_n119;
  t29_n118: return 0.03142070025205612f;
  t29_n119: return 0.05258962884545326f;
  t29_n120: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t29_n122;
  t29_n121: return 0.10500594973564148f;
  t29_n122: return 0.07512295991182327f;
  t29_n123: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t29_n219;
  t29_n124: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t29_n186;
  t29_n125: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t29_n155;
  t29_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t29_n128;
  t29_n127: return -0.09745106846094131f;
  t29_n128: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t29_n134;
  t29_n129: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t29_n133;
  t29_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t29_n132;
  t29_n131: return -0.06522787362337112f;
  t29_n132: return 0.09363895654678345f;
  t29_n133: return 0.033611394464969635f;
  t29_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t29_n144;
  t29_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t29_n137;
  t29_n136: return -0.02598552405834198f;
  t29_n137: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t29_n141;
  t29_n138: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t29_n140;
  t29_n139: return 0.04784100130200386f;
  t29_n140: return 0.010532775893807411f;
  t29_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t29_n143;
  t29_n142: return -0.08310116082429886f;
  t29_n143: return 0.06661106646060944f;
  t29_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t29_n152;
  t29_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t29_n147;
  t29_n146: return 0.045855287462472916f;
  t29_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n149;
  t29_n148: return 0.07303889840841293f;
  t29_n149: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n151;
  t29_n150: return 0.10838281363248825f;
  t29_n151: return 0.0472366027534008f;
  t29_n152: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n154;
  t29_n153: return 0.11071507632732391f;
  t29_n154: return 0.09330449998378754f;
  t29_n155: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n157;
  t29_n156: return 0.04641267657279968f;
  t29_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t29_n179;
  t29_n158: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t29_n168;
  t29_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t29_n161;
  t29_n160: return 0.05389760807156563f;
  t29_n161: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t29_n163;
  t29_n162: return 0.08058474212884903f;
  t29_n163: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t29_n165;
  t29_n164: return 0.08672366291284561f;
  t29_n165: if (E.getNumReferences() >= 3273654272 /*160.0*/) goto t29_n167;
  t29_n166: return 0.1406799554824829f;
  t29_n167: return 0.08271614462137222f;
  t29_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t29_n170;
  t29_n169: return 0.10054317116737366f;
  t29_n170: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t29_n172;
  t29_n171: return 0.1188000962138176f;
  t29_n172: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t29_n174;
  t29_n173: return 0.10865415632724762f;
  t29_n174: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t29_n178;
  t29_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t29_n177;
  t29_n176: return -0.08888290077447891f;
  t29_n177: return 0.1406112015247345f;
  t29_n178: return 0.1138056144118309f;
  t29_n179: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t29_n181;
  t29_n180: return 0.095346599817276f;
  t29_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t29_n183;
  t29_n182: return 0.023462744429707527f;
  t29_n183: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t29_n185;
  t29_n184: return 0.10685291141271591f;
  t29_n185: return 0.12185629457235336f;
  t29_n186: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t29_n192;
  t29_n187: if (E.getNumReferences() >= 3307765760 /*2696.0*/) goto t29_n189;
  t29_n188: return -0.03190362825989723f;
  t29_n189: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t29_n191;
  t29_n190: return 0.03504772111773491f;
  t29_n191: return 0.08103670924901962f;
  t29_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t29_n196;
  t29_n193: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t29_n195;
  t29_n194: return 0.035387247800827026f;
  t29_n195: return -0.08757559955120087f;
  t29_n196: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t29_n214;
  t29_n197: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t29_n211;
  t29_n198: if (E.getNumReferences() >= 3331066112 /*17924.5*/) goto t29_n210;
  t29_n199: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t29_n201;
  t29_n200: return 0.055910874158144f;
  t29_n201: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t29_n203;
  t29_n202: return 0.0831533819437027f;
  t29_n203: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n209;
  t29_n204: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t29_n206;
  t29_n205: return 0.07934632152318954f;
  t29_n206: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t29_n208;
  t29_n207: return 0.1495693325996399f;
  t29_n208: return 0.06411650031805038f;
  t29_n209: return 0.16113150119781494f;
  t29_n210: return 0.09443002939224243f;
  t29_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t29_n213;
  t29_n212: return -0.13370732963085175f;
  t29_n213: return 0.03685329481959343f;
  t29_n214: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t29_n218;
  t29_n215: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n217;
  t29_n216: return 0.08628179877996445f;
  t29_n217: return 0.09292631596326828f;
  t29_n218: return 0.05570896714925766f;
  t29_n219: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t29_n231;
  t29_n220: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n228;
  t29_n221: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t29_n223;
  t29_n222: return 0.0332760326564312f;
  t29_n223: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t29_n227;
  t29_n224: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t29_n226;
  t29_n225: return 0.10125807672739029f;
  t29_n226: return 0.09415087103843689f;
  t29_n227: return 0.05448073521256447f;
  t29_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n230;
  t29_n229: return 0.06359212845563889f;
  t29_n230: return 0.05233462527394295f;
  t29_n231: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t29_n233;
  t29_n232: return 0.1058979481458664f;
  t29_n233: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t29_n235;
  t29_n234: return 0.08542871475219727f;
  t29_n235: return 0.08596237748861313f;
  t29_n236: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t29_n248;
  t29_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t29_n241;
  t29_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n240;
  t29_n239: return 0.022498339414596558f;
  t29_n240: return 0.05123157799243927f;
  t29_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t29_n247;
  t29_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t29_n244;
  t29_n243: return 0.0492643378674984f;
  t29_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t29_n246;
  t29_n245: return 0.0634249821305275f;
  t29_n246: return 0.07778431475162506f;
  t29_n247: return 0.053083471953868866f;
  t29_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t29_n254;
  t29_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t29_n251;
  t29_n250: return 0.08113537728786469f;
  t29_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n253;
  t29_n252: return 0.09383099526166916f;
  t29_n253: return 0.09715373814105988f;
  t29_n254: return 0.096180759370327f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree30(const Example& E) {
  t30_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t30_n234;
  t30_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t30_n113;
  t30_n2: if (E.getNumReferences() >= 3273031680 /*150.5*/) goto t30_n56;
  t30_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t30_n27;
  t30_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n6;
  t30_n5: return -0.07988978922367096f;
  t30_n6: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t30_n26;
  t30_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t30_n21;
  t30_n8: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t30_n10;
  t30_n9: return -0.011837724596261978f;
  t30_n10: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t30_n12;
  t30_n11: return 0.05911026522517204f;
  t30_n12: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t30_n14;
  t30_n13: return 0.09184220433235168f;
  t30_n14: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t30_n20;
  t30_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t30_n17;
  t30_n16: return 0.1204136312007904f;
  t30_n17: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t30_n19;
  t30_n18: return 0.12008615583181381f;
  t30_n19: return 0.12615050375461578f;
  t30_n20: return 0.12712682783603668f;
  t30_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t30_n23;
  t30_n22: return 0.06711600720882416f;
  t30_n23: if (E.getNumReferences() >= 3266641920 /*90.5*/) goto t30_n25;
  t30_n24: return 0.08316154032945633f;
  t30_n25: return 0.10889960080385208f;
  t30_n26: return -0.06890865415334702f;
  t30_n27: if (E.getFileProximityDistance() >= 3254517760 /*31.5*/) goto t30_n55;
  t30_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n36;
  t30_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t30_n31;
  t30_n30: return 0.009994917549192905f;
  t30_n31: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t30_n35;
  t30_n32: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t30_n34;
  t30_n33: return 0.10679509490728378f;
  t30_n34: return -0.2426668405532837f;
  t30_n35: return -0.019458986818790436f;
  t30_n36: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t30_n52;
  t30_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t30_n39;
  t30_n38: return 0.035064976662397385f;
  t30_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t30_n41;
  t30_n40: return 0.010810046456754208f;
  t30_n41: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t30_n51;
  t30_n42: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t30_n50;
  t30_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t30_n45;
  t30_n44: return 0.05226702243089676f;
  t30_n45: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t30_n47;
  t30_n46: return 0.0873592346906662f;
  t30_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t30_n49;
  t30_n48: return 0.10537770390510559f;
  t30_n49: return 0.09859009832143784f;
  t30_n50: return 0.09168054163455963f;
  t30_n51: return 0.043188780546188354f;
  t30_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t30_n54;
  t30_n53: return 0.06667513400316238f;
  t30_n54: return 0.08815333992242813f;
  t30_n55: return -0.012444643303751945f;
  t30_n56: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t30_n84;
  t30_n57: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t30_n75;
  t30_n58: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t30_n72;
  t30_n59: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t30_n61;
  t30_n60: return 0.024656780064105988f;
  t30_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t30_n65;
  t30_n62: if (E.getNumReferences() >= 3317562368 /*6079.5*/) goto t30_n64;
  t30_n63: return -0.0012585445074364543f;
  t30_n64: return 0.06809698045253754f;
  t30_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t30_n67;
  t30_n66: return 0.08644454926252365f;
  t30_n67: if (E.getNumReferences() >= 3281534976 /*304.5*/) goto t30_n69;
  t30_n68: return 0.0885462835431099f;
  t30_n69: if (E.getNumReferences() >= 3281829888 /*313.5*/) goto t30_n71;
  t30_n70: return 0.1275576949119568f;
  t30_n71: return 0.11204013973474503f;
  t30_n72: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t30_n74;
  t30_n73: return 0.060461290180683136f;
  t30_n74: return 0.10565366595983505f;
  t30_n75: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t30_n77;
  t30_n76: return -0.008197814226150513f;
  t30_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t30_n79;
  t30_n78: return 0.018756821751594543f;
  t30_n79: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t30_n81;
  t30_n80: return 0.03962288051843643f;
  t30_n81: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t30_n83;
  t30_n82: return 0.12694329023361206f;
  t30_n83: return 0.0654509961605072f;
  t30_n84: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t30_n108;
  t30_n85: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t30_n107;
  t30_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Expression))) goto t30_n88;
  t30_n87: return 0.09616822749376297f;
  t30_n88: if (E.getNumReferences() >= 3289939968 /*610.0*/) goto t30_n106;
  t30_n89: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t30_n105;
  t30_n90: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t30_n92;
  t30_n91: return 0.1150871068239212f;
  t30_n92: if (E.getNumReferences() >= 3278077952 /*227.5*/) goto t30_n96;
  t30_n93: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t30_n95;
  t30_n94: return 0.12735208868980408f;
  t30_n95: return 0.24654537439346313f;
  t30_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t30_n104;
  t30_n97: if (E.getNumReferences() >= 3278864384 /*239.5*/) goto t30_n99;
  t30_n98: return 0.14085908234119415f;
  t30_n99: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t30_n103;
  t30_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t30_n102;
  t30_n101: return 0.11776981502771378f;
  t30_n102: return 0.11984768509864807f;
  t30_n103: return 0.07943981140851974f;
  t30_n104: return 0.14028973877429962f;
  t30_n105: return 0.09518180042505264f;
  t30_n106: return 0.0895916074514389f;
  t30_n107: return 0.10031922161579132f;
  t30_n108: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t30_n110;
  t30_n109: return 0.06518664956092834f;
  t30_n110: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t30_n112;
  t30_n111: return 0.06675998121500015f;
  t30_n112: return 0.08457107841968536f;
  t30_n113: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t30_n211;
  t30_n114: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t30_n178;
  t30_n115: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t30_n149;
  t30_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t30_n118;
  t30_n117: return -0.09598101675510406f;
  t30_n118: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t30_n134;
  t30_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t30_n121;
  t30_n120: return -0.15779836475849152f;
  t30_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t30_n133;
  t30_n122: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t30_n132;
  t30_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t30_n127;
  t30_n124: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t30_n126;
  t30_n125: return 0.04070506989955902f;
  t30_n126: return -0.021104127168655396f;
  t30_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t30_n129;
  t30_n128: return 0.040375713258981705f;
  t30_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t30_n131;
  t30_n130: return 0.04531017690896988f;
  t30_n131: return 0.07937242835760117f;
  t30_n132: return 0.05943911522626877f;
  t30_n133: return 0.009574887342751026f;
  t30_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t30_n138;
  t30_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t30_n137;
  t30_n136: return 0.013735877349972725f;
  t30_n137: return 0.0369424931704998f;
  t30_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t30_n146;
  t30_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t30_n141;
  t30_n140: return 0.04621891677379608f;
  t30_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n143;
  t30_n142: return 0.06950265914201736f;
  t30_n143: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t30_n145;
  t30_n144: return 0.10534540563821793f;
  t30_n145: return 0.044251423329114914f;
  t30_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t30_n148;
  t30_n147: return 0.10934865474700928f;
  t30_n148: return 0.092179074883461f;
  t30_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n151;
  t30_n150: return 0.04512152820825577f;
  t30_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t30_n171;
  t30_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t30_n154;
  t30_n153: return 0.055864572525024414f;
  t30_n154: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t30_n160;
  t30_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t30_n157;
  t30_n156: return 0.07703255861997604f;
  t30_n157: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t30_n159;
  t30_n158: return 0.08839262276887894f;
  t30_n159: return 0.08814766258001328f;
  t30_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t30_n162;
  t30_n161: return 0.10727155208587646f;
  t30_n162: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t30_n164;
  t30_n163: return 0.0944567546248436f;
  t30_n164: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t30_n168;
  t30_n165: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t30_n167;
  t30_n166: return 0.1304481029510498f;
  t30_n167: return 0.12278269976377487f;
  t30_n168: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t30_n170;
  t30_n169: return 0.13254466652870178f;
  t30_n170: return 0.12339652329683304f;
  t30_n171: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t30_n173;
  t30_n172: return 0.09295044094324112f;
  t30_n173: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t30_n175;
  t30_n174: return 0.02907082438468933f;
  t30_n175: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t30_n177;
  t30_n176: return 0.10415984690189362f;
  t30_n177: return 0.11795271188020706f;
  t30_n178: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t30_n188;
  t30_n179: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t30_n185;
  t30_n180: if (E.getNumReferences() >= 3300749312 /*1515.5*/) goto t30_n182;
  t30_n181: return -0.030990881845355034f;
  t30_n182: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t30_n184;
  t30_n183: return 0.028061307966709137f;
  t30_n184: return 0.08609889447689056f;
  t30_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t30_n187;
  t30_n186: return 0.05196783319115639f;
  t30_n187: return 0.10321398079395294f;
  t30_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t30_n192;
  t30_n189: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t30_n191;
  t30_n190: return 0.03004598431289196f;
  t30_n191: return -0.08122137188911438f;
  t30_n192: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t30_n206;
  t30_n193: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n195;
  t30_n194: return -0.00908403005450964f;
  t30_n195: if (E.getNumReferences() >= 3346274176 /*62487.5*/) goto t30_n205;
  t30_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t30_n204;
  t30_n197: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t30_n199;
  t30_n198: return 0.06350743770599365f;
  t30_n199: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t30_n201;
  t30_n200: return 0.08375894278287888f;
  t30_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t30_n203;
  t30_n202: return 0.09417697042226791f;
  t30_n203: return 0.1538955420255661f;
  t30_n204: return 0.03191281855106354f;
  t30_n205: return 0.07869970053434372f;
  t30_n206: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t30_n210;
  t30_n207: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n209;
  t30_n208: return 0.08197664469480515f;
  t30_n209: return 0.08672332763671875f;
  t30_n210: return 0.055646561086177826f;
  t30_n211: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t30_n229;
  t30_n212: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t30_n224;
  t30_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t30_n217;
  t30_n214: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t30_n216;
  t30_n215: return 0.030619410797953606f;
  t30_n216: return 0.06381335109472275f;
  t30_n217: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t30_n223;
  t30_n218: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t30_n222;
  t30_n219: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t30_n221;
  t30_n220: return 0.10436039417982101f;
  t30_n221: return -0.015951581299304962f;
  t30_n222: return 0.0831737220287323f;
  t30_n223: return 0.050407856702804565f;
  t30_n224: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t30_n228;
  t30_n225: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t30_n227;
  t30_n226: return -0.011512279510498047f;
  t30_n227: return 0.11691262573003769f;
  t30_n228: return 0.06845016777515411f;
  t30_n229: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t30_n231;
  t30_n230: return 0.10322204977273941f;
  t30_n231: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t30_n233;
  t30_n232: return 0.0819946825504303f;
  t30_n233: return 0.08450005948543549f;
  t30_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t30_n248;
  t30_n235: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t30_n239;
  t30_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n238;
  t30_n237: return 0.02074565924704075f;
  t30_n238: return 0.04723113030195236f;
  t30_n239: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t30_n245;
  t30_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t30_n244;
  t30_n241: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t30_n243;
  t30_n242: return 0.04593530669808388f;
  t30_n243: return 0.094930000603199f;
  t30_n244: return 0.06572984158992767f;
  t30_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n247;
  t30_n246: return 0.033618710935115814f;
  t30_n247: return 0.06796739995479584f;
  t30_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t30_n254;
  t30_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t30_n251;
  t30_n250: return 0.07882481813430786f;
  t30_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n253;
  t30_n252: return 0.09273308515548706f;
  t30_n253: return 0.09622552245855331f;
  t30_n254: return 0.09499520063400269f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree31(const Example& E) {
  t31_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t31_n234;
  t31_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t31_n109;
  t31_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t31_n98;
  t31_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t31_n7;
  t31_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t31_n6;
  t31_n5: return -0.07411451637744904f;
  t31_n6: return -0.04307333007454872f;
  t31_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t31_n9;
  t31_n8: return -0.019794322550296783f;
  t31_n9: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t31_n65;
  t31_n10: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t31_n56;
  t31_n11: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t31_n27;
  t31_n12: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t31_n18;
  t31_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t31_n15;
  t31_n14: return 0.0566537119448185f;
  t31_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t31_n17;
  t31_n16: return 0.04594162479043007f;
  t31_n17: return 0.10637771338224411f;
  t31_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t31_n20;
  t31_n19: return 0.027454162016510963f;
  t31_n20: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t31_n22;
  t31_n21: return 0.07249496877193451f;
  t31_n22: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t31_n26;
  t31_n23: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t31_n25;
  t31_n24: return 0.10535271465778351f;
  t31_n25: return 0.04813031107187271f;
  t31_n26: return 0.09252878278493881f;
  t31_n27: if (E.getNumReferences() >= 3277619200 /*220.5*/) goto t31_n41;
  t31_n28: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t31_n30;
  t31_n29: return -0.008355220779776573f;
  t31_n30: if (E.getFileProximityDistance() >= 3254779904 /*32.0*/) goto t31_n40;
  t31_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t31_n33;
  t31_n32: return 0.0012523445766419172f;
  t31_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t31_n39;
  t31_n34: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t31_n36;
  t31_n35: return 0.057008251547813416f;
  t31_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t31_n38;
  t31_n37: return 0.018205493688583374f;
  t31_n38: return 0.09689542651176453f;
  t31_n39: return -0.06283459067344666f;
  t31_n40: return 0.05421716719865799f;
  t31_n41: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t31_n53;
  t31_n42: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t31_n52;
  t31_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n45;
  t31_n44: return 0.029634563252329826f;
  t31_n45: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t31_n51;
  t31_n46: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t31_n48;
  t31_n47: return 0.09400828927755356f;
  t31_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t31_n50;
  t31_n49: return 0.09707805514335632f;
  t31_n50: return 0.11406219750642776f;
  t31_n51: return 0.07081660628318787f;
  t31_n52: return 0.01956593431532383f;
  t31_n53: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t31_n55;
  t31_n54: return 0.10719464719295502f;
  t31_n55: return 0.08770495653152466f;
  t31_n56: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n58;
  t31_n57: return 0.02456427738070488f;
  t31_n58: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t31_n60;
  t31_n59: return 0.0919668897986412f;
  t31_n60: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t31_n62;
  t31_n61: return -0.18411147594451904f;
  t31_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t31_n64;
  t31_n63: return -0.20275302231311798f;
  t31_n64: return 0.0690579041838646f;
  t31_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t31_n85;
  t31_n66: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t31_n68;
  t31_n67: return 0.08910321444272995f;
  t31_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n70;
  t31_n69: return 0.05979388579726219f;
  t31_n70: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t31_n82;
  t31_n71: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t31_n73;
  t31_n72: return 0.03572395071387291f;
  t31_n73: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t31_n81;
  t31_n74: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t31_n80;
  t31_n75: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t31_n79;
  t31_n76: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t31_n78;
  t31_n77: return 0.12533311545848846f;
  t31_n78: return 0.11479062587022781f;
  t31_n79: return 0.09869313985109329f;
  t31_n80: return 0.1146898865699768f;
  t31_n81: return 0.025061940774321556f;
  t31_n82: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t31_n84;
  t31_n83: return 0.11295679956674576f;
  t31_n84: return 0.11715521663427353f;
  t31_n85: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t31_n95;
  t31_n86: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t31_n88;
  t31_n87: return 0.05382590368390083f;
  t31_n88: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t31_n94;
  t31_n89: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t31_n93;
  t31_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t31_n92;
  t31_n91: return 0.11542722582817078f;
  t31_n92: return 0.02210078574717045f;
  t31_n93: return -0.19121751189231873f;
  t31_n94: return -0.22946575284004211f;
  t31_n95: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n97;
  t31_n96: return 0.14832377433776855f;
  t31_n97: return 0.1858838051557541f;
  t31_n98: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t31_n104;
  t31_n99: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t31_n103;
  t31_n100: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t31_n102;
  t31_n101: return 0.026507295668125153f;
  t31_n102: return 0.04763495549559593f;
  t31_n103: return 0.0511174201965332f;
  t31_n104: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t31_n108;
  t31_n105: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t31_n107;
  t31_n106: return 0.08533474802970886f;
  t31_n107: return 0.11100007593631744f;
  t31_n108: return 0.0723692774772644f;
  t31_n109: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t31_n183;
  t31_n110: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t31_n170;
  t31_n111: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t31_n145;
  t31_n112: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t31_n114;
  t31_n113: return -0.09410938620567322f;
  t31_n114: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t31_n132;
  t31_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t31_n117;
  t31_n116: return -0.15148615837097168f;
  t31_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t31_n131;
  t31_n118: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t31_n130;
  t31_n119: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t31_n123;
  t31_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t31_n122;
  t31_n121: return -0.022946802899241447f;
  t31_n122: return 0.04511291906237602f;
  t31_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t31_n125;
  t31_n124: return 0.03840666636824608f;
  t31_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t31_n127;
  t31_n126: return 0.04200948029756546f;
  t31_n127: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t31_n129;
  t31_n128: return 0.0867886170744896f;
  t31_n129: return -0.11481592059135437f;
  t31_n130: return 0.057327136397361755f;
  t31_n131: return 0.009328179061412811f;
  t31_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t31_n134;
  t31_n133: return 0.024536680430173874f;
  t31_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t31_n142;
  t31_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t31_n137;
  t31_n136: return 0.0336955189704895f;
  t31_n137: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n139;
  t31_n138: return 0.06602799892425537f;
  t31_n139: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t31_n141;
  t31_n140: return 0.10225320607423782f;
  t31_n141: return 0.04154878854751587f;
  t31_n142: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t31_n144;
  t31_n143: return 0.10880439728498459f;
  t31_n144: return 0.09298846125602722f;
  t31_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n147;
  t31_n146: return 0.040481675416231155f;
  t31_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t31_n165;
  t31_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t31_n150;
  t31_n149: return 0.05390727519989014f;
  t31_n150: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t31_n154;
  t31_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t31_n153;
  t31_n152: return 0.07455972582101822f;
  t31_n153: return 0.08534149825572968f;
  t31_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t31_n156;
  t31_n155: return 0.10435163974761963f;
  t31_n156: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t31_n158;
  t31_n157: return 0.09250275045633316f;
  t31_n158: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t31_n162;
  t31_n159: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t31_n161;
  t31_n160: return 0.1259382665157318f;
  t31_n161: return 0.12008083611726761f;
  t31_n162: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t31_n164;
  t31_n163: return 0.12787263095378876f;
  t31_n164: return 0.12167565524578094f;
  t31_n165: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t31_n167;
  t31_n166: return 0.08966151624917984f;
  t31_n167: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t31_n169;
  t31_n168: return 0.097087562084198f;
  t31_n169: return 0.11353477835655212f;
  t31_n170: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t31_n174;
  t31_n171: if (E.getNumReferences() >= 3307765760 /*2696.0*/) goto t31_n173;
  t31_n172: return -0.027178598567843437f;
  t31_n173: return 0.03448713570833206f;
  t31_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t31_n176;
  t31_n175: return -0.027857527136802673f;
  t31_n176: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t31_n180;
  t31_n177: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t31_n179;
  t31_n178: return 0.04460880532860756f;
  t31_n179: return 0.015473397448658943f;
  t31_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t31_n182;
  t31_n181: return 0.0486983060836792f;
  t31_n182: return 0.08331289887428284f;
  t31_n183: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t31_n197;
  t31_n184: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t31_n196;
  t31_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t31_n189;
  t31_n186: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t31_n188;
  t31_n187: return 0.034080833196640015f;
  t31_n188: return 0.059069495648145676f;
  t31_n189: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t31_n195;
  t31_n190: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t31_n194;
  t31_n191: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t31_n193;
  t31_n192: return 0.10036890208721161f;
  t31_n193: return -0.02507765218615532f;
  t31_n194: return 0.07879649847745895f;
  t31_n195: return 0.04814474284648895f;
  t31_n196: return 0.07219839841127396f;
  t31_n197: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t31_n231;
  t31_n198: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t31_n218;
  t31_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t31_n201;
  t31_n200: return 0.1048678383231163f;
  t31_n201: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t31_n203;
  t31_n202: return 0.09876088798046112f;
  t31_n203: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t31_n217;
  t31_n204: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t31_n208;
  t31_n205: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t31_n207;
  t31_n206: return 0.12210358679294586f;
  t31_n207: return 0.13390330970287323f;
  t31_n208: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t31_n210;
  t31_n209: return 0.11702311038970947f;
  t31_n210: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t31_n216;
  t31_n211: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t31_n215;
  t31_n212: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t31_n214;
  t31_n213: return -0.11049437522888184f;
  t31_n214: return 0.14934110641479492f;
  t31_n215: return 0.1315069943666458f;
  t31_n216: return 0.14992696046829224f;
  t31_n217: return 0.12772290408611298f;
  t31_n218: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t31_n220;
  t31_n219: return 0.013012549839913845f;
  t31_n220: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t31_n230;
  t31_n221: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t31_n223;
  t31_n222: return 0.08851122111082077f;
  t31_n223: if (E.getNumReferences() >= 3269459968 /*112.0*/) goto t31_n229;
  t31_n224: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t31_n228;
  t31_n225: if (E.getNumReferences() >= 3255304192 /*34.0*/) goto t31_n227;
  t31_n226: return 0.11316315084695816f;
  t31_n227: return 0.17409545183181763f;
  t31_n228: return 0.03492238372564316f;
  t31_n229: return 0.1178073137998581f;
  t31_n230: return 0.08135859668254852f;
  t31_n231: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t31_n233;
  t31_n232: return 0.07870391011238098f;
  t31_n233: return 0.07998043298721313f;
  t31_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t31_n248;
  t31_n235: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t31_n239;
  t31_n236: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t31_n238;
  t31_n237: return 0.02398156188428402f;
  t31_n238: return 0.0642051100730896f;
  t31_n239: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t31_n245;
  t31_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t31_n244;
  t31_n241: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t31_n243;
  t31_n242: return 0.042972054332494736f;
  t31_n243: return 0.09579891711473465f;
  t31_n244: return 0.0626397505402565f;
  t31_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n247;
  t31_n246: return 0.03134853392839432f;
  t31_n247: return 0.06560327112674713f;
  t31_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t31_n254;
  t31_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t31_n251;
  t31_n250: return 0.07719690352678299f;
  t31_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n253;
  t31_n252: return 0.09079969674348831f;
  t31_n253: return 0.09508895874023438f;
  t31_n254: return 0.09379677474498749f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree32(const Example& E) {
  t32_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t32_n244;
  t32_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t32_n121;
  t32_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t32_n114;
  t32_n3: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t32_n35;
  t32_n4: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t32_n20;
  t32_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t32_n19;
  t32_n6: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t32_n8;
  t32_n7: return -0.04602367803454399f;
  t32_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t32_n10;
  t32_n9: return -0.05131932720541954f;
  t32_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t32_n18;
  t32_n11: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t32_n13;
  t32_n12: return 0.058712247759103775f;
  t32_n13: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t32_n17;
  t32_n14: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t32_n16;
  t32_n15: return 0.11268454790115356f;
  t32_n16: return 0.018008451908826828f;
  t32_n17: return -0.1302957385778427f;
  t32_n18: return -0.05191807076334953f;
  t32_n19: return -0.01255775149911642f;
  t32_n20: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t32_n24;
  t32_n21: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t32_n23;
  t32_n22: return 0.024995483458042145f;
  t32_n23: return 0.053215205669403076f;
  t32_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t32_n26;
  t32_n25: return 0.04508533328771591f;
  t32_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t32_n28;
  t32_n27: return 0.0893661379814148f;
  t32_n28: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t32_n34;
  t32_n29: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t32_n31;
  t32_n30: return 0.09098424762487411f;
  t32_n31: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t32_n33;
  t32_n32: return 0.1129998043179512f;
  t32_n33: return 0.12127768993377686f;
  t32_n34: return 0.1045694425702095f;
  t32_n35: if (E.getNumReferences() >= 3297873920 /*1164.5*/) goto t32_n65;
  t32_n36: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t32_n64;
  t32_n37: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t32_n39;
  t32_n38: return -0.07066159695386887f;
  t32_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t32_n41;
  t32_n40: return 0.007132420781999826f;
  t32_n41: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t32_n47;
  t32_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag))) goto t32_n44;
  t32_n43: return 0.020345350727438927f;
  t32_n44: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t32_n46;
  t32_n45: return 0.04207784682512283f;
  t32_n46: return 0.08316624164581299f;
  t32_n47: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t32_n53;
  t32_n48: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t32_n52;
  t32_n49: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t32_n51;
  t32_n50: return 0.1705029159784317f;
  t32_n51: return 0.053396329283714294f;
  t32_n52: return -0.005190904717892408f;
  t32_n53: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t32_n63;
  t32_n54: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t32_n62;
  t32_n55: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t32_n57;
  t32_n56: return 0.1745147705078125f;
  t32_n57: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t32_n59;
  t32_n58: return 0.166315495967865f;
  t32_n59: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t32_n61;
  t32_n60: return 0.17488929629325867f;
  t32_n61: return 0.17180435359477997f;
  t32_n62: return 0.05354469642043114f;
  t32_n63: return 0.10866813361644745f;
  t32_n64: return -0.13024494051933289f;
  t32_n65: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t32_n67;
  t32_n66: return -0.006889455020427704f;
  t32_n67: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t32_n71;
  t32_n68: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t32_n70;
  t32_n69: return 0.037961069494485855f;
  t32_n70: return 0.07622769474983215f;
  t32_n71: if (E.getNumReferences() >= 3333896192 /*23452.0*/) goto t32_n107;
  t32_n72: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t32_n74;
  t32_n73: return 0.0605032853782177f;
  t32_n74: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t32_n90;
  t32_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t32_n81;
  t32_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t32_n78;
  t32_n77: return 0.07511378824710846f;
  t32_n78: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t32_n80;
  t32_n79: return 0.09188303351402283f;
  t32_n80: return 0.1027001366019249f;
  t32_n81: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t32_n83;
  t32_n82: return 0.10775981843471527f;
  t32_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t32_n85;
  t32_n84: return 0.09258915483951569f;
  t32_n85: if (E.getNumReferences() >= 3331329792 /*18439.5*/) goto t32_n89;
  t32_n86: if (E.getNumReferences() >= 3331038976 /*17871.5*/) goto t32_n88;
  t32_n87: return 0.11941427737474442f;
  t32_n88: return 0.11313833296298981f;
  t32_n89: return 0.10395792126655579f;
  t32_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t32_n92;
  t32_n91: return 0.10231499373912811f;
  t32_n92: if (E.getNumReferences() >= 3331545088 /*18860.0*/) goto t32_n102;
  t32_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t32_n101;
  t32_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t32_n96;
  t32_n95: return 0.0877973884344101f;
  t32_n96: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t32_n100;
  t32_n97: if (E.getNumReferences() >= 3325171712 /*11398.0*/) goto t32_n99;
  t32_n98: return 0.10151828080415726f;
  t32_n99: return 0.11287166178226471f;
  t32_n100: return 0.10811910033226013f;
  t32_n101: return 0.11399803310632706f;
  t32_n102: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t32_n106;
  t32_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t32_n105;
  t32_n104: return -0.11154328286647797f;
  t32_n105: return 0.10750268399715424f;
  t32_n106: return 0.11773435771465302f;
  t32_n107: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t32_n109;
  t32_n108: return 0.027166256681084633f;
  t32_n109: if (E.getNumReferences() >= 3360267424 /*206450.5*/) goto t32_n113;
  t32_n110: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t32_n112;
  t32_n111: return 0.09300626069307327f;
  t32_n112: return 0.11289087682962418f;
  t32_n113: return 0.05705789849162102f;
  t32_n114: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t32_n118;
  t32_n115: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t32_n117;
  t32_n116: return 0.03143789619207382f;
  t32_n117: return 0.04844158887863159f;
  t32_n118: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t32_n120;
  t32_n119: return 0.10109245032072067f;
  t32_n120: return 0.06979764252901077f;
  t32_n121: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t32_n191;
  t32_n122: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t32_n174;
  t32_n123: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t32_n149;
  t32_n124: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t32_n126;
  t32_n125: return -0.09165337681770325f;
  t32_n126: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t32_n138;
  t32_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t32_n137;
  t32_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t32_n130;
  t32_n129: return -0.06290064007043839f;
  t32_n130: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t32_n132;
  t32_n131: return 0.00994063075631857f;
  t32_n132: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t32_n134;
  t32_n133: return 0.09769657254219055f;
  t32_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t32_n136;
  t32_n135: return -0.06351738423109055f;
  t32_n136: return 0.08827611804008484f;
  t32_n137: return 0.03258704021573067f;
  t32_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t32_n140;
  t32_n139: return 0.021195976063609123f;
  t32_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t32_n146;
  t32_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t32_n143;
  t32_n142: return 0.033814575523138046f;
  t32_n143: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t32_n145;
  t32_n144: return 0.08152149617671967f;
  t32_n145: return 0.03981047123670578f;
  t32_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t32_n148;
  t32_n147: return 0.10754305124282837f;
  t32_n148: return 0.09091003239154816f;
  t32_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t32_n151;
  t32_n150: return 0.03896127641201019f;
  t32_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t32_n169;
  t32_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t32_n154;
  t32_n153: return 0.051459841430187225f;
  t32_n154: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t32_n158;
  t32_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t32_n157;
  t32_n156: return 0.07138580083847046f;
  t32_n157: return 0.08192767202854156f;
  t32_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t32_n160;
  t32_n159: return 0.09855083376169205f;
  t32_n160: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t32_n162;
  t32_n161: return 0.08927515149116516f;
  t32_n162: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t32_n166;
  t32_n163: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t32_n165;
  t32_n164: return 0.12033988535404205f;
  t32_n165: return 0.11839272826910019f;
  t32_n166: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t32_n168;
  t32_n167: return 0.12431298196315765f;
  t32_n168: return 0.12230589985847473f;
  t32_n169: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t32_n171;
  t32_n170: return 0.08777765929698944f;
  t32_n171: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t32_n173;
  t32_n172: return 0.016477419063448906f;
  t32_n173: return 0.1040799617767334f;
  t32_n174: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t32_n178;
  t32_n175: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t32_n177;
  t32_n176: return -0.019507434219121933f;
  t32_n177: return 0.06416507810354233f;
  t32_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t32_n182;
  t32_n179: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t32_n181;
  t32_n180: return 0.004355084616690874f;
  t32_n181: return 0.04691008850932121f;
  t32_n182: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t32_n186;
  t32_n183: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t32_n185;
  t32_n184: return 0.021839236840605736f;
  t32_n185: return 0.049330323934555054f;
  t32_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t32_n190;
  t32_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t32_n189;
  t32_n188: return 0.07744351029396057f;
  t32_n189: return 0.08434715867042542f;
  t32_n190: return 0.04574592784047127f;
  t32_n191: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t32_n207;
  t32_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t32_n196;
  t32_n193: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t32_n195;
  t32_n194: return 0.026734961196780205f;
  t32_n195: return 0.05505753681063652f;
  t32_n196: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t32_n206;
  t32_n197: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t32_n205;
  t32_n198: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t32_n204;
  t32_n199: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t32_n203;
  t32_n200: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t32_n202;
  t32_n201: return 0.11201421171426773f;
  t32_n202: return 0.06820883601903915f;
  t32_n203: return -0.013675825670361519f;
  t32_n204: return 0.07530423998832703f;
  t32_n205: return 0.044148705899715424f;
  t32_n206: return 0.06914860755205154f;
  t32_n207: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t32_n241;
  t32_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t32_n210;
  t32_n209: return 0.09846442937850952f;
  t32_n210: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t32_n224;
  t32_n211: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t32_n213;
  t32_n212: return 0.06975579261779785f;
  t32_n213: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t32_n215;
  t32_n214: return 0.08125975728034973f;
  t32_n215: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t32_n221;
  t32_n216: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t32_n220;
  t32_n217: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t32_n219;
  t32_n218: return 0.11469855159521103f;
  t32_n219: return 0.16268904507160187f;
  t32_n220: return 0.09036900848150253f;
  t32_n221: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t32_n223;
  t32_n222: return 0.1154247596859932f;
  t32_n223: return 0.1224432960152626f;
  t32_n224: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t32_n226;
  t32_n225: return 0.09800039976835251f;
  t32_n226: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t32_n240;
  t32_n227: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t32_n233;
  t32_n228: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t32_n230;
  t32_n229: return 0.0811709463596344f;
  t32_n230: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t32_n232;
  t32_n231: return 0.13057731091976166f;
  t32_n232: return 0.13365723192691803f;
  t32_n233: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t32_n239;
  t32_n234: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t32_n238;
  t32_n235: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t32_n237;
  t32_n236: return -0.16824063658714294f;
  t32_n237: return 0.1457187831401825f;
  t32_n238: return 0.1266189068555832f;
  t32_n239: return 0.14133939146995544f;
  t32_n240: return 0.12335138022899628f;
  t32_n241: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t32_n243;
  t32_n242: return 0.0759904533624649f;
  t32_n243: return 0.08317477256059647f;
  t32_n244: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t32_n248;
  t32_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t32_n247;
  t32_n246: return 0.0255378820002079f;
  t32_n247: return 0.05114961415529251f;
  t32_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t32_n254;
  t32_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t32_n251;
  t32_n250: return 0.07462623715400696f;
  t32_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t32_n253;
  t32_n252: return 0.08907203376293182f;
  t32_n253: return 0.09381041675806046f;
  t32_n254: return 0.09259036183357239f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree33(const Example& E) {
  t33_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t33_n242;
  t33_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t33_n167;
  t33_n2: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t33_n64;
  t33_n3: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t33_n21;
  t33_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n6;
  t33_n5: return -0.07424012571573257f;
  t33_n6: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t33_n18;
  t33_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t33_n15;
  t33_n8: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t33_n10;
  t33_n9: return 0.004568946082144976f;
  t33_n10: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t33_n12;
  t33_n11: return 0.055402301251888275f;
  t33_n12: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t33_n14;
  t33_n13: return 0.08651256561279297f;
  t33_n14: return 0.10638370364904404f;
  t33_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t33_n17;
  t33_n16: return 0.06880543380975723f;
  t33_n17: return 0.08545611053705215f;
  t33_n18: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t33_n20;
  t33_n19: return -0.06700631976127625f;
  t33_n20: return 0.020558400079607964f;
  t33_n21: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t33_n35;
  t33_n22: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t33_n34;
  t33_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t33_n25;
  t33_n24: return 0.026111025363206863f;
  t33_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t33_n29;
  t33_n26: if (E.getNumReferences() >= 3317562368 /*6079.5*/) goto t33_n28;
  t33_n27: return 1.3816131286148448e-05f;
  t33_n28: return 0.07092804461717606f;
  t33_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t33_n31;
  t33_n30: return 0.08442425727844238f;
  t33_n31: if (E.getNumReferences() >= 3288662016 /*532.0*/) goto t33_n33;
  t33_n32: return 0.10713803023099899f;
  t33_n33: return 0.11418567597866058f;
  t33_n34: return -0.009524664841592312f;
  t33_n35: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t33_n43;
  t33_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t33_n38;
  t33_n37: return 0.11339371651411057f;
  t33_n38: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t33_n40;
  t33_n39: return 0.11434896290302277f;
  t33_n40: if (E.getNumReferences() >= 3267952640 /*100.5*/) goto t33_n42;
  t33_n41: return 0.1228564903140068f;
  t33_n42: return 0.12774993479251862f;
  t33_n43: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t33_n61;
  t33_n44: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t33_n60;
  t33_n45: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t33_n59;
  t33_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t33_n48;
  t33_n47: return 0.07014434039592743f;
  t33_n48: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t33_n54;
  t33_n49: if (E.getNumReferences() >= 3280257024 /*265.5*/) goto t33_n51;
  t33_n50: return 0.11370737850666046f;
  t33_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t33_n53;
  t33_n52: return 0.1099417582154274f;
  t33_n53: return 0.13433025777339935f;
  t33_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t33_n56;
  t33_n55: return 0.11940054595470428f;
  t33_n56: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t33_n58;
  t33_n57: return 0.13003960251808167f;
  t33_n58: return 0.11454390734434128f;
  t33_n59: return 0.13039498031139374f;
  t33_n60: return 0.0628533810377121f;
  t33_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t33_n63;
  t33_n62: return 0.061495590955019f;
  t33_n63: return 0.08833400905132294f;
  t33_n64: if (E.getFileProximityDistance() >= 3255435264 /*34.5*/) goto t33_n104;
  t33_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n67;
  t33_n66: return 0.004041620995849371f;
  t33_n67: if (E.getNumReferences() >= 3335302144 /*26198.0*/) goto t33_n103;
  t33_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t33_n98;
  t33_n69: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t33_n81;
  t33_n70: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t33_n80;
  t33_n71: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t33_n79;
  t33_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t33_n74;
  t33_n73: return 0.03164295107126236f;
  t33_n74: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t33_n76;
  t33_n75: return 0.053082339465618134f;
  t33_n76: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t33_n78;
  t33_n77: return 0.09252900630235672f;
  t33_n78: return 0.026155253872275352f;
  t33_n79: return 0.029090087860822678f;
  t33_n80: return 0.005033364985138178f;
  t33_n81: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t33_n83;
  t33_n82: return 0.04401484131813049f;
  t33_n83: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t33_n97;
  t33_n84: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t33_n86;
  t33_n85: return 0.05068403482437134f;
  t33_n86: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t33_n96;
  t33_n87: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t33_n89;
  t33_n88: return 0.01939484104514122f;
  t33_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t33_n91;
  t33_n90: return 0.09934631735086441f;
  t33_n91: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t33_n93;
  t33_n92: return -0.11727119237184525f;
  t33_n93: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t33_n95;
  t33_n94: return 0.12698420882225037f;
  t33_n95: return 0.10252104699611664f;
  t33_n96: return 0.038346316665410995f;
  t33_n97: return 0.08246398717164993f;
  t33_n98: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t33_n102;
  t33_n99: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t33_n101;
  t33_n100: return 0.05859338119626045f;
  t33_n101: return 0.08106959611177444f;
  t33_n102: return 0.009252588264644146f;
  t33_n103: return 0.05976543202996254f;
  t33_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t33_n106;
  t33_n105: return -0.032753780484199524f;
  t33_n106: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t33_n142;
  t33_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t33_n109;
  t33_n108: return -0.013651938177645206f;
  t33_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t33_n111;
  t33_n110: return -0.003099750727415085f;
  t33_n111: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t33_n113;
  t33_n112: return 0.06533350050449371f;
  t33_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t33_n119;
  t33_n114: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t33_n116;
  t33_n115: return 0.08945854008197784f;
  t33_n116: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t33_n118;
  t33_n117: return 0.11460621654987335f;
  t33_n118: return 0.03149433806538582f;
  t33_n119: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t33_n127;
  t33_n120: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t33_n126;
  t33_n121: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t33_n125;
  t33_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t33_n124;
  t33_n123: return 0.10992425680160522f;
  t33_n124: return 0.01304571982473135f;
  t33_n125: return -0.14846475422382355f;
  t33_n126: return -0.13547883927822113f;
  t33_n127: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t33_n141;
  t33_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n132;
  t33_n129: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t33_n131;
  t33_n130: return 0.15059779584407806f;
  t33_n131: return 0.05925422161817551f;
  t33_n132: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t33_n140;
  t33_n133: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t33_n135;
  t33_n134: return 0.15743069350719452f;
  t33_n135: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t33_n137;
  t33_n136: return 0.15019486844539642f;
  t33_n137: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t33_n139;
  t33_n138: return 0.15655730664730072f;
  t33_n139: return 0.15667423605918884f;
  t33_n140: return 0.04684830084443092f;
  t33_n141: return 0.041480787098407745f;
  t33_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t33_n156;
  t33_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t33_n145;
  t33_n144: return -0.024218598380684853f;
  t33_n145: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t33_n149;
  t33_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n148;
  t33_n147: return 0.11734188348054886f;
  t33_n148: return 0.10816497355699539f;
  t33_n149: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t33_n151;
  t33_n150: return 0.11992766708135605f;
  t33_n151: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t33_n155;
  t33_n152: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t33_n154;
  t33_n153: return 0.12322815507650375f;
  t33_n154: return 0.11613902449607849f;
  t33_n155: return 0.08438374847173691f;
  t33_n156: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t33_n166;
  t33_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n159;
  t33_n158: return 0.20031362771987915f;
  t33_n159: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t33_n165;
  t33_n160: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t33_n164;
  t33_n161: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t33_n163;
  t33_n162: return 0.1454942375421524f;
  t33_n163: return 0.12656530737876892f;
  t33_n164: return 0.12318436801433563f;
  t33_n165: return 0.10555646568536758f;
  t33_n166: return -0.08487161993980408f;
  t33_n167: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t33_n231;
  t33_n168: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t33_n214;
  t33_n169: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t33_n197;
  t33_n170: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t33_n172;
  t33_n171: return -0.08860339969396591f;
  t33_n172: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t33_n186;
  t33_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t33_n185;
  t33_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t33_n176;
  t33_n175: return -0.060534585267305374f;
  t33_n176: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t33_n178;
  t33_n177: return 0.0018639143090695143f;
  t33_n178: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t33_n184;
  t33_n179: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t33_n181;
  t33_n180: return 0.021751653403043747f;
  t33_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n183;
  t33_n182: return 0.09722376614809036f;
  t33_n183: return 0.05784930661320686f;
  t33_n184: return -0.15091529488563538f;
  t33_n185: return 0.031117860227823257f;
  t33_n186: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t33_n188;
  t33_n187: return 0.01863723061978817f;
  t33_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t33_n190;
  t33_n189: return 0.02839483879506588f;
  t33_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t33_n194;
  t33_n191: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t33_n193;
  t33_n192: return 0.0771755650639534f;
  t33_n193: return 0.040834613144397736f;
  t33_n194: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t33_n196;
  t33_n195: return 0.10678625106811523f;
  t33_n196: return 0.0904608890414238f;
  t33_n197: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n199;
  t33_n198: return 0.038524314761161804f;
  t33_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t33_n209;
  t33_n200: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t33_n202;
  t33_n201: return 0.04926423728466034f;
  t33_n202: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t33_n204;
  t33_n203: return 0.07279983907938004f;
  t33_n204: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t33_n206;
  t33_n205: return 0.07970425486564636f;
  t33_n206: if (E.getNumReferences() >= 3273654272 /*160.0*/) goto t33_n208;
  t33_n207: return 0.128156840801239f;
  t33_n208: return 0.07702026516199112f;
  t33_n209: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t33_n211;
  t33_n210: return 0.08420182019472122f;
  t33_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t33_n213;
  t33_n212: return 0.014953520148992538f;
  t33_n213: return 0.10166723281145096f;
  t33_n214: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t33_n226;
  t33_n215: if (E.getNumReferences() >= 3283697664 /*370.5*/) goto t33_n217;
  t33_n216: return -0.027106957510113716f;
  t33_n217: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t33_n219;
  t33_n218: return 0.028075912967324257f;
  t33_n219: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t33_n223;
  t33_n220: if (E.getNumReferences() >= 3294248960 /*873.0*/) goto t33_n222;
  t33_n221: return 0.12394590675830841f;
  t33_n222: return 0.11242450028657913f;
  t33_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t33_n225;
  t33_n224: return 0.075131356716156f;
  t33_n225: return 0.09801036864519119f;
  t33_n226: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t33_n228;
  t33_n227: return -0.022769948467612267f;
  t33_n228: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t33_n230;
  t33_n229: return 0.032823596149683f;
  t33_n230: return 0.046517640352249146f;
  t33_n231: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t33_n239;
  t33_n232: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t33_n236;
  t33_n233: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t33_n235;
  t33_n234: return 0.07667089998722076f;
  t33_n235: return 0.03740975260734558f;
  t33_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n238;
  t33_n237: return 0.07089319825172424f;
  t33_n238: return 0.05505699664354324f;
  t33_n239: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t33_n241;
  t33_n240: return 0.09733989834785461f;
  t33_n241: return 0.07461578398942947f;
  t33_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t33_n248;
  t33_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t33_n245;
  t33_n244: return 0.024982482194900513f;
  t33_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n247;
  t33_n246: return 0.03455371409654617f;
  t33_n247: return 0.0645674616098404f;
  t33_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t33_n254;
  t33_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t33_n251;
  t33_n250: return 0.07250507920980453f;
  t33_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n253;
  t33_n252: return 0.0871359333395958f;
  t33_n253: return 0.09327206760644913f;
  t33_n254: return 0.09119874238967896f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree34(const Example& E) {
  t34_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t34_n238;
  t34_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t34_n219;
  t34_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t34_n62;
  t34_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t34_n5;
  t34_n4: return -0.06072438508272171f;
  t34_n5: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t34_n17;
  t34_n6: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t34_n8;
  t34_n7: return -0.04561784118413925f;
  t34_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n10;
  t34_n9: return 0.08932355046272278f;
  t34_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t34_n12;
  t34_n11: return -0.15805965662002563f;
  t34_n12: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t34_n14;
  t34_n13: return -0.1357860565185547f;
  t34_n14: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t34_n16;
  t34_n15: return 0.11533046513795853f;
  t34_n16: return -0.13522233068943024f;
  t34_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t34_n43;
  t34_n18: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t34_n40;
  t34_n19: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t34_n25;
  t34_n20: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t34_n22;
  t34_n21: return -0.10084602236747742f;
  t34_n22: if (E.getNumReferences() >= 3342575744 /*48040.5*/) goto t34_n24;
  t34_n23: return 0.025621933862566948f;
  t34_n24: return 0.1461782306432724f;
  t34_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t34_n29;
  t34_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t34_n28;
  t34_n27: return -0.052339423447847366f;
  t34_n28: return 0.03269091993570328f;
  t34_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t34_n31;
  t34_n30: return 0.010366215370595455f;
  t34_n31: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t34_n33;
  t34_n32: return 0.06497256457805634f;
  t34_n33: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t34_n39;
  t34_n34: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n36;
  t34_n35: return 0.12601089477539062f;
  t34_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n38;
  t34_n37: return 0.13228099048137665f;
  t34_n38: return 0.10307640582323074f;
  t34_n39: return 0.05546988546848297f;
  t34_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t34_n42;
  t34_n41: return -0.10367829352617264f;
  t34_n42: return 0.02383127063512802f;
  t34_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t34_n45;
  t34_n44: return 0.06204940006136894f;
  t34_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t34_n47;
  t34_n46: return -0.11880707740783691f;
  t34_n47: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t34_n51;
  t34_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t34_n50;
  t34_n49: return -0.060938913375139236f;
  t34_n50: return 0.05072594806551933f;
  t34_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t34_n55;
  t34_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n54;
  t34_n53: return 0.06743579357862473f;
  t34_n54: return 0.07367101311683655f;
  t34_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n61;
  t34_n56: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t34_n58;
  t34_n57: return 0.11575409024953842f;
  t34_n58: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t34_n60;
  t34_n59: return 0.12235099822282791f;
  t34_n60: return 0.07994335144758224f;
  t34_n61: return 0.06648736447095871f;
  t34_n62: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t34_n204;
  t34_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t34_n119;
  t34_n64: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t34_n118;
  t34_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t34_n67;
  t34_n66: return -0.017545266076922417f;
  t34_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t34_n115;
  t34_n68: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t34_n78;
  t34_n69: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t34_n71;
  t34_n70: return -0.0003260887460783124f;
  t34_n71: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t34_n77;
  t34_n72: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t34_n74;
  t34_n73: return 0.11329954117536545f;
  t34_n74: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t34_n76;
  t34_n75: return 0.07003100216388702f;
  t34_n76: return 0.14750105142593384f;
  t34_n77: return -0.13466379046440125f;
  t34_n78: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t34_n82;
  t34_n79: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t34_n81;
  t34_n80: return 0.04970945045351982f;
  t34_n81: return 0.04503951221704483f;
  t34_n82: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t34_n102;
  t34_n83: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t34_n101;
  t34_n84: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t34_n88;
  t34_n85: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t34_n87;
  t34_n86: return 0.0823080837726593f;
  t34_n87: return 0.10120455920696259f;
  t34_n88: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t34_n92;
  t34_n89: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t34_n91;
  t34_n90: return 0.10362306237220764f;
  t34_n91: return 0.11397574841976166f;
  t34_n92: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t34_n100;
  t34_n93: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t34_n97;
  t34_n94: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t34_n96;
  t34_n95: return 0.12664389610290527f;
  t34_n96: return 0.13343288004398346f;
  t34_n97: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t34_n99;
  t34_n98: return 0.14578957855701447f;
  t34_n99: return 0.13087734580039978f;
  t34_n100: return 0.11400138586759567f;
  t34_n101: return 0.08190202713012695f;
  t34_n102: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t34_n114;
  t34_n103: if (E.getNumReferences() >= 3285762048 /*433.5*/) goto t34_n109;
  t34_n104: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t34_n106;
  t34_n105: return 0.10021007061004639f;
  t34_n106: if (E.getNumReferences() >= 3268345856 /*103.5*/) goto t34_n108;
  t34_n107: return 0.12001911550760269f;
  t34_n108: return 0.11440303176641464f;
  t34_n109: if (E.getNumReferences() >= 3289915392 /*608.5*/) goto t34_n113;
  t34_n110: if (E.getNumReferences() >= 3289620480 /*590.5*/) goto t34_n112;
  t34_n111: return 0.116281658411026f;
  t34_n112: return 0.1393931806087494f;
  t34_n113: return 0.09175349771976471f;
  t34_n114: return 0.0972106009721756f;
  t34_n115: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t34_n117;
  t34_n116: return 0.0544569231569767f;
  t34_n117: return 0.09548622369766235f;
  t34_n118: return -0.027798667550086975f;
  t34_n119: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t34_n191;
  t34_n120: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t34_n144;
  t34_n121: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t34_n123;
  t34_n122: return 0.032519105821847916f;
  t34_n123: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n125;
  t34_n124: return 0.0552234873175621f;
  t34_n125: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t34_n133;
  t34_n126: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t34_n128;
  t34_n127: return 0.07187572866678238f;
  t34_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace))) goto t34_n130;
  t34_n129: return 0.0995330810546875f;
  t34_n130: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t34_n132;
  t34_n131: return 0.11814288049936295f;
  t34_n132: return 0.08248146623373032f;
  t34_n133: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t34_n135;
  t34_n134: return 0.09665967524051666f;
  t34_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t34_n137;
  t34_n136: return 0.09914509207010269f;
  t34_n137: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t34_n143;
  t34_n138: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t34_n142;
  t34_n139: if (E.getNumReferences() >= 3291078656 /*679.5*/) goto t34_n141;
  t34_n140: return 0.12309408187866211f;
  t34_n141: return 0.12831856310367584f;
  t34_n142: return 0.08111158013343811f;
  t34_n143: return 0.11137493699789047f;
  t34_n144: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t34_n174;
  t34_n145: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t34_n149;
  t34_n146: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t34_n148;
  t34_n147: return 0.011271372437477112f;
  t34_n148: return -0.05165904387831688f;
  t34_n149: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t34_n157;
  t34_n150: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t34_n156;
  t34_n151: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n153;
  t34_n152: return 0.04129946231842041f;
  t34_n153: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t34_n155;
  t34_n154: return 0.09419109672307968f;
  t34_n155: return 0.06759216636419296f;
  t34_n156: return 0.0010564586846157908f;
  t34_n157: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t34_n169;
  t34_n158: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t34_n166;
  t34_n159: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t34_n165;
  t34_n160: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n162;
  t34_n161: return -0.12638241052627563f;
  t34_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t34_n164;
  t34_n163: return 0.13006635010242462f;
  t34_n164: return 0.15906190872192383f;
  t34_n165: return 0.12889304757118225f;
  t34_n166: if (E.getFilterLength() >= 3247177728 /*17.5*/) goto t34_n168;
  t34_n167: return 0.11772385239601135f;
  t34_n168: return 0.17561016976833344f;
  t34_n169: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t34_n173;
  t34_n170: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t34_n172;
  t34_n171: return 0.11815571784973145f;
  t34_n172: return 0.08970800042152405f;
  t34_n173: return 0.08937564492225647f;
  t34_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t34_n176;
  t34_n175: return 0.0326998196542263f;
  t34_n176: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t34_n178;
  t34_n177: return 0.039908308535814285f;
  t34_n178: if (E.getFileProximityDistance() >= 3251634176 /*26.0*/) goto t34_n180;
  t34_n179: return 0.019733097404241562f;
  t34_n180: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t34_n190;
  t34_n181: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t34_n189;
  t34_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t34_n184;
  t34_n183: return -0.2560510039329529f;
  t34_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n188;
  t34_n185: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n187;
  t34_n186: return 0.1073208898305893f;
  t34_n187: return 0.03149968758225441f;
  t34_n188: return 0.08546414971351624f;
  t34_n189: return 0.00284001836553216f;
  t34_n190: return -0.10479722917079926f;
  t34_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t34_n193;
  t34_n192: return 0.02290164679288864f;
  t34_n193: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t34_n201;
  t34_n194: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t34_n198;
  t34_n195: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t34_n197;
  t34_n196: return 0.09268943220376968f;
  t34_n197: return -0.0762515589594841f;
  t34_n198: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t34_n200;
  t34_n199: return 0.09342075884342194f;
  t34_n200: return 0.11266334354877472f;
  t34_n201: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t34_n203;
  t34_n202: return -0.16036756336688995f;
  t34_n203: return 0.06167878583073616f;
  t34_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t34_n206;
  t34_n205: return 0.0746188834309578f;
  t34_n206: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t34_n218;
  t34_n207: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t34_n215;
  t34_n208: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t34_n210;
  t34_n209: return 0.11399317532777786f;
  t34_n210: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n214;
  t34_n211: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t34_n213;
  t34_n212: return 0.1455492228269577f;
  t34_n213: return 0.1443507820367813f;
  t34_n214: return 0.09960097819566727f;
  t34_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n217;
  t34_n216: return 0.05266613885760307f;
  t34_n217: return 0.10946070402860641f;
  t34_n218: return 0.027967039495706558f;
  t34_n219: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n225;
  t34_n220: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t34_n222;
  t34_n221: return 0.030657898634672165f;
  t34_n222: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t34_n224;
  t34_n223: return 0.10104648023843765f;
  t34_n224: return 0.06808734685182571f;
  t34_n225: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t34_n233;
  t34_n226: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t34_n232;
  t34_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t34_n231;
  t34_n228: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t34_n230;
  t34_n229: return 0.027385499328374863f;
  t34_n230: return 0.05310352146625519f;
  t34_n231: return 0.04970017448067665f;
  t34_n232: return 0.06097070127725601f;
  t34_n233: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t34_n235;
  t34_n234: return 0.09378325939178467f;
  t34_n235: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t34_n237;
  t34_n236: return 0.06991786509752274f;
  t34_n237: return 0.07800981402397156f;
  t34_n238: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t34_n248;
  t34_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n245;
  t34_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t34_n242;
  t34_n241: return -0.009995239786803722f;
  t34_n242: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t34_n244;
  t34_n243: return 0.043573830276727676f;
  t34_n244: return 0.013259083963930607f;
  t34_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t34_n247;
  t34_n246: return 0.03091621957719326f;
  t34_n247: return 0.06243055313825607f;
  t34_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n254;
  t34_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n251;
  t34_n250: return 0.06984447687864304f;
  t34_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t34_n253;
  t34_n252: return 0.08598382025957108f;
  t34_n253: return 0.09102986007928848f;
  t34_n254: return 0.09021837264299393f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree35(const Example& E) {
  t35_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t35_n242;
  t35_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t35_n141;
  t35_n2: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t35_n56;
  t35_n3: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t35_n15;
  t35_n4: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t35_n12;
  t35_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t35_n7;
  t35_n6: return 0.0005403000977821648f;
  t35_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t35_n9;
  t35_n8: return 0.057103365659713745f;
  t35_n9: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t35_n11;
  t35_n10: return 0.09478605538606644f;
  t35_n11: return 0.046963002532720566f;
  t35_n12: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t35_n14;
  t35_n13: return -0.0568498857319355f;
  t35_n14: return -0.09128273278474808f;
  t35_n15: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t35_n25;
  t35_n16: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t35_n24;
  t35_n17: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t35_n19;
  t35_n18: return 0.02614452876150608f;
  t35_n19: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t35_n23;
  t35_n20: if (E.getNumReferences() >= 3317562368 /*6079.5*/) goto t35_n22;
  t35_n21: return 0.003475755453109741f;
  t35_n22: return 0.07031068205833435f;
  t35_n23: return 0.0815412700176239f;
  t35_n24: return -0.008712348528206348f;
  t35_n25: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t35_n33;
  t35_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t35_n32;
  t35_n27: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t35_n29;
  t35_n28: return 0.109368234872818f;
  t35_n29: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t35_n31;
  t35_n30: return 0.04952806979417801f;
  t35_n31: return 0.1523677259683609f;
  t35_n32: return 0.11988403648138046f;
  t35_n33: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t35_n53;
  t35_n34: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t35_n52;
  t35_n35: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t35_n51;
  t35_n36: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t35_n44;
  t35_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t35_n39;
  t35_n38: return 0.018857955932617188f;
  t35_n39: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t35_n43;
  t35_n40: if (E.getNumReferences() >= 3269132288 /*109.5*/) goto t35_n42;
  t35_n41: return -0.13766707479953766f;
  t35_n42: return 0.12092752009630203f;
  t35_n43: return 0.10280290246009827f;
  t35_n44: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t35_n50;
  t35_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t35_n47;
  t35_n46: return 0.08923901617527008f;
  t35_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t35_n49;
  t35_n48: return 0.12473177909851074f;
  t35_n49: return 0.12066980451345444f;
  t35_n50: return 0.10609123110771179f;
  t35_n51: return 0.12750093638896942f;
  t35_n52: return 0.06723346561193466f;
  t35_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t35_n55;
  t35_n54: return 0.05806070938706398f;
  t35_n55: return 0.08615350723266602f;
  t35_n56: if (E.getFileProximityDistance() >= 3255435264 /*34.5*/) goto t35_n74;
  t35_n57: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t35_n59;
  t35_n58: return 0.0025837267749011517f;
  t35_n59: if (E.getNumReferences() >= 3335302144 /*26198.0*/) goto t35_n73;
  t35_n60: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t35_n70;
  t35_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t35_n67;
  t35_n62: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t35_n64;
  t35_n63: return 0.04244096949696541f;
  t35_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t35_n66;
  t35_n65: return -0.038483768701553345f;
  t35_n66: return 0.11120299249887466f;
  t35_n67: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t35_n69;
  t35_n68: return 0.05304295942187309f;
  t35_n69: return 0.07668635994195938f;
  t35_n70: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t35_n72;
  t35_n71: return 0.006087548099458218f;
  t35_n72: return 0.047567933797836304f;
  t35_n73: return 0.05561569705605507f;
  t35_n74: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t35_n130;
  t35_n75: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t35_n77;
  t35_n76: return -0.035115525126457214f;
  t35_n77: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t35_n79;
  t35_n78: return 0.02693898230791092f;
  t35_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t35_n117;
  t35_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t35_n102;
  t35_n81: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t35_n83;
  t35_n82: return -0.00499654421582818f;
  t35_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t35_n87;
  t35_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t35_n86;
  t35_n85: return -0.12129142135381699f;
  t35_n86: return 0.049073509871959686f;
  t35_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t35_n97;
  t35_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t35_n90;
  t35_n89: return -0.03729208558797836f;
  t35_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t35_n94;
  t35_n91: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t35_n93;
  t35_n92: return 0.11673139780759811f;
  t35_n93: return 0.10292956233024597f;
  t35_n94: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t35_n96;
  t35_n95: return 0.12334717810153961f;
  t35_n96: return 0.07425970584154129f;
  t35_n97: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t35_n101;
  t35_n98: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t35_n100;
  t35_n99: return 0.1406496912240982f;
  t35_n100: return 0.1056796982884407f;
  t35_n101: return -0.1353047788143158f;
  t35_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t35_n106;
  t35_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t35_n105;
  t35_n104: return 0.04022014141082764f;
  t35_n105: return 0.0989423468708992f;
  t35_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t35_n116;
  t35_n107: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t35_n109;
  t35_n108: return 0.1300990730524063f;
  t35_n109: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t35_n111;
  t35_n110: return 0.12832678854465485f;
  t35_n111: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t35_n115;
  t35_n112: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t35_n114;
  t35_n113: return -0.029461270198225975f;
  t35_n114: return 0.13858948647975922f;
  t35_n115: return 0.13586854934692383f;
  t35_n116: return 0.08711274713277817f;
  t35_n117: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t35_n121;
  t35_n118: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t35_n120;
  t35_n119: return -0.0556531623005867f;
  t35_n120: return 0.0784774199128151f;
  t35_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t35_n123;
  t35_n122: return 0.08106563240289688f;
  t35_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t35_n129;
  t35_n124: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t35_n128;
  t35_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t35_n127;
  t35_n126: return -0.13543488085269928f;
  t35_n127: return 0.12557676434516907f;
  t35_n128: return 0.11762382835149765f;
  t35_n129: return 0.11866790801286697f;
  t35_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t35_n132;
  t35_n131: return -0.12046516686677933f;
  t35_n132: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t35_n138;
  t35_n133: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t35_n135;
  t35_n134: return 0.006312707904726267f;
  t35_n135: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t35_n137;
  t35_n136: return 0.07115352898836136f;
  t35_n137: return 0.0712336078286171f;
  t35_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t35_n140;
  t35_n139: return 0.07944415509700775f;
  t35_n140: return 0.09604539722204208f;
  t35_n141: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t35_n209;
  t35_n142: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t35_n182;
  t35_n143: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t35_n159;
  t35_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t35_n146;
  t35_n145: return -0.0848437175154686f;
  t35_n146: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t35_n150;
  t35_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t35_n149;
  t35_n148: return -0.017220797017216682f;
  t35_n149: return 0.027769114822149277f;
  t35_n150: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t35_n152;
  t35_n151: return 0.014772085472941399f;
  t35_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t35_n154;
  t35_n153: return 0.02825918421149254f;
  t35_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t35_n156;
  t35_n155: return 0.06428533792495728f;
  t35_n156: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t35_n158;
  t35_n157: return 0.10603015124797821f;
  t35_n158: return 0.09006264060735703f;
  t35_n159: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t35_n161;
  t35_n160: return 0.026679806411266327f;
  t35_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t35_n179;
  t35_n162: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t35_n164;
  t35_n163: return 0.0594630166888237f;
  t35_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t35_n166;
  t35_n165: return 0.04214208200573921f;
  t35_n166: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t35_n178;
  t35_n167: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t35_n169;
  t35_n168: return 0.07201921194791794f;
  t35_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t35_n171;
  t35_n170: return 0.09101509302854538f;
  t35_n171: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t35_n175;
  t35_n172: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t35_n174;
  t35_n173: return 0.08845661580562592f;
  t35_n174: return 0.11661775410175323f;
  t35_n175: if (E.getNumReferences() >= 3290906624 /*669.0*/) goto t35_n177;
  t35_n176: return 0.1357986181974411f;
  t35_n177: return 0.0904502123594284f;
  t35_n178: return 0.11923275142908096f;
  t35_n179: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t35_n181;
  t35_n180: return 0.07549643516540527f;
  t35_n181: return 0.09471698850393295f;
  t35_n182: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t35_n202;
  t35_n183: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t35_n185;
  t35_n184: return -0.025098390877246857f;
  t35_n185: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t35_n187;
  t35_n186: return 0.02712235413491726f;
  t35_n187: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t35_n193;
  t35_n188: if (E.getNumReferences() >= 3274080256 /*166.5*/) goto t35_n190;
  t35_n189: return 0.13721300661563873f;
  t35_n190: if (E.getNumReferences() >= 3294248960 /*873.0*/) goto t35_n192;
  t35_n191: return 0.11614343523979187f;
  t35_n192: return 0.11044947803020477f;
  t35_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t35_n195;
  t35_n194: return 0.09006503224372864f;
  t35_n195: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t35_n197;
  t35_n196: return 0.07253128290176392f;
  t35_n197: if (E.getNumReferences() >= 3277520896 /*219.0*/) goto t35_n199;
  t35_n198: return 0.04583655670285225f;
  t35_n199: if (E.getNumReferences() >= 3278733312 /*237.5*/) goto t35_n201;
  t35_n200: return 0.13375620543956757f;
  t35_n201: return 0.10201161354780197f;
  t35_n202: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t35_n208;
  t35_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t35_n205;
  t35_n204: return -0.02141510508954525f;
  t35_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t35_n207;
  t35_n206: return -0.7123042345046997f;
  t35_n207: return 0.03684786334633827f;
  t35_n208: return 0.04319540783762932f;
  t35_n209: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t35_n221;
  t35_n210: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t35_n220;
  t35_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t35_n213;
  t35_n212: return 0.026365838944911957f;
  t35_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t35_n215;
  t35_n214: return 0.008043061941862106f;
  t35_n215: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t35_n217;
  t35_n216: return 0.05620558187365532f;
  t35_n217: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t35_n219;
  t35_n218: return 0.0796879231929779f;
  t35_n219: return -0.36021342873573303f;
  t35_n220: return 0.05713682621717453f;
  t35_n221: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t35_n239;
  t35_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t35_n224;
  t35_n223: return 0.08968468755483627f;
  t35_n224: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t35_n226;
  t35_n225: return 0.07216192036867142f;
  t35_n226: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t35_n228;
  t35_n227: return 0.06801736354827881f;
  t35_n228: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t35_n238;
  t35_n229: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t35_n237;
  t35_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t35_n232;
  t35_n231: return 0.10697955638170242f;
  t35_n232: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t35_n234;
  t35_n233: return 0.10877490788698196f;
  t35_n234: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t35_n236;
  t35_n235: return 0.12498417496681213f;
  t35_n236: return 0.1296081393957138f;
  t35_n237: return 0.11551684141159058f;
  t35_n238: return 0.06239255890250206f;
  t35_n239: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t35_n241;
  t35_n240: return 0.06646472960710526f;
  t35_n241: return 0.0759739875793457f;
  t35_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t35_n248;
  t35_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t35_n245;
  t35_n244: return 0.02199104055762291f;
  t35_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t35_n247;
  t35_n246: return 0.028515418991446495f;
  t35_n247: return 0.059443797916173935f;
  t35_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t35_n254;
  t35_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t35_n251;
  t35_n250: return 0.06731114536523819f;
  t35_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t35_n253;
  t35_n252: return 0.08334663510322571f;
  t35_n253: return 0.08999878168106079f;
  t35_n254: return 0.08846521377563477f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree36(const Example& E) {
  t36_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t36_n240;
  t36_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t36_n167;
  t36_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t36_n86;
  t36_n3: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t36_n63;
  t36_n4: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t36_n46;
  t36_n5: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t36_n23;
  t36_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t36_n22;
  t36_n7: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t36_n9;
  t36_n8: return -0.04003366455435753f;
  t36_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t36_n11;
  t36_n10: return -0.09768500924110413f;
  t36_n11: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t36_n21;
  t36_n12: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t36_n14;
  t36_n13: return 0.042146679013967514f;
  t36_n14: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t36_n20;
  t36_n15: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t36_n17;
  t36_n16: return 0.10409099608659744f;
  t36_n17: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t36_n19;
  t36_n18: return 0.107083760201931f;
  t36_n19: return -0.016811765730381012f;
  t36_n20: return -0.15419016778469086f;
  t36_n21: return -0.05809102579951286f;
  t36_n22: return -0.009814945049583912f;
  t36_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t36_n25;
  t36_n24: return 0.017764123156666756f;
  t36_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t36_n35;
  t36_n26: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t36_n28;
  t36_n27: return 0.031267859041690826f;
  t36_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t36_n30;
  t36_n29: return 0.03793250396847725f;
  t36_n30: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t36_n34;
  t36_n31: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t36_n33;
  t36_n32: return 0.08352570980787277f;
  t36_n33: return 0.09704339504241943f;
  t36_n34: return 0.07078282535076141f;
  t36_n35: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t36_n39;
  t36_n36: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t36_n38;
  t36_n37: return 0.07742344588041306f;
  t36_n38: return 0.10907206684350967f;
  t36_n39: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t36_n41;
  t36_n40: return 0.09391836076974869f;
  t36_n41: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t36_n45;
  t36_n42: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t36_n44;
  t36_n43: return 0.11469779163599014f;
  t36_n44: return 0.1010948196053505f;
  t36_n45: return 0.01936158910393715f;
  t36_n46: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t36_n48;
  t36_n47: return 0.10017935931682587f;
  t36_n48: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t36_n58;
  t36_n49: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t36_n57;
  t36_n50: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t36_n52;
  t36_n51: return 0.0008779636700637639f;
  t36_n52: if (E.getNumReferences() >= 3361088608 /*219281.5*/) goto t36_n56;
  t36_n53: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t36_n55;
  t36_n54: return 0.1197945848107338f;
  t36_n55: return 0.1072230264544487f;
  t36_n56: return -0.000856966245919466f;
  t36_n57: return 0.06927082687616348f;
  t36_n58: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t36_n60;
  t36_n59: return -0.25628259778022766f;
  t36_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t36_n62;
  t36_n61: return 0.07275813817977905f;
  t36_n62: return 0.09346568584442139f;
  t36_n63: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t36_n85;
  t36_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t36_n66;
  t36_n65: return -0.049013201147317886f;
  t36_n66: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t36_n68;
  t36_n67: return 0.01633325219154358f;
  t36_n68: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t36_n82;
  t36_n69: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t36_n71;
  t36_n70: return 0.004305768292397261f;
  t36_n71: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t36_n73;
  t36_n72: return 0.01747310161590576f;
  t36_n73: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t36_n77;
  t36_n74: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t36_n76;
  t36_n75: return 0.12089144438505173f;
  t36_n76: return 0.007378799840807915f;
  t36_n77: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t36_n81;
  t36_n78: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t36_n80;
  t36_n79: return 0.13110868632793427f;
  t36_n80: return 0.14532828330993652f;
  t36_n81: return 0.12902256846427917f;
  t36_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t36_n84;
  t36_n83: return 0.03690376505255699f;
  t36_n84: return 0.056593332439661026f;
  t36_n85: return -0.11925027519464493f;
  t36_n86: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t36_n140;
  t36_n87: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t36_n105;
  t36_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t36_n90;
  t36_n89: return -0.08311042189598083f;
  t36_n90: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t36_n94;
  t36_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t36_n93;
  t36_n92: return -0.016150884330272675f;
  t36_n93: return 0.02648889645934105f;
  t36_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t36_n96;
  t36_n95: return 0.013238271698355675f;
  t36_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t36_n98;
  t36_n97: return 0.020079735666513443f;
  t36_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t36_n102;
  t36_n99: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t36_n101;
  t36_n100: return 0.06919737160205841f;
  t36_n101: return 0.03123764880001545f;
  t36_n102: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t36_n104;
  t36_n103: return 0.1043151393532753f;
  t36_n104: return 0.08592595160007477f;
  t36_n105: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t36_n107;
  t36_n106: return 0.024953262880444527f;
  t36_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t36_n127;
  t36_n108: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t36_n110;
  t36_n109: return 0.057738423347473145f;
  t36_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t36_n112;
  t36_n111: return 0.0405806340277195f;
  t36_n112: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t36_n124;
  t36_n113: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t36_n115;
  t36_n114: return 0.06943071633577347f;
  t36_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t36_n117;
  t36_n116: return 0.08792875707149506f;
  t36_n117: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t36_n121;
  t36_n118: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t36_n120;
  t36_n119: return 0.08607252687215805f;
  t36_n120: return 0.11307962238788605f;
  t36_n121: if (E.getNumReferences() >= 3290906624 /*669.0*/) goto t36_n123;
  t36_n122: return 0.1323780119419098f;
  t36_n123: return 0.08857329189777374f;
  t36_n124: if (E.getNumReferences() >= 3273654272 /*160.0*/) goto t36_n126;
  t36_n125: return 0.120931476354599f;
  t36_n126: return 0.0716942697763443f;
  t36_n127: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t36_n137;
  t36_n128: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t36_n130;
  t36_n129: return 0.0719020813703537f;
  t36_n130: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t36_n136;
  t36_n131: if (E.getNumReferences() >= 3247439872 /*18.0*/) goto t36_n135;
  t36_n132: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t36_n134;
  t36_n133: return 0.1481046825647354f;
  t36_n134: return 0.12275762856006622f;
  t36_n135: return 0.11527477204799652f;
  t36_n136: return 0.10988340526819229f;
  t36_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t36_n139;
  t36_n138: return 0.0005074666696600616f;
  t36_n139: return 0.0949082002043724f;
  t36_n140: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t36_n162;
  t36_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t36_n151;
  t36_n142: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t36_n144;
  t36_n143: return -0.04227167367935181f;
  t36_n144: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t36_n146;
  t36_n145: return -0.013816981576383114f;
  t36_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t36_n148;
  t36_n147: return 0.15048983693122864f;
  t36_n148: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t36_n150;
  t36_n149: return 0.11360283941030502f;
  t36_n150: return 0.10865408182144165f;
  t36_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t36_n153;
  t36_n152: return -0.003604038618505001f;
  t36_n153: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t36_n155;
  t36_n154: return 0.046411849558353424f;
  t36_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t36_n159;
  t36_n156: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t36_n158;
  t36_n157: return 0.0997142493724823f;
  t36_n158: return 0.04903023689985275f;
  t36_n159: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t36_n161;
  t36_n160: return 0.11669991910457611f;
  t36_n161: return 0.03223467618227005f;
  t36_n162: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t36_n166;
  t36_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t36_n165;
  t36_n164: return -0.03187083080410957f;
  t36_n165: return 0.027436653152108192f;
  t36_n166: return 0.03935369849205017f;
  t36_n167: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t36_n187;
  t36_n168: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t36_n182;
  t36_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t36_n171;
  t36_n170: return 0.026426827535033226f;
  t36_n171: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t36_n177;
  t36_n172: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t36_n176;
  t36_n173: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t36_n175;
  t36_n174: return 0.05864677578210831f;
  t36_n175: return 0.07970373332500458f;
  t36_n176: return 0.07805291563272476f;
  t36_n177: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t36_n179;
  t36_n178: return -0.04232951998710632f;
  t36_n179: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t36_n181;
  t36_n180: return 0.03124614804983139f;
  t36_n181: return -0.044835615903139114f;
  t36_n182: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t36_n186;
  t36_n183: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t36_n185;
  t36_n184: return 0.046115338802337646f;
  t36_n185: return -0.0774741843342781f;
  t36_n186: return 0.08470660448074341f;
  t36_n187: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t36_n233;
  t36_n188: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t36_n200;
  t36_n189: if (E.getNumReferences() >= 3357605312 /*164855.0*/) goto t36_n197;
  t36_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t36_n192;
  t36_n191: return 0.045772578567266464f;
  t36_n192: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t36_n194;
  t36_n193: return 0.10295326262712479f;
  t36_n194: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t36_n196;
  t36_n195: return 0.1150103211402893f;
  t36_n196: return 0.14545777440071106f;
  t36_n197: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t36_n199;
  t36_n198: return 0.09712152928113937f;
  t36_n199: return 0.11236823350191116f;
  t36_n200: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t36_n204;
  t36_n201: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t36_n203;
  t36_n202: return 0.09396905452013016f;
  t36_n203: return -0.015081488527357578f;
  t36_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t36_n206;
  t36_n205: return 0.09065888822078705f;
  t36_n206: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t36_n208;
  t36_n207: return 0.06410586088895798f;
  t36_n208: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t36_n232;
  t36_n209: if (E.getNumReferences() >= 3266183168 /*87.0*/) goto t36_n227;
  t36_n210: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t36_n226;
  t36_n211: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t36_n213;
  t36_n212: return 0.10640276968479156f;
  t36_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t36_n215;
  t36_n214: return 0.11649299412965775f;
  t36_n215: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t36_n221;
  t36_n216: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t36_n220;
  t36_n217: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t36_n219;
  t36_n218: return 0.1192951649427414f;
  t36_n219: return 0.13384270668029785f;
  t36_n220: return 0.10974038392305374f;
  t36_n221: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t36_n223;
  t36_n222: return 0.0505368709564209f;
  t36_n223: if (E.getNumReferences() >= 3260809216 /*55.0*/) goto t36_n225;
  t36_n224: return 0.1217413991689682f;
  t36_n225: return 0.14843294024467468f;
  t36_n226: return 0.08504316210746765f;
  t36_n227: if (E.getNumReferences() >= 3266510848 /*89.5*/) goto t36_n229;
  t36_n228: return 0.12022082507610321f;
  t36_n229: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t36_n231;
  t36_n230: return 0.14598695933818817f;
  t36_n231: return 0.11516200006008148f;
  t36_n232: return 0.058394260704517365f;
  t36_n233: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t36_n235;
  t36_n234: return 0.03893298655748367f;
  t36_n235: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t36_n237;
  t36_n236: return 0.035107582807540894f;
  t36_n237: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t36_n239;
  t36_n238: return 0.0034113212022930384f;
  t36_n239: return 0.08880053460597992f;
  t36_n240: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t36_n248;
  t36_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t36_n245;
  t36_n242: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t36_n244;
  t36_n243: return 0.014625688083469868f;
  t36_n244: return 0.058003079146146774f;
  t36_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t36_n247;
  t36_n246: return 0.02643650956451893f;
  t36_n247: return 0.057225264608860016f;
  t36_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t36_n254;
  t36_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t36_n251;
  t36_n250: return 0.0653735026717186f;
  t36_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t36_n253;
  t36_n252: return 0.0811953991651535f;
  t36_n253: return 0.08844323456287384f;
  t36_n254: return 0.08734571933746338f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree37(const Example& E) {
  t37_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t37_n238;
  t37_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t37_n171;
  t37_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t37_n88;
  t37_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t37_n17;
  t37_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t37_n6;
  t37_n5: return -0.06601682305335999f;
  t37_n6: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t37_n8;
  t37_n7: return -0.03362270072102547f;
  t37_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t37_n10;
  t37_n9: return 0.09672114253044128f;
  t37_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t37_n12;
  t37_n11: return -0.12355320155620575f;
  t37_n12: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t37_n16;
  t37_n13: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t37_n15;
  t37_n14: return 0.11829108744859695f;
  t37_n15: return 0.11799056828022003f;
  t37_n16: return 0.09028028696775436f;
  t37_n17: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t37_n65;
  t37_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t37_n20;
  t37_n19: return -0.010517753660678864f;
  t37_n20: if (E.getNumReferences() >= 3348227392 /*74698.5*/) goto t37_n54;
  t37_n21: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t37_n43;
  t37_n22: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n42;
  t37_n23: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t37_n41;
  t37_n24: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t37_n34;
  t37_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t37_n27;
  t37_n26: return 0.015923582017421722f;
  t37_n27: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t37_n29;
  t37_n28: return 0.04109753295779228f;
  t37_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t37_n31;
  t37_n30: return -0.040462691336870193f;
  t37_n31: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t37_n33;
  t37_n32: return 0.09551220387220383f;
  t37_n33: return -0.0350465327501297f;
  t37_n34: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t37_n36;
  t37_n35: return 0.03635455295443535f;
  t37_n36: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t37_n40;
  t37_n37: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t37_n39;
  t37_n38: return 0.09648221731185913f;
  t37_n39: return 0.1059868186712265f;
  t37_n40: return 0.05899734050035477f;
  t37_n41: return -0.0043646227568387985f;
  t37_n42: return -0.0679435282945633f;
  t37_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t37_n45;
  t37_n44: return 0.05254330486059189f;
  t37_n45: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t37_n47;
  t37_n46: return 0.018944764509797096f;
  t37_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n53;
  t37_n48: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t37_n52;
  t37_n49: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n51;
  t37_n50: return 0.10181516408920288f;
  t37_n51: return 0.10279801487922668f;
  t37_n52: return -0.14899028837680817f;
  t37_n53: return 0.013200398534536362f;
  t37_n54: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n56;
  t37_n55: return 0.02390773594379425f;
  t37_n56: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t37_n64;
  t37_n57: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t37_n61;
  t37_n58: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n60;
  t37_n59: return 0.09345024079084396f;
  t37_n60: return -0.11282998323440552f;
  t37_n61: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t37_n63;
  t37_n62: return 0.0834641084074974f;
  t37_n63: return 0.11276564002037048f;
  t37_n64: return 0.05314528942108154f;
  t37_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t37_n67;
  t37_n66: return 0.06405410170555115f;
  t37_n67: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n75;
  t37_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n74;
  t37_n69: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t37_n73;
  t37_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t37_n72;
  t37_n71: return 0.12177029997110367f;
  t37_n72: return 0.10622769594192505f;
  t37_n73: return 0.03877243772149086f;
  t37_n74: return -0.010504615493118763f;
  t37_n75: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n87;
  t37_n76: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t37_n82;
  t37_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t37_n81;
  t37_n78: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t37_n80;
  t37_n79: return 0.12731562554836273f;
  t37_n80: return 0.08495151996612549f;
  t37_n81: return 0.1138947606086731f;
  t37_n82: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t37_n86;
  t37_n83: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t37_n85;
  t37_n84: return 0.12325309216976166f;
  t37_n85: return 0.09859828650951385f;
  t37_n86: return 0.12063798308372498f;
  t37_n87: return 0.062465403228998184f;
  t37_n88: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t37_n134;
  t37_n89: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t37_n109;
  t37_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t37_n92;
  t37_n91: return -0.07967056334018707f;
  t37_n92: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t37_n96;
  t37_n93: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t37_n95;
  t37_n94: return -0.05003969371318817f;
  t37_n95: return 0.021281683817505836f;
  t37_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t37_n98;
  t37_n97: return 0.013220855966210365f;
  t37_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t37_n100;
  t37_n99: return 0.025621503591537476f;
  t37_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t37_n106;
  t37_n101: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t37_n105;
  t37_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n104;
  t37_n103: return 0.08042588829994202f;
  t37_n104: return 0.09020677208900452f;
  t37_n105: return 0.028297681361436844f;
  t37_n106: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t37_n108;
  t37_n107: return 0.103019118309021f;
  t37_n108: return 0.08735395967960358f;
  t37_n109: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n111;
  t37_n110: return 0.024991707876324654f;
  t37_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t37_n129;
  t37_n112: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t37_n116;
  t37_n113: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t37_n115;
  t37_n114: return 0.05484051629900932f;
  t37_n115: return 0.07170293480157852f;
  t37_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t37_n118;
  t37_n117: return 0.06748189777135849f;
  t37_n118: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t37_n126;
  t37_n119: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t37_n121;
  t37_n120: return 0.08041789382696152f;
  t37_n121: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t37_n125;
  t37_n122: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t37_n124;
  t37_n123: return 0.1255449652671814f;
  t37_n124: return 0.08502946048974991f;
  t37_n125: return 0.10886535048484802f;
  t37_n126: if (E.getNumReferences() >= 3290349568 /*635.0*/) goto t37_n128;
  t37_n127: return 0.12839500606060028f;
  t37_n128: return 0.09021064639091492f;
  t37_n129: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t37_n133;
  t37_n130: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t37_n132;
  t37_n131: return 0.06937918812036514f;
  t37_n132: return 0.10326489806175232f;
  t37_n133: return 0.08949611335992813f;
  t37_n134: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t37_n148;
  t37_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t37_n141;
  t37_n136: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t37_n138;
  t37_n137: return -0.04038208723068237f;
  t37_n138: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n140;
  t37_n139: return -0.014226372353732586f;
  t37_n140: return 0.10989479720592499f;
  t37_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace))) goto t37_n143;
  t37_n142: return 0.004589468240737915f;
  t37_n143: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t37_n145;
  t37_n144: return 0.055153727531433105f;
  t37_n145: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t37_n147;
  t37_n146: return 0.1035095751285553f;
  t37_n147: return 0.002292314311489463f;
  t37_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t37_n152;
  t37_n149: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t37_n151;
  t37_n150: return -0.022371206432580948f;
  t37_n151: return 0.10924109816551208f;
  t37_n152: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t37_n154;
  t37_n153: return -0.02070821262896061f;
  t37_n154: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t37_n170;
  t37_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n165;
  t37_n156: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n160;
  t37_n157: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t37_n159;
  t37_n158: return -0.025951936841011047f;
  t37_n159: return 0.07115285843610764f;
  t37_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t37_n162;
  t37_n161: return 0.017039762809872627f;
  t37_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t37_n164;
  t37_n163: return -0.39387333393096924f;
  t37_n164: return 0.053098831325769424f;
  t37_n165: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t37_n167;
  t37_n166: return 0.015900282189249992f;
  t37_n167: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t37_n169;
  t37_n168: return 0.13884690403938293f;
  t37_n169: return 0.07717162370681763f;
  t37_n170: return 0.044636070728302f;
  t37_n171: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t37_n181;
  t37_n172: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t37_n176;
  t37_n173: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t37_n175;
  t37_n174: return 0.026576578617095947f;
  t37_n175: return 0.0419827401638031f;
  t37_n176: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t37_n180;
  t37_n177: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n179;
  t37_n178: return 0.06067918986082077f;
  t37_n179: return 0.10768653452396393f;
  t37_n180: return 0.06296804547309875f;
  t37_n181: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t37_n189;
  t37_n182: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t37_n186;
  t37_n183: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t37_n185;
  t37_n184: return 0.023681912571191788f;
  t37_n185: return 0.04669145494699478f;
  t37_n186: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t37_n188;
  t37_n187: return 0.05054144188761711f;
  t37_n188: return -0.02258623205125332f;
  t37_n189: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t37_n227;
  t37_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t37_n192;
  t37_n191: return 0.08416101336479187f;
  t37_n192: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t37_n200;
  t37_n193: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t37_n195;
  t37_n194: return 0.0554574653506279f;
  t37_n195: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t37_n197;
  t37_n196: return 0.08973436057567596f;
  t37_n197: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t37_n199;
  t37_n198: return 0.13132654130458832f;
  t37_n199: return 0.10722631216049194f;
  t37_n200: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t37_n202;
  t37_n201: return 0.057782724499702454f;
  t37_n202: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t37_n226;
  t37_n203: if (E.getNumReferences() >= 3266183168 /*87.0*/) goto t37_n221;
  t37_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t37_n206;
  t37_n205: return 0.1013164296746254f;
  t37_n206: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t37_n208;
  t37_n207: return 0.10148867219686508f;
  t37_n208: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t37_n214;
  t37_n209: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t37_n213;
  t37_n210: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t37_n212;
  t37_n211: return 0.1176985576748848f;
  t37_n212: return 0.12517954409122467f;
  t37_n213: return 0.10856891423463821f;
  t37_n214: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t37_n216;
  t37_n215: return 0.039364781230688095f;
  t37_n216: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t37_n220;
  t37_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t37_n219;
  t37_n218: return 0.1335185319185257f;
  t37_n219: return 0.12161162495613098f;
  t37_n220: return 0.0983230248093605f;
  t37_n221: if (E.getNumReferences() >= 3266510848 /*89.5*/) goto t37_n223;
  t37_n222: return 0.11852573603391647f;
  t37_n223: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t37_n225;
  t37_n224: return 0.14712361991405487f;
  t37_n225: return 0.11463134735822678f;
  t37_n226: return 0.05653750151395798f;
  t37_n227: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t37_n237;
  t37_n228: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t37_n230;
  t37_n229: return 0.02769591473042965f;
  t37_n230: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t37_n236;
  t37_n231: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t37_n233;
  t37_n232: return 0.10802781581878662f;
  t37_n233: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t37_n235;
  t37_n234: return 0.11169829964637756f;
  t37_n235: return 0.11697052419185638f;
  t37_n236: return 0.07000154256820679f;
  t37_n237: return 0.05344792455434799f;
  t37_n238: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t37_n248;
  t37_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t37_n245;
  t37_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t37_n242;
  t37_n241: return -0.01174853928387165f;
  t37_n242: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t37_n244;
  t37_n243: return 0.037673983722925186f;
  t37_n244: return 0.010186895728111267f;
  t37_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n247;
  t37_n246: return 0.024413418024778366f;
  t37_n247: return 0.055051740258932114f;
  t37_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t37_n254;
  t37_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t37_n251;
  t37_n250: return 0.06377891451120377f;
  t37_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n253;
  t37_n252: return 0.07976660877466202f;
  t37_n253: return 0.086338572204113f;
  t37_n254: return 0.08587254583835602f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree38(const Example& E) {
  t38_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t38_n246;
  t38_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t38_n181;
  t38_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t38_n52;
  t38_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t38_n5;
  t38_n4: return -0.055362947285175323f;
  t38_n5: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t38_n17;
  t38_n6: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t38_n8;
  t38_n7: return -0.040542684495449066f;
  t38_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t38_n10;
  t38_n9: return 0.08478958159685135f;
  t38_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t38_n12;
  t38_n11: return 0.07891104370355606f;
  t38_n12: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t38_n16;
  t38_n13: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t38_n15;
  t38_n14: return 0.11399515718221664f;
  t38_n15: return 0.11826348304748535f;
  t38_n16: return 0.09269677847623825f;
  t38_n17: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t38_n43;
  t38_n18: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t38_n26;
  t38_n19: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n21;
  t38_n20: return -0.07976806908845901f;
  t38_n21: if (E.getNumReferences() >= 3342147712 /*46368.5*/) goto t38_n25;
  t38_n22: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t38_n24;
  t38_n23: return 0.034580428153276443f;
  t38_n24: return -0.09270016103982925f;
  t38_n25: return 0.1515534222126007f;
  t38_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t38_n30;
  t38_n27: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n29;
  t38_n28: return 0.03454923629760742f;
  t38_n29: return -0.053083062171936035f;
  t38_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t38_n32;
  t38_n31: return 0.0026602400466799736f;
  t38_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t38_n34;
  t38_n33: return 0.0766591727733612f;
  t38_n34: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n40;
  t38_n35: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t38_n37;
  t38_n36: return 0.11738161742687225f;
  t38_n37: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n39;
  t38_n38: return 0.12723644077777863f;
  t38_n39: return 0.07128223031759262f;
  t38_n40: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n42;
  t38_n41: return 0.08781342953443527f;
  t38_n42: return 0.025236565619707108f;
  t38_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t38_n45;
  t38_n44: return -0.11059661954641342f;
  t38_n45: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t38_n47;
  t38_n46: return 0.021480940282344818f;
  t38_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t38_n49;
  t38_n48: return 0.05232878774404526f;
  t38_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n51;
  t38_n50: return 0.0932735875248909f;
  t38_n51: return 0.03855506330728531f;
  t38_n52: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t38_n172;
  t38_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t38_n63;
  t38_n54: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n56;
  t38_n55: return -0.007914107292890549f;
  t38_n56: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t38_n62;
  t38_n57: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t38_n59;
  t38_n58: return 0.04661652445793152f;
  t38_n59: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t38_n61;
  t38_n60: return 0.07621905952692032f;
  t38_n61: return 0.039009444415569305f;
  t38_n62: return -0.12866993248462677f;
  t38_n63: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t38_n165;
  t38_n64: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t38_n108;
  t38_n65: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t38_n85;
  t38_n66: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n84;
  t38_n67: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t38_n73;
  t38_n68: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t38_n72;
  t38_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t38_n71;
  t38_n70: return -0.03888826072216034f;
  t38_n71: return 0.045305147767066956f;
  t38_n72: return 0.06348416209220886f;
  t38_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_UnionTag))) goto t38_n75;
  t38_n74: return 0.016516538336873055f;
  t38_n75: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t38_n81;
  t38_n76: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n80;
  t38_n77: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t38_n79;
  t38_n78: return 0.0985163152217865f;
  t38_n79: return 0.1061035767197609f;
  t38_n80: return 0.06286760419607162f;
  t38_n81: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t38_n83;
  t38_n82: return 0.06595302373170853f;
  t38_n83: return 0.09655164927244186f;
  t38_n84: return -0.07888197153806686f;
  t38_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t38_n87;
  t38_n86: return 0.05073300004005432f;
  t38_n87: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t38_n107;
  t38_n88: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t38_n90;
  t38_n89: return 0.06257568299770355f;
  t38_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t38_n92;
  t38_n91: return 0.08747126907110214f;
  t38_n92: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t38_n94;
  t38_n93: return 0.10147086530923843f;
  t38_n94: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n96;
  t38_n95: return 0.10992804914712906f;
  t38_n96: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t38_n106;
  t38_n97: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t38_n99;
  t38_n98: return 0.09783713519573212f;
  t38_n99: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t38_n105;
  t38_n100: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t38_n104;
  t38_n101: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t38_n103;
  t38_n102: return 0.10447847098112106f;
  t38_n103: return 0.11919760704040527f;
  t38_n104: return 0.12259134650230408f;
  t38_n105: return 0.11399397253990173f;
  t38_n106: return 0.06022940203547478f;
  t38_n107: return 0.09473935514688492f;
  t38_n108: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t38_n142;
  t38_n109: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t38_n111;
  t38_n110: return -0.0005444589769467711f;
  t38_n111: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t38_n119;
  t38_n112: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t38_n118;
  t38_n113: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n115;
  t38_n114: return 0.04169207066297531f;
  t38_n115: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t38_n117;
  t38_n116: return 0.09289062023162842f;
  t38_n117: return 0.05714264512062073f;
  t38_n118: return -0.00037876988062635064f;
  t38_n119: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t38_n141;
  t38_n120: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t38_n140;
  t38_n121: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t38_n135;
  t38_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t38_n124;
  t38_n123: return 0.10875468701124191f;
  t38_n124: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t38_n132;
  t38_n125: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n131;
  t38_n126: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t38_n130;
  t38_n127: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t38_n129;
  t38_n128: return -0.10220228880643845f;
  t38_n129: return 0.15667930245399475f;
  t38_n130: return 0.13154517114162445f;
  t38_n131: return 0.08624933660030365f;
  t38_n132: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t38_n134;
  t38_n133: return 0.11087449640035629f;
  t38_n134: return 0.13469839096069336f;
  t38_n135: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t38_n137;
  t38_n136: return 0.14768993854522705f;
  t38_n137: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t38_n139;
  t38_n138: return -0.10561879724264145f;
  t38_n139: return 0.1634504348039627f;
  t38_n140: return 0.10752209275960922f;
  t38_n141: return 0.08582920581102371f;
  t38_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t38_n144;
  t38_n143: return 0.02860788255929947f;
  t38_n144: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t38_n154;
  t38_n145: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t38_n153;
  t38_n146: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t38_n152;
  t38_n147: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t38_n149;
  t38_n148: return 0.016714204102754593f;
  t38_n149: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n151;
  t38_n150: return 0.10164794325828552f;
  t38_n151: return -0.07687459886074066f;
  t38_n152: return -0.1266942322254181f;
  t38_n153: return -0.010576254688203335f;
  t38_n154: if (E.getFileProximityDistance() >= 3251634176 /*26.0*/) goto t38_n156;
  t38_n155: return 0.00435137702152133f;
  t38_n156: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t38_n164;
  t38_n157: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n163;
  t38_n158: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n162;
  t38_n159: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t38_n161;
  t38_n160: return 0.10029390454292297f;
  t38_n161: return 0.10127801448106766f;
  t38_n162: return 0.08141831308603287f;
  t38_n163: return -0.0813506543636322f;
  t38_n164: return -0.10530773550271988f;
  t38_n165: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t38_n167;
  t38_n166: return 0.0154801644384861f;
  t38_n167: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t38_n171;
  t38_n168: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t38_n170;
  t38_n169: return 0.08097843825817108f;
  t38_n170: return 0.10641394555568695f;
  t38_n171: return 0.04996678978204727f;
  t38_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t38_n174;
  t38_n173: return 0.06373048573732376f;
  t38_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t38_n180;
  t38_n175: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t38_n179;
  t38_n176: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n178;
  t38_n177: return 0.11850982159376144f;
  t38_n178: return 0.063189797103405f;
  t38_n179: return 0.07099172472953796f;
  t38_n180: return 0.010561195202171803f;
  t38_n181: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n187;
  t38_n182: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t38_n184;
  t38_n183: return 0.02480582892894745f;
  t38_n184: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t38_n186;
  t38_n185: return 0.09586063027381897f;
  t38_n186: return 0.05813870579004288f;
  t38_n187: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t38_n207;
  t38_n188: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t38_n194;
  t38_n189: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t38_n193;
  t38_n190: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t38_n192;
  t38_n191: return 0.06964738667011261f;
  t38_n192: return 0.07125753909349442f;
  t38_n193: return 0.01785593293607235f;
  t38_n194: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n204;
  t38_n195: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t38_n197;
  t38_n196: return -0.020522328093647957f;
  t38_n197: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t38_n203;
  t38_n198: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t38_n200;
  t38_n199: return 0.010042008943855762f;
  t38_n200: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t38_n202;
  t38_n201: return -0.7789092063903809f;
  t38_n202: return 0.1321599930524826f;
  t38_n203: return -0.012016556225717068f;
  t38_n204: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t38_n206;
  t38_n205: return 0.05125374719500542f;
  t38_n206: return 0.10201740264892578f;
  t38_n207: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t38_n239;
  t38_n208: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t38_n210;
  t38_n209: return 0.03288095444440842f;
  t38_n210: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t38_n238;
  t38_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t38_n215;
  t38_n212: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t38_n214;
  t38_n213: return 0.020977847278118134f;
  t38_n214: return 0.10807675868272781f;
  t38_n215: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t38_n217;
  t38_n216: return 0.07281500846147537f;
  t38_n217: if (E.getNumReferences() >= 3273981952 /*165.0*/) goto t38_n237;
  t38_n218: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t38_n234;
  t38_n219: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t38_n225;
  t38_n220: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t38_n222;
  t38_n221: return 0.11369062215089798f;
  t38_n222: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t38_n224;
  t38_n223: return 0.09088750183582306f;
  t38_n224: return 0.12466146051883698f;
  t38_n225: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t38_n233;
  t38_n226: if (E.getNumReferences() >= 3256090624 /*37.0*/) goto t38_n228;
  t38_n227: return 0.11126900464296341f;
  t38_n228: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t38_n232;
  t38_n229: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t38_n231;
  t38_n230: return 0.12415345758199692f;
  t38_n231: return 0.12461581826210022f;
  t38_n232: return 0.08588235825300217f;
  t38_n233: return 0.10983006656169891f;
  t38_n234: if (E.getNumReferences() >= 3266510848 /*89.5*/) goto t38_n236;
  t38_n235: return 0.11673220992088318f;
  t38_n236: return 0.12389625608921051f;
  t38_n237: return 0.0897487998008728f;
  t38_n238: return 0.08485789597034454f;
  t38_n239: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t38_n245;
  t38_n240: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t38_n244;
  t38_n241: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t38_n243;
  t38_n242: return 0.12196191400289536f;
  t38_n243: return 0.06323973834514618f;
  t38_n244: return 0.08155130594968796f;
  t38_n245: return 0.04567473381757736f;
  t38_n246: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t38_n250;
  t38_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n249;
  t38_n248: return 0.01733136922121048f;
  t38_n249: return 0.036481063812971115f;
  t38_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t38_n254;
  t38_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n253;
  t38_n252: return 0.06086074560880661f;
  t38_n253: return 0.07914861291646957f;
  t38_n254: return 0.08429668843746185f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree39(const Example& E) {
  t39_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t39_n242;
  t39_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t39_n207;
  t39_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t39_n122;
  t39_n3: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t39_n73;
  t39_n4: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t39_n36;
  t39_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t39_n35;
  t39_n6: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t39_n24;
  t39_n7: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t39_n9;
  t39_n8: return -0.05039064958691597f;
  t39_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t39_n15;
  t39_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t39_n12;
  t39_n11: return -0.06467871367931366f;
  t39_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t39_n14;
  t39_n13: return 0.07771693170070648f;
  t39_n14: return -0.03645526245236397f;
  t39_n15: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t39_n17;
  t39_n16: return 0.017934339120984077f;
  t39_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t39_n19;
  t39_n18: return 0.2047569751739502f;
  t39_n19: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n23;
  t39_n20: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t39_n22;
  t39_n21: return 0.13871021568775177f;
  t39_n22: return 0.11456659436225891f;
  t39_n23: return 0.10615316778421402f;
  t39_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t39_n26;
  t39_n25: return -0.061688825488090515f;
  t39_n26: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t39_n28;
  t39_n27: return 0.013545054942369461f;
  t39_n28: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t39_n34;
  t39_n29: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n33;
  t39_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t39_n32;
  t39_n31: return 0.09847233444452286f;
  t39_n32: return 0.10026425123214722f;
  t39_n33: return -0.14121858775615692f;
  t39_n34: return -0.009746836498379707f;
  t39_n35: return -0.005086731631308794f;
  t39_n36: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t39_n42;
  t39_n37: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t39_n39;
  t39_n38: return 0.0229460671544075f;
  t39_n39: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t39_n41;
  t39_n40: return 0.09361903369426727f;
  t39_n41: return 0.03902535140514374f;
  t39_n42: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t39_n68;
  t39_n43: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t39_n45;
  t39_n44: return 0.08085227012634277f;
  t39_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t39_n47;
  t39_n46: return 0.08599235862493515f;
  t39_n47: if (E.getNumReferences() >= 3269001216 /*108.5*/) goto t39_n49;
  t39_n48: return 0.09656066447496414f;
  t39_n49: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t39_n55;
  t39_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t39_n52;
  t39_n51: return 0.11496216803789139f;
  t39_n52: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t39_n54;
  t39_n53: return 0.10764119774103165f;
  t39_n54: return 0.1365249902009964f;
  t39_n55: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t39_n67;
  t39_n56: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t39_n64;
  t39_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t39_n59;
  t39_n58: return 0.10408973693847656f;
  t39_n59: if (E.getNumReferences() >= 3274539008 /*173.5*/) goto t39_n61;
  t39_n60: return 0.08043712377548218f;
  t39_n61: if (E.getNumReferences() >= 3275096064 /*182.0*/) goto t39_n63;
  t39_n62: return 0.1235751062631607f;
  t39_n63: return 0.1075480505824089f;
  t39_n64: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t39_n66;
  t39_n65: return 0.11461898684501648f;
  t39_n66: return 0.14421340823173523f;
  t39_n67: return 0.04627405107021332f;
  t39_n68: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t39_n72;
  t39_n69: if (E.getNumReferences() >= 3319035904 /*6799.0*/) goto t39_n71;
  t39_n70: return -0.0031901304610073566f;
  t39_n71: return 0.06717132776975632f;
  t39_n72: return 0.06722072511911392f;
  t39_n73: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t39_n91;
  t39_n74: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t39_n90;
  t39_n75: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t39_n77;
  t39_n76: return -0.055073466151952744f;
  t39_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t39_n79;
  t39_n78: return 0.008397926576435566f;
  t39_n79: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t39_n85;
  t39_n80: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t39_n84;
  t39_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t39_n83;
  t39_n82: return 0.01639508828520775f;
  t39_n83: return 0.054471299052238464f;
  t39_n84: return -0.031107665970921516f;
  t39_n85: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t39_n89;
  t39_n86: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t39_n88;
  t39_n87: return 0.11197694391012192f;
  t39_n88: return 0.018863162025809288f;
  t39_n89: return 0.01524604856967926f;
  t39_n90: return -0.11146949231624603f;
  t39_n91: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t39_n93;
  t39_n92: return -0.003956094849854708f;
  t39_n93: if (E.getNumReferences() >= 3326734336 /*12924.0*/) goto t39_n95;
  t39_n94: return 0.12686580419540405f;
  t39_n95: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t39_n107;
  t39_n96: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t39_n106;
  t39_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t39_n99;
  t39_n98: return 0.03819461166858673f;
  t39_n99: if (E.getNumReferences() >= 3327319040 /*13495.0*/) goto t39_n105;
  t39_n100: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t39_n102;
  t39_n101: return 0.11162766814231873f;
  t39_n102: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t39_n104;
  t39_n103: return 0.11762914061546326f;
  t39_n104: return 0.06004536896944046f;
  t39_n105: return 0.061402346938848495f;
  t39_n106: return 0.09200522303581238f;
  t39_n107: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t39_n111;
  t39_n108: if (E.getNumReferences() >= 3327415296 /*13589.0*/) goto t39_n110;
  t39_n109: return 0.12955045700073242f;
  t39_n110: return 0.022844398394227028f;
  t39_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t39_n113;
  t39_n112: return 0.07890859991312027f;
  t39_n113: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t39_n121;
  t39_n114: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t39_n116;
  t39_n115: return -0.10181187093257904f;
  t39_n116: if (E.getNumReferences() >= 3331241984 /*18268.0*/) goto t39_n120;
  t39_n117: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t39_n119;
  t39_n118: return 0.11582332104444504f;
  t39_n119: return 0.1099347174167633f;
  t39_n120: return 0.11461499333381653f;
  t39_n121: return 0.07722152024507523f;
  t39_n122: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t39_n166;
  t39_n123: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t39_n129;
  t39_n124: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t39_n126;
  t39_n125: return 0.020407017320394516f;
  t39_n126: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t39_n128;
  t39_n127: return -0.013935007154941559f;
  t39_n128: return -0.09359447658061981f;
  t39_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t39_n131;
  t39_n130: return -0.07779011875391006f;
  t39_n131: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t39_n133;
  t39_n132: return -0.01882772147655487f;
  t39_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t39_n139;
  t39_n134: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n138;
  t39_n135: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t39_n137;
  t39_n136: return 0.010779477655887604f;
  t39_n137: return -0.07273266464471817f;
  t39_n138: return -0.09089940041303635f;
  t39_n139: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t39_n165;
  t39_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t39_n142;
  t39_n141: return 0.014418356120586395f;
  t39_n142: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t39_n160;
  t39_n143: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n149;
  t39_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t39_n146;
  t39_n145: return 0.028086410835385323f;
  t39_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t39_n148;
  t39_n147: return 0.03394468128681183f;
  t39_n148: return 0.05011334642767906f;
  t39_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t39_n151;
  t39_n150: return 0.019248899072408676f;
  t39_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t39_n153;
  t39_n152: return -0.0605170838534832f;
  t39_n153: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t39_n155;
  t39_n154: return 0.08157581090927124f;
  t39_n155: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t39_n157;
  t39_n156: return 0.05547713115811348f;
  t39_n157: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t39_n159;
  t39_n158: return 0.13411453366279602f;
  t39_n159: return 0.06689178198575974f;
  t39_n160: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n164;
  t39_n161: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t39_n163;
  t39_n162: return 0.0690985843539238f;
  t39_n163: return 0.08400663733482361f;
  t39_n164: return 0.020922062918543816f;
  t39_n165: return 0.0013434316497296095f;
  t39_n166: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t39_n182;
  t39_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t39_n169;
  t39_n168: return 0.01971074938774109f;
  t39_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t39_n179;
  t39_n170: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t39_n172;
  t39_n171: return 0.050833795219659805f;
  t39_n172: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t39_n174;
  t39_n173: return 0.0375654436647892f;
  t39_n174: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t39_n176;
  t39_n175: return 0.06802689284086227f;
  t39_n176: if (E.getNumReferences() >= 3273654272 /*160.0*/) goto t39_n178;
  t39_n177: return 0.11746593564748764f;
  t39_n178: return 0.06939229369163513f;
  t39_n179: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t39_n181;
  t39_n180: return 0.06904544681310654f;
  t39_n181: return 0.08492900431156158f;
  t39_n182: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t39_n206;
  t39_n183: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t39_n205;
  t39_n184: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t39_n186;
  t39_n185: return 0.08043646067380905f;
  t39_n186: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t39_n196;
  t39_n187: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t39_n189;
  t39_n188: return 0.10427872836589813f;
  t39_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t39_n191;
  t39_n190: return 0.12133914977312088f;
  t39_n191: if (E.getNumReferences() >= 3275030528 /*181.0*/) goto t39_n195;
  t39_n192: if (E.getNumReferences() >= 3271491584 /*127.5*/) goto t39_n194;
  t39_n193: return 0.13398641347885132f;
  t39_n194: return 0.13232986629009247f;
  t39_n195: return 0.11004990339279175f;
  t39_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t39_n198;
  t39_n197: return 0.08845709264278412f;
  t39_n198: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t39_n204;
  t39_n199: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t39_n203;
  t39_n200: if (E.getNumReferences() >= 3238002688 /*8.0*/) goto t39_n202;
  t39_n201: return 0.13749602437019348f;
  t39_n202: return -0.12267275154590607f;
  t39_n203: return 0.14974968135356903f;
  t39_n204: return 0.1335352063179016f;
  t39_n205: return 0.0038894186727702618f;
  t39_n206: return 0.03534897789359093f;
  t39_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t39_n217;
  t39_n208: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t39_n212;
  t39_n209: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n211;
  t39_n210: return 0.02573220804333687f;
  t39_n211: return 0.0443853922188282f;
  t39_n212: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t39_n216;
  t39_n213: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t39_n215;
  t39_n214: return 0.05506022274494171f;
  t39_n215: return 0.10306484252214432f;
  t39_n216: return 0.055319562554359436f;
  t39_n217: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t39_n231;
  t39_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t39_n222;
  t39_n219: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n221;
  t39_n220: return 0.019506175071001053f;
  t39_n221: return 0.0426773838698864f;
  t39_n222: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t39_n228;
  t39_n223: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t39_n227;
  t39_n224: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t39_n226;
  t39_n225: return 0.05059078335762024f;
  t39_n226: return 0.03222066909074783f;
  t39_n227: return 0.061337150633335114f;
  t39_n228: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n230;
  t39_n229: return -0.04802776873111725f;
  t39_n230: return 0.0816223993897438f;
  t39_n231: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t39_n233;
  t39_n232: return 0.08179254829883575f;
  t39_n233: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t39_n241;
  t39_n234: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t39_n236;
  t39_n235: return 0.022647010162472725f;
  t39_n236: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t39_n240;
  t39_n237: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t39_n239;
  t39_n238: return 0.1009841337800026f;
  t39_n239: return 0.11278136074542999f;
  t39_n240: return 0.06272494047880173f;
  t39_n241: return 0.047917064279317856f;
  t39_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t39_n250;
  t39_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t39_n247;
  t39_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t39_n246;
  t39_n245: return -0.016376707702875137f;
  t39_n246: return 0.02396969497203827f;
  t39_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t39_n249;
  t39_n248: return 0.01951061747968197f;
  t39_n249: return 0.05110973119735718f;
  t39_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t39_n254;
  t39_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t39_n253;
  t39_n252: return 0.05882137641310692f;
  t39_n253: return 0.07710695266723633f;
  t39_n254: return 0.08236297965049744f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree40(const Example& E) {
  t40_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t40_n242;
  t40_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t40_n181;
  t40_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t40_n86;
  t40_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t40_n39;
  t40_n4: if (E.getNumReferences() >= 3307976704 /*2747.5*/) goto t40_n6;
  t40_n5: return -0.06253829598426819f;
  t40_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t40_n8;
  t40_n7: return -0.1420886516571045f;
  t40_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t40_n10;
  t40_n9: return 0.025398014113307f;
  t40_n10: if (E.getNumReferences() >= 3326629376 /*12821.5*/) goto t40_n14;
  t40_n11: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t40_n13;
  t40_n12: return 0.03718787431716919f;
  t40_n13: return 0.1579907387495041f;
  t40_n14: if (E.getNumReferences() >= 3327212032 /*13390.5*/) goto t40_n26;
  t40_n15: if (E.getNumReferences() >= 3327019520 /*13202.5*/) goto t40_n21;
  t40_n16: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t40_n20;
  t40_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t40_n19;
  t40_n18: return 0.12108375877141953f;
  t40_n19: return 0.13334433734416962f;
  t40_n20: return 0.1114792600274086f;
  t40_n21: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t40_n23;
  t40_n22: return 0.11964424699544907f;
  t40_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t40_n25;
  t40_n24: return 0.1441175490617752f;
  t40_n25: return 0.12809112668037415f;
  t40_n26: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t40_n30;
  t40_n27: if (E.getNumReferences() >= 3351807168 /*102665.5*/) goto t40_n29;
  t40_n28: return 0.0706353560090065f;
  t40_n29: return -0.08894065022468567f;
  t40_n30: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t40_n36;
  t40_n31: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t40_n33;
  t40_n32: return 0.11528899520635605f;
  t40_n33: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t40_n35;
  t40_n34: return 0.11655684560537338f;
  t40_n35: return 0.11592214554548264f;
  t40_n36: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t40_n38;
  t40_n37: return 0.028716960921883583f;
  t40_n38: return 0.10211734473705292f;
  t40_n39: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t40_n49;
  t40_n40: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t40_n42;
  t40_n41: return -0.03778796270489693f;
  t40_n42: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t40_n44;
  t40_n43: return 0.030653852969408035f;
  t40_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t40_n46;
  t40_n45: return 0.07520285248756409f;
  t40_n46: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t40_n48;
  t40_n47: return 0.11891970038414001f;
  t40_n48: return -0.13208414614200592f;
  t40_n49: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t40_n73;
  t40_n50: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t40_n56;
  t40_n51: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t40_n53;
  t40_n52: return -0.0863112136721611f;
  t40_n53: if (E.getNumReferences() >= 3342575744 /*48040.5*/) goto t40_n55;
  t40_n54: return 0.022299157455563545f;
  t40_n55: return 0.1561080366373062f;
  t40_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t40_n60;
  t40_n57: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n59;
  t40_n58: return 0.03122168779373169f;
  t40_n59: return -0.0510648675262928f;
  t40_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t40_n62;
  t40_n61: return 0.003581155091524124f;
  t40_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n64;
  t40_n63: return 0.07275665551424026f;
  t40_n64: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n70;
  t40_n65: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t40_n67;
  t40_n66: return 0.1151968315243721f;
  t40_n67: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n69;
  t40_n68: return 0.12476243078708649f;
  t40_n69: return 0.0686759352684021f;
  t40_n70: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n72;
  t40_n71: return 0.07914815843105316f;
  t40_n72: return 0.02330300584435463f;
  t40_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t40_n75;
  t40_n74: return -0.10158964991569519f;
  t40_n75: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t40_n81;
  t40_n76: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n78;
  t40_n77: return -0.0012293658219277859f;
  t40_n78: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t40_n80;
  t40_n79: return 0.059728264808654785f;
  t40_n80: return -0.020622052252292633f;
  t40_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t40_n83;
  t40_n82: return 0.04916961118578911f;
  t40_n83: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n85;
  t40_n84: return 0.0899810791015625f;
  t40_n85: return 0.036340486258268356f;
  t40_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t40_n106;
  t40_n87: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n89;
  t40_n88: return -0.011375101283192635f;
  t40_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t40_n91;
  t40_n90: return 0.01833478733897209f;
  t40_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t40_n93;
  t40_n92: return 0.03230121359229088f;
  t40_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n95;
  t40_n94: return 0.07017646729946136f;
  t40_n95: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t40_n97;
  t40_n96: return -0.012533650733530521f;
  t40_n97: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t40_n105;
  t40_n98: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t40_n104;
  t40_n99: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t40_n103;
  t40_n100: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t40_n102;
  t40_n101: return 0.11240291595458984f;
  t40_n102: return 0.07972382009029388f;
  t40_n103: return 0.11238057911396027f;
  t40_n104: return 0.06756579875946045f;
  t40_n105: return 0.10956333577632904f;
  t40_n106: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t40_n174;
  t40_n107: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t40_n153;
  t40_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t40_n148;
  t40_n109: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t40_n147;
  t40_n110: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t40_n132;
  t40_n111: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t40_n115;
  t40_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t40_n114;
  t40_n113: return 0.0012945469934493303f;
  t40_n114: return 0.05278632417321205f;
  t40_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t40_n117;
  t40_n116: return 0.03022637404501438f;
  t40_n117: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t40_n119;
  t40_n118: return 0.0076742516830563545f;
  t40_n119: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t40_n123;
  t40_n120: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n122;
  t40_n121: return 0.10120075196027756f;
  t40_n122: return -0.06791941076517105f;
  t40_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n131;
  t40_n124: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n130;
  t40_n125: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n129;
  t40_n126: if (E.getFileProximityDistance() >= 3250585600 /*24.0*/) goto t40_n128;
  t40_n127: return -0.03275703266263008f;
  t40_n128: return 0.09688959270715714f;
  t40_n129: return -0.1100349947810173f;
  t40_n130: return 0.07202090322971344f;
  t40_n131: return 0.0795731246471405f;
  t40_n132: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t40_n146;
  t40_n133: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t40_n141;
  t40_n134: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n136;
  t40_n135: return 0.05436254292726517f;
  t40_n136: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t40_n140;
  t40_n137: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t40_n139;
  t40_n138: return 0.06700816750526428f;
  t40_n139: return 0.08893360197544098f;
  t40_n140: return 0.06864847987890244f;
  t40_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag))) goto t40_n143;
  t40_n142: return 0.08729751408100128f;
  t40_n143: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t40_n145;
  t40_n144: return 0.09556038677692413f;
  t40_n145: return 0.1035492792725563f;
  t40_n146: return 0.03515530005097389f;
  t40_n147: return -0.04007861018180847f;
  t40_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t40_n152;
  t40_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t40_n151;
  t40_n150: return -0.058478306978940964f;
  t40_n151: return 0.09534724801778793f;
  t40_n152: return 0.011549596674740314f;
  t40_n153: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n161;
  t40_n154: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t40_n160;
  t40_n155: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t40_n159;
  t40_n156: if (E.getNumReferences() >= 3355264064 /*129672.5*/) goto t40_n158;
  t40_n157: return 0.0371662937104702f;
  t40_n158: return 0.05603684484958649f;
  t40_n159: return -0.03264615684747696f;
  t40_n160: return -0.2599371075630188f;
  t40_n161: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t40_n173;
  t40_n162: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t40_n164;
  t40_n163: return 0.0791022777557373f;
  t40_n164: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t40_n172;
  t40_n165: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t40_n171;
  t40_n166: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t40_n170;
  t40_n167: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t40_n169;
  t40_n168: return 0.057846713811159134f;
  t40_n169: return 0.1174023225903511f;
  t40_n170: return 0.11126118898391724f;
  t40_n171: return 0.10497210174798965f;
  t40_n172: return 0.09633435308933258f;
  t40_n173: return 0.053725000470876694f;
  t40_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t40_n180;
  t40_n175: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t40_n179;
  t40_n176: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n178;
  t40_n177: return 0.10469035804271698f;
  t40_n178: return 0.0569327287375927f;
  t40_n179: return 0.06464086472988129f;
  t40_n180: return 0.008206715807318687f;
  t40_n181: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t40_n201;
  t40_n182: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n196;
  t40_n183: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n185;
  t40_n184: return 0.02260560169816017f;
  t40_n185: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t40_n191;
  t40_n186: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t40_n190;
  t40_n187: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t40_n189;
  t40_n188: return 0.08089587092399597f;
  t40_n189: return 0.045040279626846313f;
  t40_n190: return 0.06985544413328171f;
  t40_n191: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t40_n193;
  t40_n192: return -0.05168046057224274f;
  t40_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t40_n195;
  t40_n194: return 0.005731320474296808f;
  t40_n195: return 0.04234291613101959f;
  t40_n196: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t40_n200;
  t40_n197: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t40_n199;
  t40_n198: return 0.04237886518239975f;
  t40_n199: return 0.07883884757757187f;
  t40_n200: return -0.06827498227357864f;
  t40_n201: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t40_n235;
  t40_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t40_n208;
  t40_n203: if (E.getNumReferences() >= 3349646912 /*85788.5*/) goto t40_n207;
  t40_n204: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n206;
  t40_n205: return 0.03911169618368149f;
  t40_n206: return 0.07485467940568924f;
  t40_n207: return 0.0867425724864006f;
  t40_n208: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t40_n214;
  t40_n209: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t40_n211;
  t40_n210: return 0.07729549705982208f;
  t40_n211: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t40_n213;
  t40_n212: return -0.16433751583099365f;
  t40_n213: return 0.14039607346057892f;
  t40_n214: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n216;
  t40_n215: return 0.041180457919836044f;
  t40_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n218;
  t40_n217: return 0.11453207582235336f;
  t40_n218: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t40_n220;
  t40_n219: return 0.1422300934791565f;
  t40_n220: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t40_n222;
  t40_n221: return 0.09113828837871552f;
  t40_n222: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t40_n224;
  t40_n223: return 0.10621506720781326f;
  t40_n224: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t40_n228;
  t40_n225: if (E.getNumReferences() >= 3266052096 /*86.0*/) goto t40_n227;
  t40_n226: return 0.11646093428134918f;
  t40_n227: return 0.1207704246044159f;
  t40_n228: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t40_n234;
  t40_n229: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t40_n233;
  t40_n230: if (E.getNumReferences() >= 3259105280 /*48.5*/) goto t40_n232;
  t40_n231: return 0.1112934798002243f;
  t40_n232: return 0.12362509220838547f;
  t40_n233: return 0.10609473288059235f;
  t40_n234: return 0.08576983213424683f;
  t40_n235: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t40_n237;
  t40_n236: return 0.030849061906337738f;
  t40_n237: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t40_n239;
  t40_n238: return 0.026993820443749428f;
  t40_n239: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t40_n241;
  t40_n240: return 0.0019141919910907745f;
  t40_n241: return 0.08259481191635132f;
  t40_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t40_n250;
  t40_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n247;
  t40_n244: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t40_n246;
  t40_n245: return 0.010034585371613503f;
  t40_n246: return 0.05233573541045189f;
  t40_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n249;
  t40_n248: return 0.01844082400202751f;
  t40_n249: return 0.049050893634557724f;
  t40_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t40_n254;
  t40_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n253;
  t40_n252: return 0.0568239800632f;
  t40_n253: return 0.07453007996082306f;
  t40_n254: return 0.08068624883890152f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree41(const Example& E) {
  t41_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t41_n240;
  t41_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t41_n203;
  t41_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t41_n114;
  t41_n3: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t41_n75;
  t41_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t41_n6;
  t41_n5: return -0.10520941764116287f;
  t41_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t41_n50;
  t41_n7: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t41_n23;
  t41_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t41_n22;
  t41_n9: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t41_n11;
  t41_n10: return -0.030468666926026344f;
  t41_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t41_n21;
  t41_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t41_n20;
  t41_n13: if (E.getFileProximityDistance() >= 3250585600 /*24.0*/) goto t41_n15;
  t41_n14: return -0.060491617769002914f;
  t41_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t41_n17;
  t41_n16: return -0.6709210872650146f;
  t41_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n19;
  t41_n18: return 0.09468092769384384f;
  t41_n19: return 0.07392194867134094f;
  t41_n20: return -0.13242489099502563f;
  t41_n21: return -0.0070925746113061905f;
  t41_n22: return 0.009462571702897549f;
  t41_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t41_n29;
  t41_n24: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t41_n26;
  t41_n25: return 0.02674075961112976f;
  t41_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t41_n28;
  t41_n27: return -0.09665833413600922f;
  t41_n28: return 0.028370190411806107f;
  t41_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t41_n39;
  t41_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t41_n32;
  t41_n31: return 0.004122622776776552f;
  t41_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t41_n34;
  t41_n33: return 0.08913730829954147f;
  t41_n34: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t41_n36;
  t41_n35: return 0.10283865034580231f;
  t41_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n38;
  t41_n37: return 0.1213344931602478f;
  t41_n38: return 0.0800972729921341f;
  t41_n39: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t41_n41;
  t41_n40: return 0.1509074866771698f;
  t41_n41: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n47;
  t41_n42: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t41_n46;
  t41_n43: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t41_n45;
  t41_n44: return 0.1461765617132187f;
  t41_n45: return 0.13011759519577026f;
  t41_n46: return 0.11241767555475235f;
  t41_n47: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t41_n49;
  t41_n48: return 0.1105131059885025f;
  t41_n49: return 0.09702363610267639f;
  t41_n50: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t41_n74;
  t41_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t41_n53;
  t41_n52: return -0.04433785751461983f;
  t41_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t41_n55;
  t41_n54: return 0.026300741359591484f;
  t41_n55: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t41_n73;
  t41_n56: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t41_n60;
  t41_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t41_n59;
  t41_n58: return 0.012058736756443977f;
  t41_n59: return 0.07541155070066452f;
  t41_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t41_n62;
  t41_n61: return 0.07302262634038925f;
  t41_n62: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t41_n68;
  t41_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n67;
  t41_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t41_n66;
  t41_n65: return 0.059767719358205795f;
  t41_n66: return 0.10328985750675201f;
  t41_n67: return 0.016554279252886772f;
  t41_n68: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t41_n70;
  t41_n69: return 0.10576734691858292f;
  t41_n70: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t41_n72;
  t41_n71: return 0.11429159343242645f;
  t41_n72: return -0.1115475744009018f;
  t41_n73: return 0.035137709230184555f;
  t41_n74: return -0.020996257662773132f;
  t41_n75: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t41_n81;
  t41_n76: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t41_n80;
  t41_n77: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t41_n79;
  t41_n78: return 0.022493954747915268f;
  t41_n79: return 0.11158695071935654f;
  t41_n80: return 0.04244447499513626f;
  t41_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t41_n91;
  t41_n82: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t41_n84;
  t41_n83: return 0.04258648306131363f;
  t41_n84: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t41_n90;
  t41_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t41_n89;
  t41_n86: if (E.getNumReferences() >= 3308359680 /*2841.0*/) goto t41_n88;
  t41_n87: return -0.017507357522845268f;
  t41_n88: return 0.058614425361156464f;
  t41_n89: return 0.09827828407287598f;
  t41_n90: return 0.07048068195581436f;
  t41_n91: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t41_n111;
  t41_n92: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t41_n94;
  t41_n93: return 0.06863448768854141f;
  t41_n94: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t41_n96;
  t41_n95: return 0.06130596250295639f;
  t41_n96: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t41_n110;
  t41_n97: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t41_n99;
  t41_n98: return 0.10796506702899933f;
  t41_n99: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t41_n105;
  t41_n100: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t41_n104;
  t41_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t41_n103;
  t41_n102: return 0.10319153964519501f;
  t41_n103: return 0.11869559437036514f;
  t41_n104: return 0.03250354155898094f;
  t41_n105: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t41_n107;
  t41_n106: return 0.10823696106672287f;
  t41_n107: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n109;
  t41_n108: return 0.0938991904258728f;
  t41_n109: return 0.12496254593133926f;
  t41_n110: return 0.09927182644605637f;
  t41_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t41_n113;
  t41_n112: return 0.047033775597810745f;
  t41_n113: return 0.0891859158873558f;
  t41_n114: if (E.getNumReferences() >= 3283271680 /*357.5*/) goto t41_n122;
  t41_n115: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t41_n117;
  t41_n116: return 0.004602473229169846f;
  t41_n117: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t41_n121;
  t41_n118: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t41_n120;
  t41_n119: return -0.033001288771629333f;
  t41_n120: return -0.09596039354801178f;
  t41_n121: return -0.07815799117088318f;
  t41_n122: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t41_n198;
  t41_n123: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t41_n125;
  t41_n124: return -0.026733607053756714f;
  t41_n125: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t41_n147;
  t41_n126: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t41_n146;
  t41_n127: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t41_n135;
  t41_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t41_n130;
  t41_n129: return 0.07280541211366653f;
  t41_n130: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t41_n134;
  t41_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t41_n133;
  t41_n132: return 0.11155259609222412f;
  t41_n133: return 0.1279035061597824f;
  t41_n134: return 0.08215364068746567f;
  t41_n135: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t41_n145;
  t41_n136: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t41_n138;
  t41_n137: return 0.05462583154439926f;
  t41_n138: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t41_n142;
  t41_n139: if (E.getNumReferences() >= 3317627904 /*6111.5*/) goto t41_n141;
  t41_n140: return 0.015329133719205856f;
  t41_n141: return 0.12388689815998077f;
  t41_n142: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n144;
  t41_n143: return 0.04841525852680206f;
  t41_n144: return 0.10519404709339142f;
  t41_n145: return 0.028063565492630005f;
  t41_n146: return 0.0012252974556759f;
  t41_n147: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t41_n149;
  t41_n148: return 0.03382670134305954f;
  t41_n149: if (E.getNumReferences() >= 3326734336 /*12924.0*/) goto t41_n151;
  t41_n150: return 0.12075314670801163f;
  t41_n151: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t41_n179;
  t41_n152: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t41_n178;
  t41_n153: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t41_n177;
  t41_n154: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t41_n176;
  t41_n155: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t41_n171;
  t41_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t41_n158;
  t41_n157: return 0.06731346994638443f;
  t41_n158: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t41_n160;
  t41_n159: return 0.051796503365039825f;
  t41_n160: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n170;
  t41_n161: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t41_n169;
  t41_n162: if (E.getNumReferences() >= 3332338944 /*20410.5*/) goto t41_n168;
  t41_n163: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t41_n167;
  t41_n164: if (E.getNumReferences() >= 3329585664 /*15708.5*/) goto t41_n166;
  t41_n165: return 0.06698241829872131f;
  t41_n166: return 0.12106805294752121f;
  t41_n167: return -0.211131751537323f;
  t41_n168: return 0.12095412611961365f;
  t41_n169: return 0.11254394799470901f;
  t41_n170: return 0.09063549339771271f;
  t41_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t41_n173;
  t41_n172: return -0.2839740216732025f;
  t41_n173: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t41_n175;
  t41_n174: return 0.111418716609478f;
  t41_n175: return 0.09826169162988663f;
  t41_n176: return 0.02019410952925682f;
  t41_n177: return 0.06618811190128326f;
  t41_n178: return 0.08371901512145996f;
  t41_n179: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t41_n185;
  t41_n180: if (E.getNumReferences() >= 3327663616 /*13831.5*/) goto t41_n184;
  t41_n181: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t41_n183;
  t41_n182: return 0.1248338595032692f;
  t41_n183: return -0.21296149492263794f;
  t41_n184: return 0.03210650756955147f;
  t41_n185: if (E.getNumReferences() >= 3333808640 /*23281.0*/) goto t41_n197;
  t41_n186: if (E.getNumReferences() >= 3331599872 /*18967.0*/) goto t41_n190;
  t41_n187: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t41_n189;
  t41_n188: return 0.07344038784503937f;
  t41_n189: return 0.11987579613924026f;
  t41_n190: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t41_n192;
  t41_n191: return 0.12313918769359589f;
  t41_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t41_n194;
  t41_n193: return 0.1057765930891037f;
  t41_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t41_n196;
  t41_n195: return -0.10316839069128036f;
  t41_n196: return 0.12021303921937943f;
  t41_n197: return 0.06958001106977463f;
  t41_n198: if (E.getNumReferences() >= 3313614848 /*4152.0*/) goto t41_n200;
  t41_n199: return 0.06341493129730225f;
  t41_n200: if (E.getNumReferences() >= 3313630208 /*4159.5*/) goto t41_n202;
  t41_n201: return 0.11983362585306168f;
  t41_n202: return 0.07276088744401932f;
  t41_n203: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t41_n215;
  t41_n204: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t41_n212;
  t41_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n207;
  t41_n206: return 0.019558515399694443f;
  t41_n207: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t41_n211;
  t41_n208: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t41_n210;
  t41_n209: return 0.06750739365816116f;
  t41_n210: return 0.06606355309486389f;
  t41_n211: return 0.010223177261650562f;
  t41_n212: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t41_n214;
  t41_n213: return 0.043015025556087494f;
  t41_n214: return -0.06493399292230606f;
  t41_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t41_n237;
  t41_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n220;
  t41_n217: if (E.getNumReferences() >= 3359238848 /*190379.0*/) goto t41_n219;
  t41_n218: return 0.058741677552461624f;
  t41_n219: return 0.09335051476955414f;
  t41_n220: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t41_n222;
  t41_n221: return 0.05868304893374443f;
  t41_n222: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t41_n236;
  t41_n223: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t41_n225;
  t41_n224: return 0.05287448689341545f;
  t41_n225: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t41_n235;
  t41_n226: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t41_n234;
  t41_n227: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t41_n229;
  t41_n228: return 0.11201127618551254f;
  t41_n229: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t41_n231;
  t41_n230: return 0.11281589418649673f;
  t41_n231: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t41_n233;
  t41_n232: return 0.11234300583600998f;
  t41_n233: return 0.14828461408615112f;
  t41_n234: return 0.07788771390914917f;
  t41_n235: return 0.09623021632432938f;
  t41_n236: return 0.0770936906337738f;
  t41_n237: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t41_n239;
  t41_n238: return 0.017961330711841583f;
  t41_n239: return 0.0655328556895256f;
  t41_n240: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t41_n250;
  t41_n241: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t41_n247;
  t41_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t41_n244;
  t41_n243: return -0.013487085700035095f;
  t41_n244: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t41_n246;
  t41_n245: return 0.027783963829278946f;
  t41_n246: return 0.006229615770280361f;
  t41_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n249;
  t41_n248: return 0.027997327968478203f;
  t41_n249: return 0.046933047473430634f;
  t41_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t41_n254;
  t41_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n253;
  t41_n252: return 0.05400834232568741f;
  t41_n253: return 0.07239622622728348f;
  t41_n254: return 0.07921694964170456f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree42(const Example& E) {
  t42_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t42_n240;
  t42_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t42_n207;
  t42_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t42_n136;
  t42_n3: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t42_n67;
  t42_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t42_n18;
  t42_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t42_n17;
  t42_n6: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t42_n8;
  t42_n7: return -0.037490855902433395f;
  t42_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t42_n10;
  t42_n9: return -0.02785281091928482f;
  t42_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t42_n16;
  t42_n11: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t42_n15;
  t42_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t42_n14;
  t42_n13: return 0.10603093355894089f;
  t42_n14: return 0.03206202760338783f;
  t42_n15: return -0.09804033488035202f;
  t42_n16: return 0.05455341190099716f;
  t42_n17: return -0.005018787458539009f;
  t42_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t42_n40;
  t42_n19: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t42_n37;
  t42_n20: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t42_n22;
  t42_n21: return -0.009330053813755512f;
  t42_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t42_n24;
  t42_n23: return 0.02008703164756298f;
  t42_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t42_n26;
  t42_n25: return 0.002837696811184287f;
  t42_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t42_n28;
  t42_n27: return 0.051161471754312515f;
  t42_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n34;
  t42_n29: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t42_n31;
  t42_n30: return 0.10466275364160538f;
  t42_n31: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t42_n33;
  t42_n32: return 0.11731909960508347f;
  t42_n33: return 0.05710399150848389f;
  t42_n34: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t42_n36;
  t42_n35: return 0.08058083802461624f;
  t42_n36: return 0.013332612812519073f;
  t42_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t42_n39;
  t42_n38: return -0.09358767420053482f;
  t42_n39: return 0.014707647264003754f;
  t42_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t42_n42;
  t42_n41: return 0.04967696592211723f;
  t42_n42: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t42_n66;
  t42_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n65;
  t42_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t42_n52;
  t42_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t42_n47;
  t42_n46: return -0.11445857584476471f;
  t42_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t42_n49;
  t42_n48: return 0.06143416836857796f;
  t42_n49: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t42_n51;
  t42_n50: return -0.13702277839183807f;
  t42_n51: return 0.07293903827667236f;
  t42_n52: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t42_n58;
  t42_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t42_n55;
  t42_n54: return 0.05544663593173027f;
  t42_n55: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t42_n57;
  t42_n56: return 0.08593448251485825f;
  t42_n57: return 0.10875973850488663f;
  t42_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t42_n60;
  t42_n59: return 0.1030084639787674f;
  t42_n60: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t42_n64;
  t42_n61: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t42_n63;
  t42_n62: return 0.1333000510931015f;
  t42_n63: return 0.10860288888216019f;
  t42_n64: return 0.10424675047397614f;
  t42_n65: return 0.018755564466118813f;
  t42_n66: return -0.119242824614048f;
  t42_n67: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t42_n71;
  t42_n68: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t42_n70;
  t42_n69: return 0.017389623448252678f;
  t42_n70: return 0.03817242011427879f;
  t42_n71: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t42_n83;
  t42_n72: if (E.getNumReferences() >= 3322313728 /*8607.0*/) goto t42_n82;
  t42_n73: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t42_n81;
  t42_n74: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t42_n76;
  t42_n75: return 0.05080670863389969f;
  t42_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t42_n78;
  t42_n77: return 0.06782162934541702f;
  t42_n78: if (E.getNumReferences() >= 3316801536 /*5708.0*/) goto t42_n80;
  t42_n79: return 0.08667787164449692f;
  t42_n80: return 0.13483598828315735f;
  t42_n81: return 0.031153041869401932f;
  t42_n82: return 0.0649285838007927f;
  t42_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t42_n85;
  t42_n84: return 0.05128517746925354f;
  t42_n85: if (E.getNumReferences() >= 3268870144 /*107.5*/) goto t42_n111;
  t42_n86: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t42_n88;
  t42_n87: return 0.07762572169303894f;
  t42_n88: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t42_n90;
  t42_n89: return 0.05270606279373169f;
  t42_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t42_n96;
  t42_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t42_n93;
  t42_n92: return 0.08847479522228241f;
  t42_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t42_n95;
  t42_n94: return 0.0f;
  t42_n95: return 0.13439396023750305f;
  t42_n96: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t42_n104;
  t42_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t42_n99;
  t42_n98: return 0.1027669906616211f;
  t42_n99: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t42_n101;
  t42_n100: return 0.10546208918094635f;
  t42_n101: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t42_n103;
  t42_n102: return 0.11156207323074341f;
  t42_n103: return 0.09655668586492538f;
  t42_n104: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t42_n110;
  t42_n105: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t42_n109;
  t42_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t42_n108;
  t42_n107: return 0.11340165138244629f;
  t42_n108: return 0.1253156214952469f;
  t42_n109: return 0.08541890978813171f;
  t42_n110: return 0.10872430354356766f;
  t42_n111: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t42_n135;
  t42_n112: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t42_n130;
  t42_n113: if (E.getNumReferences() >= 3286450176 /*454.5*/) goto t42_n125;
  t42_n114: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n124;
  t42_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t42_n117;
  t42_n116: return 0.10194632411003113f;
  t42_n117: if (E.getNumReferences() >= 3272966144 /*149.5*/) goto t42_n119;
  t42_n118: return 0.09446459263563156f;
  t42_n119: if (E.getNumReferences() >= 3275292672 /*185.0*/) goto t42_n121;
  t42_n120: return 0.1328074187040329f;
  t42_n121: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t42_n123;
  t42_n122: return 0.10952425003051758f;
  t42_n123: return 0.10936874151229858f;
  t42_n124: return 0.0877019539475441f;
  t42_n125: if (E.getNumReferences() >= 3289686016 /*594.5*/) goto t42_n129;
  t42_n126: if (E.getNumReferences() >= 3289554944 /*586.5*/) goto t42_n128;
  t42_n127: return 0.10976188629865646f;
  t42_n128: return 0.12180563062429428f;
  t42_n129: return 0.09348856657743454f;
  t42_n130: if (E.getNumReferences() >= 3288629248 /*530.0*/) goto t42_n134;
  t42_n131: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t42_n133;
  t42_n132: return 0.12286219745874405f;
  t42_n133: return 0.11836230754852295f;
  t42_n134: return 0.13431866466999054f;
  t42_n135: return 0.045828912407159805f;
  t42_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t42_n150;
  t42_n137: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t42_n141;
  t42_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t42_n140;
  t42_n139: return -0.07041773945093155f;
  t42_n140: return -0.04100750386714935f;
  t42_n141: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t42_n143;
  t42_n142: return 0.031666066497564316f;
  t42_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t42_n145;
  t42_n144: return 0.06178174167871475f;
  t42_n145: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t42_n149;
  t42_n146: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t42_n148;
  t42_n147: return 0.12028663605451584f;
  t42_n148: return 0.0878564715385437f;
  t42_n149: return -0.13512301445007324f;
  t42_n150: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t42_n200;
  t42_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t42_n153;
  t42_n152: return -0.019633334130048752f;
  t42_n153: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t42_n171;
  t42_n154: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t42_n156;
  t42_n155: return 0.00911285076290369f;
  t42_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t42_n160;
  t42_n157: if (E.getNumReferences() >= 3344570752 /*55833.5*/) goto t42_n159;
  t42_n158: return -0.047385599464178085f;
  t42_n159: return -1.6160533428192139f;
  t42_n160: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t42_n168;
  t42_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t42_n167;
  t42_n162: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t42_n164;
  t42_n163: return -0.026457034051418304f;
  t42_n164: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t42_n166;
  t42_n165: return 0.09324149787425995f;
  t42_n166: return 0.06676327437162399f;
  t42_n167: return 0.08768998086452484f;
  t42_n168: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t42_n170;
  t42_n169: return 0.06881550699472427f;
  t42_n170: return 0.008022638969123363f;
  t42_n171: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t42_n173;
  t42_n172: return -0.04163543879985809f;
  t42_n173: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t42_n199;
  t42_n174: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t42_n192;
  t42_n175: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t42_n191;
  t42_n176: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t42_n178;
  t42_n177: return 0.06310597062110901f;
  t42_n178: if (E.getNumReferences() >= 3351357120 /*99149.5*/) goto t42_n180;
  t42_n179: return 0.07562904059886932f;
  t42_n180: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t42_n184;
  t42_n181: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t42_n183;
  t42_n182: return 0.11571775376796722f;
  t42_n183: return -0.09872382134199142f;
  t42_n184: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t42_n190;
  t42_n185: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t42_n189;
  t42_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t42_n188;
  t42_n187: return 0.004338487982749939f;
  t42_n188: return 0.11079677194356918f;
  t42_n189: return 0.09285352379083633f;
  t42_n190: return 0.11346780508756638f;
  t42_n191: return 0.02190997824072838f;
  t42_n192: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t42_n196;
  t42_n193: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t42_n195;
  t42_n194: return 0.023407146334648132f;
  t42_n195: return 0.11092424392700195f;
  t42_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t42_n198;
  t42_n197: return 0.059443745762109756f;
  t42_n198: return 0.13954001665115356f;
  t42_n199: return 0.02061515301465988f;
  t42_n200: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t42_n206;
  t42_n201: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t42_n205;
  t42_n202: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n204;
  t42_n203: return 0.10075397789478302f;
  t42_n204: return 0.049083106219768524f;
  t42_n205: return -0.005070025566965342f;
  t42_n206: return 0.006138732191175222f;
  t42_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n215;
  t42_n208: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t42_n210;
  t42_n209: return 0.02257363311946392f;
  t42_n210: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t42_n214;
  t42_n211: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t42_n213;
  t42_n212: return 0.0469496063888073f;
  t42_n213: return 0.10076364874839783f;
  t42_n214: return 0.04595816135406494f;
  t42_n215: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t42_n221;
  t42_n216: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t42_n220;
  t42_n217: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t42_n219;
  t42_n218: return 0.06146440654993057f;
  t42_n219: return 0.01357225701212883f;
  t42_n220: return 0.051501110196113586f;
  t42_n221: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t42_n237;
  t42_n222: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t42_n224;
  t42_n223: return 0.0283907912671566f;
  t42_n224: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t42_n236;
  t42_n225: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t42_n233;
  t42_n226: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t42_n232;
  t42_n227: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t42_n231;
  t42_n228: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t42_n230;
  t42_n229: return 0.11413849145174026f;
  t42_n230: return -0.42751097679138184f;
  t42_n231: return 0.06262442469596863f;
  t42_n232: return 0.10536643862724304f;
  t42_n233: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t42_n235;
  t42_n234: return 0.10150540620088577f;
  t42_n235: return 0.11348651349544525f;
  t42_n236: return 0.06280223280191422f;
  t42_n237: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t42_n239;
  t42_n238: return 0.0741322860121727f;
  t42_n239: return 0.033270929008722305f;
  t42_n240: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t42_n248;
  t42_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t42_n247;
  t42_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t42_n244;
  t42_n243: return -0.009360347874462605f;
  t42_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n246;
  t42_n245: return 0.015722405165433884f;
  t42_n246: return 0.025051068514585495f;
  t42_n247: return 0.053251221776008606f;
  t42_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t42_n254;
  t42_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n253;
  t42_n250: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t42_n252;
  t42_n251: return 0.052400365471839905f;
  t42_n252: return -1.1818149089813232f;
  t42_n253: return 0.07040401548147202f;
  t42_n254: return 0.07726709544658661f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree43(const Example& E) {
  t43_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t43_n244;
  t43_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t43_n205;
  t43_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t43_n50;
  t43_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t43_n5;
  t43_n4: return -0.047468893229961395f;
  t43_n5: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t43_n17;
  t43_n6: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t43_n8;
  t43_n7: return -0.03401704877614975f;
  t43_n8: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t43_n10;
  t43_n9: return 0.02503488026559353f;
  t43_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n12;
  t43_n11: return 0.06323012709617615f;
  t43_n12: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t43_n16;
  t43_n13: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t43_n15;
  t43_n14: return 0.11596348136663437f;
  t43_n15: return 0.08510378748178482f;
  t43_n16: return -0.13344962894916534f;
  t43_n17: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t43_n41;
  t43_n18: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t43_n24;
  t43_n19: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t43_n21;
  t43_n20: return -0.07709621638059616f;
  t43_n21: if (E.getNumReferences() >= 3342575744 /*48040.5*/) goto t43_n23;
  t43_n22: return 0.019858218729496002f;
  t43_n23: return 0.1569412350654602f;
  t43_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t43_n28;
  t43_n25: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n27;
  t43_n26: return 0.02586708404123783f;
  t43_n27: return -0.044863343238830566f;
  t43_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t43_n30;
  t43_n29: return 0.0037555077578872442f;
  t43_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n32;
  t43_n31: return 0.06564286351203918f;
  t43_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n38;
  t43_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t43_n35;
  t43_n34: return 0.10233079642057419f;
  t43_n35: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n37;
  t43_n36: return 0.11678358912467957f;
  t43_n37: return 0.05778829753398895f;
  t43_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n40;
  t43_n39: return 0.06870138645172119f;
  t43_n40: return 0.02060181088745594f;
  t43_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t43_n43;
  t43_n42: return -0.0906379371881485f;
  t43_n43: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t43_n45;
  t43_n44: return 0.016817495226860046f;
  t43_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t43_n47;
  t43_n46: return 0.04150906205177307f;
  t43_n47: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n49;
  t43_n48: return 0.08193935453891754f;
  t43_n49: return 0.03334878385066986f;
  t43_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t43_n122;
  t43_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t43_n101;
  t43_n52: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n74;
  t43_n53: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t43_n73;
  t43_n54: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n72;
  t43_n55: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t43_n57;
  t43_n56: return 0.029866671189665794f;
  t43_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t43_n61;
  t43_n58: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t43_n60;
  t43_n59: return -0.0016610396560281515f;
  t43_n60: return 0.04609021544456482f;
  t43_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t43_n71;
  t43_n62: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t43_n70;
  t43_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n69;
  t43_n64: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t43_n66;
  t43_n65: return 0.09256085008382797f;
  t43_n66: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t43_n68;
  t43_n67: return 0.1041339859366417f;
  t43_n68: return 0.045266296714544296f;
  t43_n69: return 0.05903179571032524f;
  t43_n70: return -0.011987753212451935f;
  t43_n71: return 0.07302061468362808f;
  t43_n72: return -0.02367425709962845f;
  t43_n73: return -0.0335930772125721f;
  t43_n74: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t43_n100;
  t43_n75: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n77;
  t43_n76: return 0.08939637988805771f;
  t43_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t43_n81;
  t43_n78: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t43_n80;
  t43_n79: return -0.2809866666793823f;
  t43_n80: return 0.0629500225186348f;
  t43_n81: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n93;
  t43_n82: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t43_n92;
  t43_n83: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t43_n89;
  t43_n84: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t43_n86;
  t43_n85: return 0.10059891641139984f;
  t43_n86: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n88;
  t43_n87: return 0.11481710523366928f;
  t43_n88: return -0.39259129762649536f;
  t43_n89: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t43_n91;
  t43_n90: return 0.12458371371030807f;
  t43_n91: return 0.10884097218513489f;
  t43_n92: return 0.02665458247065544f;
  t43_n93: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t43_n95;
  t43_n94: return 0.037609200924634933f;
  t43_n95: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t43_n99;
  t43_n96: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t43_n98;
  t43_n97: return 0.04284759238362312f;
  t43_n98: return 0.12971840798854828f;
  t43_n99: return -0.002188628539443016f;
  t43_n100: return -0.12506498396396637f;
  t43_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t43_n113;
  t43_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n104;
  t43_n103: return 0.017531948164105415f;
  t43_n104: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t43_n110;
  t43_n105: if (E.getNumReferences() >= 3313957888 /*4319.5*/) goto t43_n107;
  t43_n106: return 0.06755475699901581f;
  t43_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t43_n109;
  t43_n108: return -0.12873367965221405f;
  t43_n109: return 0.1151280403137207f;
  t43_n110: if (E.getNumReferences() >= 3350304896 /*90929.0*/) goto t43_n112;
  t43_n111: return 0.004521478433161974f;
  t43_n112: return 0.03488617390394211f;
  t43_n113: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t43_n117;
  t43_n114: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t43_n116;
  t43_n115: return 0.022266047075390816f;
  t43_n116: return -0.08904312551021576f;
  t43_n117: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t43_n119;
  t43_n118: return 0.0865335538983345f;
  t43_n119: if (E.getNumReferences() >= 3345471616 /*59352.5*/) goto t43_n121;
  t43_n120: return 0.05738483741879463f;
  t43_n121: return 0.09534192830324173f;
  t43_n122: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t43_n198;
  t43_n123: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t43_n173;
  t43_n124: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n172;
  t43_n125: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t43_n169;
  t43_n126: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t43_n148;
  t43_n127: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t43_n133;
  t43_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t43_n130;
  t43_n129: return 0.003496906952932477f;
  t43_n130: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n132;
  t43_n131: return 0.04115966707468033f;
  t43_n132: return -0.15925078094005585f;
  t43_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t43_n135;
  t43_n134: return 0.03409409523010254f;
  t43_n135: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t43_n141;
  t43_n136: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t43_n138;
  t43_n137: return 0.05551021918654442f;
  t43_n138: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n140;
  t43_n139: return 0.09374657273292542f;
  t43_n140: return -0.09019798040390015f;
  t43_n141: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n147;
  t43_n142: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n146;
  t43_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t43_n145;
  t43_n144: return 0.09136015176773071f;
  t43_n145: return 0.05027921870350838f;
  t43_n146: return 0.06806188821792603f;
  t43_n147: return -0.11321104317903519f;
  t43_n148: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t43_n168;
  t43_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n151;
  t43_n150: return 0.046049319207668304f;
  t43_n151: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t43_n163;
  t43_n152: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t43_n162;
  t43_n153: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t43_n155;
  t43_n154: return 0.06706079840660095f;
  t43_n155: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t43_n161;
  t43_n156: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t43_n158;
  t43_n157: return 0.06960850954055786f;
  t43_n158: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t43_n160;
  t43_n159: return 0.11081524193286896f;
  t43_n160: return 0.12274874746799469f;
  t43_n161: return 0.08196306973695755f;
  t43_n162: return 0.06274178624153137f;
  t43_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag))) goto t43_n165;
  t43_n164: return 0.08095846325159073f;
  t43_n165: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t43_n167;
  t43_n166: return 0.09182743728160858f;
  t43_n167: return 0.09877505898475647f;
  t43_n168: return 0.031619809567928314f;
  t43_n169: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t43_n171;
  t43_n170: return -0.10401492565870285f;
  t43_n171: return 0.005989354103803635f;
  t43_n172: return -0.04418177902698517f;
  t43_n173: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n181;
  t43_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n180;
  t43_n175: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t43_n179;
  t43_n176: if (E.getNumReferences() >= 3355264064 /*129672.5*/) goto t43_n178;
  t43_n177: return 0.03815910965204239f;
  t43_n178: return 0.05118688568472862f;
  t43_n179: return -0.02009310945868492f;
  t43_n180: return -0.22815470397472382f;
  t43_n181: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t43_n195;
  t43_n182: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t43_n194;
  t43_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n193;
  t43_n184: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t43_n190;
  t43_n185: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t43_n189;
  t43_n186: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t43_n188;
  t43_n187: return 0.06824788451194763f;
  t43_n188: return 0.09501289576292038f;
  t43_n189: return 0.02164395898580551f;
  t43_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t43_n192;
  t43_n191: return 0.06637893617153168f;
  t43_n192: return 0.1261409968137741f;
  t43_n193: return -0.09256494045257568f;
  t43_n194: return 0.09235575050115585f;
  t43_n195: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t43_n197;
  t43_n196: return -0.14329716563224792f;
  t43_n197: return 0.05123712494969368f;
  t43_n198: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n204;
  t43_n199: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t43_n203;
  t43_n200: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n202;
  t43_n201: return 0.09682772308588028f;
  t43_n202: return 0.04578198865056038f;
  t43_n203: return 0.05650106072425842f;
  t43_n204: return 0.0003987904929090291f;
  t43_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n213;
  t43_n206: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t43_n208;
  t43_n207: return 0.022221341729164124f;
  t43_n208: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t43_n212;
  t43_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n211;
  t43_n210: return 0.04750833287835121f;
  t43_n211: return 0.09767487645149231f;
  t43_n212: return 0.04451904445886612f;
  t43_n213: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t43_n225;
  t43_n214: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t43_n220;
  t43_n215: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t43_n219;
  t43_n216: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t43_n218;
  t43_n217: return 0.07800448685884476f;
  t43_n218: return 0.00871039554476738f;
  t43_n219: return 0.05504220724105835f;
  t43_n220: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n222;
  t43_n221: return 0.01676081120967865f;
  t43_n222: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t43_n224;
  t43_n223: return 0.03468573838472366f;
  t43_n224: return 0.10070764273405075f;
  t43_n225: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t43_n243;
  t43_n226: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t43_n238;
  t43_n227: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t43_n229;
  t43_n228: return 0.03757056966423988f;
  t43_n229: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t43_n237;
  t43_n230: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t43_n232;
  t43_n231: return 0.10807815194129944f;
  t43_n232: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t43_n234;
  t43_n233: return 0.1108432337641716f;
  t43_n234: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t43_n236;
  t43_n235: return 0.11203009635210037f;
  t43_n236: return 0.15363642573356628f;
  t43_n237: return 0.06537214666604996f;
  t43_n238: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t43_n240;
  t43_n239: return 0.07382272928953171f;
  t43_n240: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t43_n242;
  t43_n241: return 0.10670778900384903f;
  t43_n242: return 0.08848480135202408f;
  t43_n243: return 0.05793815851211548f;
  t43_n244: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t43_n250;
  t43_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n247;
  t43_n246: return 0.012484190985560417f;
  t43_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n249;
  t43_n248: return 0.014666415750980377f;
  t43_n249: return 0.04296388849616051f;
  t43_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t43_n254;
  t43_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n253;
  t43_n252: return 0.05096007138490677f;
  t43_n253: return 0.06841588765382767f;
  t43_n254: return 0.07612770795822144f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree44(const Example& E) {
  t44_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t44_n242;
  t44_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t44_n133;
  t44_n2: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t44_n110;
  t44_n3: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t44_n49;
  t44_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t44_n6;
  t44_n5: return -0.024293536320328712f;
  t44_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t44_n24;
  t44_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t44_n21;
  t44_n8: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t44_n10;
  t44_n9: return -0.011778797954320908f;
  t44_n10: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t44_n14;
  t44_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t44_n13;
  t44_n12: return 0.020518586039543152f;
  t44_n13: return 0.04299282655119896f;
  t44_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t44_n16;
  t44_n15: return 0.035126443952322006f;
  t44_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t44_n18;
  t44_n17: return 0.026254205033183098f;
  t44_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t44_n20;
  t44_n19: return 0.10384384542703629f;
  t44_n20: return 0.09839324653148651f;
  t44_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t44_n23;
  t44_n22: return -0.09765972942113876f;
  t44_n23: return 0.016834130510687828f;
  t44_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t44_n26;
  t44_n25: return 0.06195678561925888f;
  t44_n26: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t44_n48;
  t44_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t44_n33;
  t44_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t44_n30;
  t44_n29: return -0.11009704321622849f;
  t44_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t44_n32;
  t44_n31: return -0.13598990440368652f;
  t44_n32: return 0.06757490336894989f;
  t44_n33: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t44_n37;
  t44_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t44_n36;
  t44_n35: return -0.02851085364818573f;
  t44_n36: return 0.07464741170406342f;
  t44_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t44_n43;
  t44_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t44_n42;
  t44_n39: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t44_n41;
  t44_n40: return 0.1150076687335968f;
  t44_n41: return 0.1360168159008026f;
  t44_n42: return 0.05542629212141037f;
  t44_n43: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t44_n47;
  t44_n44: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t44_n46;
  t44_n45: return 0.1295044720172882f;
  t44_n46: return 0.10656126588582993f;
  t44_n47: return 0.10404347628355026f;
  t44_n48: return -0.13346245884895325f;
  t44_n49: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t44_n79;
  t44_n50: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t44_n76;
  t44_n51: if (E.getNumReferences() >= 3354076032 /*120391.0*/) goto t44_n65;
  t44_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t44_n54;
  t44_n53: return 0.008919809944927692f;
  t44_n54: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t44_n62;
  t44_n55: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t44_n57;
  t44_n56: return 0.04695183411240578f;
  t44_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t44_n59;
  t44_n58: return 0.06456561386585236f;
  t44_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t44_n61;
  t44_n60: return 0.07089012116193771f;
  t44_n61: return 0.09559787064790726f;
  t44_n62: if (E.getNumReferences() >= 3308046336 /*2764.5*/) goto t44_n64;
  t44_n63: return -0.0015968570951372385f;
  t44_n64: return 0.05976584926247597f;
  t44_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t44_n67;
  t44_n66: return 0.021609829738736153f;
  t44_n67: if (E.getNumReferences() >= 3354462528 /*123410.5*/) goto t44_n75;
  t44_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t44_n70;
  t44_n69: return -0.1258685439825058f;
  t44_n70: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t44_n74;
  t44_n71: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t44_n73;
  t44_n72: return 0.19213242828845978f;
  t44_n73: return 0.11959285289049149f;
  t44_n74: return 0.09849417209625244f;
  t44_n75: return 0.05542486906051636f;
  t44_n76: if (E.getNumReferences() >= 3359238848 /*190379.0*/) goto t44_n78;
  t44_n77: return 0.057353027164936066f;
  t44_n78: return 0.08758872747421265f;
  t44_n79: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t44_n105;
  t44_n80: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t44_n82;
  t44_n81: return 0.0862971618771553f;
  t44_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t44_n84;
  t44_n83: return 0.08606243133544922f;
  t44_n84: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t44_n104;
  t44_n85: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t44_n103;
  t44_n86: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t44_n92;
  t44_n87: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t44_n91;
  t44_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t44_n90;
  t44_n89: return 0.10303869843482971f;
  t44_n90: return 0.14521700143814087f;
  t44_n91: return 0.1063937395811081f;
  t44_n92: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t44_n102;
  t44_n93: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t44_n95;
  t44_n94: return 0.1014941856265068f;
  t44_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t44_n99;
  t44_n96: if (E.getNumReferences() >= 3278340096 /*231.5*/) goto t44_n98;
  t44_n97: return 0.12005867063999176f;
  t44_n98: return 0.10155146569013596f;
  t44_n99: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t44_n101;
  t44_n100: return -0.17856334149837494f;
  t44_n101: return 0.12699751555919647f;
  t44_n102: return 0.13959693908691406f;
  t44_n103: return 0.10161413997411728f;
  t44_n104: return 0.053550444543361664f;
  t44_n105: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t44_n107;
  t44_n106: return 0.0604475662112236f;
  t44_n107: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t44_n109;
  t44_n108: return -0.12869277596473694f;
  t44_n109: return 0.12870340049266815f;
  t44_n110: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t44_n112;
  t44_n111: return -0.037972357124090195f;
  t44_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t44_n114;
  t44_n113: return 0.001228130073286593f;
  t44_n114: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t44_n130;
  t44_n115: if (E.getNumReferences() >= 3332134144 /*20010.5*/) goto t44_n129;
  t44_n116: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t44_n126;
  t44_n117: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t44_n119;
  t44_n118: return 0.0725105032324791f;
  t44_n119: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t44_n125;
  t44_n120: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t44_n124;
  t44_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t44_n123;
  t44_n122: return -0.16863998770713806f;
  t44_n123: return 0.123162642121315f;
  t44_n124: return 0.11804983764886856f;
  t44_n125: return -0.11471951007843018f;
  t44_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t44_n128;
  t44_n127: return 0.0081983283162117f;
  t44_n128: return 0.12315896898508072f;
  t44_n129: return 0.11299879103899002f;
  t44_n130: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t44_n132;
  t44_n131: return 0.035231444984674454f;
  t44_n132: return 0.08153291791677475f;
  t44_n133: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t44_n221;
  t44_n134: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t44_n146;
  t44_n135: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t44_n145;
  t44_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t44_n138;
  t44_n137: return 0.013064312748610973f;
  t44_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t44_n144;
  t44_n139: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t44_n141;
  t44_n140: return 0.04656098410487175f;
  t44_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t44_n143;
  t44_n142: return -0.36557188630104065f;
  t44_n143: return -0.025142816826701164f;
  t44_n144: return 0.05496266484260559f;
  t44_n145: return -0.01204124465584755f;
  t44_n146: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t44_n174;
  t44_n147: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t44_n171;
  t44_n148: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t44_n162;
  t44_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t44_n151;
  t44_n150: return 0.042962681502103806f;
  t44_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t44_n153;
  t44_n152: return 0.03757135942578316f;
  t44_n153: if (E.getNumReferences() >= 3324333056 /*10579.0*/) goto t44_n161;
  t44_n154: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t44_n160;
  t44_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t44_n157;
  t44_n156: return 0.07114937156438828f;
  t44_n157: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t44_n159;
  t44_n158: return 0.07020167261362076f;
  t44_n159: return 0.08212114870548248f;
  t44_n160: return 0.045522406697273254f;
  t44_n161: return 0.06765322387218475f;
  t44_n162: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t44_n164;
  t44_n163: return 0.06920038163661957f;
  t44_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t44_n166;
  t44_n165: return 0.07005167752504349f;
  t44_n166: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t44_n168;
  t44_n167: return 0.09941409528255463f;
  t44_n168: if (E.getNumReferences() >= 3290054656 /*617.0*/) goto t44_n170;
  t44_n169: return 0.1207844540476799f;
  t44_n170: return 0.09590913355350494f;
  t44_n171: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t44_n173;
  t44_n172: return -0.03408896178007126f;
  t44_n173: return 0.016319725662469864f;
  t44_n174: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t44_n218;
  t44_n175: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t44_n213;
  t44_n176: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t44_n178;
  t44_n177: return 0.07559382915496826f;
  t44_n178: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t44_n204;
  t44_n179: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t44_n191;
  t44_n180: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t44_n182;
  t44_n181: return 0.10389962047338486f;
  t44_n182: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t44_n190;
  t44_n183: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t44_n185;
  t44_n184: return -0.1762019842863083f;
  t44_n185: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t44_n187;
  t44_n186: return -0.14951059222221375f;
  t44_n187: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t44_n189;
  t44_n188: return 0.1819792538881302f;
  t44_n189: return 0.14863939583301544f;
  t44_n190: return 0.032886963337659836f;
  t44_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t44_n193;
  t44_n192: return 0.12535598874092102f;
  t44_n193: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t44_n199;
  t44_n194: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t44_n196;
  t44_n195: return 0.1414700150489807f;
  t44_n196: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t44_n198;
  t44_n197: return 0.10212089121341705f;
  t44_n198: return 0.12140429019927979f;
  t44_n199: if (E.getNumReferences() >= 3287072768 /*473.5*/) goto t44_n201;
  t44_n200: return 0.12312133610248566f;
  t44_n201: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t44_n203;
  t44_n202: return -0.11236371099948883f;
  t44_n203: return 0.11701709777116776f;
  t44_n204: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t44_n212;
  t44_n205: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t44_n207;
  t44_n206: return 0.08600073307752609f;
  t44_n207: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t44_n209;
  t44_n208: return 0.12506987154483795f;
  t44_n209: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t44_n211;
  t44_n210: return 0.1431622952222824f;
  t44_n211: return 0.11914102733135223f;
  t44_n212: return 0.21360664069652557f;
  t44_n213: if (E.getNumReferences() >= 3304226816 /*1940.0*/) goto t44_n215;
  t44_n214: return -0.01688382960855961f;
  t44_n215: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t44_n217;
  t44_n216: return 0.026220517233014107f;
  t44_n217: return 0.07306814193725586f;
  t44_n218: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t44_n220;
  t44_n219: return -0.010550318285822868f;
  t44_n220: return 0.040736258029937744f;
  t44_n221: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t44_n225;
  t44_n222: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t44_n224;
  t44_n223: return 0.03751401603221893f;
  t44_n224: return 0.015811672434210777f;
  t44_n225: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t44_n227;
  t44_n226: return 0.06772035360336304f;
  t44_n227: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t44_n241;
  t44_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t44_n238;
  t44_n229: if (E.getNumReferences() >= 3318290432 /*6435.0*/) goto t44_n237;
  t44_n230: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t44_n234;
  t44_n231: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t44_n233;
  t44_n232: return 0.16837111115455627f;
  t44_n233: return 0.11226489394903183f;
  t44_n234: if (E.getNumReferences() >= 3291725824 /*719.0*/) goto t44_n236;
  t44_n235: return 0.05654074251651764f;
  t44_n236: return 0.11220324784517288f;
  t44_n237: return -0.008908032439649105f;
  t44_n238: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t44_n240;
  t44_n239: return 0.016976967453956604f;
  t44_n240: return 0.06794597953557968f;
  t44_n241: return -0.4171523451805115f;
  t44_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t44_n250;
  t44_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t44_n249;
  t44_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t44_n246;
  t44_n245: return -0.011124324053525925f;
  t44_n246: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t44_n248;
  t44_n247: return 0.026654329150915146f;
  t44_n248: return 0.009893125854432583f;
  t44_n249: return 0.049071092158555984f;
  t44_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t44_n254;
  t44_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t44_n253;
  t44_n252: return 0.04693726822733879f;
  t44_n253: return 0.06612439453601837f;
  t44_n254: return 0.07333523035049438f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree45(const Example& E) {
  t45_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t45_n242;
  t45_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t45_n205;
  t45_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t45_n140;
  t45_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t45_n85;
  t45_n4: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t45_n10;
  t45_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t45_n7;
  t45_n6: return -0.03878267854452133f;
  t45_n7: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t45_n9;
  t45_n8: return -0.01337344478815794f;
  t45_n9: return -0.05581933632493019f;
  t45_n10: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t45_n22;
  t45_n11: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t45_n21;
  t45_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t45_n14;
  t45_n13: return 0.019077986478805542f;
  t45_n14: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t45_n18;
  t45_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t45_n17;
  t45_n16: return 0.07008162140846252f;
  t45_n17: return 0.08890661597251892f;
  t45_n18: if (E.getNumReferences() >= 3322075136 /*8374.0*/) goto t45_n20;
  t45_n19: return 0.02962479554116726f;
  t45_n20: return 0.06446485966444016f;
  t45_n21: return -0.0069566648453474045f;
  t45_n22: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t45_n68;
  t45_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t45_n25;
  t45_n24: return 0.09693577885627747f;
  t45_n25: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t45_n31;
  t45_n26: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t45_n30;
  t45_n27: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t45_n29;
  t45_n28: return 0.15922586619853973f;
  t45_n29: return 0.07758715003728867f;
  t45_n30: return 0.1022767424583435f;
  t45_n31: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t45_n59;
  t45_n32: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t45_n34;
  t45_n33: return 0.15491251647472382f;
  t45_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t45_n36;
  t45_n35: return 0.09551940113306046f;
  t45_n36: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t45_n48;
  t45_n37: if (E.getNumReferences() >= 3272245248 /*138.5*/) goto t45_n45;
  t45_n38: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t45_n44;
  t45_n39: if (E.getNumReferences() >= 3269656576 /*113.5*/) goto t45_n43;
  t45_n40: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t45_n42;
  t45_n41: return 0.12738971412181854f;
  t45_n42: return 0.14097119867801666f;
  t45_n43: return 0.14542363584041595f;
  t45_n44: return 0.08997993916273117f;
  t45_n45: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t45_n47;
  t45_n46: return 0.09831365197896957f;
  t45_n47: return 0.14865538477897644f;
  t45_n48: if (E.getNumReferences() >= 3277455360 /*218.0*/) goto t45_n50;
  t45_n49: return 0.0826878771185875f;
  t45_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t45_n56;
  t45_n51: if (E.getNumReferences() >= 3280732160 /*280.0*/) goto t45_n55;
  t45_n52: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t45_n54;
  t45_n53: return 0.10951296985149384f;
  t45_n54: return 0.09954026341438293f;
  t45_n55: return 0.08836407214403152f;
  t45_n56: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t45_n58;
  t45_n57: return 0.4833403527736664f;
  t45_n58: return 0.12412381917238235f;
  t45_n59: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t45_n67;
  t45_n60: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t45_n64;
  t45_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t45_n63;
  t45_n62: return 0.09927617758512497f;
  t45_n63: return 0.117418572306633f;
  t45_n64: if (E.getNumReferences() >= 3273064448 /*151.0*/) goto t45_n66;
  t45_n65: return 0.10001974552869797f;
  t45_n66: return 0.13324688374996185f;
  t45_n67: return 0.08219517767429352f;
  t45_n68: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t45_n76;
  t45_n69: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t45_n71;
  t45_n70: return 0.040486760437488556f;
  t45_n71: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t45_n73;
  t45_n72: return 0.09676642715930939f;
  t45_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t45_n75;
  t45_n74: return 0.053833793848752975f;
  t45_n75: return 0.09287746250629425f;
  t45_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t45_n78;
  t45_n77: return 0.04133662208914757f;
  t45_n78: if (E.getNumReferences() >= 3332703232 /*21122.0*/) goto t45_n84;
  t45_n79: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t45_n83;
  t45_n80: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t45_n82;
  t45_n81: return 0.06931572407484055f;
  t45_n82: return 0.09536321461200714f;
  t45_n83: return 0.09295689314603806f;
  t45_n84: return 0.060586024075746536f;
  t45_n85: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t45_n107;
  t45_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t45_n88;
  t45_n87: return -0.10673873126506805f;
  t45_n88: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t45_n90;
  t45_n89: return 0.011147492565214634f;
  t45_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t45_n98;
  t45_n91: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t45_n93;
  t45_n92: return 0.02597849629819393f;
  t45_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t45_n95;
  t45_n94: return -0.09082065522670746f;
  t45_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t45_n97;
  t45_n96: return 0.02052619308233261f;
  t45_n97: return 0.08582962304353714f;
  t45_n98: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t45_n100;
  t45_n99: return 0.021511323750019073f;
  t45_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t45_n102;
  t45_n101: return 0.07449206709861755f;
  t45_n102: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t45_n106;
  t45_n103: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t45_n105;
  t45_n104: return 0.11190628260374069f;
  t45_n105: return 0.13856804370880127f;
  t45_n106: return 0.04853130131959915f;
  t45_n107: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t45_n113;
  t45_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t45_n110;
  t45_n109: return 0.004695583134889603f;
  t45_n110: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t45_n112;
  t45_n111: return 0.1033553034067154f;
  t45_n112: return -0.017506830394268036f;
  t45_n113: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t45_n125;
  t45_n114: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t45_n120;
  t45_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t45_n117;
  t45_n116: return 0.03701140731573105f;
  t45_n117: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t45_n119;
  t45_n118: return 0.07165718078613281f;
  t45_n119: return 0.0051089623011648655f;
  t45_n120: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t45_n122;
  t45_n121: return -0.12756288051605225f;
  t45_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t45_n124;
  t45_n123: return 0.007927682250738144f;
  t45_n124: return 0.05236465111374855f;
  t45_n125: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t45_n131;
  t45_n126: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t45_n128;
  t45_n127: return 0.10187677294015884f;
  t45_n128: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t45_n130;
  t45_n129: return 0.14183728396892548f;
  t45_n130: return 0.10869599133729935f;
  t45_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t45_n133;
  t45_n132: return 0.04168513044714928f;
  t45_n133: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t45_n135;
  t45_n134: return 0.07948527485132217f;
  t45_n135: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t45_n137;
  t45_n136: return 0.08438087999820709f;
  t45_n137: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t45_n139;
  t45_n138: return 0.1729329228401184f;
  t45_n139: return 0.1082054078578949f;
  t45_n140: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t45_n156;
  t45_n141: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t45_n153;
  t45_n142: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t45_n150;
  t45_n143: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t45_n145;
  t45_n144: return -0.0636780634522438f;
  t45_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t45_n149;
  t45_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t45_n148;
  t45_n147: return -0.0006485919002443552f;
  t45_n148: return -0.06564050912857056f;
  t45_n149: return 0.024252155795693398f;
  t45_n150: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t45_n152;
  t45_n151: return 0.05023109167814255f;
  t45_n152: return -0.022992076352238655f;
  t45_n153: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t45_n155;
  t45_n154: return -0.009619501419365406f;
  t45_n155: return 0.0228411927819252f;
  t45_n156: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t45_n162;
  t45_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t45_n159;
  t45_n158: return 0.02211480215191841f;
  t45_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t45_n161;
  t45_n160: return 0.05214855074882507f;
  t45_n161: return 0.0711488351225853f;
  t45_n162: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t45_n170;
  t45_n163: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t45_n165;
  t45_n164: return 0.023578010499477386f;
  t45_n165: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t45_n169;
  t45_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t45_n168;
  t45_n167: return -0.17271342873573303f;
  t45_n168: return 0.10995496064424515f;
  t45_n169: return 0.029430394992232323f;
  t45_n170: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t45_n172;
  t45_n171: return 0.10972420126199722f;
  t45_n172: if (E.getNumReferences() >= 3276963840 /*210.5*/) goto t45_n190;
  t45_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t45_n175;
  t45_n174: return 0.06336010992527008f;
  t45_n175: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t45_n177;
  t45_n176: return 0.06906703859567642f;
  t45_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t45_n189;
  t45_n178: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t45_n182;
  t45_n179: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t45_n181;
  t45_n180: return 0.15486927330493927f;
  t45_n181: return 0.14347843825817108f;
  t45_n182: if (E.getFilterLength() >= 3247177728 /*17.5*/) goto t45_n188;
  t45_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t45_n185;
  t45_n184: return -0.021088963374495506f;
  t45_n185: if (E.getNumReferences() >= 3263692800 /*68.0*/) goto t45_n187;
  t45_n186: return 0.1312038153409958f;
  t45_n187: return 0.13446931540966034f;
  t45_n188: return 0.1492665857076645f;
  t45_n189: return 0.09188620001077652f;
  t45_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t45_n196;
  t45_n191: if (E.getNumReferences() >= 3277094912 /*212.5*/) goto t45_n195;
  t45_n192: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t45_n194;
  t45_n193: return -0.10162874311208725f;
  t45_n194: return 0.13233321905136108f;
  t45_n195: return 0.07762180268764496f;
  t45_n196: if (E.getNumReferences() >= 3280060416 /*259.5*/) goto t45_n204;
  t45_n197: if (E.getNumReferences() >= 3278012416 /*226.5*/) goto t45_n199;
  t45_n198: return -0.18827524781227112f;
  t45_n199: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t45_n203;
  t45_n200: if (E.getNumReferences() >= 3278667776 /*236.5*/) goto t45_n202;
  t45_n201: return 0.12221164256334305f;
  t45_n202: return 0.02977663278579712f;
  t45_n203: return 0.1368335783481598f;
  t45_n204: return 0.07915378361940384f;
  t45_n205: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t45_n223;
  t45_n206: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t45_n208;
  t45_n207: return 0.018576303496956825f;
  t45_n208: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t45_n222;
  t45_n209: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t45_n215;
  t45_n210: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t45_n214;
  t45_n211: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t45_n213;
  t45_n212: return 0.06871616095304489f;
  t45_n213: return 0.02969803288578987f;
  t45_n214: return 0.05477425828576088f;
  t45_n215: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t45_n217;
  t45_n216: return -0.02044288069009781f;
  t45_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Expression))) goto t45_n221;
  t45_n218: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t45_n220;
  t45_n219: return 0.012430910021066666f;
  t45_n220: return -0.10691875219345093f;
  t45_n221: return 0.0346798412501812f;
  t45_n222: return 0.044489651918411255f;
  t45_n223: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t45_n239;
  t45_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t45_n228;
  t45_n225: if (E.getNumReferences() >= 3359238848 /*190379.0*/) goto t45_n227;
  t45_n226: return 0.059422656893730164f;
  t45_n227: return 0.08699791878461838f;
  t45_n228: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t45_n230;
  t45_n229: return 0.020796215161681175f;
  t45_n230: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t45_n238;
  t45_n231: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t45_n235;
  t45_n232: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t45_n234;
  t45_n233: return 0.000983759411610663f;
  t45_n234: return 0.09038735926151276f;
  t45_n235: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t45_n237;
  t45_n236: return 0.05147552117705345f;
  t45_n237: return 0.10151077061891556f;
  t45_n238: return 0.0676175132393837f;
  t45_n239: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t45_n241;
  t45_n240: return 0.012625953182578087f;
  t45_n241: return 0.06771672517061234f;
  t45_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t45_n250;
  t45_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t45_n247;
  t45_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t45_n246;
  t45_n245: return -0.01825018785893917f;
  t45_n246: return 0.015718890354037285f;
  t45_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t45_n249;
  t45_n248: return 0.012398050166666508f;
  t45_n249: return 0.039137545973062515f;
  t45_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t45_n254;
  t45_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t45_n253;
  t45_n252: return 0.046930912882089615f;
  t45_n253: return 0.06347072869539261f;
  t45_n254: return 0.07209525257349014f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree46(const Example& E) {
  t46_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t46_n240;
  t46_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t46_n157;
  t46_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t46_n136;
  t46_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t46_n127;
  t46_n4: if (E.getNumReferences() >= 3302477824 /*1726.5*/) goto t46_n58;
  t46_n5: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t46_n55;
  t46_n6: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t46_n48;
  t46_n7: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t46_n9;
  t46_n8: return -0.007959683425724506f;
  t46_n9: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t46_n11;
  t46_n10: return 0.044617895036935806f;
  t46_n11: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t46_n15;
  t46_n12: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t46_n14;
  t46_n13: return 0.07049542665481567f;
  t46_n14: return 0.09853275120258331f;
  t46_n15: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t46_n25;
  t46_n16: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t46_n24;
  t46_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t46_n19;
  t46_n18: return 0.06253321468830109f;
  t46_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t46_n23;
  t46_n20: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t46_n22;
  t46_n21: return 0.0658816322684288f;
  t46_n22: return 0.14533160626888275f;
  t46_n23: return 0.11468365043401718f;
  t46_n24: return 0.083208367228508f;
  t46_n25: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t46_n35;
  t46_n26: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t46_n32;
  t46_n27: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t46_n31;
  t46_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t46_n30;
  t46_n29: return 0.1959695816040039f;
  t46_n30: return 0.14690111577510834f;
  t46_n31: return 0.09773681312799454f;
  t46_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t46_n34;
  t46_n33: return 0.210405170917511f;
  t46_n34: return 0.12790364027023315f;
  t46_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t46_n37;
  t46_n36: return -0.1023319661617279f;
  t46_n37: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t46_n47;
  t46_n38: if (E.getNumReferences() >= 3272245248 /*138.5*/) goto t46_n44;
  t46_n39: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t46_n43;
  t46_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t46_n42;
  t46_n41: return -0.1119351014494896f;
  t46_n42: return 0.11413811147212982f;
  t46_n43: return 0.14134271442890167f;
  t46_n44: if (E.getNumReferences() >= 3272802304 /*147.0*/) goto t46_n46;
  t46_n45: return 0.14060662686824799f;
  t46_n46: return 0.12811458110809326f;
  t46_n47: return 0.10041888058185577f;
  t46_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_UnionTag))) goto t46_n50;
  t46_n49: return 0.030355393886566162f;
  t46_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t46_n54;
  t46_n51: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t46_n53;
  t46_n52: return 0.10221845656633377f;
  t46_n53: return -0.14968737959861755f;
  t46_n54: return 0.07315105944871902f;
  t46_n55: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t46_n57;
  t46_n56: return -0.04201190918684006f;
  t46_n57: return -0.01669915020465851f;
  t46_n58: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t46_n68;
  t46_n59: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t46_n67;
  t46_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t46_n62;
  t46_n61: return 0.015902584418654442f;
  t46_n62: if (E.getNumReferences() >= 3348072384 /*73487.5*/) goto t46_n66;
  t46_n63: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t46_n65;
  t46_n64: return 0.052728552371263504f;
  t46_n65: return 0.10803741961717606f;
  t46_n66: return 0.06409996747970581f;
  t46_n67: return -0.019266163930296898f;
  t46_n68: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t46_n74;
  t46_n69: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t46_n71;
  t46_n70: return -0.48632505536079407f;
  t46_n71: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t46_n73;
  t46_n72: return 0.032842740416526794f;
  t46_n73: return 0.05773879587650299f;
  t46_n74: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t46_n88;
  t46_n75: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t46_n87;
  t46_n76: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t46_n86;
  t46_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t46_n79;
  t46_n78: return 0.05442443862557411f;
  t46_n79: if (E.getNumReferences() >= 3353598912 /*116663.5*/) goto t46_n81;
  t46_n80: return 0.06010521948337555f;
  t46_n81: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t46_n85;
  t46_n82: if (E.getNumReferences() >= 3355447552 /*131140.0*/) goto t46_n84;
  t46_n83: return 0.10142756253480911f;
  t46_n84: return 0.0902186706662178f;
  t46_n85: return 0.08533700555562973f;
  t46_n86: return -0.008874350227415562f;
  t46_n87: return 0.06633585691452026f;
  t46_n88: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t46_n112;
  t46_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t46_n107;
  t46_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t46_n92;
  t46_n91: return -0.08389978855848312f;
  t46_n92: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t46_n94;
  t46_n93: return 0.056193333119153976f;
  t46_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t46_n100;
  t46_n95: if (E.getNumReferences() >= 3327959040 /*14120.0*/) goto t46_n99;
  t46_n96: if (E.getNumReferences() >= 3327660032 /*13828.0*/) goto t46_n98;
  t46_n97: return 0.10023672878742218f;
  t46_n98: return 0.10775056481361389f;
  t46_n99: return 0.04757571592926979f;
  t46_n100: if (E.getNumReferences() >= 3331473152 /*18719.5*/) goto t46_n106;
  t46_n101: if (E.getNumReferences() >= 3331038976 /*17871.5*/) goto t46_n103;
  t46_n102: return 0.11143804341554642f;
  t46_n103: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t46_n105;
  t46_n104: return 0.10905306041240692f;
  t46_n105: return 0.10691864788532257f;
  t46_n106: return 0.07935803383588791f;
  t46_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t46_n109;
  t46_n108: return 0.04994148388504982f;
  t46_n109: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t46_n111;
  t46_n110: return 0.08306130021810532f;
  t46_n111: return -0.016047261655330658f;
  t46_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t46_n116;
  t46_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t46_n115;
  t46_n114: return 0.07699542492628098f;
  t46_n115: return 0.10280206799507141f;
  t46_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t46_n118;
  t46_n117: return -0.23771105706691742f;
  t46_n118: if (E.getNumReferences() >= 3341127552 /*42383.5*/) goto t46_n126;
  t46_n119: if (E.getNumReferences() >= 3328147968 /*14304.5*/) goto t46_n121;
  t46_n120: return 0.1191849336028099f;
  t46_n121: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t46_n125;
  t46_n122: if (E.getNumReferences() >= 3331241984 /*18268.0*/) goto t46_n124;
  t46_n123: return 0.1121678426861763f;
  t46_n124: return 0.10910829156637192f;
  t46_n125: return 0.10100672394037247f;
  t46_n126: return 0.05175783112645149f;
  t46_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t46_n135;
  t46_n128: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t46_n134;
  t46_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t46_n131;
  t46_n130: return 0.04916958883404732f;
  t46_n131: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t46_n133;
  t46_n132: return 0.049035705626010895f;
  t46_n133: return 0.0816156417131424f;
  t46_n134: return 0.019725831225514412f;
  t46_n135: return 0.09188001602888107f;
  t46_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t46_n138;
  t46_n137: return -0.05462833121418953f;
  t46_n138: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t46_n156;
  t46_n139: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t46_n141;
  t46_n140: return 0.05611738562583923f;
  t46_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t46_n147;
  t46_n142: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t46_n146;
  t46_n143: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t46_n145;
  t46_n144: return 0.03338908404111862f;
  t46_n145: return 0.10628322511911392f;
  t46_n146: return 0.055573105812072754f;
  t46_n147: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t46_n155;
  t46_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t46_n150;
  t46_n149: return 0.01408223807811737f;
  t46_n150: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t46_n154;
  t46_n151: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t46_n153;
  t46_n152: return 0.11885558068752289f;
  t46_n153: return 0.11284635961055756f;
  t46_n154: return 0.03053661808371544f;
  t46_n155: return 0.0008501035626977682f;
  t46_n156: return -0.08354692906141281f;
  t46_n157: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t46_n211;
  t46_n158: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t46_n166;
  t46_n159: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t46_n165;
  t46_n160: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t46_n162;
  t46_n161: return 0.010987053625285625f;
  t46_n162: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t46_n164;
  t46_n163: return 0.04845085367560387f;
  t46_n164: return -0.021321328356862068f;
  t46_n165: return -0.0071618990041315556f;
  t46_n166: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t46_n172;
  t46_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t46_n169;
  t46_n168: return 0.018797580152750015f;
  t46_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t46_n171;
  t46_n170: return 0.04981033504009247f;
  t46_n171: return 0.06886359304189682f;
  t46_n172: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t46_n180;
  t46_n173: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t46_n175;
  t46_n174: return 0.024459002539515495f;
  t46_n175: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t46_n179;
  t46_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t46_n178;
  t46_n177: return -0.05438021197915077f;
  t46_n178: return 0.10936104506254196f;
  t46_n179: return 0.027668334543704987f;
  t46_n180: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t46_n194;
  t46_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t46_n187;
  t46_n182: if (E.getNumReferences() >= 3294576640 /*893.0*/) goto t46_n184;
  t46_n183: return 0.09344179183244705f;
  t46_n184: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t46_n186;
  t46_n185: return 0.0810207724571228f;
  t46_n186: return 0.10859508067369461f;
  t46_n187: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t46_n191;
  t46_n188: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t46_n190;
  t46_n189: return 0.03037494421005249f;
  t46_n190: return 0.14585596323013306f;
  t46_n191: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t46_n193;
  t46_n192: return 0.1252736896276474f;
  t46_n193: return 0.07796800881624222f;
  t46_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t46_n202;
  t46_n195: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t46_n201;
  t46_n196: if (E.getFilterLength() >= 3250323456 /*23.5*/) goto t46_n198;
  t46_n197: return 0.09638211131095886f;
  t46_n198: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t46_n200;
  t46_n199: return 0.17756541073322296f;
  t46_n200: return 0.11225973814725876f;
  t46_n201: return 0.07309702783823013f;
  t46_n202: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t46_n204;
  t46_n203: return 0.0670749768614769f;
  t46_n204: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t46_n206;
  t46_n205: return 0.08196453750133514f;
  t46_n206: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t46_n208;
  t46_n207: return 0.14256294071674347f;
  t46_n208: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t46_n210;
  t46_n209: return 0.11430492997169495f;
  t46_n210: return 0.0725393146276474f;
  t46_n211: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t46_n227;
  t46_n212: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t46_n218;
  t46_n213: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t46_n215;
  t46_n214: return 0.052971284836530685f;
  t46_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t46_n217;
  t46_n216: return 0.007263694889843464f;
  t46_n217: return 0.04154454916715622f;
  t46_n218: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t46_n220;
  t46_n219: return 0.0676555186510086f;
  t46_n220: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t46_n226;
  t46_n221: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t46_n225;
  t46_n222: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t46_n224;
  t46_n223: return 0.12140152603387833f;
  t46_n224: return 0.08621010929346085f;
  t46_n225: return 0.05425418168306351f;
  t46_n226: return 0.02429996058344841f;
  t46_n227: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t46_n237;
  t46_n228: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t46_n230;
  t46_n229: return -0.013770418241620064f;
  t46_n230: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t46_n232;
  t46_n231: return -0.045352108776569366f;
  t46_n232: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t46_n236;
  t46_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t46_n235;
  t46_n234: return -0.5102289319038391f;
  t46_n235: return 0.12910036742687225f;
  t46_n236: return -0.07760182023048401f;
  t46_n237: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t46_n239;
  t46_n238: return 0.04052695631980896f;
  t46_n239: return 0.09927772730588913f;
  t46_n240: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t46_n250;
  t46_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t46_n245;
  t46_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t46_n244;
  t46_n243: return -0.019328102469444275f;
  t46_n244: return 0.01463851984590292f;
  t46_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t46_n249;
  t46_n246: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t46_n248;
  t46_n247: return 0.005481171887367964f;
  t46_n248: return 0.09106045216321945f;
  t46_n249: return 0.026983633637428284f;
  t46_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t46_n254;
  t46_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t46_n253;
  t46_n252: return 0.04511869698762894f;
  t46_n253: return 0.061853982508182526f;
  t46_n254: return 0.07015928626060486f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree47(const Example& E) {
  t47_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t47_n242;
  t47_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t47_n225;
  t47_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t47_n108;
  t47_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t47_n27;
  t47_n4: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t47_n6;
  t47_n5: return -0.045847706496715546f;
  t47_n6: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t47_n18;
  t47_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t47_n13;
  t47_n8: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t47_n12;
  t47_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t47_n11;
  t47_n10: return 0.10240629315376282f;
  t47_n11: return -0.12097807228565216f;
  t47_n12: return -0.13723382353782654f;
  t47_n13: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t47_n15;
  t47_n14: return 0.3271450996398926f;
  t47_n15: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t47_n17;
  t47_n16: return 0.1157015711069107f;
  t47_n17: return 0.11161697655916214f;
  t47_n18: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t47_n24;
  t47_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t47_n21;
  t47_n20: return -0.03486471250653267f;
  t47_n21: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t47_n23;
  t47_n22: return 0.03383694589138031f;
  t47_n23: return 0.09053122252225876f;
  t47_n24: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t47_n26;
  t47_n25: return 0.11802715063095093f;
  t47_n26: return 0.09112399071455002f;
  t47_n27: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t47_n99;
  t47_n28: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t47_n70;
  t47_n29: if (E.getNumReferences() >= 3354001600 /*119809.5*/) goto t47_n61;
  t47_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t47_n32;
  t47_n31: return -0.09896514564752579f;
  t47_n32: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t47_n38;
  t47_n33: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t47_n35;
  t47_n34: return -0.0798402652144432f;
  t47_n35: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n37;
  t47_n36: return -0.00421931641176343f;
  t47_n37: return 0.023450279608368874f;
  t47_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t47_n46;
  t47_n39: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t47_n41;
  t47_n40: return 0.018842153251171112f;
  t47_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t47_n43;
  t47_n42: return -0.05975435674190521f;
  t47_n43: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t47_n45;
  t47_n44: return 0.044935014098882675f;
  t47_n45: return 0.0688767358660698f;
  t47_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t47_n48;
  t47_n47: return 0.002993321744725108f;
  t47_n48: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t47_n50;
  t47_n49: return 0.048716578632593155f;
  t47_n50: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t47_n58;
  t47_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n57;
  t47_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t47_n56;
  t47_n53: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t47_n55;
  t47_n54: return 0.1302167773246765f;
  t47_n55: return 0.10469905287027359f;
  t47_n56: return 0.11114340275526047f;
  t47_n57: return 0.06417609006166458f;
  t47_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n60;
  t47_n59: return 0.047633808106184006f;
  t47_n60: return 0.0099726477637887f;
  t47_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t47_n63;
  t47_n62: return 0.24871762096881866f;
  t47_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t47_n65;
  t47_n64: return -0.06693190336227417f;
  t47_n65: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t47_n69;
  t47_n66: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t47_n68;
  t47_n67: return 0.1299591213464737f;
  t47_n68: return 0.11656012386083603f;
  t47_n69: return 0.09156139940023422f;
  t47_n70: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t47_n72;
  t47_n71: return -0.048438750207424164f;
  t47_n72: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t47_n96;
  t47_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t47_n75;
  t47_n74: return -0.09685519337654114f;
  t47_n75: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t47_n95;
  t47_n76: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t47_n78;
  t47_n77: return 0.04466497525572777f;
  t47_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t47_n86;
  t47_n79: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t47_n85;
  t47_n80: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t47_n84;
  t47_n81: if (E.getNumReferences() >= 3338441472 /*32329.5*/) goto t47_n83;
  t47_n82: return 0.05211235210299492f;
  t47_n83: return 0.08950281888246536f;
  t47_n84: return 0.03151756152510643f;
  t47_n85: return 0.10511350631713867f;
  t47_n86: if (E.getNumReferences() >= 3247964160 /*19.0*/) goto t47_n88;
  t47_n87: return 0.09129566699266434f;
  t47_n88: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t47_n94;
  t47_n89: if (E.getNumReferences() >= 3287973888 /*501.0*/) goto t47_n91;
  t47_n90: return 0.04237419739365578f;
  t47_n91: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t47_n93;
  t47_n92: return 0.1176171526312828f;
  t47_n93: return 0.14930547773838043f;
  t47_n94: return 0.1109669879078865f;
  t47_n95: return -0.16154879331588745f;
  t47_n96: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t47_n98;
  t47_n97: return 0.09704131633043289f;
  t47_n98: return 0.12709587812423706f;
  t47_n99: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t47_n101;
  t47_n100: return 0.023399552330374718f;
  t47_n101: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t47_n103;
  t47_n102: return 0.058761920779943466f;
  t47_n103: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t47_n107;
  t47_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t47_n106;
  t47_n105: return 0.11358317732810974f;
  t47_n106: return 0.07917433977127075f;
  t47_n107: return -0.13207079470157623f;
  t47_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t47_n144;
  t47_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n111;
  t47_n110: return -0.008939000777900219f;
  t47_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t47_n129;
  t47_n112: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t47_n128;
  t47_n113: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t47_n115;
  t47_n114: return 0.012876151129603386f;
  t47_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t47_n117;
  t47_n116: return -0.3514515161514282f;
  t47_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t47_n123;
  t47_n118: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t47_n122;
  t47_n119: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t47_n121;
  t47_n120: return 0.045128338038921356f;
  t47_n121: return 0.1107548251748085f;
  t47_n122: return 0.006431868299841881f;
  t47_n123: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t47_n125;
  t47_n124: return 0.04534413293004036f;
  t47_n125: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t47_n127;
  t47_n126: return 0.12512412667274475f;
  t47_n127: return 0.030039561912417412f;
  t47_n128: return -0.1107720285654068f;
  t47_n129: if (E.getNumReferences() >= 3347359424 /*67917.5*/) goto t47_n143;
  t47_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t47_n132;
  t47_n131: return 0.026596959680318832f;
  t47_n132: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t47_n136;
  t47_n133: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t47_n135;
  t47_n134: return 0.07979274541139603f;
  t47_n135: return -0.02128704823553562f;
  t47_n136: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t47_n138;
  t47_n137: return -0.02386574074625969f;
  t47_n138: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t47_n142;
  t47_n139: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t47_n141;
  t47_n140: return 0.0769573524594307f;
  t47_n141: return 0.106548011302948f;
  t47_n142: return 0.055953919887542725f;
  t47_n143: return 0.062066104263067245f;
  t47_n144: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t47_n216;
  t47_n145: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t47_n191;
  t47_n146: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t47_n190;
  t47_n147: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t47_n183;
  t47_n148: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t47_n166;
  t47_n149: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t47_n165;
  t47_n150: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t47_n162;
  t47_n151: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t47_n161;
  t47_n152: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t47_n154;
  t47_n153: return 0.03372858464717865f;
  t47_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t47_n156;
  t47_n155: return 0.06563778966665268f;
  t47_n156: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t47_n158;
  t47_n157: return -0.004311565775424242f;
  t47_n158: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n160;
  t47_n159: return 0.0858621671795845f;
  t47_n160: return 0.0612034909427166f;
  t47_n161: return -0.01841914653778076f;
  t47_n162: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t47_n164;
  t47_n163: return -0.059935230761766434f;
  t47_n164: return 0.020282501354813576f;
  t47_n165: return -0.1462099403142929f;
  t47_n166: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t47_n182;
  t47_n167: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t47_n175;
  t47_n168: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t47_n170;
  t47_n169: return 0.03810138255357742f;
  t47_n170: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t47_n174;
  t47_n171: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t47_n173;
  t47_n172: return 0.05744525045156479f;
  t47_n173: return 0.07691103219985962f;
  t47_n174: return 0.05480698123574257f;
  t47_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t47_n177;
  t47_n176: return 0.07393854111433029f;
  t47_n177: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t47_n181;
  t47_n178: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t47_n180;
  t47_n179: return 0.07634568214416504f;
  t47_n180: return 0.09669946879148483f;
  t47_n181: return 0.09420102834701538f;
  t47_n182: return 0.026633772999048233f;
  t47_n183: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t47_n187;
  t47_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t47_n186;
  t47_n185: return -0.052018627524375916f;
  t47_n186: return 0.09479127079248428f;
  t47_n187: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t47_n189;
  t47_n188: return -0.07795128971338272f;
  t47_n189: return 0.01690850220620632f;
  t47_n190: return -0.042088497430086136f;
  t47_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t47_n193;
  t47_n192: return 0.016147444024682045f;
  t47_n193: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t47_n211;
  t47_n194: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t47_n206;
  t47_n195: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t47_n205;
  t47_n196: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t47_n202;
  t47_n197: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t47_n201;
  t47_n198: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t47_n200;
  t47_n199: return 0.06203779578208923f;
  t47_n200: return 0.09004157781600952f;
  t47_n201: return 0.012087193317711353f;
  t47_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t47_n204;
  t47_n203: return 0.06119203567504883f;
  t47_n204: return 0.12356191128492355f;
  t47_n205: return -0.09218922257423401f;
  t47_n206: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t47_n208;
  t47_n207: return 0.07553490251302719f;
  t47_n208: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t47_n210;
  t47_n209: return 0.10723134875297546f;
  t47_n210: return 0.09716886281967163f;
  t47_n211: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t47_n213;
  t47_n212: return -0.12791045010089874f;
  t47_n213: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t47_n215;
  t47_n214: return 0.05825604870915413f;
  t47_n215: return -0.0349796824157238f;
  t47_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t47_n224;
  t47_n217: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t47_n221;
  t47_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n220;
  t47_n219: return 0.09225229173898697f;
  t47_n220: return 0.03939049318432808f;
  t47_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t47_n223;
  t47_n222: return 0.012802254408597946f;
  t47_n223: return 0.09358344227075577f;
  t47_n224: return -0.002525538206100464f;
  t47_n225: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t47_n231;
  t47_n226: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n228;
  t47_n227: return 0.019262637943029404f;
  t47_n228: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t47_n230;
  t47_n229: return 0.03413253650069237f;
  t47_n230: return 0.013267013244330883f;
  t47_n231: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t47_n237;
  t47_n232: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t47_n234;
  t47_n233: return 0.07597023248672485f;
  t47_n234: if (E.getNumReferences() >= 3349646912 /*85788.5*/) goto t47_n236;
  t47_n235: return 0.044736847281455994f;
  t47_n236: return 0.07936464995145798f;
  t47_n237: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t47_n239;
  t47_n238: return 0.012294942513108253f;
  t47_n239: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t47_n241;
  t47_n240: return -0.004812796600162983f;
  t47_n241: return 0.0780157595872879f;
  t47_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t47_n250;
  t47_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t47_n249;
  t47_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t47_n246;
  t47_n245: return -0.006953505799174309f;
  t47_n246: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t47_n248;
  t47_n247: return 0.023779602721333504f;
  t47_n248: return 0.007769410032778978f;
  t47_n249: return 0.04558553174138069f;
  t47_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t47_n254;
  t47_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n253;
  t47_n252: return 0.045222219079732895f;
  t47_n253: return 0.059219326823949814f;
  t47_n254: return 0.06808535009622574f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree48(const Example& E) {
  t48_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t48_n242;
  t48_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t48_n189;
  t48_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t48_n78;
  t48_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t48_n23;
  t48_n4: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t48_n6;
  t48_n5: return -0.04384564980864525f;
  t48_n6: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t48_n18;
  t48_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t48_n13;
  t48_n8: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t48_n12;
  t48_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t48_n11;
  t48_n10: return 0.09814662486314774f;
  t48_n11: return -0.1028486117720604f;
  t48_n12: return -0.11925717443227768f;
  t48_n13: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t48_n17;
  t48_n14: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t48_n16;
  t48_n15: return 0.13494610786437988f;
  t48_n16: return 0.1250736117362976f;
  t48_n17: return 0.10791732370853424f;
  t48_n18: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t48_n20;
  t48_n19: return 0.00987265631556511f;
  t48_n20: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t48_n22;
  t48_n21: return 0.11670646071434021f;
  t48_n22: return 0.08498862385749817f;
  t48_n23: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t48_n69;
  t48_n24: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t48_n50;
  t48_n25: if (E.getNumReferences() >= 3354001600 /*119809.5*/) goto t48_n29;
  t48_n26: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t48_n28;
  t48_n27: return -0.0022802921012043953f;
  t48_n28: return 0.04317060858011246f;
  t48_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t48_n31;
  t48_n30: return 0.16341367363929749f;
  t48_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t48_n33;
  t48_n32: return -0.06175748258829117f;
  t48_n33: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t48_n49;
  t48_n34: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t48_n38;
  t48_n35: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t48_n37;
  t48_n36: return 0.06575874984264374f;
  t48_n37: return 0.12846626341342926f;
  t48_n38: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t48_n46;
  t48_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t48_n41;
  t48_n40: return 0.07895856350660324f;
  t48_n41: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t48_n45;
  t48_n42: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t48_n44;
  t48_n43: return 0.12368374317884445f;
  t48_n44: return 0.11630748212337494f;
  t48_n45: return 0.09990520030260086f;
  t48_n46: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t48_n48;
  t48_n47: return 0.12792466580867767f;
  t48_n48: return 0.05362152308225632f;
  t48_n49: return 0.09078188985586166f;
  t48_n50: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t48_n52;
  t48_n51: return -0.04662219062447548f;
  t48_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t48_n54;
  t48_n53: return -0.07950426638126373f;
  t48_n54: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t48_n68;
  t48_n55: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t48_n67;
  t48_n56: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t48_n66;
  t48_n57: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t48_n61;
  t48_n58: if (E.getNumReferences() >= 3332189440 /*20118.5*/) goto t48_n60;
  t48_n59: return 0.043959807604551315f;
  t48_n60: return 0.08219298720359802f;
  t48_n61: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t48_n63;
  t48_n62: return 0.03838725388050079f;
  t48_n63: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t48_n65;
  t48_n64: return 0.0860578715801239f;
  t48_n65: return 0.13692933320999146f;
  t48_n66: return 0.0975499153137207f;
  t48_n67: return -0.15229997038841248f;
  t48_n68: return 0.11163006722927094f;
  t48_n69: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t48_n71;
  t48_n70: return 0.027282414957880974f;
  t48_n71: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t48_n73;
  t48_n72: return 0.053020499646663666f;
  t48_n73: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t48_n77;
  t48_n74: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t48_n76;
  t48_n75: return 0.11068890988826752f;
  t48_n76: return 0.07621318101882935f;
  t48_n77: return -0.13151895999908447f;
  t48_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t48_n104;
  t48_n79: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t48_n81;
  t48_n80: return -0.009189669042825699f;
  t48_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t48_n83;
  t48_n82: return 0.015291326679289341f;
  t48_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t48_n85;
  t48_n84: return 0.024666404351592064f;
  t48_n85: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t48_n95;
  t48_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t48_n88;
  t48_n87: return 0.05316344276070595f;
  t48_n88: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t48_n90;
  t48_n89: return -0.023692753165960312f;
  t48_n90: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t48_n92;
  t48_n91: return -0.07934925705194473f;
  t48_n92: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t48_n94;
  t48_n93: return 0.1165269985795021f;
  t48_n94: return 0.08977712690830231f;
  t48_n95: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t48_n101;
  t48_n96: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t48_n100;
  t48_n97: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t48_n99;
  t48_n98: return 0.07977869361639023f;
  t48_n99: return 0.10750984400510788f;
  t48_n100: return 0.05374440550804138f;
  t48_n101: if (E.getNumReferences() >= 3351690304 /*101752.5*/) goto t48_n103;
  t48_n102: return 0.11166912317276001f;
  t48_n103: return 0.09187794476747513f;
  t48_n104: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t48_n180;
  t48_n105: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t48_n149;
  t48_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t48_n148;
  t48_n107: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t48_n141;
  t48_n108: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t48_n126;
  t48_n109: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t48_n123;
  t48_n110: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t48_n122;
  t48_n111: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t48_n121;
  t48_n112: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t48_n114;
  t48_n113: return 0.03231531009078026f;
  t48_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t48_n116;
  t48_n115: return 0.05799880251288414f;
  t48_n116: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t48_n118;
  t48_n117: return -0.004337986931204796f;
  t48_n118: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t48_n120;
  t48_n119: return 0.08355078101158142f;
  t48_n120: return 0.0564713180065155f;
  t48_n121: return -0.14175626635551453f;
  t48_n122: return -0.023703493177890778f;
  t48_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t48_n125;
  t48_n124: return -0.05948984622955322f;
  t48_n125: return 0.0222018975764513f;
  t48_n126: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t48_n140;
  t48_n127: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t48_n129;
  t48_n128: return 0.03137115761637688f;
  t48_n129: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t48_n131;
  t48_n130: return 0.05839965492486954f;
  t48_n131: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t48_n137;
  t48_n132: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t48_n134;
  t48_n133: return 0.060443200170993805f;
  t48_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion))) goto t48_n136;
  t48_n135: return 0.08330818265676498f;
  t48_n136: return 0.10898367315530777f;
  t48_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t48_n139;
  t48_n138: return 0.06859918683767319f;
  t48_n139: return 0.0913970023393631f;
  t48_n140: return 0.023177558556199074f;
  t48_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t48_n145;
  t48_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t48_n144;
  t48_n143: return -0.04915129765868187f;
  t48_n144: return 0.09043075144290924f;
  t48_n145: if (E.getFileProximityDistance() >= 3254910976 /*32.5*/) goto t48_n147;
  t48_n146: return 0.016475317999720573f;
  t48_n147: return -0.1757425218820572f;
  t48_n148: return -0.042192600667476654f;
  t48_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t48_n155;
  t48_n150: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t48_n154;
  t48_n151: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t48_n153;
  t48_n152: return 0.042957283556461334f;
  t48_n153: return -0.021462902426719666f;
  t48_n154: return -0.19391462206840515f;
  t48_n155: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t48_n177;
  t48_n156: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t48_n172;
  t48_n157: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t48_n161;
  t48_n158: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t48_n160;
  t48_n159: return 0.06416954845190048f;
  t48_n160: return 0.011415870860219002f;
  t48_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t48_n163;
  t48_n162: return 0.03194235637784004f;
  t48_n163: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t48_n171;
  t48_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t48_n170;
  t48_n165: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t48_n169;
  t48_n166: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t48_n168;
  t48_n167: return 0.10362294316291809f;
  t48_n168: return 0.11512645334005356f;
  t48_n169: return 0.10204895585775375f;
  t48_n170: return 0.07562866061925888f;
  t48_n171: return 0.12464451044797897f;
  t48_n172: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t48_n174;
  t48_n173: return 0.07200933992862701f;
  t48_n174: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t48_n176;
  t48_n175: return 0.1063447892665863f;
  t48_n176: return 0.09575214982032776f;
  t48_n177: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t48_n179;
  t48_n178: return -0.11666768044233322f;
  t48_n179: return 0.0423554964363575f;
  t48_n180: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t48_n188;
  t48_n181: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t48_n185;
  t48_n182: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t48_n184;
  t48_n183: return 0.08655806630849838f;
  t48_n184: return 0.034406114369630814f;
  t48_n185: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t48_n187;
  t48_n186: return 0.012664949521422386f;
  t48_n187: return 0.09242243319749832f;
  t48_n188: return -0.004659170750528574f;
  t48_n189: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t48_n225;
  t48_n190: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t48_n216;
  t48_n191: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t48_n215;
  t48_n192: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t48_n212;
  t48_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t48_n195;
  t48_n194: return -0.23240312933921814f;
  t48_n195: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t48_n211;
  t48_n196: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t48_n210;
  t48_n197: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t48_n199;
  t48_n198: return 0.03360581025481224f;
  t48_n199: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t48_n201;
  t48_n200: return 0.03834622725844383f;
  t48_n201: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t48_n209;
  t48_n202: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t48_n204;
  t48_n203: return -0.020636308938264847f;
  t48_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t48_n206;
  t48_n205: return 0.12051068991422653f;
  t48_n206: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t48_n208;
  t48_n207: return 0.11243531852960587f;
  t48_n208: return 0.0260930135846138f;
  t48_n209: return 0.06324395537376404f;
  t48_n210: return 0.05248526856303215f;
  t48_n211: return -0.0038150129839777946f;
  t48_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t48_n214;
  t48_n213: return -0.3445795476436615f;
  t48_n214: return 0.03277602046728134f;
  t48_n215: return -0.05489566922187805f;
  t48_n216: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t48_n224;
  t48_n217: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t48_n223;
  t48_n218: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t48_n220;
  t48_n219: return 0.04342828691005707f;
  t48_n220: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t48_n222;
  t48_n221: return -0.03262172266840935f;
  t48_n222: return 0.057404227554798126f;
  t48_n223: return 0.07405927032232285f;
  t48_n224: return -0.10923736542463303f;
  t48_n225: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t48_n231;
  t48_n226: if (E.getNumReferences() >= 3349646912 /*85788.5*/) goto t48_n230;
  t48_n227: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t48_n229;
  t48_n228: return 0.052105292677879333f;
  t48_n229: return 0.0583263635635376f;
  t48_n230: return 0.07582864910364151f;
  t48_n231: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t48_n233;
  t48_n232: return 0.008800377137959003f;
  t48_n233: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t48_n235;
  t48_n234: return 0.005562382750213146f;
  t48_n235: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t48_n241;
  t48_n236: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t48_n240;
  t48_n237: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t48_n239;
  t48_n238: return 0.09486287087202072f;
  t48_n239: return 0.15499897301197052f;
  t48_n240: return -0.08354710042476654f;
  t48_n241: return 0.06999339163303375f;
  t48_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t48_n250;
  t48_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t48_n249;
  t48_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t48_n246;
  t48_n245: return -0.011260349303483963f;
  t48_n246: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t48_n248;
  t48_n247: return 0.015681782737374306f;
  t48_n248: return -0.2677670121192932f;
  t48_n249: return 0.04364495724439621f;
  t48_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t48_n254;
  t48_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t48_n253;
  t48_n252: return 0.039197325706481934f;
  t48_n253: return 0.05754837766289711f;
  t48_n254: return 0.06619742512702942f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree49(const Example& E) {
  t49_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t49_n244;
  t49_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t49_n203;
  t49_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t49_n150;
  t49_n3: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t49_n21;
  t49_n4: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t49_n6;
  t49_n5: return -0.0071006654761731625f;
  t49_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t49_n8;
  t49_n7: return 0.016056198626756668f;
  t49_n8: if (E.getNumReferences() >= 3322075136 /*8374.0*/) goto t49_n20;
  t49_n9: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t49_n19;
  t49_n10: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t49_n14;
  t49_n11: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t49_n13;
  t49_n12: return 0.04005441814661026f;
  t49_n13: return 0.06396548449993134f;
  t49_n14: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t49_n16;
  t49_n15: return 0.07404827326536179f;
  t49_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t49_n18;
  t49_n17: return 0.07894711941480637f;
  t49_n18: return 0.09220299124717712f;
  t49_n19: return 0.025485316291451454f;
  t49_n20: return 0.06034582853317261f;
  t49_n21: if (E.getNumReferences() >= 3302477824 /*1726.5*/) goto t49_n23;
  t49_n22: return -0.03828606754541397f;
  t49_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t49_n25;
  t49_n24: return -0.013273654505610466f;
  t49_n25: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t49_n45;
  t49_n26: if (E.getNumReferences() >= 3302612992 /*1743.0*/) goto t49_n38;
  t49_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t49_n35;
  t49_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t49_n30;
  t49_n29: return -0.06457944214344025f;
  t49_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t49_n32;
  t49_n31: return -0.11997425556182861f;
  t49_n32: if (E.getNumReferences() >= 3302539264 /*1734.0*/) goto t49_n34;
  t49_n33: return -0.15876121819019318f;
  t49_n34: return 0.1284700632095337f;
  t49_n35: if (E.getNumReferences() >= 3302567936 /*1737.5*/) goto t49_n37;
  t49_n36: return 0.1210581511259079f;
  t49_n37: return 0.11772502958774567f;
  t49_n38: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t49_n40;
  t49_n39: return 0.010903328657150269f;
  t49_n40: if (E.getNumReferences() >= 3319614464 /*7081.5*/) goto t49_n44;
  t49_n41: if (E.getNumReferences() >= 3306715136 /*2439.5*/) goto t49_n43;
  t49_n42: return 0.008649859577417374f;
  t49_n43: return 0.06551069021224976f;
  t49_n44: return -0.9966633319854736f;
  t49_n45: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t49_n55;
  t49_n46: if (E.getNumReferences() >= 3350366592 /*91411.0*/) goto t49_n52;
  t49_n47: if (E.getNumReferences() >= 3344779136 /*56647.5*/) goto t49_n49;
  t49_n48: return 0.01582244411110878f;
  t49_n49: if (E.getNumReferences() >= 3345992448 /*61387.0*/) goto t49_n51;
  t49_n50: return -0.2695603370666504f;
  t49_n51: return -0.011394688859581947f;
  t49_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t49_n54;
  t49_n53: return -0.316650927066803f;
  t49_n54: return 0.05662946403026581f;
  t49_n55: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t49_n111;
  t49_n56: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t49_n108;
  t49_n57: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t49_n71;
  t49_n58: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t49_n60;
  t49_n59: return 0.0417284294962883f;
  t49_n60: if (E.getNumReferences() >= 3339274880 /*35146.5*/) goto t49_n62;
  t49_n61: return 0.08221323788166046f;
  t49_n62: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t49_n66;
  t49_n63: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t49_n65;
  t49_n64: return 0.09869615733623505f;
  t49_n65: return 0.12250382453203201f;
  t49_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t49_n70;
  t49_n67: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t49_n69;
  t49_n68: return -0.0845021978020668f;
  t49_n69: return 0.09057016670703888f;
  t49_n70: return 0.10654788464307785f;
  t49_n71: if (E.getNumReferences() >= 3325080064 /*11308.5*/) goto t49_n95;
  t49_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t49_n74;
  t49_n73: return -0.01306490134447813f;
  t49_n74: if (E.getNumReferences() >= 3324975616 /*11206.5*/) goto t49_n92;
  t49_n75: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t49_n91;
  t49_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t49_n86;
  t49_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t49_n79;
  t49_n78: return 0.09161747246980667f;
  t49_n79: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t49_n81;
  t49_n80: return 0.11490260809659958f;
  t49_n81: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t49_n83;
  t49_n82: return 0.06962916254997253f;
  t49_n83: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t49_n85;
  t49_n84: return -0.06388957798480988f;
  t49_n85: return 0.11955096572637558f;
  t49_n86: if (E.getNumReferences() >= 3322129920 /*8427.5*/) goto t49_n90;
  t49_n87: if (E.getNumReferences() >= 3321240576 /*7875.5*/) goto t49_n89;
  t49_n88: return 0.11492963880300522f;
  t49_n89: return 0.12519164383411407f;
  t49_n90: return 0.04900578781962395f;
  t49_n91: return 0.0965886190533638f;
  t49_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t49_n94;
  t49_n93: return -0.11210517585277557f;
  t49_n94: return 0.11321491748094559f;
  t49_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t49_n103;
  t49_n96: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t49_n102;
  t49_n97: if (E.getNumReferences() >= 3334835456 /*25286.5*/) goto t49_n101;
  t49_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t49_n100;
  t49_n99: return 0.061438195407390594f;
  t49_n100: return 0.0830722451210022f;
  t49_n101: return -0.0651339665055275f;
  t49_n102: return 0.07960812747478485f;
  t49_n103: if (E.getNumReferences() >= 3331329792 /*18439.5*/) goto t49_n107;
  t49_n104: if (E.getNumReferences() >= 3331157760 /*18103.5*/) goto t49_n106;
  t49_n105: return 0.0637628585100174f;
  t49_n106: return 0.10811486840248108f;
  t49_n107: return 0.09574811905622482f;
  t49_n108: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t49_n110;
  t49_n109: return -0.14152005314826965f;
  t49_n110: return 0.013371014036238194f;
  t49_n111: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t49_n149;
  t49_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t49_n140;
  t49_n113: if (E.getNumReferences() >= 3329839104 /*15956.0*/) goto t49_n121;
  t49_n114: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t49_n116;
  t49_n115: return 0.051595382392406464f;
  t49_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t49_n118;
  t49_n117: return 0.08934242278337479f;
  t49_n118: if (E.getNumReferences() >= 3325309440 /*11532.5*/) goto t49_n120;
  t49_n119: return -0.5525740385055542f;
  t49_n120: return 0.11077194660902023f;
  t49_n121: if (E.getNumReferences() >= 3330013184 /*16126.0*/) goto t49_n123;
  t49_n122: return 0.12585948407649994f;
  t49_n123: if (E.getNumReferences() >= 3333808640 /*23281.0*/) goto t49_n137;
  t49_n124: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t49_n126;
  t49_n125: return 0.08524616062641144f;
  t49_n126: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t49_n128;
  t49_n127: return 0.12033101171255112f;
  t49_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t49_n130;
  t49_n129: return 0.09863711148500443f;
  t49_n130: if (E.getNumReferences() >= 3332047872 /*19842.0*/) goto t49_n132;
  t49_n131: return 0.11165256798267365f;
  t49_n132: if (E.getNumReferences() >= 3332793856 /*21299.0*/) goto t49_n134;
  t49_n133: return -0.021748008206486702f;
  t49_n134: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t49_n136;
  t49_n135: return 0.11763385683298111f;
  t49_n136: return 0.01464210357517004f;
  t49_n137: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t49_n139;
  t49_n138: return 0.06868623197078705f;
  t49_n139: return 0.1007356271147728f;
  t49_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t49_n142;
  t49_n141: return 0.08579104393720627f;
  t49_n142: if (E.getNumReferences() >= 3327026688 /*13209.5*/) goto t49_n144;
  t49_n143: return 0.11479629576206207f;
  t49_n144: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t49_n148;
  t49_n145: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t49_n147;
  t49_n146: return 0.11135392636060715f;
  t49_n147: return 0.10566720366477966f;
  t49_n148: return 0.08902639895677567f;
  t49_n149: return 0.027570132166147232f;
  t49_n150: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t49_n154;
  t49_n151: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t49_n153;
  t49_n152: return 0.014073965139687061f;
  t49_n153: return -0.0035217220429331064f;
  t49_n154: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t49_n162;
  t49_n155: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t49_n159;
  t49_n156: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t49_n158;
  t49_n157: return 0.04396215081214905f;
  t49_n158: return -0.029263505712151527f;
  t49_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t49_n161;
  t49_n160: return 0.03692518547177315f;
  t49_n161: return 0.056985363364219666f;
  t49_n162: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t49_n180;
  t49_n163: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t49_n179;
  t49_n164: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t49_n166;
  t49_n165: return 0.08570831269025803f;
  t49_n166: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t49_n170;
  t49_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t49_n169;
  t49_n168: return -0.1775335669517517f;
  t49_n169: return 0.10961410403251648f;
  t49_n170: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t49_n172;
  t49_n171: return 0.01992739364504814f;
  t49_n172: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t49_n174;
  t49_n173: return 0.03656117990612984f;
  t49_n174: if (E.getNumReferences() >= 3294330880 /*878.0*/) goto t49_n176;
  t49_n175: return 0.030974987894296646f;
  t49_n176: if (E.getNumReferences() >= 3297783808 /*1153.5*/) goto t49_n178;
  t49_n177: return 0.10512590408325195f;
  t49_n178: return -0.03786160796880722f;
  t49_n179: return 0.016046438366174698f;
  t49_n180: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t49_n182;
  t49_n181: return 0.10182895511388779f;
  t49_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t49_n190;
  t49_n183: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t49_n189;
  t49_n184: if (E.getFilterLength() >= 3250323456 /*23.5*/) goto t49_n186;
  t49_n185: return 0.08860290050506592f;
  t49_n186: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t49_n188;
  t49_n187: return 0.15794207155704498f;
  t49_n188: return 0.07388676702976227f;
  t49_n189: return 0.07138396799564362f;
  t49_n190: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t49_n192;
  t49_n191: return 0.05833430960774422f;
  t49_n192: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t49_n194;
  t49_n193: return 0.08090172708034515f;
  t49_n194: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t49_n198;
  t49_n195: if (E.getNumReferences() >= 3264610304 /*75.0*/) goto t49_n197;
  t49_n196: return 0.13626548647880554f;
  t49_n197: return 0.03387799859046936f;
  t49_n198: if (E.getNumReferences() >= 3270246400 /*118.0*/) goto t49_n200;
  t49_n199: return 0.10067499428987503f;
  t49_n200: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t49_n202;
  t49_n201: return 0.14716176688671112f;
  t49_n202: return 0.10025899857282639f;
  t49_n203: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t49_n239;
  t49_n204: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t49_n236;
  t49_n205: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t49_n233;
  t49_n206: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t49_n230;
  t49_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t49_n209;
  t49_n208: return -0.2279350310564041f;
  t49_n209: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t49_n229;
  t49_n210: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t49_n224;
  t49_n211: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t49_n213;
  t49_n212: return 0.030281545594334602f;
  t49_n213: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t49_n215;
  t49_n214: return 0.040441129356622696f;
  t49_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t49_n223;
  t49_n216: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t49_n218;
  t49_n217: return 0.005902497563511133f;
  t49_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t49_n220;
  t49_n219: return 0.18750415742397308f;
  t49_n220: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t49_n222;
  t49_n221: return 0.11178500950336456f;
  t49_n222: return 0.02780691534280777f;
  t49_n223: return 0.06177663803100586f;
  t49_n224: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t49_n228;
  t49_n225: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t49_n227;
  t49_n226: return 0.050442490726709366f;
  t49_n227: return 0.07691120356321335f;
  t49_n228: return 0.026438813656568527f;
  t49_n229: return -0.004177542869001627f;
  t49_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t49_n232;
  t49_n231: return -0.19554468989372253f;
  t49_n232: return 0.031446799635887146f;
  t49_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t49_n235;
  t49_n234: return -0.09656501561403275f;
  t49_n235: return 0.02716492861509323f;
  t49_n236: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t49_n238;
  t49_n237: return 0.03498346358537674f;
  t49_n238: return -0.055831823498010635f;
  t49_n239: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t49_n241;
  t49_n240: return 0.05599178746342659f;
  t49_n241: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t49_n243;
  t49_n242: return 0.010698794387280941f;
  t49_n243: return 0.0620381124317646f;
  t49_n244: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t49_n250;
  t49_n245: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t49_n249;
  t49_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t49_n248;
  t49_n247: return -0.010166266933083534f;
  t49_n248: return 0.01356172002851963f;
  t49_n249: return 0.041744306683540344f;
  t49_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t49_n254;
  t49_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t49_n253;
  t49_n252: return 0.0395376980304718f;
  t49_n253: return 0.05389593169093132f;
  t49_n254: return 0.06438782066106796f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree50(const Example& E) {
  t50_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t50_n242;
  t50_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t50_n205;
  t50_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t50_n46;
  t50_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t50_n5;
  t50_n4: return -0.04134805127978325f;
  t50_n5: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t50_n37;
  t50_n6: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t50_n8;
  t50_n7: return -0.026538684964179993f;
  t50_n8: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t50_n32;
  t50_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t50_n15;
  t50_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t50_n12;
  t50_n11: return -0.12388809770345688f;
  t50_n12: if (E.getNumReferences() >= 3342575744 /*48040.5*/) goto t50_n14;
  t50_n13: return 0.009273992851376534f;
  t50_n14: return 0.1657734364271164f;
  t50_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t50_n19;
  t50_n16: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t50_n18;
  t50_n17: return 0.020824279636144638f;
  t50_n18: return -0.04737229272723198f;
  t50_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t50_n21;
  t50_n20: return 0.0032060735393315554f;
  t50_n21: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n23;
  t50_n22: return 0.057568058371543884f;
  t50_n23: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n29;
  t50_n24: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t50_n28;
  t50_n25: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t50_n27;
  t50_n26: return 0.12297863513231277f;
  t50_n27: return 0.11021848022937775f;
  t50_n28: return 0.051185671240091324f;
  t50_n29: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t50_n31;
  t50_n30: return 0.062262166291475296f;
  t50_n31: return 0.016139905899763107f;
  t50_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t50_n34;
  t50_n33: return -0.07762875407934189f;
  t50_n34: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t50_n36;
  t50_n35: return 0.011380570940673351f;
  t50_n36: return 0.05144425854086876f;
  t50_n37: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t50_n39;
  t50_n38: return 0.019228573888540268f;
  t50_n39: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t50_n41;
  t50_n40: return 0.04975035414099693f;
  t50_n41: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t50_n45;
  t50_n42: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t50_n44;
  t50_n43: return 0.10898903012275696f;
  t50_n44: return 0.07228424400091171f;
  t50_n45: return -0.12793424725532532f;
  t50_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t50_n136;
  t50_n47: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t50_n85;
  t50_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t50_n70;
  t50_n49: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t50_n69;
  t50_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t50_n68;
  t50_n51: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t50_n53;
  t50_n52: return 0.027341162785887718f;
  t50_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t50_n57;
  t50_n54: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t50_n56;
  t50_n55: return -0.009783999063074589f;
  t50_n56: return 0.03894713893532753f;
  t50_n57: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t50_n67;
  t50_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n62;
  t50_n59: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n61;
  t50_n60: return 0.10064518451690674f;
  t50_n61: return 0.04000569134950638f;
  t50_n62: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t50_n64;
  t50_n63: return 0.06306443363428116f;
  t50_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t50_n66;
  t50_n65: return 0.09746736288070679f;
  t50_n66: return 0.09049498289823532f;
  t50_n67: return -0.0383845716714859f;
  t50_n68: return -0.020974550396203995f;
  t50_n69: return -0.028728077188134193f;
  t50_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t50_n72;
  t50_n71: return 0.02507183700799942f;
  t50_n72: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t50_n78;
  t50_n73: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t50_n75;
  t50_n74: return 0.01889736019074917f;
  t50_n75: if (E.getNumReferences() >= 3332487680 /*20701.0*/) goto t50_n77;
  t50_n76: return -0.073529914021492f;
  t50_n77: return -0.23788972198963165f;
  t50_n78: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t50_n80;
  t50_n79: return 0.0789819210767746f;
  t50_n80: if (E.getNumReferences() >= 3345471616 /*59352.5*/) goto t50_n84;
  t50_n81: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t50_n83;
  t50_n82: return 0.02278936840593815f;
  t50_n83: return 0.061685312539339066f;
  t50_n84: return 0.0921202227473259f;
  t50_n85: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t50_n135;
  t50_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n88;
  t50_n87: return 0.03869762644171715f;
  t50_n88: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t50_n90;
  t50_n89: return -0.04303742200136185f;
  t50_n90: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t50_n132;
  t50_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t50_n123;
  t50_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t50_n98;
  t50_n93: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t50_n95;
  t50_n94: return -0.0065425848588347435f;
  t50_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t50_n97;
  t50_n96: return 0.1079166904091835f;
  t50_n97: return 0.06182792782783508f;
  t50_n98: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t50_n116;
  t50_n99: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t50_n105;
  t50_n100: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t50_n102;
  t50_n101: return 0.11343332380056381f;
  t50_n102: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t50_n104;
  t50_n103: return 0.13738210499286652f;
  t50_n104: return 0.09714511781930923f;
  t50_n105: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t50_n107;
  t50_n106: return 0.0997411385178566f;
  t50_n107: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t50_n109;
  t50_n108: return 0.1317363828420639f;
  t50_n109: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t50_n115;
  t50_n110: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t50_n112;
  t50_n111: return 0.11926400661468506f;
  t50_n112: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t50_n114;
  t50_n113: return 0.17992882430553436f;
  t50_n114: return 0.1305561363697052f;
  t50_n115: return 0.03566669300198555f;
  t50_n116: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n120;
  t50_n117: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t50_n119;
  t50_n118: return 0.1044851690530777f;
  t50_n119: return 0.11056826263666153f;
  t50_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t50_n122;
  t50_n121: return -0.21412676572799683f;
  t50_n122: return 0.06948933750391006f;
  t50_n123: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t50_n127;
  t50_n124: if (E.getNumReferences() >= 3339920000 /*37666.5*/) goto t50_n126;
  t50_n125: return 0.05030626803636551f;
  t50_n126: return 0.09811358153820038f;
  t50_n127: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t50_n131;
  t50_n128: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n130;
  t50_n129: return 0.12655505537986755f;
  t50_n130: return 0.12201696634292603f;
  t50_n131: return 0.07862817496061325f;
  t50_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t50_n134;
  t50_n133: return -0.445903480052948f;
  t50_n134: return 0.0186452753841877f;
  t50_n135: return -0.12699289619922638f;
  t50_n136: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t50_n198;
  t50_n137: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t50_n173;
  t50_n138: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t50_n172;
  t50_n139: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t50_n171;
  t50_n140: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t50_n162;
  t50_n141: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t50_n161;
  t50_n142: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t50_n148;
  t50_n143: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n145;
  t50_n144: return -0.012254390865564346f;
  t50_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t50_n147;
  t50_n146: return 0.01045322511345148f;
  t50_n147: return 0.03542685881257057f;
  t50_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t50_n150;
  t50_n149: return 0.026217792183160782f;
  t50_n150: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t50_n152;
  t50_n151: return 0.03494812548160553f;
  t50_n152: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t50_n156;
  t50_n153: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t50_n155;
  t50_n154: return 0.08516044914722443f;
  t50_n155: return -0.056391965597867966f;
  t50_n156: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n160;
  t50_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n159;
  t50_n158: return 0.07855089753866196f;
  t50_n159: return 0.048486556857824326f;
  t50_n160: return 0.06578179448843002f;
  t50_n161: return -0.132791206240654f;
  t50_n162: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t50_n170;
  t50_n163: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t50_n165;
  t50_n164: return 0.05058204382658005f;
  t50_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t50_n167;
  t50_n166: return 0.06653691828250885f;
  t50_n167: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t50_n169;
  t50_n168: return 0.07408850640058517f;
  t50_n169: return 0.08862550556659698f;
  t50_n170: return 0.023115815594792366f;
  t50_n171: return 0.00764461187645793f;
  t50_n172: return -0.042261358350515366f;
  t50_n173: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n175;
  t50_n174: return 0.01381650846451521f;
  t50_n175: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t50_n197;
  t50_n176: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t50_n192;
  t50_n177: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t50_n179;
  t50_n178: return 0.05360906571149826f;
  t50_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t50_n181;
  t50_n180: return 0.029452955350279808f;
  t50_n181: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t50_n191;
  t50_n182: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t50_n190;
  t50_n183: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t50_n189;
  t50_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t50_n186;
  t50_n185: return 0.10107163339853287f;
  t50_n186: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t50_n188;
  t50_n187: return 0.10413412749767303f;
  t50_n188: return 0.12062022089958191f;
  t50_n189: return -0.2855970859527588f;
  t50_n190: return 0.07257197797298431f;
  t50_n191: return 0.12048619240522385f;
  t50_n192: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t50_n194;
  t50_n193: return 0.06880953907966614f;
  t50_n194: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t50_n196;
  t50_n195: return 0.10560346394777298f;
  t50_n196: return 0.09416430443525314f;
  t50_n197: return 0.03192706033587456f;
  t50_n198: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t50_n204;
  t50_n199: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t50_n203;
  t50_n200: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n202;
  t50_n201: return 0.08188936114311218f;
  t50_n202: return 0.028954869136214256f;
  t50_n203: return 0.03227877616882324f;
  t50_n204: return -0.005101862829178572f;
  t50_n205: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t50_n235;
  t50_n206: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t50_n232;
  t50_n207: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t50_n231;
  t50_n208: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t50_n228;
  t50_n209: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t50_n227;
  t50_n210: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n226;
  t50_n211: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t50_n213;
  t50_n212: return 0.02519003488123417f;
  t50_n213: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t50_n215;
  t50_n214: return 0.03199714049696922f;
  t50_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t50_n225;
  t50_n216: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t50_n218;
  t50_n217: return 0.05099630355834961f;
  t50_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t50_n220;
  t50_n219: return 0.09037555009126663f;
  t50_n220: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t50_n224;
  t50_n221: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t50_n223;
  t50_n222: return 0.2917834520339966f;
  t50_n223: return 0.10759331285953522f;
  t50_n224: return 0.027771135792136192f;
  t50_n225: return 0.043648116290569305f;
  t50_n226: return 0.048263318836688995f;
  t50_n227: return -0.03764214366674423f;
  t50_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t50_n230;
  t50_n229: return 0.019585177302360535f;
  t50_n230: return 0.06294625997543335f;
  t50_n231: return -0.047912854701280594f;
  t50_n232: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t50_n234;
  t50_n233: return 0.032482992857694626f;
  t50_n234: return -0.09266506880521774f;
  t50_n235: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t50_n237;
  t50_n236: return 0.0543208122253418f;
  t50_n237: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t50_n239;
  t50_n238: return 0.05184972286224365f;
  t50_n239: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t50_n241;
  t50_n240: return 0.00410868227481842f;
  t50_n241: return 0.05685129389166832f;
  t50_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t50_n250;
  t50_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n247;
  t50_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t50_n246;
  t50_n245: return -0.014628834091126919f;
  t50_n246: return 0.008296489715576172f;
  t50_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t50_n249;
  t50_n248: return 0.006730273831635714f;
  t50_n249: return 0.032410744577646255f;
  t50_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t50_n254;
  t50_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n253;
  t50_n252: return 0.03775531426072121f;
  t50_n253: return 0.05281894654035568f;
  t50_n254: return 0.0633334144949913f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree51(const Example& E) {
  t51_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t51_n242;
  t51_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t51_n181;
  t51_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t51_n132;
  t51_n3: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t51_n97;
  t51_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t51_n6;
  t51_n5: return -0.10008023679256439f;
  t51_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t51_n10;
  t51_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t51_n9;
  t51_n8: return -0.028660377487540245f;
  t51_n9: return 0.0009207770926877856f;
  t51_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t51_n40;
  t51_n11: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t51_n25;
  t51_n12: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t51_n20;
  t51_n13: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t51_n15;
  t51_n14: return -6.07479851169046e-05f;
  t51_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t51_n17;
  t51_n16: return 0.019823433831334114f;
  t51_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t51_n19;
  t51_n18: return 0.08727134764194489f;
  t51_n19: return 0.08624925464391708f;
  t51_n20: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t51_n22;
  t51_n21: return -0.04731930047273636f;
  t51_n22: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t51_n24;
  t51_n23: return 0.014646998606622219f;
  t51_n24: return 0.06068236753344536f;
  t51_n25: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t51_n39;
  t51_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t51_n28;
  t51_n27: return 0.02075262926518917f;
  t51_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t51_n30;
  t51_n29: return 0.06784842163324356f;
  t51_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t51_n32;
  t51_n31: return -0.09729500859975815f;
  t51_n32: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t51_n38;
  t51_n33: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t51_n37;
  t51_n34: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t51_n36;
  t51_n35: return 0.09988777339458466f;
  t51_n36: return 0.10896018892526627f;
  t51_n37: return 0.05765452980995178f;
  t51_n38: return 0.05373663082718849f;
  t51_n39: return -0.012967594899237156f;
  t51_n40: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t51_n96;
  t51_n41: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t51_n83;
  t51_n42: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t51_n82;
  t51_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t51_n53;
  t51_n44: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t51_n46;
  t51_n45: return 0.029533429071307182f;
  t51_n46: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t51_n50;
  t51_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t51_n49;
  t51_n48: return 0.09660156071186066f;
  t51_n49: return 0.08169213682413101f;
  t51_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t51_n52;
  t51_n51: return -0.12639819085597992f;
  t51_n52: return 0.07922067493200302f;
  t51_n53: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t51_n55;
  t51_n54: return -0.016608865931630135f;
  t51_n55: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t51_n81;
  t51_n56: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t51_n80;
  t51_n57: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t51_n73;
  t51_n58: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t51_n68;
  t51_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t51_n65;
  t51_n60: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t51_n62;
  t51_n61: return 0.024267712607979774f;
  t51_n62: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t51_n64;
  t51_n63: return 0.10823991149663925f;
  t51_n64: return 0.16870132088661194f;
  t51_n65: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t51_n67;
  t51_n66: return 0.08685863763093948f;
  t51_n67: return 0.06822140514850616f;
  t51_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t51_n72;
  t51_n69: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t51_n71;
  t51_n70: return 0.066021628677845f;
  t51_n71: return 0.07984019815921783f;
  t51_n72: return -0.12042003124952316f;
  t51_n73: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t51_n75;
  t51_n74: return 0.08530237525701523f;
  t51_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t51_n77;
  t51_n76: return 0.02107425220310688f;
  t51_n77: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t51_n79;
  t51_n78: return 0.08761854469776154f;
  t51_n79: return 0.17276939749717712f;
  t51_n80: return 0.14991039037704468f;
  t51_n81: return -0.04158106818795204f;
  t51_n82: return -0.1394587755203247f;
  t51_n83: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t51_n85;
  t51_n84: return 0.020540708675980568f;
  t51_n85: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t51_n95;
  t51_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t51_n88;
  t51_n87: return 0.15503810346126556f;
  t51_n88: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t51_n92;
  t51_n89: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t51_n91;
  t51_n90: return 0.1337841898202896f;
  t51_n91: return 0.10422546416521072f;
  t51_n92: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t51_n94;
  t51_n93: return 0.11333973705768585f;
  t51_n94: return 0.09107884764671326f;
  t51_n95: return 0.0985180139541626f;
  t51_n96: return -0.08237232267856598f;
  t51_n97: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t51_n99;
  t51_n98: return 0.01483225543051958f;
  t51_n99: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t51_n111;
  t51_n100: if (E.getNumReferences() >= 3322313728 /*8607.0*/) goto t51_n110;
  t51_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t51_n105;
  t51_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t51_n104;
  t51_n103: return -0.0002643891202751547f;
  t51_n104: return 0.051075488328933716f;
  t51_n105: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t51_n107;
  t51_n106: return 0.03412409871816635f;
  t51_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t51_n109;
  t51_n108: return 0.05016158148646355f;
  t51_n109: return 0.06977683305740356f;
  t51_n110: return 0.05865240842103958f;
  t51_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t51_n113;
  t51_n112: return 0.04029959812760353f;
  t51_n113: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t51_n119;
  t51_n114: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t51_n116;
  t51_n115: return 0.05640612170100212f;
  t51_n116: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t51_n118;
  t51_n117: return 0.03491213917732239f;
  t51_n118: return 0.08955834060907364f;
  t51_n119: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t51_n131;
  t51_n120: if (E.getNumReferences() >= 3286450176 /*454.5*/) goto t51_n124;
  t51_n121: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t51_n123;
  t51_n122: return 0.09029603004455566f;
  t51_n123: return 0.027315175160765648f;
  t51_n124: if (E.getNumReferences() >= 3289915392 /*608.5*/) goto t51_n130;
  t51_n125: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t51_n129;
  t51_n126: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t51_n128;
  t51_n127: return 0.090761698782444f;
  t51_n128: return 0.12894944846630096f;
  t51_n129: return 0.11572017520666122f;
  t51_n130: return 0.07422088831663132f;
  t51_n131: return 0.12760351598262787f;
  t51_n132: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t51_n144;
  t51_n133: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t51_n143;
  t51_n134: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t51_n138;
  t51_n135: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t51_n137;
  t51_n136: return 0.0041726985946297646f;
  t51_n137: return -0.047311387956142426f;
  t51_n138: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t51_n142;
  t51_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t51_n141;
  t51_n140: return -0.06445800513029099f;
  t51_n141: return 0.017773283645510674f;
  t51_n142: return -0.12040869146585464f;
  t51_n143: return -0.08488812297582626f;
  t51_n144: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t51_n146;
  t51_n145: return 0.0009405958699062467f;
  t51_n146: if (E.getNumReferences() >= 3305330688 /*2101.5*/) goto t51_n180;
  t51_n147: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t51_n153;
  t51_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t51_n150;
  t51_n149: return 0.0954778790473938f;
  t51_n150: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t51_n152;
  t51_n151: return 0.12196951359510422f;
  t51_n152: return 0.1053016260266304f;
  t51_n153: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t51_n161;
  t51_n154: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t51_n156;
  t51_n155: return 0.053942374885082245f;
  t51_n156: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t51_n158;
  t51_n157: return 0.05887967720627785f;
  t51_n158: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t51_n160;
  t51_n159: return 0.08431582897901535f;
  t51_n160: return 0.10805691033601761f;
  t51_n161: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t51_n163;
  t51_n162: return 0.05690474435687065f;
  t51_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t51_n165;
  t51_n164: return 0.09101638942956924f;
  t51_n165: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t51_n179;
  t51_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t51_n168;
  t51_n167: return 0.09666786342859268f;
  t51_n168: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t51_n178;
  t51_n169: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t51_n177;
  t51_n170: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t51_n172;
  t51_n171: return -0.23752228915691376f;
  t51_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t51_n176;
  t51_n173: if (E.getNumReferences() >= 3264610304 /*75.0*/) goto t51_n175;
  t51_n174: return -0.07282708585262299f;
  t51_n175: return 0.13471876084804535f;
  t51_n176: return 0.13607141375541687f;
  t51_n177: return 0.08723253011703491f;
  t51_n178: return 0.11431910842657089f;
  t51_n179: return 0.09049317240715027f;
  t51_n180: return 0.06194601207971573f;
  t51_n181: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t51_n211;
  t51_n182: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t51_n208;
  t51_n183: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t51_n205;
  t51_n184: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t51_n202;
  t51_n185: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t51_n201;
  t51_n186: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t51_n200;
  t51_n187: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t51_n189;
  t51_n188: return 0.026585564017295837f;
  t51_n189: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t51_n191;
  t51_n190: return 0.036901723593473434f;
  t51_n191: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t51_n199;
  t51_n192: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t51_n194;
  t51_n193: return 0.044806744903326035f;
  t51_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t51_n196;
  t51_n195: return 0.16821569204330444f;
  t51_n196: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t51_n198;
  t51_n197: return 0.10853410512208939f;
  t51_n198: return 0.025955818593502045f;
  t51_n199: return 0.050318412482738495f;
  t51_n200: return 0.045413874089717865f;
  t51_n201: return -0.006247398909181356f;
  t51_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t51_n204;
  t51_n203: return -0.24469321966171265f;
  t51_n204: return 0.02732834219932556f;
  t51_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t51_n207;
  t51_n206: return -0.08739649504423141f;
  t51_n207: return 0.028588082641363144f;
  t51_n208: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t51_n210;
  t51_n209: return 0.02335643768310547f;
  t51_n210: return 0.06940221786499023f;
  t51_n211: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t51_n239;
  t51_n212: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t51_n214;
  t51_n213: return 0.07605765014886856f;
  t51_n214: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t51_n232;
  t51_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t51_n221;
  t51_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t51_n218;
  t51_n217: return -0.011795085854828358f;
  t51_n218: if (E.getFileProximityDistance() >= 3249537024 /*22.0*/) goto t51_n220;
  t51_n219: return 0.08917725831270218f;
  t51_n220: return 0.13676831126213074f;
  t51_n221: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t51_n231;
  t51_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t51_n230;
  t51_n223: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t51_n227;
  t51_n224: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t51_n226;
  t51_n225: return 0.13366715610027313f;
  t51_n226: return -0.06363644450902939f;
  t51_n227: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t51_n229;
  t51_n228: return -0.0859861671924591f;
  t51_n229: return 0.13724838197231293f;
  t51_n230: return 0.06553714722394943f;
  t51_n231: return 0.05068916454911232f;
  t51_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t51_n236;
  t51_n233: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t51_n235;
  t51_n234: return 0.12179490178823471f;
  t51_n235: return 0.05919289216399193f;
  t51_n236: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t51_n238;
  t51_n237: return 0.11769304424524307f;
  t51_n238: return 0.08528245240449905f;
  t51_n239: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t51_n241;
  t51_n240: return 0.01918763294816017f;
  t51_n241: return 0.04876163601875305f;
  t51_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t51_n248;
  t51_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t51_n245;
  t51_n244: return 0.003121410496532917f;
  t51_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t51_n247;
  t51_n246: return 0.013019402511417866f;
  t51_n247: return 0.03146563842892647f;
  t51_n248: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t51_n252;
  t51_n249: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t51_n251;
  t51_n250: return 0.043255515396595f;
  t51_n251: return 0.06133098527789116f;
  t51_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t51_n254;
  t51_n253: return 0.09447713196277618f;
  t51_n254: return -0.05863041430711746f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree52(const Example& E) {
  t52_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t52_n248;
  t52_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t52_n229;
  t52_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t52_n122;
  t52_n3: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t52_n91;
  t52_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t52_n42;
  t52_n5: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t52_n7;
  t52_n6: return -0.028378136456012726f;
  t52_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t52_n19;
  t52_n8: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t52_n18;
  t52_n9: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t52_n15;
  t52_n10: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n12;
  t52_n11: return 0.04299920052289963f;
  t52_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t52_n14;
  t52_n13: return 0.0930233746767044f;
  t52_n14: return 0.15866044163703918f;
  t52_n15: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n17;
  t52_n16: return 0.1394285261631012f;
  t52_n17: return -0.1026780754327774f;
  t52_n18: return -0.12375067174434662f;
  t52_n19: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t52_n31;
  t52_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t52_n30;
  t52_n21: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t52_n29;
  t52_n22: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t52_n28;
  t52_n23: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t52_n27;
  t52_n24: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n26;
  t52_n25: return 0.09354108572006226f;
  t52_n26: return 0.08712858706712723f;
  t52_n27: return 0.07187109440565109f;
  t52_n28: return -0.09735995531082153f;
  t52_n29: return 0.05862484127283096f;
  t52_n30: return 0.01897485740482807f;
  t52_n31: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n39;
  t52_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t52_n34;
  t52_n33: return 0.15244701504707336f;
  t52_n34: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t52_n38;
  t52_n35: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t52_n37;
  t52_n36: return 0.1314072459936142f;
  t52_n37: return 0.10142859816551208f;
  t52_n38: return 0.10374916344881058f;
  t52_n39: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t52_n41;
  t52_n40: return 0.10275956243276596f;
  t52_n41: return 0.08674181252717972f;
  t52_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t52_n44;
  t52_n43: return -0.09604907780885696f;
  t52_n44: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t52_n78;
  t52_n45: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t52_n47;
  t52_n46: return -0.0022822695318609476f;
  t52_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t52_n77;
  t52_n48: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t52_n58;
  t52_n49: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t52_n57;
  t52_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t52_n56;
  t52_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n55;
  t52_n52: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t52_n54;
  t52_n53: return 0.021031904965639114f;
  t52_n54: return 0.05259525403380394f;
  t52_n55: return 0.0497216135263443f;
  t52_n56: return 0.0022051515989005566f;
  t52_n57: return -0.04130452871322632f;
  t52_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t52_n66;
  t52_n59: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t52_n65;
  t52_n60: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n62;
  t52_n61: return 0.03232536092400551f;
  t52_n62: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t52_n64;
  t52_n63: return -8.442633406957611e-05f;
  t52_n64: return -0.13689470291137695f;
  t52_n65: return -0.06391794234514236f;
  t52_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t52_n72;
  t52_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t52_n69;
  t52_n68: return 0.02729213796555996f;
  t52_n69: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t52_n71;
  t52_n70: return 0.08777285367250443f;
  t52_n71: return 0.03795889392495155f;
  t52_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n76;
  t52_n73: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t52_n75;
  t52_n74: return 0.11242359131574631f;
  t52_n75: return 0.10573946684598923f;
  t52_n76: return 0.058043222874403f;
  t52_n77: return 0.05399106815457344f;
  t52_n78: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t52_n90;
  t52_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t52_n83;
  t52_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n82;
  t52_n81: return -0.004594679921865463f;
  t52_n82: return -0.08119597285985947f;
  t52_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t52_n85;
  t52_n84: return 0.018645592033863068f;
  t52_n85: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t52_n87;
  t52_n86: return 0.07804474979639053f;
  t52_n87: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t52_n89;
  t52_n88: return 0.07378573715686798f;
  t52_n89: return 0.04875962808728218f;
  t52_n90: return -0.01335485465824604f;
  t52_n91: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t52_n95;
  t52_n92: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t52_n94;
  t52_n93: return 0.0134520148858428f;
  t52_n94: return 0.10304031521081924f;
  t52_n95: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t52_n105;
  t52_n96: if (E.getNumReferences() >= 3320403968 /*7467.0*/) goto t52_n104;
  t52_n97: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t52_n99;
  t52_n98: return 0.0183434896171093f;
  t52_n99: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t52_n101;
  t52_n100: return 0.03243129700422287f;
  t52_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t52_n103;
  t52_n102: return 0.04611947759985924f;
  t52_n103: return 0.06412260234355927f;
  t52_n104: return 0.05763658881187439f;
  t52_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t52_n107;
  t52_n106: return 0.04038873687386513f;
  t52_n107: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t52_n111;
  t52_n108: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t52_n110;
  t52_n109: return 0.05612390488386154f;
  t52_n110: return 0.07466696202754974f;
  t52_n111: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t52_n121;
  t52_n112: if (E.getNumReferences() >= 3286450176 /*454.5*/) goto t52_n114;
  t52_n113: return 0.07972965389490128f;
  t52_n114: if (E.getNumReferences() >= 3289915392 /*608.5*/) goto t52_n120;
  t52_n115: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t52_n119;
  t52_n116: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t52_n118;
  t52_n117: return 0.08881927281618118f;
  t52_n118: return 0.12557657063007355f;
  t52_n119: return 0.11417718231678009f;
  t52_n120: return 0.07160821557044983f;
  t52_n121: return 0.1251259297132492f;
  t52_n122: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t52_n162;
  t52_n123: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t52_n125;
  t52_n124: return -0.00792151689529419f;
  t52_n125: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t52_n127;
  t52_n126: return 0.036507006734609604f;
  t52_n127: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t52_n129;
  t52_n128: return 0.07897599786520004f;
  t52_n129: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t52_n137;
  t52_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t52_n132;
  t52_n131: return 0.09076914936304092f;
  t52_n132: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t52_n136;
  t52_n133: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t52_n135;
  t52_n134: return 0.11921140551567078f;
  t52_n135: return 0.17296388745307922f;
  t52_n136: return 0.10721610486507416f;
  t52_n137: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t52_n139;
  t52_n138: return 0.0957835465669632f;
  t52_n139: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t52_n157;
  t52_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t52_n142;
  t52_n141: return 0.07707501202821732f;
  t52_n142: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t52_n144;
  t52_n143: return 0.14610522985458374f;
  t52_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t52_n146;
  t52_n145: return 0.09277653694152832f;
  t52_n146: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t52_n154;
  t52_n147: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t52_n153;
  t52_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t52_n150;
  t52_n149: return 0.15936768054962158f;
  t52_n150: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t52_n152;
  t52_n151: return 0.17408387362957f;
  t52_n152: return 0.12924019992351532f;
  t52_n153: return 0.15099135041236877f;
  t52_n154: if (E.getNumReferences() >= 3268214784 /*102.5*/) goto t52_n156;
  t52_n155: return 0.1290314793586731f;
  t52_n156: return 0.12046767771244049f;
  t52_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t52_n159;
  t52_n158: return 0.10075583308935165f;
  t52_n159: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t52_n161;
  t52_n160: return 0.15523257851600647f;
  t52_n161: return 0.11913907527923584f;
  t52_n162: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t52_n228;
  t52_n163: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t52_n167;
  t52_n164: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t52_n166;
  t52_n165: return -0.06887055188417435f;
  t52_n166: return -0.03189649060368538f;
  t52_n167: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t52_n169;
  t52_n168: return 0.001671694335527718f;
  t52_n169: if (E.getNumReferences() >= 3326734336 /*12924.0*/) goto t52_n171;
  t52_n170: return 0.11599329859018326f;
  t52_n171: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t52_n205;
  t52_n172: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t52_n200;
  t52_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t52_n183;
  t52_n174: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t52_n176;
  t52_n175: return 0.059763625264167786f;
  t52_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t52_n178;
  t52_n177: return 0.043315060436725616f;
  t52_n178: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t52_n180;
  t52_n179: return 0.03556403890252113f;
  t52_n180: if (E.getNumReferences() >= 3331729664 /*19220.5*/) goto t52_n182;
  t52_n181: return 0.12051813304424286f;
  t52_n182: return 0.10993154346942902f;
  t52_n183: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t52_n185;
  t52_n184: return 0.08681832998991013f;
  t52_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t52_n187;
  t52_n186: return 0.06171135976910591f;
  t52_n187: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t52_n195;
  t52_n188: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t52_n194;
  t52_n189: if (E.getNumReferences() >= 3329585664 /*15708.5*/) goto t52_n191;
  t52_n190: return -0.24531316757202148f;
  t52_n191: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t52_n193;
  t52_n192: return 0.12176381796598434f;
  t52_n193: return 0.11065977066755295f;
  t52_n194: return 0.09905698895454407f;
  t52_n195: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t52_n197;
  t52_n196: return 0.10667841881513596f;
  t52_n197: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t52_n199;
  t52_n198: return 0.11309338361024857f;
  t52_n199: return 0.10824301093816757f;
  t52_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t52_n202;
  t52_n201: return -0.3290286958217621f;
  t52_n202: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t52_n204;
  t52_n203: return 0.10903338342905045f;
  t52_n204: return 0.09662605077028275f;
  t52_n205: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t52_n227;
  t52_n206: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t52_n226;
  t52_n207: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t52_n223;
  t52_n208: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t52_n210;
  t52_n209: return -0.051660675555467606f;
  t52_n210: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t52_n218;
  t52_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t52_n213;
  t52_n212: return -0.027487220242619514f;
  t52_n213: if (E.getNumReferences() >= 3348532032 /*77078.5*/) goto t52_n215;
  t52_n214: return -0.27939271926879883f;
  t52_n215: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t52_n217;
  t52_n216: return 0.09919018298387527f;
  t52_n217: return 0.08779013156890869f;
  t52_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n222;
  t52_n219: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t52_n221;
  t52_n220: return 0.10364067554473877f;
  t52_n221: return 0.055245235562324524f;
  t52_n222: return 0.1143907979130745f;
  t52_n223: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t52_n225;
  t52_n224: return 0.008769764564931393f;
  t52_n225: return 0.05349496752023697f;
  t52_n226: return 0.05436914786696434f;
  t52_n227: return 0.07662377506494522f;
  t52_n228: return 0.023646216839551926f;
  t52_n229: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t52_n243;
  t52_n230: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t52_n238;
  t52_n231: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t52_n237;
  t52_n232: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t52_n236;
  t52_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t52_n235;
  t52_n234: return -0.21049700677394867f;
  t52_n235: return 0.02030525915324688f;
  t52_n236: return 0.026184551417827606f;
  t52_n237: return -0.043974585831165314f;
  t52_n238: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t52_n242;
  t52_n239: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t52_n241;
  t52_n240: return -0.012704744935035706f;
  t52_n241: return 0.03869209811091423f;
  t52_n242: return 0.0461750254034996f;
  t52_n243: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t52_n245;
  t52_n244: return 0.05303353816270828f;
  t52_n245: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t52_n247;
  t52_n246: return 0.018993176519870758f;
  t52_n247: return 0.04736955463886261f;
  t52_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t52_n254;
  t52_n249: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t52_n253;
  t52_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t52_n252;
  t52_n251: return -0.010401153936982155f;
  t52_n252: return 0.011326550506055355f;
  t52_n253: return 0.03763800114393234f;
  t52_n254: return 0.04616343230009079f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree53(const Example& E) {
  t53_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t53_n244;
  t53_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t53_n187;
  t53_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t53_n112;
  t53_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t53_n23;
  t53_n4: if (E.getNumReferences() >= 3307976704 /*2747.5*/) goto t53_n16;
  t53_n5: if (E.getFileProximityDistance() >= 3254910976 /*32.5*/) goto t53_n7;
  t53_n6: return -0.06692574173212051f;
  t53_n7: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t53_n9;
  t53_n8: return 0.02192174643278122f;
  t53_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t53_n11;
  t53_n10: return -0.09703777730464935f;
  t53_n11: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t53_n15;
  t53_n12: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t53_n14;
  t53_n13: return 0.13158933818340302f;
  t53_n14: return 0.097732774913311f;
  t53_n15: return -0.0797831192612648f;
  t53_n16: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t53_n22;
  t53_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n19;
  t53_n18: return 0.013686539605259895f;
  t53_n19: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t53_n21;
  t53_n20: return 0.06078856810927391f;
  t53_n21: return 0.08992575109004974f;
  t53_n22: return -0.13666671514511108f;
  t53_n23: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t53_n103;
  t53_n24: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t53_n50;
  t53_n25: if (E.getNumReferences() >= 3354001600 /*119809.5*/) goto t53_n29;
  t53_n26: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t53_n28;
  t53_n27: return -0.0014712034026160836f;
  t53_n28: return 0.037848252803087234f;
  t53_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n31;
  t53_n30: return 0.12655532360076904f;
  t53_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t53_n33;
  t53_n32: return -0.09044033288955688f;
  t53_n33: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t53_n49;
  t53_n34: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t53_n38;
  t53_n35: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t53_n37;
  t53_n36: return 0.05742073804140091f;
  t53_n37: return 0.12563742697238922f;
  t53_n38: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t53_n46;
  t53_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t53_n41;
  t53_n40: return 0.0811174139380455f;
  t53_n41: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t53_n45;
  t53_n42: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t53_n44;
  t53_n43: return 0.12142620980739594f;
  t53_n44: return 0.11233923584222794f;
  t53_n45: return 0.09406829625368118f;
  t53_n46: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t53_n48;
  t53_n47: return 0.12586012482643127f;
  t53_n48: return 0.04237079620361328f;
  t53_n49: return 0.08632025867700577f;
  t53_n50: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t53_n52;
  t53_n51: return -0.04071420803666115f;
  t53_n52: if (E.getNumReferences() >= 3316514816 /*5568.0*/) goto t53_n74;
  t53_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t53_n57;
  t53_n54: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t53_n56;
  t53_n55: return -0.06430169939994812f;
  t53_n56: return 0.03644204139709473f;
  t53_n57: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t53_n59;
  t53_n58: return 0.031398478895425797f;
  t53_n59: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t53_n61;
  t53_n60: return 0.06437842547893524f;
  t53_n61: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t53_n73;
  t53_n62: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t53_n64;
  t53_n63: return 0.08309860527515411f;
  t53_n64: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t53_n66;
  t53_n65: return -0.10762985050678253f;
  t53_n66: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t53_n72;
  t53_n67: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t53_n71;
  t53_n68: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t53_n70;
  t53_n69: return 0.11262725293636322f;
  t53_n70: return 0.08936849981546402f;
  t53_n71: return 0.1090352013707161f;
  t53_n72: return 0.11696723848581314f;
  t53_n73: return 0.06583115458488464f;
  t53_n74: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t53_n88;
  t53_n75: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t53_n87;
  t53_n76: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n78;
  t53_n77: return -0.10250687599182129f;
  t53_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t53_n84;
  t53_n79: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t53_n83;
  t53_n80: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t53_n82;
  t53_n81: return 0.13286982476711273f;
  t53_n82: return 0.1034792810678482f;
  t53_n83: return -0.08452804386615753f;
  t53_n84: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t53_n86;
  t53_n85: return 0.11501934379339218f;
  t53_n86: return 0.11322396248579025f;
  t53_n87: return 0.09190214425325394f;
  t53_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t53_n90;
  t53_n89: return -0.2039903849363327f;
  t53_n90: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t53_n94;
  t53_n91: if (E.getNumReferences() >= 3338441472 /*32329.5*/) goto t53_n93;
  t53_n92: return 0.04225044697523117f;
  t53_n93: return 0.08674310147762299f;
  t53_n94: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t53_n102;
  t53_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t53_n97;
  t53_n96: return -0.007449064403772354f;
  t53_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t53_n101;
  t53_n98: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t53_n100;
  t53_n99: return 0.11082323640584946f;
  t53_n100: return 0.14386503398418427f;
  t53_n101: return -0.056547582149505615f;
  t53_n102: return 0.10661908984184265f;
  t53_n103: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t53_n105;
  t53_n104: return 0.009446686133742332f;
  t53_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t53_n107;
  t53_n106: return -0.25866755843162537f;
  t53_n107: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t53_n111;
  t53_n108: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t53_n110;
  t53_n109: return 0.10450591892004013f;
  t53_n110: return 0.05755152925848961f;
  t53_n111: return -0.13234569132328033f;
  t53_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t53_n114;
  t53_n113: return -0.009445993229746819f;
  t53_n114: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t53_n182;
  t53_n115: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t53_n179;
  t53_n116: if (E.getNumReferences() >= 3347329664 /*67685.0*/) goto t53_n150;
  t53_n117: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t53_n131;
  t53_n118: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n120;
  t53_n119: return 0.003395016072317958f;
  t53_n120: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t53_n128;
  t53_n121: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t53_n127;
  t53_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Type))) goto t53_n124;
  t53_n123: return 0.016081025823950768f;
  t53_n124: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t53_n126;
  t53_n125: return 0.06157607212662697f;
  t53_n126: return 0.024039238691329956f;
  t53_n127: return 0.021717360243201256f;
  t53_n128: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t53_n130;
  t53_n129: return 0.05465981736779213f;
  t53_n130: return 0.08713045716285706f;
  t53_n131: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t53_n149;
  t53_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t53_n134;
  t53_n133: return 0.010135279037058353f;
  t53_n134: if (E.getFileProximityDistance() >= 3254517760 /*31.5*/) goto t53_n138;
  t53_n135: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t53_n137;
  t53_n136: return 0.01489149872213602f;
  t53_n137: return 0.04482150077819824f;
  t53_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t53_n140;
  t53_n139: return 0.04232081398367882f;
  t53_n140: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t53_n148;
  t53_n141: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t53_n147;
  t53_n142: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t53_n146;
  t53_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t53_n145;
  t53_n144: return 0.07775154709815979f;
  t53_n145: return 0.003860082710161805f;
  t53_n146: return 0.06951897591352463f;
  t53_n147: return -0.06286740303039551f;
  t53_n148: return -0.16438767313957214f;
  t53_n149: return -0.14647820591926575f;
  t53_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n154;
  t53_n151: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t53_n153;
  t53_n152: return 0.03862074017524719f;
  t53_n153: return -0.04423801228404045f;
  t53_n154: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t53_n168;
  t53_n155: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t53_n163;
  t53_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t53_n158;
  t53_n157: return 0.062373485416173935f;
  t53_n158: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t53_n160;
  t53_n159: return 0.04269137606024742f;
  t53_n160: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t53_n162;
  t53_n161: return 0.1063528060913086f;
  t53_n162: return 0.13821353018283844f;
  t53_n163: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t53_n165;
  t53_n164: return 0.07379163056612015f;
  t53_n165: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t53_n167;
  t53_n166: return 0.12141172587871552f;
  t53_n167: return 0.07001359760761261f;
  t53_n168: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t53_n170;
  t53_n169: return -0.14040598273277283f;
  t53_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t53_n178;
  t53_n171: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t53_n173;
  t53_n172: return -0.3227871060371399f;
  t53_n173: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t53_n177;
  t53_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t53_n176;
  t53_n175: return 0.0726749524474144f;
  t53_n176: return 0.11593247950077057f;
  t53_n177: return 0.022665346041321754f;
  t53_n178: return 0.03759416937828064f;
  t53_n179: if (E.getNumReferences() >= 3354069824 /*120342.5*/) goto t53_n181;
  t53_n180: return -0.04313991591334343f;
  t53_n181: return -0.13889269530773163f;
  t53_n182: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t53_n186;
  t53_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t53_n185;
  t53_n184: return 0.06335221230983734f;
  t53_n185: return -0.006355036050081253f;
  t53_n186: return 0.02067609876394272f;
  t53_n187: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t53_n221;
  t53_n188: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t53_n212;
  t53_n189: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t53_n207;
  t53_n190: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t53_n200;
  t53_n191: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t53_n199;
  t53_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t53_n194;
  t53_n193: return 0.023319916799664497f;
  t53_n194: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t53_n198;
  t53_n195: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n197;
  t53_n196: return 0.0457376167178154f;
  t53_n197: return 0.07033480703830719f;
  t53_n198: return 0.02188863232731819f;
  t53_n199: return -0.038320038467645645f;
  t53_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t53_n202;
  t53_n201: return 0.017372701317071915f;
  t53_n202: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t53_n204;
  t53_n203: return 0.01818196102976799f;
  t53_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t53_n206;
  t53_n205: return 0.03508342429995537f;
  t53_n206: return 0.07924194633960724f;
  t53_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t53_n209;
  t53_n208: return -0.08599089831113815f;
  t53_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n211;
  t53_n210: return -0.010396979749202728f;
  t53_n211: return 0.054484471678733826f;
  t53_n212: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t53_n220;
  t53_n213: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t53_n219;
  t53_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t53_n218;
  t53_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t53_n217;
  t53_n216: return -0.024118565022945404f;
  t53_n217: return 0.06975599378347397f;
  t53_n218: return 0.0319049209356308f;
  t53_n219: return 0.04393422231078148f;
  t53_n220: return 0.06724686920642853f;
  t53_n221: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t53_n235;
  t53_n222: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t53_n224;
  t53_n223: return 0.06506972759962082f;
  t53_n224: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t53_n226;
  t53_n225: return 0.020453866571187973f;
  t53_n226: if (E.getNumReferences() >= 3318682624 /*6626.5*/) goto t53_n234;
  t53_n227: if (E.getNumReferences() >= 3318517760 /*6546.0*/) goto t53_n231;
  t53_n228: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t53_n230;
  t53_n229: return 0.12461809813976288f;
  t53_n230: return -0.11714226752519608f;
  t53_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t53_n233;
  t53_n232: return 0.11134513467550278f;
  t53_n233: return 0.10123241692781448f;
  t53_n234: return 0.05584186315536499f;
  t53_n235: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t53_n243;
  t53_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n240;
  t53_n237: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t53_n239;
  t53_n238: return 0.11295196413993835f;
  t53_n239: return -0.1546712964773178f;
  t53_n240: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t53_n242;
  t53_n241: return 0.010489128530025482f;
  t53_n242: return 0.06585469096899033f;
  t53_n243: return 0.05750352516770363f;
  t53_n244: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t53_n250;
  t53_n245: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t53_n249;
  t53_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t53_n248;
  t53_n247: return -0.012059112079441547f;
  t53_n248: return 0.009939678013324738f;
  t53_n249: return 0.03632717579603195f;
  t53_n250: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t53_n254;
  t53_n251: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t53_n253;
  t53_n252: return 0.04098358750343323f;
  t53_n253: return 0.058229777961969376f;
  t53_n254: return -0.7989847660064697f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree54(const Example& E) {
  t54_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t54_n248;
  t54_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t54_n165;
  t54_n2: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t54_n134;
  t54_n3: if (E.getNumReferences() >= 3304886272 /*2020.5*/) goto t54_n43;
  t54_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t54_n40;
  t54_n5: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t54_n27;
  t54_n6: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t54_n8;
  t54_n7: return -0.004043603781610727f;
  t54_n8: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t54_n10;
  t54_n9: return 0.03234751150012016f;
  t54_n10: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t54_n12;
  t54_n11: return 0.038089025765657425f;
  t54_n12: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t54_n14;
  t54_n13: return 0.07774387300014496f;
  t54_n14: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t54_n16;
  t54_n15: return 0.0919678583741188f;
  t54_n16: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t54_n18;
  t54_n17: return 0.09092561155557632f;
  t54_n18: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t54_n20;
  t54_n19: return 0.12867088615894318f;
  t54_n20: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t54_n26;
  t54_n21: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t54_n25;
  t54_n22: if (E.getNumReferences() >= 3271426048 /*127.0*/) goto t54_n24;
  t54_n23: return 0.03943594917654991f;
  t54_n24: return 0.12672226130962372f;
  t54_n25: return 0.10372014343738556f;
  t54_n26: return -0.1632649451494217f;
  t54_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t54_n29;
  t54_n28: return -0.04482576996088028f;
  t54_n29: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t54_n31;
  t54_n30: return -0.03810261934995651f;
  t54_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t54_n33;
  t54_n32: return -0.033190369606018066f;
  t54_n33: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t54_n39;
  t54_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t54_n36;
  t54_n35: return 0.05901749059557915f;
  t54_n36: if (E.getNumReferences() >= 3296428032 /*1006.0*/) goto t54_n38;
  t54_n37: return 0.011628005653619766f;
  t54_n38: return 0.09428676217794418f;
  t54_n39: return -0.1359575390815735f;
  t54_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t54_n42;
  t54_n41: return 0.01621297001838684f;
  t54_n42: return 0.08895114064216614f;
  t54_n43: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t54_n49;
  t54_n44: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t54_n48;
  t54_n45: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t54_n47;
  t54_n46: return 0.017338335514068604f;
  t54_n47: return 0.05569792911410332f;
  t54_n48: return -0.013615616597235203f;
  t54_n49: if (E.getNumReferences() >= 3316521984 /*5571.5*/) goto t54_n51;
  t54_n50: return 0.027042511850595474f;
  t54_n51: if (E.getNumReferences() >= 3334350336 /*24339.0*/) goto t54_n133;
  t54_n52: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t54_n74;
  t54_n53: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t54_n57;
  t54_n54: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t54_n56;
  t54_n55: return 0.056389741599559784f;
  t54_n56: return 0.09335660934448242f;
  t54_n57: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t54_n59;
  t54_n58: return 0.12458930909633636f;
  t54_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t54_n65;
  t54_n60: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t54_n62;
  t54_n61: return 0.05149953067302704f;
  t54_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t54_n64;
  t54_n63: return 0.06878671795129776f;
  t54_n64: return 0.10778716206550598f;
  t54_n65: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t54_n71;
  t54_n66: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t54_n70;
  t54_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t54_n69;
  t54_n68: return 0.1236315593123436f;
  t54_n69: return 0.11038236320018768f;
  t54_n70: return -0.10365977883338928f;
  t54_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t54_n73;
  t54_n72: return 0.07902926951646805f;
  t54_n73: return 0.11290470510721207f;
  t54_n74: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t54_n76;
  t54_n75: return 0.05539710819721222f;
  t54_n76: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t54_n116;
  t54_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t54_n79;
  t54_n78: return 0.013714050874114037f;
  t54_n79: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t54_n81;
  t54_n80: return 0.06895851343870163f;
  t54_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t54_n111;
  t54_n82: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t54_n84;
  t54_n83: return 0.07479062676429749f;
  t54_n84: if (E.getNumReferences() >= 3319414784 /*6984.0*/) goto t54_n86;
  t54_n85: return 0.09149014949798584f;
  t54_n86: if (E.getNumReferences() >= 3319705600 /*7126.0*/) goto t54_n90;
  t54_n87: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t54_n89;
  t54_n88: return 0.10933281481266022f;
  t54_n89: return 0.09403278678655624f;
  t54_n90: if (E.getNumReferences() >= 3325492736 /*11711.5*/) goto t54_n110;
  t54_n91: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t54_n107;
  t54_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t54_n94;
  t54_n93: return 0.09071861952543259f;
  t54_n94: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t54_n102;
  t54_n95: if (E.getNumReferences() >= 3320114176 /*7325.5*/) goto t54_n97;
  t54_n96: return 0.11647003144025803f;
  t54_n97: if (E.getNumReferences() >= 3321433088 /*7969.5*/) goto t54_n99;
  t54_n98: return 0.05781690031290054f;
  t54_n99: if (E.getNumReferences() >= 3322399744 /*8691.0*/) goto t54_n101;
  t54_n100: return 0.11537521332502365f;
  t54_n101: return 0.11342838406562805f;
  t54_n102: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t54_n104;
  t54_n103: return 0.07361665368080139f;
  t54_n104: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t54_n106;
  t54_n105: return -0.254279226064682f;
  t54_n106: return 0.11887724697589874f;
  t54_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t54_n109;
  t54_n108: return 0.11461954563856125f;
  t54_n109: return 0.09359626471996307f;
  t54_n110: return 0.07602909207344055f;
  t54_n111: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t54_n115;
  t54_n112: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t54_n114;
  t54_n113: return 0.10421483963727951f;
  t54_n114: return 0.10658140480518341f;
  t54_n115: return 0.09166561812162399f;
  t54_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t54_n130;
  t54_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t54_n123;
  t54_n118: if (E.getNumReferences() >= 3323042816 /*9319.0*/) goto t54_n120;
  t54_n119: return 0.06294715404510498f;
  t54_n120: if (E.getNumReferences() >= 3323761664 /*10021.0*/) goto t54_n122;
  t54_n121: return 0.10628610104322433f;
  t54_n122: return 0.09417130798101425f;
  t54_n123: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t54_n129;
  t54_n124: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t54_n128;
  t54_n125: if (E.getNumReferences() >= 3325171712 /*11398.0*/) goto t54_n127;
  t54_n126: return 0.10144303739070892f;
  t54_n127: return 0.10770926624536514f;
  t54_n128: return 0.10549898445606232f;
  t54_n129: return 0.09716591238975525f;
  t54_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t54_n132;
  t54_n131: return 0.07972411066293716f;
  t54_n132: return 0.11280640214681625f;
  t54_n133: return 0.01947798766195774f;
  t54_n134: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t54_n162;
  t54_n135: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t54_n137;
  t54_n136: return 0.02121984027326107f;
  t54_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t54_n141;
  t54_n138: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t54_n140;
  t54_n139: return 0.02530048042535782f;
  t54_n140: return -0.11290370672941208f;
  t54_n141: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t54_n155;
  t54_n142: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t54_n148;
  t54_n143: if (E.getNumReferences() >= 3318422528 /*6499.5*/) goto t54_n147;
  t54_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t54_n146;
  t54_n145: return -0.05302947759628296f;
  t54_n146: return 0.04115046188235283f;
  t54_n147: return -0.20506104826927185f;
  t54_n148: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t54_n154;
  t54_n149: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t54_n151;
  t54_n150: return 0.08383271098136902f;
  t54_n151: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t54_n153;
  t54_n152: return 0.1201913133263588f;
  t54_n153: return 0.055800314992666245f;
  t54_n154: return 0.02745695970952511f;
  t54_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t54_n157;
  t54_n156: return 0.05987654998898506f;
  t54_n157: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t54_n161;
  t54_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t54_n160;
  t54_n159: return 0.10629049688577652f;
  t54_n160: return 0.10792804509401321f;
  t54_n161: return 0.03826398402452469f;
  t54_n162: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t54_n164;
  t54_n163: return -0.05362619459629059f;
  t54_n164: return 0.048034414649009705f;
  t54_n165: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t54_n235;
  t54_n166: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t54_n170;
  t54_n167: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t54_n169;
  t54_n168: return 0.012989888899028301f;
  t54_n169: return -0.002927703084424138f;
  t54_n170: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t54_n184;
  t54_n171: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t54_n183;
  t54_n172: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t54_n178;
  t54_n173: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t54_n175;
  t54_n174: return 0.04598940908908844f;
  t54_n175: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t54_n177;
  t54_n176: return 0.1123078241944313f;
  t54_n177: return -0.10423526167869568f;
  t54_n178: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t54_n182;
  t54_n179: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t54_n181;
  t54_n180: return -0.02053767256438732f;
  t54_n181: return 0.09131718426942825f;
  t54_n182: return 0.1321694701910019f;
  t54_n183: return 0.017220662906765938f;
  t54_n184: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t54_n190;
  t54_n185: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t54_n187;
  t54_n186: return 0.07465335726737976f;
  t54_n187: if (E.getNumReferences() >= 3289849856 /*604.5*/) goto t54_n189;
  t54_n188: return 0.11337003856897354f;
  t54_n189: return 0.0679202601313591f;
  t54_n190: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t54_n230;
  t54_n191: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t54_n193;
  t54_n192: return 0.039669204503297806f;
  t54_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t54_n215;
  t54_n194: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t54_n208;
  t54_n195: if (E.getNumReferences() >= 3274080256 /*166.5*/) goto t54_n197;
  t54_n196: return 0.09174210578203201f;
  t54_n197: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t54_n199;
  t54_n198: return 0.0710831955075264f;
  t54_n199: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t54_n207;
  t54_n200: if (E.getNumReferences() >= 3289341952 /*573.5*/) goto t54_n206;
  t54_n201: if (E.getNumReferences() >= 3288743936 /*537.0*/) goto t54_n205;
  t54_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t54_n204;
  t54_n203: return 0.11670421063899994f;
  t54_n204: return 0.11991678178310394f;
  t54_n205: return 0.11956088244915009f;
  t54_n206: return 0.07784068584442139f;
  t54_n207: return 0.0846572071313858f;
  t54_n208: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t54_n214;
  t54_n209: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t54_n213;
  t54_n210: if (E.getFilterLength() >= 3247177728 /*17.5*/) goto t54_n212;
  t54_n211: return -0.14544430375099182f;
  t54_n212: return 0.13894224166870117f;
  t54_n213: return 0.16630621254444122f;
  t54_n214: return 0.10274066030979156f;
  t54_n215: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t54_n217;
  t54_n216: return 0.12040441483259201f;
  t54_n217: if (E.getNumReferences() >= 3277488128 /*218.5*/) goto t54_n219;
  t54_n218: return 0.06486739963293076f;
  t54_n219: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t54_n227;
  t54_n220: if (E.getNumReferences() >= 3278733312 /*237.5*/) goto t54_n224;
  t54_n221: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t54_n223;
  t54_n222: return 0.10981435328722f;
  t54_n223: return 0.11789770424365997f;
  t54_n224: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t54_n226;
  t54_n225: return 0.0020303400233387947f;
  t54_n226: return 0.09185721725225449f;
  t54_n227: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t54_n229;
  t54_n228: return 0.13049019873142242f;
  t54_n229: return -0.3266313076019287f;
  t54_n230: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t54_n234;
  t54_n231: if (E.getNumReferences() >= 3260153856 /*52.5*/) goto t54_n233;
  t54_n232: return 0.09925307333469391f;
  t54_n233: return 0.1834123134613037f;
  t54_n234: return 0.09052475541830063f;
  t54_n235: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t54_n243;
  t54_n236: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t54_n238;
  t54_n237: return 0.03828210011124611f;
  t54_n238: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t54_n240;
  t54_n239: return 0.0029668547213077545f;
  t54_n240: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t54_n242;
  t54_n241: return -0.9418485164642334f;
  t54_n242: return 0.02741936780512333f;
  t54_n243: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t54_n247;
  t54_n244: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t54_n246;
  t54_n245: return 0.08478087931871414f;
  t54_n246: return 0.06191844493150711f;
  t54_n247: return 0.041287846863269806f;
  t54_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t54_n254;
  t54_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t54_n251;
  t54_n250: return 0.0016432598931714892f;
  t54_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t54_n253;
  t54_n252: return 0.009760385379195213f;
  t54_n253: return 0.028340382501482964f;
  t54_n254: return 0.04236803203821182f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree55(const Example& E) {
  t55_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t55_n244;
  t55_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t55_n209;
  t55_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t55_n94;
  t55_n3: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t55_n53;
  t55_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t55_n52;
  t55_n5: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t55_n13;
  t55_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t55_n8;
  t55_n7: return -0.02618253417313099f;
  t55_n8: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t55_n10;
  t55_n9: return -0.043867286294698715f;
  t55_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t55_n12;
  t55_n11: return -0.30092155933380127f;
  t55_n12: return 0.022116094827651978f;
  t55_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t55_n31;
  t55_n14: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t55_n30;
  t55_n15: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t55_n27;
  t55_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t55_n18;
  t55_n17: return 0.047979604452848434f;
  t55_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t55_n20;
  t55_n19: return 0.0625975951552391f;
  t55_n20: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t55_n26;
  t55_n21: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t55_n23;
  t55_n22: return 0.20342470705509186f;
  t55_n23: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t55_n25;
  t55_n24: return 0.16038107872009277f;
  t55_n25: return 0.10314429551362991f;
  t55_n26: return 0.10631828010082245f;
  t55_n27: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t55_n29;
  t55_n28: return 0.13000018894672394f;
  t55_n29: return -0.10304326564073563f;
  t55_n30: return -0.12002936750650406f;
  t55_n31: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t55_n39;
  t55_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t55_n38;
  t55_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t55_n37;
  t55_n34: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t55_n36;
  t55_n35: return 0.07772191613912582f;
  t55_n36: return -0.07995694875717163f;
  t55_n37: return 0.0480717271566391f;
  t55_n38: return 0.005483776330947876f;
  t55_n39: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t55_n49;
  t55_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t55_n42;
  t55_n41: return 0.1382446438074112f;
  t55_n42: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t55_n48;
  t55_n43: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t55_n45;
  t55_n44: return 0.12904059886932373f;
  t55_n45: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t55_n47;
  t55_n46: return 0.1315823644399643f;
  t55_n47: return 0.11529511958360672f;
  t55_n48: return 0.10232257843017578f;
  t55_n49: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t55_n51;
  t55_n50: return 0.10088439285755157f;
  t55_n51: return 0.08303450793027878f;
  t55_n52: return 0.0040911114774644375f;
  t55_n53: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t55_n55;
  t55_n54: return 0.01186628919094801f;
  t55_n55: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t55_n79;
  t55_n56: if (E.getNumReferences() >= 3320403968 /*7467.0*/) goto t55_n78;
  t55_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t55_n61;
  t55_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t55_n60;
  t55_n59: return 0.014144793152809143f;
  t55_n60: return 0.08714856207370758f;
  t55_n61: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t55_n63;
  t55_n62: return 0.028210405260324478f;
  t55_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t55_n77;
  t55_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t55_n66;
  t55_n65: return 0.03799925744533539f;
  t55_n66: if (E.getNumReferences() >= 3301523456 /*1610.0*/) goto t55_n74;
  t55_n67: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t55_n69;
  t55_n68: return 0.029009219259023666f;
  t55_n69: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t55_n71;
  t55_n70: return 0.08809152990579605f;
  t55_n71: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t55_n73;
  t55_n72: return 0.12699681520462036f;
  t55_n73: return 0.24628785252571106f;
  t55_n74: if (E.getNumReferences() >= 3303129088 /*1806.0*/) goto t55_n76;
  t55_n75: return 0.11470681428909302f;
  t55_n76: return 0.10216522216796875f;
  t55_n77: return 0.05903928354382515f;
  t55_n78: return 0.05295789986848831f;
  t55_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t55_n81;
  t55_n80: return 0.03655308857560158f;
  t55_n81: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t55_n83;
  t55_n82: return 0.055298812687397f;
  t55_n83: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t55_n93;
  t55_n84: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t55_n92;
  t55_n85: if (E.getNumReferences() >= 3286450176 /*454.5*/) goto t55_n87;
  t55_n86: return 0.0824919044971466f;
  t55_n87: if (E.getNumReferences() >= 3289686016 /*594.5*/) goto t55_n91;
  t55_n88: if (E.getNumReferences() >= 3289554944 /*586.5*/) goto t55_n90;
  t55_n89: return 0.10703763365745544f;
  t55_n90: return 0.1102779358625412f;
  t55_n91: return 0.08188609778881073f;
  t55_n92: return 0.019277848303318024f;
  t55_n93: return 0.12387661635875702f;
  t55_n94: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t55_n136;
  t55_n95: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t55_n97;
  t55_n96: return -0.007465111091732979f;
  t55_n97: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t55_n99;
  t55_n98: return 0.03471221402287483f;
  t55_n99: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t55_n115;
  t55_n100: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t55_n102;
  t55_n101: return 0.07116418331861496f;
  t55_n102: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t55_n104;
  t55_n103: return 0.08153471350669861f;
  t55_n104: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t55_n110;
  t55_n105: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t55_n109;
  t55_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t55_n108;
  t55_n107: return -0.12243428081274033f;
  t55_n108: return 0.15306301414966583f;
  t55_n109: return -0.12565480172634125f;
  t55_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t55_n112;
  t55_n111: return 0.0803140178322792f;
  t55_n112: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t55_n114;
  t55_n113: return -0.10223569720983505f;
  t55_n114: return 0.15618360042572021f;
  t55_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t55_n117;
  t55_n116: return 0.09212552756071091f;
  t55_n117: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t55_n125;
  t55_n118: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t55_n124;
  t55_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t55_n121;
  t55_n120: return 0.13975657522678375f;
  t55_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t55_n123;
  t55_n122: return -0.2999022603034973f;
  t55_n123: return 0.1165139228105545f;
  t55_n124: return 0.10321028530597687f;
  t55_n125: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t55_n127;
  t55_n126: return 0.09810017794370651f;
  t55_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t55_n129;
  t55_n128: return 0.07189474254846573f;
  t55_n129: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t55_n131;
  t55_n130: return 0.16269803047180176f;
  t55_n131: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t55_n135;
  t55_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t55_n134;
  t55_n133: return 0.11665543913841248f;
  t55_n134: return 0.12334485352039337f;
  t55_n135: return 0.0979657769203186f;
  t55_n136: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t55_n206;
  t55_n137: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t55_n139;
  t55_n138: return -0.046585921198129654f;
  t55_n139: if (E.getNumReferences() >= 3283271680 /*357.5*/) goto t55_n161;
  t55_n140: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t55_n158;
  t55_n141: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t55_n157;
  t55_n142: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t55_n144;
  t55_n143: return -0.01385625172406435f;
  t55_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t55_n146;
  t55_n145: return 0.02649054490029812f;
  t55_n146: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t55_n156;
  t55_n147: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t55_n155;
  t55_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t55_n150;
  t55_n149: return 0.07210898399353027f;
  t55_n150: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t55_n152;
  t55_n151: return 0.0030792062170803547f;
  t55_n152: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t55_n154;
  t55_n153: return 0.10227359086275101f;
  t55_n154: return 0.03800854831933975f;
  t55_n155: return -0.042414698749780655f;
  t55_n156: return -0.016151169314980507f;
  t55_n157: return -0.0828913152217865f;
  t55_n158: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t55_n160;
  t55_n159: return -0.06845709681510925f;
  t55_n160: return 0.09075707197189331f;
  t55_n161: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t55_n195;
  t55_n162: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t55_n164;
  t55_n163: return -0.005301549099385738f;
  t55_n164: if (E.getNumReferences() >= 3316905984 /*5759.0*/) goto t55_n166;
  t55_n165: return 0.01489268895238638f;
  t55_n166: if (E.getNumReferences() >= 3316937728 /*5774.5*/) goto t55_n170;
  t55_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t55_n169;
  t55_n168: return -0.11037790030241013f;
  t55_n169: return 0.11421182006597519f;
  t55_n170: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t55_n178;
  t55_n171: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t55_n177;
  t55_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t55_n176;
  t55_n173: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t55_n175;
  t55_n174: return -0.332120418548584f;
  t55_n175: return -0.007095750421285629f;
  t55_n176: return 0.04365735501050949f;
  t55_n177: return 0.050327517092227936f;
  t55_n178: if (E.getNumReferences() >= 3329839104 /*15956.0*/) goto t55_n180;
  t55_n179: return 0.07464227080345154f;
  t55_n180: if (E.getNumReferences() >= 3333808640 /*23281.0*/) goto t55_n194;
  t55_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t55_n185;
  t55_n182: if (E.getNumReferences() >= 3329918464 /*16033.5*/) goto t55_n184;
  t55_n183: return 0.11969279497861862f;
  t55_n184: return 0.09910733252763748f;
  t55_n185: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t55_n191;
  t55_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t55_n188;
  t55_n187: return 0.0650075152516365f;
  t55_n188: if (E.getNumReferences() >= 3331962112 /*19674.5*/) goto t55_n190;
  t55_n189: return 0.09397447854280472f;
  t55_n190: return 0.1042194589972496f;
  t55_n191: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t55_n193;
  t55_n192: return 0.05667433515191078f;
  t55_n193: return 0.11759112030267715f;
  t55_n194: return 0.048473961651325226f;
  t55_n195: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t55_n199;
  t55_n196: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t55_n198;
  t55_n197: return 0.043594617396593094f;
  t55_n198: return 0.07330428063869476f;
  t55_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Expression))) goto t55_n201;
  t55_n200: return 0.054445549845695496f;
  t55_n201: if (E.getNumReferences() >= 3283501056 /*364.5*/) goto t55_n205;
  t55_n202: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t55_n204;
  t55_n203: return -0.10439988970756531f;
  t55_n204: return 0.12940481305122375f;
  t55_n205: return 0.08461374789476395f;
  t55_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t55_n208;
  t55_n207: return -0.10716474801301956f;
  t55_n208: return 0.02313307859003544f;
  t55_n209: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t55_n225;
  t55_n210: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t55_n222;
  t55_n211: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t55_n219;
  t55_n212: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t55_n214;
  t55_n213: return 0.017272360622882843f;
  t55_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t55_n216;
  t55_n215: return 0.015551174990832806f;
  t55_n216: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t55_n218;
  t55_n217: return 0.0014325595693662763f;
  t55_n218: return 0.056890860199928284f;
  t55_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t55_n221;
  t55_n220: return -0.08382689952850342f;
  t55_n221: return 0.0314466767013073f;
  t55_n222: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t55_n224;
  t55_n223: return 0.028685329481959343f;
  t55_n224: return -0.07331707328557968f;
  t55_n225: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t55_n227;
  t55_n226: return 0.04606683924794197f;
  t55_n227: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t55_n229;
  t55_n228: return 0.004946296568959951f;
  t55_n229: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t55_n231;
  t55_n230: return -0.003083112183958292f;
  t55_n231: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t55_n243;
  t55_n232: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t55_n234;
  t55_n233: return -0.04841690510511398f;
  t55_n234: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t55_n240;
  t55_n235: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t55_n237;
  t55_n236: return 0.08375070244073868f;
  t55_n237: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t55_n239;
  t55_n238: return 0.06983144581317902f;
  t55_n239: return 0.1344091147184372f;
  t55_n240: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t55_n242;
  t55_n241: return 0.12260536104440689f;
  t55_n242: return 0.14644229412078857f;
  t55_n243: return 0.05417695268988609f;
  t55_n244: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t55_n250;
  t55_n245: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t55_n249;
  t55_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t55_n248;
  t55_n247: return -0.013725814409554005f;
  t55_n248: return 0.008792513981461525f;
  t55_n249: return 0.03315022587776184f;
  t55_n250: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t55_n252;
  t55_n251: return 0.040615327656269073f;
  t55_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t55_n254;
  t55_n253: return 0.09258484840393066f;
  t55_n254: return -0.06301511824131012f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree56(const Example& E) {
  t56_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t56_n246;
  t56_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t56_n117;
  t56_n2: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t56_n36;
  t56_n3: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t56_n5;
  t56_n4: return -0.028395865112543106f;
  t56_n5: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t56_n19;
  t56_n6: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t56_n18;
  t56_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t56_n9;
  t56_n8: return 0.01715143583714962f;
  t56_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t56_n17;
  t56_n10: if (E.getNumReferences() >= 3317558272 /*6077.5*/) goto t56_n14;
  t56_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t56_n13;
  t56_n12: return 0.010789885185658932f;
  t56_n13: return 0.045269742608070374f;
  t56_n14: if (E.getNumReferences() >= 3317673984 /*6134.0*/) goto t56_n16;
  t56_n15: return 0.1208549439907074f;
  t56_n16: return 0.05191534757614136f;
  t56_n17: return 0.06462010741233826f;
  t56_n18: return -0.005505191162228584f;
  t56_n19: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t56_n35;
  t56_n20: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t56_n22;
  t56_n21: return 0.09102446585893631f;
  t56_n22: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t56_n24;
  t56_n23: return 0.07866226136684418f;
  t56_n24: if (E.getNumReferences() >= 3268149248 /*102.0*/) goto t56_n26;
  t56_n25: return 0.1214124858379364f;
  t56_n26: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t56_n34;
  t56_n27: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t56_n31;
  t56_n28: if (E.getNumReferences() >= 3271557120 /*128.0*/) goto t56_n30;
  t56_n29: return 0.017710542306303978f;
  t56_n30: return 0.12324868142604828f;
  t56_n31: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t56_n33;
  t56_n32: return 0.11067543923854828f;
  t56_n33: return 0.018648948520421982f;
  t56_n34: return -0.023633569478988647f;
  t56_n35: return 0.06373438239097595f;
  t56_n36: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t56_n84;
  t56_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t56_n39;
  t56_n38: return -0.027206474915146828f;
  t56_n39: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t56_n75;
  t56_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t56_n46;
  t56_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t56_n45;
  t56_n42: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t56_n44;
  t56_n43: return 0.020887691527605057f;
  t56_n44: return 0.04870140925049782f;
  t56_n45: return 0.1313479095697403f;
  t56_n46: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t56_n74;
  t56_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t56_n63;
  t56_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t56_n62;
  t56_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t56_n51;
  t56_n50: return -0.06705496460199356f;
  t56_n51: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t56_n53;
  t56_n52: return 0.004908725619316101f;
  t56_n53: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t56_n61;
  t56_n54: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t56_n60;
  t56_n55: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t56_n57;
  t56_n56: return 0.12592290341854095f;
  t56_n57: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t56_n59;
  t56_n58: return 0.13101987540721893f;
  t56_n59: return 0.11452649533748627f;
  t56_n60: return 0.10085144639015198f;
  t56_n61: return -0.11891677975654602f;
  t56_n62: return 0.02507016435265541f;
  t56_n63: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t56_n67;
  t56_n64: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t56_n66;
  t56_n65: return 0.028608912602066994f;
  t56_n66: return -0.09607906639575958f;
  t56_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t56_n71;
  t56_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t56_n70;
  t56_n69: return -0.013636451214551926f;
  t56_n70: return 0.06110746040940285f;
  t56_n71: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t56_n73;
  t56_n72: return 0.10059826076030731f;
  t56_n73: return 0.0451757088303566f;
  t56_n74: return -0.04965496063232422f;
  t56_n75: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t56_n83;
  t56_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t56_n78;
  t56_n77: return -0.08320450037717819f;
  t56_n78: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t56_n80;
  t56_n79: return 0.0045302086509764194f;
  t56_n80: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t56_n82;
  t56_n81: return 0.05933540314435959f;
  t56_n82: return 0.09980198740959167f;
  t56_n83: return 0.04951826483011246f;
  t56_n84: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t56_n90;
  t56_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t56_n87;
  t56_n86: return 0.005393452476710081f;
  t56_n87: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t56_n89;
  t56_n88: return 0.0980093851685524f;
  t56_n89: return -0.03159739822149277f;
  t56_n90: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t56_n102;
  t56_n91: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t56_n97;
  t56_n92: if (E.getNumReferences() >= 3318775808 /*6672.0*/) goto t56_n94;
  t56_n93: return 0.029269210994243622f;
  t56_n94: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t56_n96;
  t56_n95: return 0.10710415244102478f;
  t56_n96: return -0.138566792011261f;
  t56_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t56_n101;
  t56_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t56_n100;
  t56_n99: return -0.01066665817052126f;
  t56_n100: return 0.02806418016552925f;
  t56_n101: return 0.04582575336098671f;
  t56_n102: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t56_n108;
  t56_n103: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t56_n105;
  t56_n104: return 0.09871810674667358f;
  t56_n105: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t56_n107;
  t56_n106: return 0.129996657371521f;
  t56_n107: return 0.10522422939538956f;
  t56_n108: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t56_n110;
  t56_n109: return 0.047497935593128204f;
  t56_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t56_n112;
  t56_n111: return -0.12793193757534027f;
  t56_n112: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t56_n116;
  t56_n113: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t56_n115;
  t56_n114: return -0.04861535131931305f;
  t56_n115: return 0.04222072660923004f;
  t56_n116: return -0.08246210217475891f;
  t56_n117: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t56_n209;
  t56_n118: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t56_n122;
  t56_n119: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t56_n121;
  t56_n120: return 0.010042550042271614f;
  t56_n121: return -0.005443733651190996f;
  t56_n122: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t56_n148;
  t56_n123: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t56_n143;
  t56_n124: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t56_n138;
  t56_n125: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t56_n135;
  t56_n126: if (E.getNumReferences() >= 3350349056 /*91274.0*/) goto t56_n128;
  t56_n127: return 0.041053950786590576f;
  t56_n128: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t56_n134;
  t56_n129: if (E.getNumReferences() >= 3361098688 /*219439.0*/) goto t56_n131;
  t56_n130: return 0.0647038072347641f;
  t56_n131: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t56_n133;
  t56_n132: return 0.09801509976387024f;
  t56_n133: return 0.10711853206157684f;
  t56_n134: return -0.016608918085694313f;
  t56_n135: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t56_n137;
  t56_n136: return 0.10988640785217285f;
  t56_n137: return -0.10387194156646729f;
  t56_n138: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t56_n142;
  t56_n139: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t56_n141;
  t56_n140: return -0.02030392922461033f;
  t56_n141: return 0.08604293316602707f;
  t56_n142: return 0.13393129408359528f;
  t56_n143: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t56_n145;
  t56_n144: return 0.04445578530430794f;
  t56_n145: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t56_n147;
  t56_n146: return 0.07027552276849747f;
  t56_n147: return 0.00357452011667192f;
  t56_n148: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t56_n154;
  t56_n149: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t56_n151;
  t56_n150: return 0.06883924454450607f;
  t56_n151: if (E.getNumReferences() >= 3289849856 /*604.5*/) goto t56_n153;
  t56_n152: return 0.11140549182891846f;
  t56_n153: return 0.06280160695314407f;
  t56_n154: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t56_n180;
  t56_n155: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t56_n175;
  t56_n156: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t56_n158;
  t56_n157: return 0.030418654903769493f;
  t56_n158: if (E.getNumReferences() >= 3274080256 /*166.5*/) goto t56_n160;
  t56_n159: return 0.08484512567520142f;
  t56_n160: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t56_n162;
  t56_n161: return 0.06626735627651215f;
  t56_n162: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t56_n174;
  t56_n163: if (E.getNumReferences() >= 3289341952 /*573.5*/) goto t56_n173;
  t56_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t56_n166;
  t56_n165: return 0.07950937002897263f;
  t56_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t56_n172;
  t56_n167: if (E.getNumReferences() >= 3284877312 /*406.5*/) goto t56_n171;
  t56_n168: if (E.getNumReferences() >= 3277422592 /*217.5*/) goto t56_n170;
  t56_n169: return 0.12006192654371262f;
  t56_n170: return 0.11541525274515152f;
  t56_n171: return 0.11798924952745438f;
  t56_n172: return 0.16988405585289001f;
  t56_n173: return 0.07683926075696945f;
  t56_n174: return 0.0855187401175499f;
  t56_n175: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t56_n179;
  t56_n176: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t56_n178;
  t56_n177: return 0.09634869545698166f;
  t56_n178: return 0.16912654042243958f;
  t56_n179: return 0.08615800738334656f;
  t56_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t56_n194;
  t56_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t56_n183;
  t56_n182: return 0.0470280647277832f;
  t56_n183: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t56_n185;
  t56_n184: return 0.09005807340145111f;
  t56_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t56_n191;
  t56_n186: if (E.getFilterLength() >= 3250323456 /*23.5*/) goto t56_n188;
  t56_n187: return 0.1048746258020401f;
  t56_n188: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t56_n190;
  t56_n189: return 0.1439269632101059f;
  t56_n190: return -0.16173399984836578f;
  t56_n191: if (E.getNumReferences() >= 3262119936 /*60.0*/) goto t56_n193;
  t56_n192: return 0.148658886551857f;
  t56_n193: return 0.10932236164808273f;
  t56_n194: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t56_n200;
  t56_n195: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t56_n199;
  t56_n196: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t56_n198;
  t56_n197: return 0.11352526396512985f;
  t56_n198: return 0.12485138326883316f;
  t56_n199: return 0.04812386631965637f;
  t56_n200: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t56_n202;
  t56_n201: return 0.05823812633752823f;
  t56_n202: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t56_n204;
  t56_n203: return 0.09244706481695175f;
  t56_n204: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t56_n208;
  t56_n205: if (E.getNumReferences() >= 3279028224 /*242.0*/) goto t56_n207;
  t56_n206: return 0.12180452793836594f;
  t56_n207: return 0.08644383400678635f;
  t56_n208: return 0.08118460327386856f;
  t56_n209: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t56_n241;
  t56_n210: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t56_n216;
  t56_n211: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t56_n215;
  t56_n212: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t56_n214;
  t56_n213: return 0.03510567545890808f;
  t56_n214: return 0.06005130708217621f;
  t56_n215: return 0.018875770270824432f;
  t56_n216: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t56_n240;
  t56_n217: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t56_n219;
  t56_n218: return 0.06810932606458664f;
  t56_n219: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t56_n231;
  t56_n220: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t56_n222;
  t56_n221: return -0.07146089524030685f;
  t56_n222: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t56_n230;
  t56_n223: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t56_n225;
  t56_n224: return 0.11136108636856079f;
  t56_n225: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t56_n227;
  t56_n226: return -0.06838732212781906f;
  t56_n227: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t56_n229;
  t56_n228: return 0.1154981255531311f;
  t56_n229: return 0.11764450371265411f;
  t56_n230: return -0.009000002406537533f;
  t56_n231: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t56_n233;
  t56_n232: return -0.004317325074225664f;
  t56_n233: if (E.getNumReferences() >= 3267362816 /*96.0*/) goto t56_n235;
  t56_n234: return 0.1106829047203064f;
  t56_n235: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t56_n239;
  t56_n236: if (E.getNumReferences() >= 3269984256 /*116.0*/) goto t56_n238;
  t56_n237: return -0.0016672967467457056f;
  t56_n238: return 0.12054001539945602f;
  t56_n239: return 0.060497842729091644f;
  t56_n240: return 0.03979995846748352f;
  t56_n241: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t56_n245;
  t56_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t56_n244;
  t56_n243: return -0.004180398769676685f;
  t56_n244: return 0.029623497277498245f;
  t56_n245: return 0.022709328681230545f;
  t56_n246: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t56_n254;
  t56_n247: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t56_n253;
  t56_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t56_n250;
  t56_n249: return -0.005689495243132114f;
  t56_n250: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t56_n252;
  t56_n251: return 0.0066826920956373215f;
  t56_n252: return 0.025346772745251656f;
  t56_n253: return -0.2514071762561798f;
  t56_n254: return 0.03902595490217209f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree57(const Example& E) {
  t57_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t57_n248;
  t57_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t57_n207;
  t57_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t57_n54;
  t57_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t57_n5;
  t57_n4: return -0.03601117804646492f;
  t57_n5: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t57_n45;
  t57_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t57_n10;
  t57_n7: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t57_n9;
  t57_n8: return 0.018970850855112076f;
  t57_n9: return -0.04390953853726387f;
  t57_n10: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t57_n16;
  t57_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t57_n13;
  t57_n12: return -0.0920642539858818f;
  t57_n13: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t57_n15;
  t57_n14: return 0.014566046185791492f;
  t57_n15: return -0.01867746375501156f;
  t57_n16: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t57_n20;
  t57_n17: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t57_n19;
  t57_n18: return 0.11764746904373169f;
  t57_n19: return 0.0028511302080005407f;
  t57_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t57_n22;
  t57_n21: return 0.0023553213104605675f;
  t57_n22: if (E.getNumReferences() >= 3361127968 /*219896.5*/) goto t57_n44;
  t57_n23: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t57_n43;
  t57_n24: if (E.getNumReferences() >= 3358365376 /*176731.0*/) goto t57_n42;
  t57_n25: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t57_n27;
  t57_n26: return 0.04386430233716965f;
  t57_n27: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t57_n35;
  t57_n28: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t57_n30;
  t57_n29: return 0.09392116963863373f;
  t57_n30: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t57_n32;
  t57_n31: return 0.12194361537694931f;
  t57_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t57_n34;
  t57_n33: return 0.09844647347927094f;
  t57_n34: return 0.11017860472202301f;
  t57_n35: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t57_n41;
  t57_n36: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t57_n40;
  t57_n37: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t57_n39;
  t57_n38: return 0.07622881978750229f;
  t57_n39: return -0.031209522858262062f;
  t57_n40: return 0.08673743158578873f;
  t57_n41: return 0.15919621288776398f;
  t57_n42: return -0.14982178807258606f;
  t57_n43: return 0.09309288114309311f;
  t57_n44: return 0.12211702018976212f;
  t57_n45: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t57_n47;
  t57_n46: return 0.013541446067392826f;
  t57_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t57_n49;
  t57_n48: return 0.04217858612537384f;
  t57_n49: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t57_n53;
  t57_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t57_n52;
  t57_n51: return 0.10409177839756012f;
  t57_n52: return 0.06521057337522507f;
  t57_n53: return -0.11373437196016312f;
  t57_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t57_n56;
  t57_n55: return -0.008731350302696228f;
  t57_n56: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t57_n206;
  t57_n57: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t57_n197;
  t57_n58: if (E.getNumReferences() >= 3347329664 /*67685.0*/) goto t57_n146;
  t57_n59: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t57_n145;
  t57_n60: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t57_n144;
  t57_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t57_n127;
  t57_n62: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t57_n66;
  t57_n63: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t57_n65;
  t57_n64: return 0.01891287788748741f;
  t57_n65: return 0.023664014413952827f;
  t57_n66: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t57_n68;
  t57_n67: return -0.029191656038165092f;
  t57_n68: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t57_n70;
  t57_n69: return -0.0011171776568517089f;
  t57_n70: if (E.getNumReferences() >= 3316685824 /*5651.5*/) goto t57_n96;
  t57_n71: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t57_n73;
  t57_n72: return 0.011972908861935139f;
  t57_n73: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t57_n83;
  t57_n74: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t57_n76;
  t57_n75: return 0.09553514420986176f;
  t57_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t57_n80;
  t57_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t57_n79;
  t57_n78: return -0.023492278531193733f;
  t57_n79: return 0.08144426345825195f;
  t57_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t57_n82;
  t57_n81: return -0.19521740078926086f;
  t57_n82: return 0.21832291781902313f;
  t57_n83: if (E.getNumReferences() >= 3280060416 /*259.5*/) goto t57_n85;
  t57_n84: return -0.07427753508090973f;
  t57_n85: if (E.getNumReferences() >= 3280093184 /*260.5*/) goto t57_n87;
  t57_n86: return 0.12282276153564453f;
  t57_n87: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t57_n95;
  t57_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t57_n90;
  t57_n89: return 0.09554644674062729f;
  t57_n90: if (E.getNumReferences() >= 3299962880 /*1419.5*/) goto t57_n94;
  t57_n91: if (E.getNumReferences() >= 3290324992 /*633.5*/) goto t57_n93;
  t57_n92: return -0.14711898565292358f;
  t57_n93: return 0.12200018018484116f;
  t57_n94: return 0.041434019804000854f;
  t57_n95: return 0.04387602582573891f;
  t57_n96: if (E.getNumReferences() >= 3332719104 /*21153.0*/) goto t57_n126;
  t57_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t57_n103;
  t57_n98: if (E.getNumReferences() >= 3317223424 /*5914.0*/) goto t57_n102;
  t57_n99: if (E.getNumReferences() >= 3316872192 /*5742.5*/) goto t57_n101;
  t57_n100: return -1.8568289279937744f;
  t57_n101: return 0.11567310243844986f;
  t57_n102: return 0.007152167614549398f;
  t57_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t57_n105;
  t57_n104: return -0.006938971113413572f;
  t57_n105: if (E.getNumReferences() >= 3319414784 /*6984.0*/) goto t57_n107;
  t57_n106: return 0.1030222550034523f;
  t57_n107: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t57_n113;
  t57_n108: if (E.getNumReferences() >= 3320056832 /*7297.5*/) goto t57_n112;
  t57_n109: if (E.getNumReferences() >= 3319805952 /*7175.0*/) goto t57_n111;
  t57_n110: return 0.08747990429401398f;
  t57_n111: return 0.1176200807094574f;
  t57_n112: return 0.1078438088297844f;
  t57_n113: if (E.getNumReferences() >= 3319788544 /*7166.5*/) goto t57_n115;
  t57_n114: return 0.10982216894626617f;
  t57_n115: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t57_n123;
  t57_n116: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t57_n122;
  t57_n117: if (E.getNumReferences() >= 3321991168 /*8292.0*/) goto t57_n121;
  t57_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t57_n120;
  t57_n119: return 0.05788784101605415f;
  t57_n120: return 0.12877611815929413f;
  t57_n121: return 0.015894288197159767f;
  t57_n122: return 0.09801942110061646f;
  t57_n123: if (E.getNumReferences() >= 3321857024 /*8176.5*/) goto t57_n125;
  t57_n124: return -0.04209703952074051f;
  t57_n125: return 0.10140670090913773f;
  t57_n126: return 0.022784437984228134f;
  t57_n127: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t57_n133;
  t57_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t57_n130;
  t57_n129: return -0.1277177482843399f;
  t57_n130: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t57_n132;
  t57_n131: return -0.021714717149734497f;
  t57_n132: return 0.0994676724076271f;
  t57_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t57_n135;
  t57_n134: return 0.020832741633057594f;
  t57_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t57_n143;
  t57_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t57_n140;
  t57_n137: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t57_n139;
  t57_n138: return -0.04300206899642944f;
  t57_n139: return -0.44097089767456055f;
  t57_n140: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t57_n142;
  t57_n141: return 0.028585389256477356f;
  t57_n142: return 0.10850002616643906f;
  t57_n143: return 0.05162881687283516f;
  t57_n144: return -0.11273659765720367f;
  t57_n145: return -0.13544166088104248f;
  t57_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t57_n150;
  t57_n147: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t57_n149;
  t57_n148: return 0.03711828961968422f;
  t57_n149: return -0.04368000477552414f;
  t57_n150: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t57_n186;
  t57_n151: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t57_n169;
  t57_n152: if (E.getNumReferences() >= 3356390976 /*145881.0*/) goto t57_n168;
  t57_n153: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t57_n155;
  t57_n154: return 0.047712136059999466f;
  t57_n155: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t57_n167;
  t57_n156: if (E.getNumReferences() >= 3351357120 /*99149.5*/) goto t57_n160;
  t57_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t57_n159;
  t57_n158: return 0.06302326172590256f;
  t57_n159: return 0.08544263243675232f;
  t57_n160: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t57_n162;
  t57_n161: return 0.07813819497823715f;
  t57_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t57_n164;
  t57_n163: return -0.6979694962501526f;
  t57_n164: if (E.getFileProximityDistance() >= 3249537024 /*22.0*/) goto t57_n166;
  t57_n165: return 0.10616399347782135f;
  t57_n166: return 0.11478207260370255f;
  t57_n167: return 0.04573431611061096f;
  t57_n168: return -0.22960692644119263f;
  t57_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t57_n175;
  t57_n170: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t57_n172;
  t57_n171: return 0.04691813141107559f;
  t57_n172: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t57_n174;
  t57_n173: return 0.12711626291275024f;
  t57_n174: return -0.24834848940372467f;
  t57_n175: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t57_n185;
  t57_n176: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t57_n184;
  t57_n177: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t57_n183;
  t57_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t57_n182;
  t57_n179: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t57_n181;
  t57_n180: return 0.103073351085186f;
  t57_n181: return 0.1083160787820816f;
  t57_n182: return 0.11628159880638123f;
  t57_n183: return -0.2905237674713135f;
  t57_n184: return 0.08653702586889267f;
  t57_n185: return 0.11084402352571487f;
  t57_n186: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t57_n188;
  t57_n187: return -0.15295575559139252f;
  t57_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t57_n196;
  t57_n189: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t57_n191;
  t57_n190: return -0.23072127997875214f;
  t57_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t57_n193;
  t57_n192: return -0.0027285171672701836f;
  t57_n193: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t57_n195;
  t57_n194: return 0.11717559397220612f;
  t57_n195: return 0.0729503482580185f;
  t57_n196: return 0.03436581417918205f;
  t57_n197: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t57_n199;
  t57_n198: return 0.032783228904008865f;
  t57_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t57_n205;
  t57_n200: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t57_n204;
  t57_n201: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t57_n203;
  t57_n202: return 0.077858567237854f;
  t57_n203: return 0.039654359221458435f;
  t57_n204: return -0.031966980546712875f;
  t57_n205: return 0.08889190107584f;
  t57_n206: return -0.04518652707338333f;
  t57_n207: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t57_n231;
  t57_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t57_n224;
  t57_n209: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t57_n213;
  t57_n210: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t57_n212;
  t57_n211: return 0.038254015147686005f;
  t57_n212: return 0.04960792511701584f;
  t57_n213: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t57_n221;
  t57_n214: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t57_n216;
  t57_n215: return 0.009055497124791145f;
  t57_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t57_n218;
  t57_n217: return 0.013970781117677689f;
  t57_n218: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t57_n220;
  t57_n219: return 0.02153218723833561f;
  t57_n220: return 0.05531010776758194f;
  t57_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t57_n223;
  t57_n222: return -0.07813636213541031f;
  t57_n223: return 0.029568171128630638f;
  t57_n224: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t57_n228;
  t57_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t57_n227;
  t57_n226: return -0.01153387688100338f;
  t57_n227: return 0.03300582617521286f;
  t57_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t57_n230;
  t57_n229: return 0.0512324720621109f;
  t57_n230: return 0.02882315218448639f;
  t57_n231: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t57_n243;
  t57_n232: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t57_n238;
  t57_n233: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t57_n237;
  t57_n234: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t57_n236;
  t57_n235: return 0.03372114151716232f;
  t57_n236: return 0.08032214641571045f;
  t57_n237: return -0.027748089283704758f;
  t57_n238: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t57_n242;
  t57_n239: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t57_n241;
  t57_n240: return 0.04312559589743614f;
  t57_n241: return 0.09221307933330536f;
  t57_n242: return -0.0025013049598783255f;
  t57_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t57_n245;
  t57_n244: return 0.032458145171403885f;
  t57_n245: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t57_n247;
  t57_n246: return 0.09903321415185928f;
  t57_n247: return 0.07515005767345428f;
  t57_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t57_n254;
  t57_n249: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t57_n253;
  t57_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t57_n252;
  t57_n251: return -0.00852471124380827f;
  t57_n252: return 0.008561967872083187f;
  t57_n253: return 0.030439266934990883f;
  t57_n254: return 0.03814397379755974f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree58(const Example& E) {
  t58_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t58_n242;
  t58_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t58_n207;
  t58_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t58_n16;
  t58_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t58_n5;
  t58_n4: return -0.03507724776864052f;
  t58_n5: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t58_n7;
  t58_n6: return -0.0065452540293335915f;
  t58_n7: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t58_n9;
  t58_n8: return 0.014411908574402332f;
  t58_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t58_n11;
  t58_n10: return -0.22793163359165192f;
  t58_n11: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t58_n15;
  t58_n12: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t58_n14;
  t58_n13: return 0.10025568306446075f;
  t58_n14: return 0.04393937811255455f;
  t58_n15: return -0.13194122910499573f;
  t58_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t58_n18;
  t58_n17: return -0.008191397413611412f;
  t58_n18: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t58_n198;
  t58_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t58_n197;
  t58_n20: if (E.getNumReferences() >= 3347329664 /*67685.0*/) goto t58_n148;
  t58_n21: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t58_n77;
  t58_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t58_n24;
  t58_n23: return 0.001183574553579092f;
  t58_n24: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t58_n26;
  t58_n25: return 0.019321879372000694f;
  t58_n26: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t58_n28;
  t58_n27: return 0.04385947808623314f;
  t58_n28: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t58_n60;
  t58_n29: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t58_n31;
  t58_n30: return 0.05418954789638519f;
  t58_n31: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t58_n59;
  t58_n32: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t58_n38;
  t58_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t58_n35;
  t58_n34: return -0.13767355680465698f;
  t58_n35: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t58_n37;
  t58_n36: return 0.14104238152503967f;
  t58_n37: return -0.13787490129470825f;
  t58_n38: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t58_n42;
  t58_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t58_n41;
  t58_n40: return 0.01361524686217308f;
  t58_n41: return 0.09459508955478668f;
  t58_n42: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t58_n44;
  t58_n43: return 0.09489434957504272f;
  t58_n44: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t58_n46;
  t58_n45: return 0.11792459338903427f;
  t58_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t58_n56;
  t58_n47: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t58_n51;
  t58_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t58_n50;
  t58_n49: return 0.12502361834049225f;
  t58_n50: return 0.13896444439888f;
  t58_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t58_n53;
  t58_n52: return 0.10827797651290894f;
  t58_n53: if (E.getNumReferences() >= 3285434368 /*423.5*/) goto t58_n55;
  t58_n54: return 0.12428557127714157f;
  t58_n55: return 0.10041698813438416f;
  t58_n56: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t58_n58;
  t58_n57: return 0.11601947247982025f;
  t58_n58: return 0.11609695851802826f;
  t58_n59: return 0.02196270413696766f;
  t58_n60: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t58_n62;
  t58_n61: return 0.06205722689628601f;
  t58_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t58_n68;
  t58_n63: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t58_n67;
  t58_n64: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t58_n66;
  t58_n65: return 0.07101740688085556f;
  t58_n66: return 0.15049685537815094f;
  t58_n67: return 0.0770079493522644f;
  t58_n68: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t58_n70;
  t58_n69: return 0.09867080301046371f;
  t58_n70: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t58_n74;
  t58_n71: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t58_n73;
  t58_n72: return 0.06970725208520889f;
  t58_n73: return 0.12154272943735123f;
  t58_n74: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t58_n76;
  t58_n75: return 0.09206676483154297f;
  t58_n76: return 0.1357317715883255f;
  t58_n77: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t58_n103;
  t58_n78: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t58_n102;
  t58_n79: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t58_n81;
  t58_n80: return 0.016095157712697983f;
  t58_n81: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t58_n83;
  t58_n82: return 0.01058509573340416f;
  t58_n83: if (E.getFileProximityDistance() >= 3255435264 /*34.5*/) goto t58_n101;
  t58_n84: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t58_n86;
  t58_n85: return 0.05518040806055069f;
  t58_n86: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t58_n88;
  t58_n87: return 0.02833366021513939f;
  t58_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t58_n92;
  t58_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t58_n91;
  t58_n90: return -0.026291390880942345f;
  t58_n91: return 0.07480942457914352f;
  t58_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t58_n96;
  t58_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t58_n95;
  t58_n94: return -0.10842353105545044f;
  t58_n95: return 0.13253633677959442f;
  t58_n96: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t58_n98;
  t58_n97: return 0.16105398535728455f;
  t58_n98: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t58_n100;
  t58_n99: return 0.17631489038467407f;
  t58_n100: return 0.12071259319782257f;
  t58_n101: return -0.025658272206783295f;
  t58_n102: return -0.13746561110019684f;
  t58_n103: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t58_n105;
  t58_n104: return -0.0988907516002655f;
  t58_n105: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t58_n109;
  t58_n106: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t58_n108;
  t58_n107: return 0.010241303592920303f;
  t58_n108: return 0.03843256086111069f;
  t58_n109: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t58_n111;
  t58_n110: return -0.015939801931381226f;
  t58_n111: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t58_n113;
  t58_n112: return -0.03383716568350792f;
  t58_n113: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t58_n133;
  t58_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t58_n116;
  t58_n115: return 0.0941232368350029f;
  t58_n116: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t58_n132;
  t58_n117: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t58_n131;
  t58_n118: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t58_n128;
  t58_n119: if (E.getFilterLength() >= 3241148416 /*11.0*/) goto t58_n127;
  t58_n120: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t58_n122;
  t58_n121: return 0.15633444488048553f;
  t58_n122: if (E.getNumReferences() >= 3266445312 /*89.0*/) goto t58_n126;
  t58_n123: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t58_n125;
  t58_n124: return 0.134489506483078f;
  t58_n125: return 0.12876802682876587f;
  t58_n126: return -0.1251208484172821f;
  t58_n127: return 0.12538185715675354f;
  t58_n128: if (E.getNumReferences() >= 3262119936 /*60.0*/) goto t58_n130;
  t58_n129: return 0.15600800514221191f;
  t58_n130: return 0.1281343698501587f;
  t58_n131: return 0.07572410255670547f;
  t58_n132: return 0.09030641615390778f;
  t58_n133: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t58_n135;
  t58_n134: return 0.061687178909778595f;
  t58_n135: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t58_n147;
  t58_n136: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t58_n140;
  t58_n137: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t58_n139;
  t58_n138: return 0.14410504698753357f;
  t58_n139: return -0.10200608521699905f;
  t58_n140: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t58_n144;
  t58_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t58_n143;
  t58_n142: return 0.10915616899728775f;
  t58_n143: return 0.1233077421784401f;
  t58_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t58_n146;
  t58_n145: return 0.09365689754486084f;
  t58_n146: return 0.12211688607931137f;
  t58_n147: return 0.0748870000243187f;
  t58_n148: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t58_n152;
  t58_n149: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t58_n151;
  t58_n150: return 0.033976949751377106f;
  t58_n151: return -0.029644612222909927f;
  t58_n152: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t58_n190;
  t58_n153: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t58_n173;
  t58_n154: if (E.getNumReferences() >= 3357271616 /*159641.0*/) goto t58_n172;
  t58_n155: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t58_n157;
  t58_n156: return 0.04398266598582268f;
  t58_n157: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t58_n171;
  t58_n158: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t58_n162;
  t58_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t58_n161;
  t58_n160: return 0.05291805416345596f;
  t58_n161: return 0.08002932369709015f;
  t58_n162: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t58_n164;
  t58_n163: return 0.07505594193935394f;
  t58_n164: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t58_n168;
  t58_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t58_n167;
  t58_n166: return 0.043938636779785156f;
  t58_n167: return 0.10787079483270645f;
  t58_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t58_n170;
  t58_n169: return 0.053585171699523926f;
  t58_n170: return 0.11406859755516052f;
  t58_n171: return 0.04003770649433136f;
  t58_n172: return -0.3964356482028961f;
  t58_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t58_n179;
  t58_n174: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t58_n176;
  t58_n175: return 0.044570159167051315f;
  t58_n176: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t58_n178;
  t58_n177: return 0.12292042374610901f;
  t58_n178: return -0.2066422402858734f;
  t58_n179: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t58_n189;
  t58_n180: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t58_n188;
  t58_n181: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t58_n187;
  t58_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t58_n184;
  t58_n183: return 0.09508128464221954f;
  t58_n184: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t58_n186;
  t58_n185: return 0.09877237677574158f;
  t58_n186: return 0.11919255554676056f;
  t58_n187: return -0.2405826598405838f;
  t58_n188: return 0.08375641703605652f;
  t58_n189: return 0.10682514309883118f;
  t58_n190: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t58_n192;
  t58_n191: return -0.1432967633008957f;
  t58_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t58_n194;
  t58_n193: return -0.029465477913618088f;
  t58_n194: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t58_n196;
  t58_n195: return 0.050000958144664764f;
  t58_n196: return -0.019488830119371414f;
  t58_n197: return -0.04733634740114212f;
  t58_n198: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t58_n206;
  t58_n199: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t58_n205;
  t58_n200: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t58_n204;
  t58_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t58_n203;
  t58_n202: return 0.1048400029540062f;
  t58_n203: return 0.06765785813331604f;
  t58_n204: return 0.019994208589196205f;
  t58_n205: return -0.008247138932347298f;
  t58_n206: return 0.018031716346740723f;
  t58_n207: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t58_n221;
  t58_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t58_n214;
  t58_n209: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t58_n213;
  t58_n210: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t58_n212;
  t58_n211: return 0.03527610003948212f;
  t58_n212: return 0.047442857176065445f;
  t58_n213: return 0.008656452409923077f;
  t58_n214: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t58_n218;
  t58_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t58_n217;
  t58_n216: return -0.008014943450689316f;
  t58_n217: return 0.03142165392637253f;
  t58_n218: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t58_n220;
  t58_n219: return 0.05187510699033737f;
  t58_n220: return 0.02738073095679283f;
  t58_n221: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t58_n235;
  t58_n222: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t58_n234;
  t58_n223: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t58_n227;
  t58_n224: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t58_n226;
  t58_n225: return 0.09098463505506516f;
  t58_n226: return 0.002955822739750147f;
  t58_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t58_n231;
  t58_n228: if (E.getNumReferences() >= 3319676928 /*7112.0*/) goto t58_n230;
  t58_n229: return 0.10081290453672409f;
  t58_n230: return 0.04893730580806732f;
  t58_n231: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t58_n233;
  t58_n232: return 0.11851964145898819f;
  t58_n233: return -0.006772007793188095f;
  t58_n234: return 0.013781111687421799f;
  t58_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t58_n237;
  t58_n236: return 0.031814251095056534f;
  t58_n237: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t58_n239;
  t58_n238: return 0.08926472067832947f;
  t58_n239: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t58_n241;
  t58_n240: return 0.0678781121969223f;
  t58_n241: return 0.107761912047863f;
  t58_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t58_n248;
  t58_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t58_n245;
  t58_n244: return -0.007338813506066799f;
  t58_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t58_n247;
  t58_n246: return 0.005029075313359499f;
  t58_n247: return 0.023271599784493446f;
  t58_n248: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t58_n252;
  t58_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t58_n251;
  t58_n250: return 0.022818025201559067f;
  t58_n251: return 0.04517855495214462f;
  t58_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t58_n254;
  t58_n253: return 0.0914125144481659f;
  t58_n254: return -0.06916659325361252f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree59(const Example& E) {
  t59_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t59_n248;
  t59_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t59_n185;
  t59_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t59_n144;
  t59_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t59_n41;
  t59_n4: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t59_n6;
  t59_n5: return -0.03043026477098465f;
  t59_n6: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t59_n20;
  t59_n7: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t59_n19;
  t59_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t59_n10;
  t59_n9: return 0.015493226237595081f;
  t59_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t59_n16;
  t59_n11: if (E.getNumReferences() >= 3320417280 /*7473.5*/) goto t59_n13;
  t59_n12: return 0.02774951420724392f;
  t59_n13: if (E.getNumReferences() >= 3320443904 /*7486.5*/) goto t59_n15;
  t59_n14: return 0.12180066108703613f;
  t59_n15: return 0.05086171627044678f;
  t59_n16: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t59_n18;
  t59_n17: return 0.0698990449309349f;
  t59_n18: return 0.08096829801797867f;
  t59_n19: return -0.005249600391834974f;
  t59_n20: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t59_n34;
  t59_n21: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t59_n23;
  t59_n22: return 0.08724913746118546f;
  t59_n23: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t59_n25;
  t59_n24: return 0.05805863440036774f;
  t59_n25: if (E.getNumReferences() >= 3268149248 /*102.0*/) goto t59_n27;
  t59_n26: return 0.11779167503118515f;
  t59_n27: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t59_n33;
  t59_n28: if (E.getNumReferences() >= 3272802304 /*147.0*/) goto t59_n32;
  t59_n29: if (E.getNumReferences() >= 3272245248 /*138.5*/) goto t59_n31;
  t59_n30: return 0.09995192289352417f;
  t59_n31: return 0.11957811564207077f;
  t59_n32: return 0.09956876933574677f;
  t59_n33: return -0.04394328221678734f;
  t59_n34: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t59_n36;
  t59_n35: return 0.04663391038775444f;
  t59_n36: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t59_n38;
  t59_n37: return 0.06843870133161545f;
  t59_n38: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t59_n40;
  t59_n39: return 0.10812054574489594f;
  t59_n40: return -0.11600537598133087f;
  t59_n41: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t59_n111;
  t59_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t59_n60;
  t59_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t59_n45;
  t59_n44: return -0.0430549755692482f;
  t59_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t59_n47;
  t59_n46: return -0.11306784301996231f;
  t59_n47: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t59_n55;
  t59_n48: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t59_n54;
  t59_n49: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t59_n51;
  t59_n50: return 0.03783860802650452f;
  t59_n51: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t59_n53;
  t59_n52: return 0.10014761984348297f;
  t59_n53: return 0.06569910049438477f;
  t59_n54: return 0.02508256584405899f;
  t59_n55: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t59_n59;
  t59_n56: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t59_n58;
  t59_n57: return 0.0635298490524292f;
  t59_n58: return 0.026469821110367775f;
  t59_n59: return 0.0006109342211857438f;
  t59_n60: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t59_n108;
  t59_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t59_n63;
  t59_n62: return 0.02104356698691845f;
  t59_n63: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t59_n107;
  t59_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t59_n90;
  t59_n65: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t59_n89;
  t59_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t59_n68;
  t59_n67: return -0.06194634735584259f;
  t59_n68: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t59_n78;
  t59_n69: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t59_n73;
  t59_n70: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t59_n72;
  t59_n71: return -0.2693660259246826f;
  t59_n72: return 0.07462586462497711f;
  t59_n73: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t59_n75;
  t59_n74: return 0.014499283395707607f;
  t59_n75: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t59_n77;
  t59_n76: return 0.09158748388290405f;
  t59_n77: return -0.04360635578632355f;
  t59_n78: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t59_n88;
  t59_n79: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t59_n87;
  t59_n80: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t59_n84;
  t59_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t59_n83;
  t59_n82: return 0.1255514919757843f;
  t59_n83: return 0.12999236583709717f;
  t59_n84: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t59_n86;
  t59_n85: return 0.11576598137617111f;
  t59_n86: return 0.09093362092971802f;
  t59_n87: return 0.10095775127410889f;
  t59_n88: return -0.0987502932548523f;
  t59_n89: return 0.026002898812294006f;
  t59_n90: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t59_n98;
  t59_n91: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t59_n95;
  t59_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t59_n94;
  t59_n93: return -0.026555292308330536f;
  t59_n94: return 0.047669194638729095f;
  t59_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t59_n97;
  t59_n96: return 0.02210824191570282f;
  t59_n97: return 0.04340921342372894f;
  t59_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t59_n102;
  t59_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t59_n101;
  t59_n100: return -0.036774616688489914f;
  t59_n101: return 0.056324951350688934f;
  t59_n102: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t59_n106;
  t59_n103: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t59_n105;
  t59_n104: return 0.10065712034702301f;
  t59_n105: return 0.09733164310455322f;
  t59_n106: return 0.03818165510892868f;
  t59_n107: return -0.05151715502142906f;
  t59_n108: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t59_n110;
  t59_n109: return -0.04959558695554733f;
  t59_n110: return 0.044928550720214844f;
  t59_n111: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t59_n113;
  t59_n112: return 0.00747439730912447f;
  t59_n113: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t59_n127;
  t59_n114: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t59_n116;
  t59_n115: return 0.025509728118777275f;
  t59_n116: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t59_n118;
  t59_n117: return -0.01768270507454872f;
  t59_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t59_n120;
  t59_n119: return 0.031802888959646225f;
  t59_n120: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t59_n126;
  t59_n121: if (E.getNumReferences() >= 3290988544 /*674.0*/) goto t59_n123;
  t59_n122: return 0.05743851512670517f;
  t59_n123: if (E.getNumReferences() >= 3302379520 /*1714.5*/) goto t59_n125;
  t59_n124: return 0.11154046654701233f;
  t59_n125: return 0.0523095466196537f;
  t59_n126: return 0.04912682995200157f;
  t59_n127: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t59_n133;
  t59_n128: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t59_n130;
  t59_n129: return 0.09731828421354294f;
  t59_n130: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t59_n132;
  t59_n131: return 0.1251310557126999f;
  t59_n132: return 0.10334423184394836f;
  t59_n133: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t59_n137;
  t59_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t59_n136;
  t59_n135: return 0.07387450337409973f;
  t59_n136: return 0.10284655541181564f;
  t59_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t59_n139;
  t59_n138: return 0.024327026680111885f;
  t59_n139: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t59_n141;
  t59_n140: return 0.08040785789489746f;
  t59_n141: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t59_n143;
  t59_n142: return 0.1632184088230133f;
  t59_n143: return 0.10698967427015305f;
  t59_n144: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t59_n148;
  t59_n145: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t59_n147;
  t59_n146: return 0.008855876512825489f;
  t59_n147: return -0.004813947714865208f;
  t59_n148: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t59_n174;
  t59_n149: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t59_n161;
  t59_n150: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t59_n156;
  t59_n151: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t59_n153;
  t59_n152: return 0.0421241857111454f;
  t59_n153: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t59_n155;
  t59_n154: return 0.10878458619117737f;
  t59_n155: return -0.10261866450309753f;
  t59_n156: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t59_n160;
  t59_n157: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t59_n159;
  t59_n158: return -0.019769420847296715f;
  t59_n159: return 0.08307718485593796f;
  t59_n160: return 0.13568681478500366f;
  t59_n161: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t59_n163;
  t59_n162: return 0.046924393624067307f;
  t59_n163: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t59_n173;
  t59_n164: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t59_n170;
  t59_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t59_n167;
  t59_n166: return 0.056099530309438705f;
  t59_n167: if (E.getNumReferences() >= 3260416000 /*53.5*/) goto t59_n169;
  t59_n168: return 0.12718546390533447f;
  t59_n169: return 0.09343980252742767f;
  t59_n170: if (E.getNumReferences() >= 3269853184 /*115.0*/) goto t59_n172;
  t59_n171: return -0.1176443099975586f;
  t59_n172: return 0.11401204019784927f;
  t59_n173: return 0.007484785746783018f;
  t59_n174: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t59_n184;
  t59_n175: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t59_n183;
  t59_n176: if (E.getNumReferences() >= 3291078656 /*679.5*/) goto t59_n178;
  t59_n177: return 0.09508075565099716f;
  t59_n178: if (E.getNumReferences() >= 3297103872 /*1070.5*/) goto t59_n182;
  t59_n179: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t59_n181;
  t59_n180: return 0.11613381654024124f;
  t59_n181: return 0.09638731181621552f;
  t59_n182: return 0.09145185351371765f;
  t59_n183: return 0.0139005733653903f;
  t59_n184: return 0.07074028998613358f;
  t59_n185: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t59_n223;
  t59_n186: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t59_n222;
  t59_n187: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t59_n219;
  t59_n188: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t59_n216;
  t59_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t59_n191;
  t59_n190: return -0.21217229962348938f;
  t59_n191: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t59_n215;
  t59_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t59_n210;
  t59_n193: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t59_n195;
  t59_n194: return 0.023489654064178467f;
  t59_n195: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t59_n197;
  t59_n196: return 0.03336751088500023f;
  t59_n197: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t59_n209;
  t59_n198: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t59_n200;
  t59_n199: return 0.08425962924957275f;
  t59_n200: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t59_n202;
  t59_n201: return 0.01667575165629387f;
  t59_n202: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t59_n208;
  t59_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t59_n205;
  t59_n204: return -0.8038914799690247f;
  t59_n205: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t59_n207;
  t59_n206: return 0.10745241492986679f;
  t59_n207: return 0.0355253703892231f;
  t59_n208: return 0.07370508462190628f;
  t59_n209: return -0.03816882520914078f;
  t59_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t59_n214;
  t59_n211: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t59_n213;
  t59_n212: return 0.03428839147090912f;
  t59_n213: return 0.054996591061353683f;
  t59_n214: return 0.014646204188466072f;
  t59_n215: return -0.00501621887087822f;
  t59_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t59_n218;
  t59_n217: return -0.22803011536598206f;
  t59_n218: return 0.020241212099790573f;
  t59_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t59_n221;
  t59_n220: return -0.07180842012166977f;
  t59_n221: return 0.028505578637123108f;
  t59_n222: return 0.021962668746709824f;
  t59_n223: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t59_n225;
  t59_n224: return 0.044248782098293304f;
  t59_n225: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t59_n241;
  t59_n226: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t59_n228;
  t59_n227: return -0.0012423215666785836f;
  t59_n228: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t59_n230;
  t59_n229: return 0.055163558572530746f;
  t59_n230: if (E.getNumReferences() >= 3318789120 /*6678.5*/) goto t59_n232;
  t59_n231: return 0.11633841693401337f;
  t59_n232: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t59_n240;
  t59_n233: if (E.getNumReferences() >= 3322049024 /*8348.5*/) goto t59_n235;
  t59_n234: return 0.0543094240128994f;
  t59_n235: if (E.getNumReferences() >= 3331291648 /*18365.0*/) goto t59_n239;
  t59_n236: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t59_n238;
  t59_n237: return 0.11729241907596588f;
  t59_n238: return 0.08539179712533951f;
  t59_n239: return 0.08474057912826538f;
  t59_n240: return 0.07004372775554657f;
  t59_n241: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t59_n243;
  t59_n242: return 0.001951553043909371f;
  t59_n243: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t59_n247;
  t59_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t59_n246;
  t59_n245: return 0.02603313885629177f;
  t59_n246: return 0.09260714054107666f;
  t59_n247: return -0.02911706455051899f;
  t59_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t59_n254;
  t59_n249: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t59_n253;
  t59_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t59_n252;
  t59_n251: return -0.00788121111690998f;
  t59_n252: return 0.006310129072517157f;
  t59_n253: return 0.02808763086795807f;
  t59_n254: return 0.034822434186935425f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree60(const Example& E) {
  t60_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t60_n246;
  t60_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t60_n235;
  t60_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t60_n130;
  t60_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t60_n97;
  t60_n4: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t60_n14;
  t60_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t60_n9;
  t60_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t60_n8;
  t60_n7: return -0.05631787329912186f;
  t60_n8: return -0.04235048592090607f;
  t60_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t60_n11;
  t60_n10: return -0.02224130742251873f;
  t60_n11: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t60_n13;
  t60_n12: return 0.01286856085062027f;
  t60_n13: return -0.06060114502906799f;
  t60_n14: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t60_n16;
  t60_n15: return 0.002462713746353984f;
  t60_n16: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t60_n40;
  t60_n17: if (E.getNumReferences() >= 3327408128 /*13582.0*/) goto t60_n23;
  t60_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t60_n20;
  t60_n19: return 0.09657931327819824f;
  t60_n20: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t60_n22;
  t60_n21: return -0.10462412983179092f;
  t60_n22: return 0.11122963577508926f;
  t60_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t60_n25;
  t60_n24: return 0.040202733129262924f;
  t60_n25: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t60_n27;
  t60_n26: return -0.03671230748295784f;
  t60_n27: if (E.getNumReferences() >= 3350807040 /*94852.0*/) goto t60_n31;
  t60_n28: if (E.getNumReferences() >= 3328604672 /*14750.5*/) goto t60_n30;
  t60_n29: return 0.1340457946062088f;
  t60_n30: return 0.09071008861064911f;
  t60_n31: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t60_n39;
  t60_n32: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t60_n38;
  t60_n33: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t60_n37;
  t60_n34: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t60_n36;
  t60_n35: return 0.13217195868492126f;
  t60_n36: return 0.09474249184131622f;
  t60_n37: return 0.06394568830728531f;
  t60_n38: return 0.06458675861358643f;
  t60_n39: return 0.08873936533927917f;
  t60_n40: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t60_n42;
  t60_n41: return -0.015393906272947788f;
  t60_n42: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t60_n44;
  t60_n43: return 0.033584266901016235f;
  t60_n44: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t60_n96;
  t60_n45: if (E.getNumReferences() >= 3326734336 /*12924.0*/) goto t60_n47;
  t60_n46: return 0.11353379487991333f;
  t60_n47: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t60_n75;
  t60_n48: if (E.getNumReferences() >= 3341306880 /*43084.0*/) goto t60_n64;
  t60_n49: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t60_n63;
  t60_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t60_n52;
  t60_n51: return 0.054002806544303894f;
  t60_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t60_n54;
  t60_n53: return 0.07380134612321854f;
  t60_n54: if (E.getNumReferences() >= 3326979584 /*13163.5*/) goto t60_n56;
  t60_n55: return 0.12798672914505005f;
  t60_n56: if (E.getNumReferences() >= 3331808000 /*19373.5*/) goto t60_n58;
  t60_n57: return 0.09176182746887207f;
  t60_n58: if (E.getNumReferences() >= 3332440064 /*20608.0*/) goto t60_n62;
  t60_n59: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t60_n61;
  t60_n60: return 0.11046604812145233f;
  t60_n61: return 0.08555535972118378f;
  t60_n62: return -0.3849108815193176f;
  t60_n63: return -0.008188370615243912f;
  t60_n64: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t60_n70;
  t60_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t60_n67;
  t60_n66: return -0.22298219799995422f;
  t60_n67: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t60_n69;
  t60_n68: return 0.11216237396001816f;
  t60_n69: return 0.11431744694709778f;
  t60_n70: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t60_n72;
  t60_n71: return 0.059654105454683304f;
  t60_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t60_n74;
  t60_n73: return 0.0723109170794487f;
  t60_n74: return 0.11220204085111618f;
  t60_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t60_n89;
  t60_n76: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t60_n78;
  t60_n77: return 0.06580409407615662f;
  t60_n78: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t60_n86;
  t60_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t60_n81;
  t60_n80: return 0.04755913093686104f;
  t60_n81: if (E.getNumReferences() >= 3332023808 /*19795.0*/) goto t60_n85;
  t60_n82: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t60_n84;
  t60_n83: return 0.0431520901620388f;
  t60_n84: return 0.11625411361455917f;
  t60_n85: return -0.0007792871329002082f;
  t60_n86: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t60_n88;
  t60_n87: return 0.05975800380110741f;
  t60_n88: return 0.12481998652219772f;
  t60_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t60_n91;
  t60_n90: return -0.7609343528747559f;
  t60_n91: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t60_n95;
  t60_n92: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t60_n94;
  t60_n93: return 0.10710237175226212f;
  t60_n94: return 0.10394173115491867f;
  t60_n95: return 0.09090090543031693f;
  t60_n96: return 0.0010811637621372938f;
  t60_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t60_n101;
  t60_n98: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t60_n100;
  t60_n99: return 0.014291294850409031f;
  t60_n100: return -0.04532682150602341f;
  t60_n101: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t60_n103;
  t60_n102: return 0.05599929764866829f;
  t60_n103: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t60_n129;
  t60_n104: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t60_n122;
  t60_n105: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t60_n111;
  t60_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t60_n108;
  t60_n107: return -0.00344191025942564f;
  t60_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t60_n110;
  t60_n109: return 0.05617876350879669f;
  t60_n110: return -0.032825179398059845f;
  t60_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t60_n113;
  t60_n112: return 0.051988475024700165f;
  t60_n113: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t60_n117;
  t60_n114: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t60_n116;
  t60_n115: return 0.07324790209531784f;
  t60_n116: return 0.031770795583724976f;
  t60_n117: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t60_n121;
  t60_n118: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t60_n120;
  t60_n119: return 0.1291067749261856f;
  t60_n120: return 0.14483290910720825f;
  t60_n121: return -0.028615526854991913f;
  t60_n122: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t60_n128;
  t60_n123: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t60_n125;
  t60_n124: return 0.07464428246021271f;
  t60_n125: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t60_n127;
  t60_n126: return 0.11110544949769974f;
  t60_n127: return 0.050598349422216415f;
  t60_n128: return 0.03960830345749855f;
  t60_n129: return -0.1280868798494339f;
  t60_n130: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t60_n168;
  t60_n131: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t60_n161;
  t60_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t60_n134;
  t60_n133: return 0.0015788371674716473f;
  t60_n134: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t60_n160;
  t60_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t60_n155;
  t60_n136: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t60_n142;
  t60_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t60_n139;
  t60_n138: return 0.014166762121021748f;
  t60_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t60_n141;
  t60_n140: return 0.022863101214170456f;
  t60_n141: return 0.04387182369828224f;
  t60_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t60_n144;
  t60_n143: return -0.07638002932071686f;
  t60_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t60_n146;
  t60_n145: return -0.03806503862142563f;
  t60_n146: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t60_n150;
  t60_n147: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t60_n149;
  t60_n148: return 0.009622116573154926f;
  t60_n149: return 0.07078113406896591f;
  t60_n150: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t60_n152;
  t60_n151: return 0.06872764974832535f;
  t60_n152: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t60_n154;
  t60_n153: return 0.12067794054746628f;
  t60_n154: return 0.05371250584721565f;
  t60_n155: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t60_n159;
  t60_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t60_n158;
  t60_n157: return -0.12095515429973602f;
  t60_n158: return 0.008608156815171242f;
  t60_n159: return 0.048249028623104095f;
  t60_n160: return -0.10917449742555618f;
  t60_n161: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t60_n165;
  t60_n162: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t60_n164;
  t60_n163: return -0.0754142701625824f;
  t60_n164: return -0.10792076587677002f;
  t60_n165: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t60_n167;
  t60_n166: return 0.02110866643488407f;
  t60_n167: return -0.03313973918557167f;
  t60_n168: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t60_n212;
  t60_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t60_n177;
  t60_n170: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t60_n174;
  t60_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t60_n173;
  t60_n172: return -0.021449686959385872f;
  t60_n173: return 0.05627036839723587f;
  t60_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t60_n176;
  t60_n175: return -0.24280261993408203f;
  t60_n176: return -0.036495987325906754f;
  t60_n177: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t60_n183;
  t60_n178: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t60_n182;
  t60_n179: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t60_n181;
  t60_n180: return 0.03640257194638252f;
  t60_n181: return 0.07550405710935593f;
  t60_n182: return 0.04547599330544472f;
  t60_n183: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t60_n211;
  t60_n184: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t60_n186;
  t60_n185: return 0.05236944183707237f;
  t60_n186: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t60_n202;
  t60_n187: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t60_n189;
  t60_n188: return 0.07427399605512619f;
  t60_n189: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t60_n193;
  t60_n190: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t60_n192;
  t60_n191: return 0.1438719630241394f;
  t60_n192: return 0.05685099586844444f;
  t60_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t60_n201;
  t60_n194: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t60_n196;
  t60_n195: return 0.06818115711212158f;
  t60_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t60_n198;
  t60_n197: return 0.07604147493839264f;
  t60_n198: if (E.getNumReferences() >= 3280158720 /*262.5*/) goto t60_n200;
  t60_n199: return 0.1268640160560608f;
  t60_n200: return 0.18133918941020966f;
  t60_n201: return 0.12830959260463715f;
  t60_n202: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t60_n204;
  t60_n203: return 0.08314311504364014f;
  t60_n204: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t60_n210;
  t60_n205: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t60_n209;
  t60_n206: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t60_n208;
  t60_n207: return 0.12404906749725342f;
  t60_n208: return 0.13209721446037292f;
  t60_n209: return 0.08591880649328232f;
  t60_n210: return -0.022107305005192757f;
  t60_n211: return 0.06590757519006729f;
  t60_n212: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t60_n232;
  t60_n213: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t60_n223;
  t60_n214: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t60_n216;
  t60_n215: return 0.03237684443593025f;
  t60_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t60_n218;
  t60_n217: return -0.05507660284638405f;
  t60_n218: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t60_n220;
  t60_n219: return 0.01901942677795887f;
  t60_n220: if (E.getNumReferences() >= 3304472576 /*1970.0*/) goto t60_n222;
  t60_n221: return 0.08980867266654968f;
  t60_n222: return 0.09019015729427338f;
  t60_n223: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t60_n229;
  t60_n224: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t60_n228;
  t60_n225: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t60_n227;
  t60_n226: return 0.12102415412664413f;
  t60_n227: return 0.13946186006069183f;
  t60_n228: return -0.5730909705162048f;
  t60_n229: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t60_n231;
  t60_n230: return 0.0002330445422558114f;
  t60_n231: return 0.05648306384682655f;
  t60_n232: if (E.getNumReferences() >= 3307765760 /*2696.0*/) goto t60_n234;
  t60_n233: return -0.02189508266746998f;
  t60_n234: return 0.017946740612387657f;
  t60_n235: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t60_n243;
  t60_n236: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t60_n242;
  t60_n237: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t60_n241;
  t60_n238: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t60_n240;
  t60_n239: return 0.048310648649930954f;
  t60_n240: return 0.0300438292324543f;
  t60_n241: return 0.0078104776330292225f;
  t60_n242: return 0.021170342341065407f;
  t60_n243: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t60_n245;
  t60_n244: return 0.023792345076799393f;
  t60_n245: return 0.06291677057743073f;
  t60_n246: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t60_n250;
  t60_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t60_n249;
  t60_n248: return -0.016890840604901314f;
  t60_n249: return 0.007367019075900316f;
  t60_n250: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t60_n254;
  t60_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t60_n253;
  t60_n252: return 0.003450787393376231f;
  t60_n253: return 0.022402344271540642f;
  t60_n254: return 0.041175514459609985f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree61(const Example& E) {
  t61_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t61_n234;
  t61_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t61_n59;
  t61_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t61_n40;
  t61_n3: if (E.getNumReferences() >= 3317190656 /*5898.0*/) goto t61_n35;
  t61_n4: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t61_n6;
  t61_n5: return -0.002688474953174591f;
  t61_n6: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t61_n34;
  t61_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t61_n11;
  t61_n8: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t61_n10;
  t61_n9: return 0.04169640690088272f;
  t61_n10: return -0.020323986187577248f;
  t61_n11: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t61_n25;
  t61_n12: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t61_n22;
  t61_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t61_n15;
  t61_n14: return 0.03903903812170029f;
  t61_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t61_n17;
  t61_n16: return 0.009758579544723034f;
  t61_n17: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t61_n21;
  t61_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t61_n20;
  t61_n19: return -0.0078056282363832f;
  t61_n20: return 0.09727604687213898f;
  t61_n21: return 0.008263950236141682f;
  t61_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t61_n24;
  t61_n23: return 0.07697572559118271f;
  t61_n24: return 0.020888613536953926f;
  t61_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t61_n31;
  t61_n26: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t61_n28;
  t61_n27: return 0.04597935080528259f;
  t61_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t61_n30;
  t61_n29: return -0.015829036012291908f;
  t61_n30: return 0.07852741330862045f;
  t61_n31: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t61_n33;
  t61_n32: return 0.1063232347369194f;
  t61_n33: return 0.09550962597131729f;
  t61_n34: return -0.07893868535757065f;
  t61_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t61_n37;
  t61_n36: return 0.018427683040499687f;
  t61_n37: if (E.getNumReferences() >= 3317207040 /*5906.0*/) goto t61_n39;
  t61_n38: return 0.11418096721172333f;
  t61_n39: return 0.054638225585222244f;
  t61_n40: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t61_n58;
  t61_n41: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t61_n57;
  t61_n42: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t61_n44;
  t61_n43: return -0.019901754334568977f;
  t61_n44: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t61_n46;
  t61_n45: return 0.022051164880394936f;
  t61_n46: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t61_n54;
  t61_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t61_n49;
  t61_n48: return 0.07629828155040741f;
  t61_n49: if (E.getNumReferences() >= 3252158464 /*27.0*/) goto t61_n51;
  t61_n50: return 0.08644882589578629f;
  t61_n51: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t61_n53;
  t61_n52: return 0.12055447697639465f;
  t61_n53: return 0.09805988520383835f;
  t61_n54: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t61_n56;
  t61_n55: return 0.05989977344870567f;
  t61_n56: return 0.07214871793985367f;
  t61_n57: return -0.05379561707377434f;
  t61_n58: return -0.007837734185159206f;
  t61_n59: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t61_n189;
  t61_n60: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t61_n70;
  t61_n61: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t61_n69;
  t61_n62: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t61_n64;
  t61_n63: return 0.008888653479516506f;
  t61_n64: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t61_n66;
  t61_n65: return -0.005769222974777222f;
  t61_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t61_n68;
  t61_n67: return 0.029972977936267853f;
  t61_n68: return 0.11482084542512894f;
  t61_n69: return -0.09369645267724991f;
  t61_n70: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t61_n102;
  t61_n71: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t61_n87;
  t61_n72: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t61_n74;
  t61_n73: return 0.036313071846961975f;
  t61_n74: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t61_n86;
  t61_n75: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t61_n85;
  t61_n76: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t61_n82;
  t61_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t61_n81;
  t61_n78: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t61_n80;
  t61_n79: return -1.2646253108978271f;
  t61_n80: return -0.032868947833776474f;
  t61_n81: return -0.020635036751627922f;
  t61_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t61_n84;
  t61_n83: return 0.0005253305425867438f;
  t61_n84: return 0.058422401547431946f;
  t61_n85: return 0.07955671846866608f;
  t61_n86: return 0.13692334294319153f;
  t61_n87: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t61_n89;
  t61_n88: return 0.037726372480392456f;
  t61_n89: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t61_n101;
  t61_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t61_n96;
  t61_n91: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t61_n93;
  t61_n92: return 0.0495709553360939f;
  t61_n93: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t61_n95;
  t61_n94: return -0.11376836150884628f;
  t61_n95: return 0.11328643560409546f;
  t61_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t61_n100;
  t61_n97: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t61_n99;
  t61_n98: return -0.27687013149261475f;
  t61_n99: return 0.10849657654762268f;
  t61_n100: return 0.1204078197479248f;
  t61_n101: return 0.0004890883574262261f;
  t61_n102: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t61_n116;
  t61_n103: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t61_n113;
  t61_n104: if (E.getNumReferences() >= 3289055232 /*556.0*/) goto t61_n108;
  t61_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t61_n107;
  t61_n106: return 0.048806775361299515f;
  t61_n107: return 0.07506565004587173f;
  t61_n108: if (E.getNumReferences() >= 3289702400 /*595.5*/) goto t61_n112;
  t61_n109: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t61_n111;
  t61_n110: return 0.10502558201551437f;
  t61_n111: return 0.17893637716770172f;
  t61_n112: return 0.053672462701797485f;
  t61_n113: if (E.getNumReferences() >= 3258449920 /*46.0*/) goto t61_n115;
  t61_n114: return 0.1228170096874237f;
  t61_n115: return 0.12319090962409973f;
  t61_n116: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t61_n184;
  t61_n117: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t61_n125;
  t61_n118: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t61_n120;
  t61_n119: return 0.050032489001750946f;
  t61_n120: if (E.getNumReferences() >= 3364747568 /*290761.5*/) goto t61_n122;
  t61_n121: return 0.015030228532850742f;
  t61_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t61_n124;
  t61_n123: return 0.10159795731306076f;
  t61_n124: return 0.10863190144300461f;
  t61_n125: if (E.getNumReferences() >= 3274080256 /*166.5*/) goto t61_n145;
  t61_n126: if (E.getFilterLength() >= 3250323456 /*23.5*/) goto t61_n144;
  t61_n127: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t61_n143;
  t61_n128: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t61_n140;
  t61_n129: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t61_n139;
  t61_n130: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t61_n138;
  t61_n131: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t61_n137;
  t61_n132: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t61_n136;
  t61_n133: if (E.getNumReferences() >= 3257008128 /*40.5*/) goto t61_n135;
  t61_n134: return 0.1322612464427948f;
  t61_n135: return 0.7578839063644409f;
  t61_n136: return 0.1287287473678589f;
  t61_n137: return -0.12451189011335373f;
  t61_n138: return -0.10627590864896774f;
  t61_n139: return 0.11298331618309021f;
  t61_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t61_n142;
  t61_n141: return 0.13345971703529358f;
  t61_n142: return 0.11776729673147202f;
  t61_n143: return 0.07949875295162201f;
  t61_n144: return 0.12992428243160248f;
  t61_n145: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t61_n149;
  t61_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t61_n148;
  t61_n147: return 0.0596432127058506f;
  t61_n148: return 0.07255249470472336f;
  t61_n149: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t61_n167;
  t61_n150: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t61_n152;
  t61_n151: return 0.10946575552225113f;
  t61_n152: if (E.getNumReferences() >= 3289341952 /*573.5*/) goto t61_n166;
  t61_n153: if (E.getNumReferences() >= 3288825856 /*542.0*/) goto t61_n165;
  t61_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t61_n160;
  t61_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t61_n157;
  t61_n156: return 0.09601285308599472f;
  t61_n157: if (E.getNumReferences() >= 3283124224 /*353.0*/) goto t61_n159;
  t61_n158: return -0.12552593648433685f;
  t61_n159: return 0.11896578967571259f;
  t61_n160: if (E.getNumReferences() >= 3278569472 /*235.0*/) goto t61_n162;
  t61_n161: return 0.12447575479745865f;
  t61_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t61_n164;
  t61_n163: return -0.19613017141819f;
  t61_n164: return 0.11275612562894821f;
  t61_n165: return 0.116266168653965f;
  t61_n166: return 0.06831816583871841f;
  t61_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t61_n169;
  t61_n168: return 0.0715729221701622f;
  t61_n169: if (E.getNumReferences() >= 3278077952 /*227.5*/) goto t61_n171;
  t61_n170: return -0.10752568393945694f;
  t61_n171: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t61_n181;
  t61_n172: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t61_n180;
  t61_n173: if (E.getNumReferences() >= 3306014720 /*2268.5*/) goto t61_n179;
  t61_n174: if (E.getNumReferences() >= 3292626944 /*774.0*/) goto t61_n176;
  t61_n175: return 0.09414530545473099f;
  t61_n176: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t61_n178;
  t61_n177: return 0.11186406761407852f;
  t61_n178: return 0.0977545753121376f;
  t61_n179: return 0.0658622682094574f;
  t61_n180: return 0.05958600714802742f;
  t61_n181: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t61_n183;
  t61_n182: return 0.12410902231931686f;
  t61_n183: return -0.021171918138861656f;
  t61_n184: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t61_n188;
  t61_n185: if (E.getNumReferences() >= 3261857792 /*59.0*/) goto t61_n187;
  t61_n186: return 0.14672920107841492f;
  t61_n187: return 0.10187336057424545f;
  t61_n188: return 0.08818325400352478f;
  t61_n189: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t61_n215;
  t61_n190: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t61_n200;
  t61_n191: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t61_n197;
  t61_n192: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t61_n196;
  t61_n193: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t61_n195;
  t61_n194: return 0.02975280210375786f;
  t61_n195: return 0.05303137004375458f;
  t61_n196: return 0.015888717025518417f;
  t61_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t61_n199;
  t61_n198: return -0.00499187596142292f;
  t61_n199: return 0.028774067759513855f;
  t61_n200: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t61_n210;
  t61_n201: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t61_n203;
  t61_n202: return -0.050620969384908676f;
  t61_n203: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t61_n205;
  t61_n204: return 0.025668948888778687f;
  t61_n205: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t61_n209;
  t61_n206: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t61_n208;
  t61_n207: return -0.0008961393614299595f;
  t61_n208: return 0.1275956928730011f;
  t61_n209: return 0.001083776936866343f;
  t61_n210: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t61_n212;
  t61_n211: return 0.021579047664999962f;
  t61_n212: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t61_n214;
  t61_n213: return 0.09180894494056702f;
  t61_n214: return 0.01763906143605709f;
  t61_n215: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t61_n225;
  t61_n216: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t61_n222;
  t61_n217: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t61_n219;
  t61_n218: return -0.012368135154247284f;
  t61_n219: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t61_n221;
  t61_n220: return 0.10645473003387451f;
  t61_n221: return 0.07627753913402557f;
  t61_n222: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t61_n224;
  t61_n223: return 0.018539641052484512f;
  t61_n224: return 0.070647232234478f;
  t61_n225: if (E.getNumReferences() >= 3335803904 /*27178.0*/) goto t61_n233;
  t61_n226: if (E.getNumReferences() >= 3315746816 /*5193.0*/) goto t61_n228;
  t61_n227: return 0.031953420490026474f;
  t61_n228: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t61_n232;
  t61_n229: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t61_n231;
  t61_n230: return 0.048473652452230453f;
  t61_n231: return 0.11262958496809006f;
  t61_n232: return 0.05313548073172569f;
  t61_n233: return -0.08172745257616043f;
  t61_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t61_n252;
  t61_n235: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t61_n243;
  t61_n236: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t61_n242;
  t61_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t61_n239;
  t61_n238: return -0.007230739574879408f;
  t61_n239: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown))) goto t61_n241;
  t61_n240: return -0.153207466006279f;
  t61_n241: return 0.006546650547534227f;
  t61_n242: return -0.23377101123332977f;
  t61_n243: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t61_n245;
  t61_n244: return 0.025960542261600494f;
  t61_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t61_n247;
  t61_n246: return 0.0873272493481636f;
  t61_n247: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t61_n249;
  t61_n248: return -0.0907054990530014f;
  t61_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t61_n251;
  t61_n250: return 0.10119717568159103f;
  t61_n251: return -0.010043847374618053f;
  t61_n252: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t61_n254;
  t61_n253: return 0.032954584807157516f;
  t61_n254: return -0.6991387605667114f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree62(const Example& E) {
  t62_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t62_n248;
  t62_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t62_n239;
  t62_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t62_n106;
  t62_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t62_n5;
  t62_n4: return -0.11910229921340942f;
  t62_n5: if (E.getNumReferences() >= 3301474304 /*1604.0*/) goto t62_n63;
  t62_n6: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t62_n12;
  t62_n7: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t62_n11;
  t62_n8: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t62_n10;
  t62_n9: return 0.01652831770479679f;
  t62_n10: return 0.043927207589149475f;
  t62_n11: return -0.0424213632941246f;
  t62_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t62_n14;
  t62_n13: return -0.003630460938438773f;
  t62_n14: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t62_n30;
  t62_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t62_n17;
  t62_n16: return -0.0777616798877716f;
  t62_n17: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t62_n19;
  t62_n18: return 0.004328985698521137f;
  t62_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t62_n29;
  t62_n20: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t62_n26;
  t62_n21: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t62_n23;
  t62_n22: return 0.03399229794740677f;
  t62_n23: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t62_n25;
  t62_n24: return 0.11660578846931458f;
  t62_n25: return 0.022402655333280563f;
  t62_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n28;
  t62_n27: return 0.13387563824653625f;
  t62_n28: return 0.0332576259970665f;
  t62_n29: return 0.0028056923765689135f;
  t62_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t62_n48;
  t62_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t62_n33;
  t62_n32: return 0.004617501050233841f;
  t62_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n35;
  t62_n34: return 0.03449399024248123f;
  t62_n35: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t62_n47;
  t62_n36: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t62_n38;
  t62_n37: return 0.06824631243944168f;
  t62_n38: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t62_n46;
  t62_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t62_n41;
  t62_n40: return 0.0924854725599289f;
  t62_n41: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t62_n43;
  t62_n42: return 0.04965367913246155f;
  t62_n43: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t62_n45;
  t62_n44: return 0.12507595121860504f;
  t62_n45: return 0.12103359401226044f;
  t62_n46: return 0.06209895759820938f;
  t62_n47: return 0.014065111055970192f;
  t62_n48: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t62_n62;
  t62_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t62_n59;
  t62_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n52;
  t62_n51: return 0.14178341627120972f;
  t62_n52: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t62_n58;
  t62_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t62_n55;
  t62_n54: return 0.12498944997787476f;
  t62_n55: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t62_n57;
  t62_n56: return 0.12990520894527435f;
  t62_n57: return 0.11423948407173157f;
  t62_n58: return 0.09548838436603546f;
  t62_n59: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t62_n61;
  t62_n60: return 0.09989149123430252f;
  t62_n61: return 0.08362066000699997f;
  t62_n62: return -0.07602657377719879f;
  t62_n63: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t62_n105;
  t62_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t62_n66;
  t62_n65: return 0.011322420090436935f;
  t62_n66: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t62_n98;
  t62_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t62_n75;
  t62_n68: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t62_n70;
  t62_n69: return 0.03270870819687843f;
  t62_n70: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n72;
  t62_n71: return -0.1820523589849472f;
  t62_n72: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t62_n74;
  t62_n73: return 0.11488620936870575f;
  t62_n74: return 0.09266892075538635f;
  t62_n75: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t62_n97;
  t62_n76: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t62_n90;
  t62_n77: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t62_n79;
  t62_n78: return 0.10776535421609879f;
  t62_n79: if (E.getNumReferences() >= 3320205312 /*7370.0*/) goto t62_n81;
  t62_n80: return 0.03906910866498947f;
  t62_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n85;
  t62_n82: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t62_n84;
  t62_n83: return 0.12530717253684998f;
  t62_n84: return 0.1493035852909088f;
  t62_n85: if (E.getNumReferences() >= 3348038400 /*73222.0*/) goto t62_n89;
  t62_n86: if (E.getNumReferences() >= 3331855104 /*19465.5*/) goto t62_n88;
  t62_n87: return -0.24254107475280762f;
  t62_n88: return 0.15630397200584412f;
  t62_n89: return 0.0018753298791125417f;
  t62_n90: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t62_n92;
  t62_n91: return -0.1998811960220337f;
  t62_n92: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t62_n96;
  t62_n93: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t62_n95;
  t62_n94: return 0.12128446251153946f;
  t62_n95: return 0.11609316617250443f;
  t62_n96: return 0.10900365561246872f;
  t62_n97: return 0.037162598222494125f;
  t62_n98: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t62_n100;
  t62_n99: return 0.00827123410999775f;
  t62_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t62_n102;
  t62_n101: return -0.23015335202217102f;
  t62_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n104;
  t62_n103: return 0.06376876682043076f;
  t62_n104: return 0.1101238876581192f;
  t62_n105: return 0.04291210696101189f;
  t62_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t62_n108;
  t62_n107: return -0.007092191372066736f;
  t62_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t62_n238;
  t62_n109: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t62_n233;
  t62_n110: if (E.getNumReferences() >= 3347329664 /*67685.0*/) goto t62_n194;
  t62_n111: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t62_n161;
  t62_n112: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n114;
  t62_n113: return 0.0006546808290295303f;
  t62_n114: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t62_n116;
  t62_n115: return 0.018081214278936386f;
  t62_n116: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t62_n118;
  t62_n117: return 0.038946911692619324f;
  t62_n118: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t62_n152;
  t62_n119: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t62_n123;
  t62_n120: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t62_n122;
  t62_n121: return 0.023653985932469368f;
  t62_n122: return 0.07976188510656357f;
  t62_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t62_n151;
  t62_n124: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t62_n130;
  t62_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t62_n127;
  t62_n126: return 0.04283050820231438f;
  t62_n127: if (E.getNumReferences() >= 3272114176 /*136.5*/) goto t62_n129;
  t62_n128: return 0.11266927421092987f;
  t62_n129: return 0.10206324607133865f;
  t62_n130: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t62_n150;
  t62_n131: if (E.getNumReferences() >= 3301101568 /*1558.5*/) goto t62_n149;
  t62_n132: if (E.getNumReferences() >= 3289096192 /*558.5*/) goto t62_n144;
  t62_n133: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t62_n143;
  t62_n134: if (E.getNumReferences() >= 3283894272 /*376.5*/) goto t62_n142;
  t62_n135: if (E.getNumReferences() >= 3278929920 /*240.5*/) goto t62_n141;
  t62_n136: if (E.getNumReferences() >= 3275816960 /*193.0*/) goto t62_n140;
  t62_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t62_n139;
  t62_n138: return 0.11428509652614594f;
  t62_n139: return 0.12509790062904358f;
  t62_n140: return -0.10402829945087433f;
  t62_n141: return 0.13814778625965118f;
  t62_n142: return 0.08530663698911667f;
  t62_n143: return 0.09001000970602036f;
  t62_n144: if (E.getNumReferences() >= 3291480064 /*704.0*/) goto t62_n146;
  t62_n145: return 0.13960784673690796f;
  t62_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t62_n148;
  t62_n147: return 0.11492361128330231f;
  t62_n148: return 0.12272553890943527f;
  t62_n149: return 0.08490412682294846f;
  t62_n150: return 0.09028047323226929f;
  t62_n151: return 0.0228284802287817f;
  t62_n152: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t62_n154;
  t62_n153: return 0.05710701644420624f;
  t62_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t62_n160;
  t62_n155: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t62_n159;
  t62_n156: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t62_n158;
  t62_n157: return 0.012671458534896374f;
  t62_n158: return 0.13898177444934845f;
  t62_n159: return 0.07008057087659836f;
  t62_n160: return 0.10040083527565002f;
  t62_n161: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t62_n183;
  t62_n162: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t62_n182;
  t62_n163: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t62_n165;
  t62_n164: return 0.013152171857655048f;
  t62_n165: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t62_n167;
  t62_n166: return 0.0061471350491046906f;
  t62_n167: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t62_n171;
  t62_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Symbol))) goto t62_n170;
  t62_n169: return -0.031028112396597862f;
  t62_n170: return 0.038136959075927734f;
  t62_n171: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t62_n173;
  t62_n172: return 0.07181185483932495f;
  t62_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t62_n179;
  t62_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t62_n178;
  t62_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t62_n177;
  t62_n176: return -0.02574349008500576f;
  t62_n177: return 0.07266063988208771f;
  t62_n178: return 0.1353096067905426f;
  t62_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t62_n181;
  t62_n180: return -0.11153765022754669f;
  t62_n181: return 0.14969614148139954f;
  t62_n182: return -0.13167212903499603f;
  t62_n183: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t62_n185;
  t62_n184: return -0.0946994200348854f;
  t62_n185: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t62_n189;
  t62_n186: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t62_n188;
  t62_n187: return 0.007587837520986795f;
  t62_n188: return 0.035135142505168915f;
  t62_n189: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t62_n191;
  t62_n190: return -0.016243215650320053f;
  t62_n191: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t62_n193;
  t62_n192: return -0.023419920355081558f;
  t62_n193: return 0.07121126353740692f;
  t62_n194: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n198;
  t62_n195: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t62_n197;
  t62_n196: return 0.03199189156293869f;
  t62_n197: return -0.027957599610090256f;
  t62_n198: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t62_n230;
  t62_n199: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t62_n217;
  t62_n200: if (E.getNumReferences() >= 3357271616 /*159641.0*/) goto t62_n216;
  t62_n201: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t62_n203;
  t62_n202: return 0.04082849621772766f;
  t62_n203: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t62_n215;
  t62_n204: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t62_n206;
  t62_n205: return 0.05322428047657013f;
  t62_n206: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t62_n208;
  t62_n207: return 0.07276217639446259f;
  t62_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t62_n210;
  t62_n209: return 0.0406542643904686f;
  t62_n210: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t62_n212;
  t62_n211: return 0.10391473770141602f;
  t62_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t62_n214;
  t62_n213: return 0.11465714871883392f;
  t62_n214: return 0.1153777539730072f;
  t62_n215: return 0.037165023386478424f;
  t62_n216: return -0.33891257643699646f;
  t62_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t62_n223;
  t62_n218: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t62_n220;
  t62_n219: return 0.04136281833052635f;
  t62_n220: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t62_n222;
  t62_n221: return 0.11836188286542892f;
  t62_n222: return -0.17109569907188416f;
  t62_n223: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t62_n229;
  t62_n224: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t62_n228;
  t62_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t62_n227;
  t62_n226: return 0.09518096596002579f;
  t62_n227: return 0.111060231924057f;
  t62_n228: return 0.08195760846138f;
  t62_n229: return 0.10361205786466599f;
  t62_n230: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t62_n232;
  t62_n231: return -0.12635259330272675f;
  t62_n232: return 0.024838123470544815f;
  t62_n233: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t62_n237;
  t62_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t62_n236;
  t62_n235: return 0.061910469084978104f;
  t62_n236: return 0.017036184668540955f;
  t62_n237: return 0.02409341186285019f;
  t62_n238: return -0.04369986429810524f;
  t62_n239: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t62_n245;
  t62_n240: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t62_n244;
  t62_n241: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t62_n243;
  t62_n242: return 0.015338650904595852f;
  t62_n243: return -0.03537432476878166f;
  t62_n244: return 0.019526425749063492f;
  t62_n245: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t62_n247;
  t62_n246: return 0.022495562210679054f;
  t62_n247: return 0.060240842401981354f;
  t62_n248: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t62_n250;
  t62_n249: return 0.0013547015842050314f;
  t62_n250: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t62_n254;
  t62_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n253;
  t62_n252: return 0.0032222727313637733f;
  t62_n253: return 0.021199572831392288f;
  t62_n254: return 0.03910352289676666f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree63(const Example& E) {
  t63_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t63_n248;
  t63_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t63_n223;
  t63_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t63_n40;
  t63_n3: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t63_n5;
  t63_n4: return 0.0007447571842931211f;
  t63_n5: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t63_n7;
  t63_n6: return 0.0113283796235919f;
  t63_n7: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t63_n9;
  t63_n8: return 0.02094602771103382f;
  t63_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t63_n23;
  t63_n10: if (E.getNumReferences() >= 3308015616 /*2757.0*/) goto t63_n16;
  t63_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t63_n13;
  t63_n12: return -0.0099408570677042f;
  t63_n13: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t63_n15;
  t63_n14: return 0.04074479267001152f;
  t63_n15: return -0.0324704572558403f;
  t63_n16: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t63_n20;
  t63_n17: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t63_n19;
  t63_n18: return 0.044752128422260284f;
  t63_n19: return 0.11421708762645721f;
  t63_n20: if (E.getNumReferences() >= 3314900992 /*4780.0*/) goto t63_n22;
  t63_n21: return 0.13111642003059387f;
  t63_n22: return -0.04850918799638748f;
  t63_n23: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t63_n25;
  t63_n24: return 0.04647286981344223f;
  t63_n25: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t63_n27;
  t63_n26: return 0.04308740049600601f;
  t63_n27: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t63_n29;
  t63_n28: return 0.0689612552523613f;
  t63_n29: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t63_n31;
  t63_n30: return 0.12836581468582153f;
  t63_n31: if (E.getNumReferences() >= 3280142336 /*262.0*/) goto t63_n33;
  t63_n32: return 0.06265280395746231f;
  t63_n33: if (E.getNumReferences() >= 3281092608 /*291.0*/) goto t63_n35;
  t63_n34: return 0.1174449548125267f;
  t63_n35: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t63_n37;
  t63_n36: return 0.08132028579711914f;
  t63_n37: if (E.getNumReferences() >= 3289153536 /*562.0*/) goto t63_n39;
  t63_n38: return 0.09752271324396133f;
  t63_n39: return 0.12709374725818634f;
  t63_n40: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t63_n100;
  t63_n41: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t63_n43;
  t63_n42: return -0.007808484602719545f;
  t63_n43: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t63_n69;
  t63_n44: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t63_n46;
  t63_n45: return -0.004790439270436764f;
  t63_n46: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t63_n58;
  t63_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t63_n49;
  t63_n48: return 0.04036032781004906f;
  t63_n49: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t63_n57;
  t63_n50: if (E.getNumReferences() >= 3280977920 /*287.5*/) goto t63_n52;
  t63_n51: return 0.05743573606014252f;
  t63_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t63_n54;
  t63_n53: return 0.10068926960229874f;
  t63_n54: if (E.getNumReferences() >= 3293446144 /*824.0*/) goto t63_n56;
  t63_n55: return 0.13360269367694855f;
  t63_n56: return 0.09850990772247314f;
  t63_n57: return 0.033065810799598694f;
  t63_n58: if (E.getNumReferences() >= 3294625792 /*896.0*/) goto t63_n62;
  t63_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t63_n61;
  t63_n60: return -0.020835064351558685f;
  t63_n61: return 0.02942359633743763f;
  t63_n62: if (E.getNumReferences() >= 3294732288 /*902.5*/) goto t63_n64;
  t63_n63: return 0.10402513295412064f;
  t63_n64: if (E.getNumReferences() >= 3337586944 /*30660.5*/) goto t63_n66;
  t63_n65: return 0.016173774376511574f;
  t63_n66: if (E.getNumReferences() >= 3338315520 /*32083.5*/) goto t63_n68;
  t63_n67: return 0.10886112600564957f;
  t63_n68: return 0.05429811030626297f;
  t63_n69: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t63_n91;
  t63_n70: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t63_n74;
  t63_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t63_n73;
  t63_n72: return 0.062272872775793076f;
  t63_n73: return 0.08659258484840393f;
  t63_n74: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t63_n76;
  t63_n75: return 0.0722891241312027f;
  t63_n76: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t63_n90;
  t63_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t63_n85;
  t63_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Expression))) goto t63_n80;
  t63_n79: return 0.06823477894067764f;
  t63_n80: if (E.getNumReferences() >= 3289284608 /*570.0*/) goto t63_n82;
  t63_n81: return 0.10697054862976074f;
  t63_n82: if (E.getNumReferences() >= 3296874496 /*1042.5*/) goto t63_n84;
  t63_n83: return 0.11500608175992966f;
  t63_n84: return 0.1015983298420906f;
  t63_n85: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t63_n89;
  t63_n86: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t63_n88;
  t63_n87: return 0.10268504172563553f;
  t63_n88: return 0.12175045162439346f;
  t63_n89: return 0.10780651122331619f;
  t63_n90: return 0.030830416828393936f;
  t63_n91: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t63_n93;
  t63_n92: return 0.0743471011519432f;
  t63_n93: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t63_n99;
  t63_n94: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t63_n98;
  t63_n95: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t63_n97;
  t63_n96: return 0.09705880284309387f;
  t63_n97: return 0.13587133586406708f;
  t63_n98: return 0.08937767893075943f;
  t63_n99: return 0.10446525365114212f;
  t63_n100: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t63_n102;
  t63_n101: return -0.040894437581300735f;
  t63_n102: if (E.getNumReferences() >= 3297136640 /*1074.5*/) goto t63_n134;
  t63_n103: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t63_n109;
  t63_n104: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t63_n108;
  t63_n105: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t63_n107;
  t63_n106: return -0.006937433034181595f;
  t63_n107: return 0.018998360261321068f;
  t63_n108: return -0.07100225985050201f;
  t63_n109: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t63_n111;
  t63_n110: return -0.09767231345176697f;
  t63_n111: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t63_n113;
  t63_n112: return -0.04092225059866905f;
  t63_n113: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t63_n115;
  t63_n114: return 0.057492226362228394f;
  t63_n115: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t63_n127;
  t63_n116: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t63_n118;
  t63_n117: return 0.05360598862171173f;
  t63_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t63_n120;
  t63_n119: return 0.0863308236002922f;
  t63_n120: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t63_n126;
  t63_n121: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t63_n125;
  t63_n122: if (E.getNumReferences() >= 3272114176 /*136.5*/) goto t63_n124;
  t63_n123: return 0.12502773106098175f;
  t63_n124: return 0.11587391048669815f;
  t63_n125: return -0.18643465638160706f;
  t63_n126: return 0.07628177106380463f;
  t63_n127: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t63_n131;
  t63_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t63_n130;
  t63_n129: return -0.10258322954177856f;
  t63_n130: return 0.14371179044246674f;
  t63_n131: if (E.getNumReferences() >= 3273621504 /*159.5*/) goto t63_n133;
  t63_n132: return 0.068174347281456f;
  t63_n133: return 0.08748720586299896f;
  t63_n134: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t63_n136;
  t63_n135: return -0.0031219685915857553f;
  t63_n136: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t63_n182;
  t63_n137: if (E.getNumReferences() >= 3313728512 /*4207.5*/) goto t63_n139;
  t63_n138: return 0.012720564380288124f;
  t63_n139: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t63_n153;
  t63_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t63_n148;
  t63_n141: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t63_n145;
  t63_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t63_n144;
  t63_n143: return -0.32402926683425903f;
  t63_n144: return 0.045374590903520584f;
  t63_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t63_n147;
  t63_n146: return -0.03592067211866379f;
  t63_n147: return 0.10044491291046143f;
  t63_n148: if (E.getNumReferences() >= 3313753088 /*4219.5*/) goto t63_n150;
  t63_n149: return 0.1035466194152832f;
  t63_n150: if (E.getNumReferences() >= 3319138304 /*6849.0*/) goto t63_n152;
  t63_n151: return 0.06400834769010544f;
  t63_n152: return 0.07005418092012405f;
  t63_n153: if (E.getNumReferences() >= 3347118592 /*66036.0*/) goto t63_n161;
  t63_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t63_n160;
  t63_n155: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t63_n157;
  t63_n156: return -0.23394614458084106f;
  t63_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t63_n159;
  t63_n158: return -1.8256585597991943f;
  t63_n159: return -0.2291814684867859f;
  t63_n160: return -0.021160556003451347f;
  t63_n161: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t63_n177;
  t63_n162: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t63_n166;
  t63_n163: if (E.getNumReferences() >= 3355687776 /*134893.5*/) goto t63_n165;
  t63_n164: return 0.021040402352809906f;
  t63_n165: return -0.20569559931755066f;
  t63_n166: if (E.getNumReferences() >= 3360228064 /*205835.5*/) goto t63_n174;
  t63_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t63_n169;
  t63_n168: return -0.1231517642736435f;
  t63_n169: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t63_n171;
  t63_n170: return 0.10540192574262619f;
  t63_n171: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t63_n173;
  t63_n172: return 0.09994592517614365f;
  t63_n173: return 0.13689520955085754f;
  t63_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t63_n176;
  t63_n175: return -0.08152545243501663f;
  t63_n176: return 0.06487927585840225f;
  t63_n177: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t63_n181;
  t63_n178: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t63_n180;
  t63_n179: return -0.2817407548427582f;
  t63_n180: return 0.061266928911209106f;
  t63_n181: return -0.13484859466552734f;
  t63_n182: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t63_n204;
  t63_n183: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t63_n185;
  t63_n184: return 0.050951190292835236f;
  t63_n185: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t63_n187;
  t63_n186: return 0.11991261690855026f;
  t63_n187: if (E.getNumReferences() >= 3334377216 /*24391.5*/) goto t63_n203;
  t63_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t63_n198;
  t63_n189: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t63_n197;
  t63_n190: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t63_n192;
  t63_n191: return -0.008353037759661674f;
  t63_n192: if (E.getNumReferences() >= 3332719104 /*21153.0*/) goto t63_n194;
  t63_n193: return -0.12222342938184738f;
  t63_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t63_n196;
  t63_n195: return 0.11854426562786102f;
  t63_n196: return 0.1180325374007225f;
  t63_n197: return 0.09821303188800812f;
  t63_n198: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t63_n202;
  t63_n199: if (E.getNumReferences() >= 3332878080 /*21463.5*/) goto t63_n201;
  t63_n200: return 0.08401595801115036f;
  t63_n201: return 0.10483069717884064f;
  t63_n202: return 0.11419687420129776f;
  t63_n203: return 0.04077260568737984f;
  t63_n204: if (E.getNumReferences() >= 3297198080 /*1082.0*/) goto t63_n208;
  t63_n205: if (E.getNumReferences() >= 3297153024 /*1076.5*/) goto t63_n207;
  t63_n206: return 0.09803646802902222f;
  t63_n207: return 0.11916948109865189f;
  t63_n208: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t63_n210;
  t63_n209: return 0.06551878154277802f;
  t63_n210: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t63_n214;
  t63_n211: if (E.getNumReferences() >= 3302932480 /*1782.0*/) goto t63_n213;
  t63_n212: return 0.1172180026769638f;
  t63_n213: return 0.05466178432106972f;
  t63_n214: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t63_n220;
  t63_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t63_n219;
  t63_n216: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t63_n218;
  t63_n217: return 0.059932004660367966f;
  t63_n218: return 0.12282747775316238f;
  t63_n219: return 0.11154378205537796f;
  t63_n220: if (E.getNumReferences() >= 3306420224 /*2367.5*/) goto t63_n222;
  t63_n221: return 0.11383315920829773f;
  t63_n222: return 0.06141388416290283f;
  t63_n223: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t63_n231;
  t63_n224: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t63_n230;
  t63_n225: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t63_n229;
  t63_n226: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t63_n228;
  t63_n227: return 0.046275608241558075f;
  t63_n228: return 0.027195684611797333f;
  t63_n229: return 0.007354373577982187f;
  t63_n230: return 0.01817762665450573f;
  t63_n231: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t63_n243;
  t63_n232: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t63_n238;
  t63_n233: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t63_n237;
  t63_n234: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t63_n236;
  t63_n235: return 0.027653485536575317f;
  t63_n236: return 0.07645416259765625f;
  t63_n237: return -0.02901928313076496f;
  t63_n238: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t63_n242;
  t63_n239: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t63_n241;
  t63_n240: return 0.04458116367459297f;
  t63_n241: return 0.09025359153747559f;
  t63_n242: return -0.000820386572740972f;
  t63_n243: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t63_n245;
  t63_n244: return 0.05629705637693405f;
  t63_n245: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t63_n247;
  t63_n246: return 0.11339908838272095f;
  t63_n247: return 0.08640097081661224f;
  t63_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t63_n254;
  t63_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t63_n251;
  t63_n250: return -0.0016391681274399161f;
  t63_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t63_n253;
  t63_n252: return 0.0025910327676683664f;
  t63_n253: return 0.019565949216485023f;
  t63_n254: return 0.030125197023153305f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree64(const Example& E) {
  t64_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t64_n248;
  t64_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t64_n157;
  t64_n2: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t64_n120;
  t64_n3: if (E.getNumReferences() >= 3305242624 /*2080.0*/) goto t64_n5;
  t64_n4: return -0.015650469809770584f;
  t64_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t64_n17;
  t64_n6: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t64_n16;
  t64_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t64_n9;
  t64_n8: return 0.01510203629732132f;
  t64_n9: if (E.getNumReferences() >= 3317228544 /*5916.5*/) goto t64_n11;
  t64_n10: return 0.01952078379690647f;
  t64_n11: if (E.getNumReferences() >= 3317296128 /*5949.5*/) goto t64_n15;
  t64_n12: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t64_n14;
  t64_n13: return -0.35022637248039246f;
  t64_n14: return 0.11193179339170456f;
  t64_n15: return 0.05653587728738785f;
  t64_n16: return -0.010409989394247532f;
  t64_n17: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t64_n119;
  t64_n18: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t64_n38;
  t64_n19: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t64_n29;
  t64_n20: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t64_n26;
  t64_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t64_n23;
  t64_n22: return 0.03693248704075813f;
  t64_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t64_n25;
  t64_n24: return 0.008617357350885868f;
  t64_n25: return 0.10135617852210999f;
  t64_n26: if (E.getNumReferences() >= 3318874112 /*6720.0*/) goto t64_n28;
  t64_n27: return 0.11961625516414642f;
  t64_n28: return 0.2094815969467163f;
  t64_n29: if (E.getNumReferences() >= 3367213520 /*367822.5*/) goto t64_n33;
  t64_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t64_n32;
  t64_n31: return -0.07458770275115967f;
  t64_n32: return -0.01327170804142952f;
  t64_n33: if (E.getNumReferences() >= 3368655888 /*412896.5*/) goto t64_n37;
  t64_n34: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t64_n36;
  t64_n35: return 0.11106342822313309f;
  t64_n36: return 0.07492045313119888f;
  t64_n37: return 0.04428272694349289f;
  t64_n38: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t64_n94;
  t64_n39: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t64_n93;
  t64_n40: if (E.getNumReferences() >= 3341306880 /*43084.0*/) goto t64_n76;
  t64_n41: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t64_n43;
  t64_n42: return 0.03357803821563721f;
  t64_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t64_n45;
  t64_n44: return -0.004673770163208246f;
  t64_n45: if (E.getNumReferences() >= 3318883328 /*6724.5*/) goto t64_n47;
  t64_n46: return 0.05133851245045662f;
  t64_n47: if (E.getNumReferences() >= 3325080064 /*11308.5*/) goto t64_n69;
  t64_n48: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t64_n68;
  t64_n49: if (E.getNumReferences() >= 3324699136 /*10936.5*/) goto t64_n65;
  t64_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t64_n58;
  t64_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t64_n53;
  t64_n52: return 0.07192136347293854f;
  t64_n53: if (E.getNumReferences() >= 3319440384 /*6996.5*/) goto t64_n55;
  t64_n54: return 0.0617440827190876f;
  t64_n55: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t64_n57;
  t64_n56: return 0.11156341433525085f;
  t64_n57: return 0.08630163967609406f;
  t64_n58: if (E.getNumReferences() >= 3322129920 /*8427.5*/) goto t64_n64;
  t64_n59: if (E.getNumReferences() >= 3321240576 /*7875.5*/) goto t64_n63;
  t64_n60: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t64_n62;
  t64_n61: return 0.10298074036836624f;
  t64_n62: return 0.1360694020986557f;
  t64_n63: return 0.1268225461244583f;
  t64_n64: return 0.01764564774930477f;
  t64_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t64_n67;
  t64_n66: return -0.1112494096159935f;
  t64_n67: return 0.1071305125951767f;
  t64_n68: return 0.0796777755022049f;
  t64_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t64_n71;
  t64_n70: return 0.03607213497161865f;
  t64_n71: if (E.getNumReferences() >= 3331329792 /*18439.5*/) goto t64_n75;
  t64_n72: if (E.getNumReferences() >= 3331157760 /*18103.5*/) goto t64_n74;
  t64_n73: return 0.019610291346907616f;
  t64_n74: return 0.10466224700212479f;
  t64_n75: return 0.08185446262359619f;
  t64_n76: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t64_n88;
  t64_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t64_n79;
  t64_n78: return -0.24048803746700287f;
  t64_n79: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t64_n85;
  t64_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t64_n82;
  t64_n81: return 0.10708088427782059f;
  t64_n82: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t64_n84;
  t64_n83: return 0.11103545129299164f;
  t64_n84: return 0.09615489095449448f;
  t64_n85: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t64_n87;
  t64_n86: return 0.11561645567417145f;
  t64_n87: return 0.0984160378575325f;
  t64_n88: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t64_n90;
  t64_n89: return 0.048064667731523514f;
  t64_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t64_n92;
  t64_n91: return 0.06870903819799423f;
  t64_n92: return 0.10507741570472717f;
  t64_n93: return -0.012510381639003754f;
  t64_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t64_n112;
  t64_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t64_n99;
  t64_n96: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t64_n98;
  t64_n97: return 0.040057651698589325f;
  t64_n98: return 0.06098034232854843f;
  t64_n99: if (E.getNumReferences() >= 3350280192 /*90736.0*/) goto t64_n111;
  t64_n100: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t64_n102;
  t64_n101: return 0.07540962100028992f;
  t64_n102: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t64_n104;
  t64_n103: return 0.10608634352684021f;
  t64_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t64_n110;
  t64_n105: if (E.getNumReferences() >= 3334486784 /*24605.5*/) goto t64_n109;
  t64_n106: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t64_n108;
  t64_n107: return 0.09320776164531708f;
  t64_n108: return 0.10702026635408401f;
  t64_n109: return 0.0689849853515625f;
  t64_n110: return 0.04317961633205414f;
  t64_n111: return -0.023771122097969055f;
  t64_n112: if (E.getNumReferences() >= 3306094592 /*2288.0*/) goto t64_n114;
  t64_n113: return 0.12401192635297775f;
  t64_n114: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t64_n116;
  t64_n115: return 0.08579037338495255f;
  t64_n116: if (E.getNumReferences() >= 3308046336 /*2764.5*/) goto t64_n118;
  t64_n117: return 0.12239048629999161f;
  t64_n118: return 0.09845999628305435f;
  t64_n119: return 0.06019754707813263f;
  t64_n120: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t64_n148;
  t64_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t64_n123;
  t64_n122: return 0.014814074151217937f;
  t64_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t64_n125;
  t64_n124: return 0.05027838051319122f;
  t64_n125: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t64_n147;
  t64_n126: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t64_n134;
  t64_n127: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t64_n129;
  t64_n128: return 0.02608424611389637f;
  t64_n129: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t64_n133;
  t64_n130: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t64_n132;
  t64_n131: return 0.0768139660358429f;
  t64_n132: return 0.1011427491903305f;
  t64_n133: return 0.03797631338238716f;
  t64_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t64_n140;
  t64_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t64_n137;
  t64_n136: return 0.07635113596916199f;
  t64_n137: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t64_n139;
  t64_n138: return -0.11095718294382095f;
  t64_n139: return 0.08144692331552505f;
  t64_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t64_n142;
  t64_n141: return 0.0979367196559906f;
  t64_n142: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t64_n146;
  t64_n143: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t64_n145;
  t64_n144: return 0.17299604415893555f;
  t64_n145: return 0.15530087053775787f;
  t64_n146: return -0.10150470584630966f;
  t64_n147: return 0.004438433330506086f;
  t64_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t64_n150;
  t64_n149: return -0.07145600020885468f;
  t64_n150: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t64_n152;
  t64_n151: return 0.0022665977012366056f;
  t64_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t64_n156;
  t64_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t64_n155;
  t64_n154: return 0.029187016189098358f;
  t64_n155: return 0.08714766800403595f;
  t64_n156: return 0.06918095052242279f;
  t64_n157: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t64_n179;
  t64_n158: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t64_n174;
  t64_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t64_n165;
  t64_n160: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t64_n162;
  t64_n161: return -0.0035827995743602514f;
  t64_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t64_n164;
  t64_n163: return -0.07360649853944778f;
  t64_n164: return -0.0188454482704401f;
  t64_n165: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t64_n169;
  t64_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t64_n168;
  t64_n167: return -0.024988757446408272f;
  t64_n168: return 0.013878131285309792f;
  t64_n169: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t64_n171;
  t64_n170: return 0.04068358987569809f;
  t64_n171: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t64_n173;
  t64_n172: return -0.09092620760202408f;
  t64_n173: return -0.0071328734047710896f;
  t64_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t64_n176;
  t64_n175: return -0.009482506662607193f;
  t64_n176: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t64_n178;
  t64_n177: return 0.025495463982224464f;
  t64_n178: return 0.0004686205356847495f;
  t64_n179: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t64_n207;
  t64_n180: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t64_n186;
  t64_n181: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t64_n183;
  t64_n182: return 0.027688592672348022f;
  t64_n183: if (E.getNumReferences() >= 3334835456 /*25286.5*/) goto t64_n185;
  t64_n184: return -0.039729032665491104f;
  t64_n185: return 0.028255118057131767f;
  t64_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t64_n192;
  t64_n187: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t64_n189;
  t64_n188: return 0.03458377346396446f;
  t64_n189: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t64_n191;
  t64_n190: return 0.10842622816562653f;
  t64_n191: return 0.12370363622903824f;
  t64_n192: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t64_n200;
  t64_n193: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t64_n195;
  t64_n194: return 0.052328240126371384f;
  t64_n195: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t64_n199;
  t64_n196: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t64_n198;
  t64_n197: return -0.1493755728006363f;
  t64_n198: return 0.12404794245958328f;
  t64_n199: return 0.07402962446212769f;
  t64_n200: if (E.getNumReferences() >= 3280207872 /*264.0*/) goto t64_n202;
  t64_n201: return 0.10936228930950165f;
  t64_n202: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t64_n206;
  t64_n203: if (E.getNumReferences() >= 3282075648 /*321.0*/) goto t64_n205;
  t64_n204: return 0.11748813837766647f;
  t64_n205: return 0.11620476841926575f;
  t64_n206: return 0.04086945578455925f;
  t64_n207: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t64_n219;
  t64_n208: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t64_n210;
  t64_n209: return 0.03553832322359085f;
  t64_n210: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t64_n218;
  t64_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t64_n217;
  t64_n212: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t64_n214;
  t64_n213: return 0.048836857080459595f;
  t64_n214: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t64_n216;
  t64_n215: return -0.11207370460033417f;
  t64_n216: return 0.11305306851863861f;
  t64_n217: return 0.10521330684423447f;
  t64_n218: return 0.0008481668191961944f;
  t64_n219: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t64_n237;
  t64_n220: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t64_n222;
  t64_n221: return 0.06916981190443039f;
  t64_n222: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t64_n228;
  t64_n223: if (E.getNumReferences() >= 3364747568 /*290761.5*/) goto t64_n225;
  t64_n224: return 0.018041646108031273f;
  t64_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t64_n227;
  t64_n226: return 0.10143215954303741f;
  t64_n227: return 0.10973773151636124f;
  t64_n228: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t64_n230;
  t64_n229: return 0.07672259956598282f;
  t64_n230: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t64_n236;
  t64_n231: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t64_n233;
  t64_n232: return 0.054659366607666016f;
  t64_n233: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t64_n235;
  t64_n234: return 0.11243365705013275f;
  t64_n235: return 0.0828460156917572f;
  t64_n236: return 0.07781333476305008f;
  t64_n237: if (E.getNumReferences() >= 3263692800 /*68.0*/) goto t64_n247;
  t64_n238: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t64_n246;
  t64_n239: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t64_n243;
  t64_n240: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t64_n242;
  t64_n241: return 0.10490712523460388f;
  t64_n242: return 0.1520596295595169f;
  t64_n243: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t64_n245;
  t64_n244: return -0.10040918737649918f;
  t64_n245: return 0.12808799743652344f;
  t64_n246: return -0.19436940550804138f;
  t64_n247: return 0.0777873545885086f;
  t64_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t64_n250;
  t64_n249: return -0.005219256039708853f;
  t64_n250: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t64_n254;
  t64_n251: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t64_n253;
  t64_n252: return 0.004042814951390028f;
  t64_n253: return 0.024084853008389473f;
  t64_n254: return 0.029685167595744133f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree65(const Example& E) {
  t65_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t65_n226;
  t65_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t65_n131;
  t65_n2: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t65_n98;
  t65_n3: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t65_n67;
  t65_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t65_n6;
  t65_n5: return -0.01834535412490368f;
  t65_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t65_n66;
  t65_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t65_n57;
  t65_n8: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t65_n52;
  t65_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t65_n13;
  t65_n10: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t65_n12;
  t65_n11: return -0.1248989999294281f;
  t65_n12: return -0.032169684767723083f;
  t65_n13: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t65_n23;
  t65_n14: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t65_n22;
  t65_n15: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t65_n21;
  t65_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t65_n20;
  t65_n17: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t65_n19;
  t65_n18: return 0.06657944619655609f;
  t65_n19: return 0.08379063755273819f;
  t65_n20: return 0.11389318853616714f;
  t65_n21: return 0.04432129114866257f;
  t65_n22: return -0.018720533698797226f;
  t65_n23: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t65_n35;
  t65_n24: if (E.getNumReferences() >= 3328830976 /*14971.5*/) goto t65_n34;
  t65_n25: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n27;
  t65_n26: return -0.01682526245713234f;
  t65_n27: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t65_n33;
  t65_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t65_n32;
  t65_n29: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t65_n31;
  t65_n30: return -0.13796746730804443f;
  t65_n31: return -0.37000998854637146f;
  t65_n32: return 0.10431923717260361f;
  t65_n33: return -0.002061940962448716f;
  t65_n34: return 0.08060920983552933f;
  t65_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t65_n37;
  t65_n36: return -0.013337423093616962f;
  t65_n37: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t65_n47;
  t65_n38: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t65_n46;
  t65_n39: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n41;
  t65_n40: return 0.028336089104413986f;
  t65_n41: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t65_n43;
  t65_n42: return 0.07120483368635178f;
  t65_n43: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t65_n45;
  t65_n44: return 0.09381303191184998f;
  t65_n45: return -0.14064271748065948f;
  t65_n46: return -0.09779283404350281f;
  t65_n47: if (E.getNumReferences() >= 3310286848 /*3311.5*/) goto t65_n49;
  t65_n48: return -0.04116370901465416f;
  t65_n49: if (E.getNumReferences() >= 3311257600 /*3548.5*/) goto t65_n51;
  t65_n50: return 0.12097527831792831f;
  t65_n51: return 0.062277767807245255f;
  t65_n52: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n54;
  t65_n53: return 0.058804310858249664f;
  t65_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t65_n56;
  t65_n55: return 0.04473995789885521f;
  t65_n56: return 0.052860382944345474f;
  t65_n57: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t65_n59;
  t65_n58: return -0.02222730964422226f;
  t65_n59: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t65_n61;
  t65_n60: return 0.06608603149652481f;
  t65_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t65_n63;
  t65_n62: return -0.015503346920013428f;
  t65_n63: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t65_n65;
  t65_n64: return 0.022833826020359993f;
  t65_n65: return 0.06102503091096878f;
  t65_n66: return 0.08392838388681412f;
  t65_n67: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n69;
  t65_n68: return -0.015233042649924755f;
  t65_n69: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t65_n97;
  t65_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t65_n74;
  t65_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t65_n73;
  t65_n72: return -0.03896204009652138f;
  t65_n73: return 0.045022912323474884f;
  t65_n74: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t65_n76;
  t65_n75: return -0.05986245721578598f;
  t65_n76: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t65_n94;
  t65_n77: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t65_n85;
  t65_n78: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t65_n84;
  t65_n79: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t65_n81;
  t65_n80: return 0.1271180361509323f;
  t65_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t65_n83;
  t65_n82: return 0.14449086785316467f;
  t65_n83: return 0.13546694815158844f;
  t65_n84: return 0.12186844646930695f;
  t65_n85: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t65_n91;
  t65_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t65_n88;
  t65_n87: return 0.13285496830940247f;
  t65_n88: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t65_n90;
  t65_n89: return 0.11944764852523804f;
  t65_n90: return 0.11730841547250748f;
  t65_n91: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t65_n93;
  t65_n92: return 0.12142549455165863f;
  t65_n93: return 0.02002578042447567f;
  t65_n94: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t65_n96;
  t65_n95: return 0.08824627846479416f;
  t65_n96: return 0.08851653337478638f;
  t65_n97: return 0.02225440926849842f;
  t65_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t65_n102;
  t65_n99: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t65_n101;
  t65_n100: return 0.012532896362245083f;
  t65_n101: return -0.04207745939493179f;
  t65_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t65_n104;
  t65_n103: return 0.04307427257299423f;
  t65_n104: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t65_n130;
  t65_n105: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t65_n109;
  t65_n106: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t65_n108;
  t65_n107: return 0.21937048435211182f;
  t65_n108: return 0.12788791954517365f;
  t65_n109: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t65_n123;
  t65_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t65_n112;
  t65_n111: return -0.04938111826777458f;
  t65_n112: if (E.getFileProximityDistance() >= 3254255616 /*31.0*/) goto t65_n122;
  t65_n113: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t65_n115;
  t65_n114: return -2.6403826268506236e-05f;
  t65_n115: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t65_n121;
  t65_n116: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t65_n118;
  t65_n117: return -0.00994004774838686f;
  t65_n118: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t65_n120;
  t65_n119: return 0.09655483812093735f;
  t65_n120: return 0.07238021492958069f;
  t65_n121: return 0.028426405042409897f;
  t65_n122: return 0.08717422187328339f;
  t65_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t65_n125;
  t65_n124: return 0.06361331790685654f;
  t65_n125: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t65_n127;
  t65_n126: return 0.0760316327214241f;
  t65_n127: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t65_n129;
  t65_n128: return 0.12253823131322861f;
  t65_n129: return 0.11715424805879593f;
  t65_n130: return 0.0056626093573868275f;
  t65_n131: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t65_n223;
  t65_n132: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t65_n142;
  t65_n133: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t65_n141;
  t65_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t65_n140;
  t65_n135: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t65_n137;
  t65_n136: return -0.004807045683264732f;
  t65_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t65_n139;
  t65_n138: return -0.06637326627969742f;
  t65_n139: return -0.016405219212174416f;
  t65_n140: return 0.010238813236355782f;
  t65_n141: return -0.02927108108997345f;
  t65_n142: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t65_n216;
  t65_n143: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t65_n175;
  t65_n144: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n152;
  t65_n145: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t65_n149;
  t65_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t65_n148;
  t65_n147: return -0.018985873088240623f;
  t65_n148: return 0.05122999846935272f;
  t65_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t65_n151;
  t65_n150: return -0.19654276967048645f;
  t65_n151: return -0.04118020087480545f;
  t65_n152: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t65_n154;
  t65_n153: return 0.03103025071322918f;
  t65_n154: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t65_n156;
  t65_n155: return 0.04514029622077942f;
  t65_n156: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t65_n158;
  t65_n157: return 0.0445169061422348f;
  t65_n158: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t65_n160;
  t65_n159: return 0.07754278928041458f;
  t65_n160: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t65_n166;
  t65_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t65_n163;
  t65_n162: return 0.0933670848608017f;
  t65_n163: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t65_n165;
  t65_n164: return 0.12194278091192245f;
  t65_n165: return -0.03668301925063133f;
  t65_n166: if (E.getNumReferences() >= 3271360512 /*126.5*/) goto t65_n168;
  t65_n167: return 0.1229807436466217f;
  t65_n168: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t65_n174;
  t65_n169: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t65_n173;
  t65_n170: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t65_n172;
  t65_n171: return -0.12309914827346802f;
  t65_n172: return 0.11089044064283371f;
  t65_n173: return 0.12740188837051392f;
  t65_n174: return 0.10391107201576233f;
  t65_n175: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t65_n211;
  t65_n176: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t65_n196;
  t65_n177: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t65_n179;
  t65_n178: return 0.026458794251084328f;
  t65_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t65_n183;
  t65_n180: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t65_n182;
  t65_n181: return -0.1367088407278061f;
  t65_n182: return -0.020558379590511322f;
  t65_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t65_n185;
  t65_n184: return 0.003483752952888608f;
  t65_n185: if (E.getNumReferences() >= 3304472576 /*1970.0*/) goto t65_n195;
  t65_n186: if (E.getNumReferences() >= 3273555968 /*158.5*/) goto t65_n194;
  t65_n187: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t65_n189;
  t65_n188: return 0.06893852353096008f;
  t65_n189: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t65_n191;
  t65_n190: return 0.10518111288547516f;
  t65_n191: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t65_n193;
  t65_n192: return 0.11338888108730316f;
  t65_n193: return 0.09977762401103973f;
  t65_n194: return -0.011484429240226746f;
  t65_n195: return 0.08865810185670853f;
  t65_n196: if (E.getNumReferences() >= 3342400384 /*47355.5*/) goto t65_n200;
  t65_n197: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t65_n199;
  t65_n198: return -0.12718261778354645f;
  t65_n199: return 0.12448772042989731f;
  t65_n200: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t65_n210;
  t65_n201: if (E.getNumReferences() >= 3343995264 /*53585.5*/) goto t65_n203;
  t65_n202: return 0.11714880168437958f;
  t65_n203: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t65_n209;
  t65_n204: if (E.getNumReferences() >= 3345907328 /*61054.5*/) goto t65_n208;
  t65_n205: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n207;
  t65_n206: return 0.10536844283342361f;
  t65_n207: return 0.08858092129230499f;
  t65_n208: return -0.017686134204268456f;
  t65_n209: return 0.05843604728579521f;
  t65_n210: return -0.027631811797618866f;
  t65_n211: if (E.getNumReferences() >= 3320657920 /*7591.0*/) goto t65_n215;
  t65_n212: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t65_n214;
  t65_n213: return -0.19564083218574524f;
  t65_n214: return -0.018543360754847527f;
  t65_n215: return 0.017672158777713776f;
  t65_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t65_n218;
  t65_n217: return -0.0805223286151886f;
  t65_n218: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t65_n220;
  t65_n219: return 0.0726984515786171f;
  t65_n220: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t65_n222;
  t65_n221: return 0.001973107224330306f;
  t65_n222: return 0.18564501404762268f;
  t65_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n225;
  t65_n224: return 0.0018229072447866201f;
  t65_n225: return 0.01843740977346897f;
  t65_n226: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t65_n246;
  t65_n227: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t65_n229;
  t65_n228: return 0.010475614108145237f;
  t65_n229: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t65_n235;
  t65_n230: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t65_n232;
  t65_n231: return 0.05222548916935921f;
  t65_n232: if (E.getNumReferences() >= 3349646912 /*85788.5*/) goto t65_n234;
  t65_n233: return 0.018112080171704292f;
  t65_n234: return 0.0674857348203659f;
  t65_n235: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t65_n237;
  t65_n236: return 0.0007083556265570223f;
  t65_n237: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t65_n239;
  t65_n238: return -0.05567193403840065f;
  t65_n239: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t65_n245;
  t65_n240: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t65_n244;
  t65_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t65_n243;
  t65_n242: return 0.13909722864627838f;
  t65_n243: return 0.12334182858467102f;
  t65_n244: return -0.09540338814258575f;
  t65_n245: return 0.04827047139406204f;
  t65_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t65_n252;
  t65_n247: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t65_n251;
  t65_n248: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t65_n250;
  t65_n249: return -0.019413067027926445f;
  t65_n250: return 0.056212443858385086f;
  t65_n251: return 0.028848571702837944f;
  t65_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t65_n254;
  t65_n253: return -0.0361565463244915f;
  t65_n254: return 0.030102472752332687f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree66(const Example& E) {
  t66_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t66_n246;
  t66_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t66_n219;
  t66_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t66_n54;
  t66_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t66_n5;
  t66_n4: return -0.11749647557735443f;
  t66_n5: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t66_n7;
  t66_n6: return -0.006548475474119186f;
  t66_n7: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t66_n37;
  t66_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t66_n20;
  t66_n9: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t66_n11;
  t66_n10: return 0.14938980340957642f;
  t66_n11: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t66_n13;
  t66_n12: return -0.20491832494735718f;
  t66_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t66_n15;
  t66_n14: return -0.038697369396686554f;
  t66_n15: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t66_n17;
  t66_n16: return 0.1082383245229721f;
  t66_n17: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t66_n19;
  t66_n18: return 0.10128773748874664f;
  t66_n19: return 0.13744063675403595f;
  t66_n20: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t66_n32;
  t66_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t66_n27;
  t66_n22: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t66_n26;
  t66_n23: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t66_n25;
  t66_n24: return 0.025848103687167168f;
  t66_n25: return 0.09775490313768387f;
  t66_n26: return -0.08685760945081711f;
  t66_n27: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t66_n31;
  t66_n28: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t66_n30;
  t66_n29: return 0.13490204513072968f;
  t66_n30: return 0.12302614748477936f;
  t66_n31: return 0.10456787049770355f;
  t66_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t66_n36;
  t66_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t66_n35;
  t66_n34: return 0.056079380214214325f;
  t66_n35: return 0.09601928293704987f;
  t66_n36: return 0.08895443379878998f;
  t66_n37: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t66_n41;
  t66_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t66_n40;
  t66_n39: return -0.10115362703800201f;
  t66_n40: return 0.11796797811985016f;
  t66_n41: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n47;
  t66_n42: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t66_n44;
  t66_n43: return -0.09427766501903534f;
  t66_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t66_n46;
  t66_n45: return -0.16443845629692078f;
  t66_n46: return 0.1180739477276802f;
  t66_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t66_n49;
  t66_n48: return 0.028523679822683334f;
  t66_n49: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t66_n53;
  t66_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t66_n52;
  t66_n51: return 0.09343649446964264f;
  t66_n52: return 0.038096822798252106f;
  t66_n53: return -0.13087837398052216f;
  t66_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t66_n104;
  t66_n55: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t66_n81;
  t66_n56: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t66_n58;
  t66_n57: return -0.017538875341415405f;
  t66_n58: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t66_n80;
  t66_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t66_n63;
  t66_n60: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t66_n62;
  t66_n61: return -0.1042635515332222f;
  t66_n62: return -0.5235981941223145f;
  t66_n63: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n65;
  t66_n64: return 0.05678054690361023f;
  t66_n65: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t66_n77;
  t66_n66: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t66_n72;
  t66_n67: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t66_n71;
  t66_n68: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t66_n70;
  t66_n69: return 0.09298224002122879f;
  t66_n70: return 0.05289963632822037f;
  t66_n71: return 0.12552925944328308f;
  t66_n72: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t66_n74;
  t66_n73: return 0.05896072834730148f;
  t66_n74: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t66_n76;
  t66_n75: return 0.11733075231313705f;
  t66_n76: return 0.04896078631281853f;
  t66_n77: if (E.getNumReferences() >= 3348976000 /*80547.0*/) goto t66_n79;
  t66_n78: return 0.008963296189904213f;
  t66_n79: return -0.30585771799087524f;
  t66_n80: return -0.1218060553073883f;
  t66_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t66_n83;
  t66_n82: return 0.018118536099791527f;
  t66_n83: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t66_n85;
  t66_n84: return -0.016465406864881516f;
  t66_n85: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t66_n87;
  t66_n86: return 0.06580720841884613f;
  t66_n87: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t66_n99;
  t66_n88: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t66_n90;
  t66_n89: return 0.01657169498503208f;
  t66_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t66_n92;
  t66_n91: return -0.015738381072878838f;
  t66_n92: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t66_n98;
  t66_n93: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t66_n97;
  t66_n94: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t66_n96;
  t66_n95: return 0.10685066133737564f;
  t66_n96: return 0.1292070597410202f;
  t66_n97: return 0.05766758695244789f;
  t66_n98: return 0.015241788700222969f;
  t66_n99: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t66_n101;
  t66_n100: return 0.06852275133132935f;
  t66_n101: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t66_n103;
  t66_n102: return 0.10783430933952332f;
  t66_n103: return 0.08059168606996536f;
  t66_n104: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t66_n216;
  t66_n105: if (E.getNumReferences() >= 3347329664 /*67685.0*/) goto t66_n189;
  t66_n106: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t66_n184;
  t66_n107: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t66_n183;
  t66_n108: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t66_n182;
  t66_n109: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t66_n137;
  t66_n110: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n112;
  t66_n111: return 0.015041018836200237f;
  t66_n112: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t66_n126;
  t66_n113: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t66_n123;
  t66_n114: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t66_n116;
  t66_n115: return 0.026719655841588974f;
  t66_n116: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t66_n122;
  t66_n117: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t66_n121;
  t66_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t66_n120;
  t66_n119: return -0.14771457016468048f;
  t66_n120: return -0.034178294241428375f;
  t66_n121: return 0.02551785297691822f;
  t66_n122: return 0.008792242966592312f;
  t66_n123: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t66_n125;
  t66_n124: return -0.04521724954247475f;
  t66_n125: return 0.01573498547077179f;
  t66_n126: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t66_n136;
  t66_n127: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t66_n129;
  t66_n128: return 0.11126060783863068f;
  t66_n129: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t66_n135;
  t66_n130: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t66_n134;
  t66_n131: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t66_n133;
  t66_n132: return 0.045604851096868515f;
  t66_n133: return 0.06324257701635361f;
  t66_n134: return 0.04431990534067154f;
  t66_n135: return -0.0033913259394466877f;
  t66_n136: return 0.01712394505739212f;
  t66_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t66_n159;
  t66_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t66_n142;
  t66_n139: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t66_n141;
  t66_n140: return -0.035788826644420624f;
  t66_n141: return -0.3209773004055023f;
  t66_n142: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t66_n150;
  t66_n143: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t66_n145;
  t66_n144: return 0.05448324978351593f;
  t66_n145: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t66_n149;
  t66_n146: if (E.getNumReferences() >= 3288686592 /*533.5*/) goto t66_n148;
  t66_n147: return 0.09760706126689911f;
  t66_n148: return 0.10917531698942184f;
  t66_n149: return 0.06487594544887543f;
  t66_n150: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t66_n152;
  t66_n151: return -0.19444134831428528f;
  t66_n152: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t66_n158;
  t66_n153: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t66_n155;
  t66_n154: return 0.1309516578912735f;
  t66_n155: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t66_n157;
  t66_n156: return 0.09561850875616074f;
  t66_n157: return 0.1521230936050415f;
  t66_n158: return 0.10997404158115387f;
  t66_n159: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t66_n177;
  t66_n160: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t66_n162;
  t66_n161: return -0.0011018242221325636f;
  t66_n162: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t66_n166;
  t66_n163: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t66_n165;
  t66_n164: return 0.012131360359489918f;
  t66_n165: return 0.0903579592704773f;
  t66_n166: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t66_n168;
  t66_n167: return -0.08425764739513397f;
  t66_n168: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t66_n172;
  t66_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t66_n171;
  t66_n170: return 0.1150236427783966f;
  t66_n171: return 0.14500924944877625f;
  t66_n172: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t66_n176;
  t66_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t66_n175;
  t66_n174: return 0.18616430461406708f;
  t66_n175: return 0.1498935967683792f;
  t66_n176: return 0.04728851467370987f;
  t66_n177: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t66_n179;
  t66_n178: return -0.05371614173054695f;
  t66_n179: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t66_n181;
  t66_n180: return 0.007559794932603836f;
  t66_n181: return 0.0706649199128151f;
  t66_n182: return -0.1176450178027153f;
  t66_n183: return -0.10551843047142029f;
  t66_n184: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t66_n186;
  t66_n185: return 0.02619863860309124f;
  t66_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t66_n188;
  t66_n187: return 0.04607498645782471f;
  t66_n188: return 0.0905148833990097f;
  t66_n189: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n193;
  t66_n190: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t66_n192;
  t66_n191: return 0.028348784893751144f;
  t66_n192: return -0.019709071144461632f;
  t66_n193: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t66_n213;
  t66_n194: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t66_n206;
  t66_n195: if (E.getNumReferences() >= 3354069824 /*120342.5*/) goto t66_n205;
  t66_n196: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t66_n198;
  t66_n197: return 0.03638699650764465f;
  t66_n198: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t66_n200;
  t66_n199: return 0.058627624064683914f;
  t66_n200: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t66_n202;
  t66_n201: return 0.06327999383211136f;
  t66_n202: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t66_n204;
  t66_n203: return 0.09836070984601974f;
  t66_n204: return 0.10772162675857544f;
  t66_n205: return -0.020845597609877586f;
  t66_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t66_n212;
  t66_n207: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t66_n209;
  t66_n208: return 0.04963737726211548f;
  t66_n209: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t66_n211;
  t66_n210: return 0.10723704844713211f;
  t66_n211: return -0.17972122132778168f;
  t66_n212: return 0.09913966059684753f;
  t66_n213: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t66_n215;
  t66_n214: return -0.10378751158714294f;
  t66_n215: return 0.026712151244282722f;
  t66_n216: if (E.getNumReferences() >= 3354069824 /*120342.5*/) goto t66_n218;
  t66_n217: return -0.039203446358442307f;
  t66_n218: return -0.12158408015966415f;
  t66_n219: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t66_n225;
  t66_n220: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t66_n222;
  t66_n221: return 0.011048514395952225f;
  t66_n222: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t66_n224;
  t66_n223: return 0.006641191430389881f;
  t66_n224: return 0.03022889420390129f;
  t66_n225: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t66_n229;
  t66_n226: if (E.getNumReferences() >= 3309795328 /*3191.5*/) goto t66_n228;
  t66_n227: return 0.08323679864406586f;
  t66_n228: return -0.08843325823545456f;
  t66_n229: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t66_n241;
  t66_n230: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t66_n240;
  t66_n231: if (E.getNumReferences() >= 3354462528 /*123410.5*/) goto t66_n235;
  t66_n232: if (E.getNumReferences() >= 3354001600 /*119809.5*/) goto t66_n234;
  t66_n233: return 0.018805790692567825f;
  t66_n234: return -2.654709577560425f;
  t66_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n239;
  t66_n236: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t66_n238;
  t66_n237: return 0.11708507686853409f;
  t66_n238: return 0.09068281948566437f;
  t66_n239: return 0.10787360370159149f;
  t66_n240: return -0.27176523208618164f;
  t66_n241: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t66_n245;
  t66_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n244;
  t66_n243: return 0.03307950496673584f;
  t66_n244: return 0.08522992581129074f;
  t66_n245: return -0.01038298662751913f;
  t66_n246: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n248;
  t66_n247: return 0.0016488278051838279f;
  t66_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t66_n254;
  t66_n249: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t66_n251;
  t66_n250: return -0.0006187302060425282f;
  t66_n251: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t66_n253;
  t66_n252: return 0.08667685836553574f;
  t66_n253: return 0.012421585619449615f;
  t66_n254: return 0.02232012152671814f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree67(const Example& E) {
  t67_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t67_n248;
  t67_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t67_n119;
  t67_n2: if (E.getNumReferences() >= 3348227392 /*74698.5*/) goto t67_n72;
  t67_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t67_n71;
  t67_n4: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t67_n18;
  t67_n5: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t67_n7;
  t67_n6: return -0.005166045390069485f;
  t67_n7: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t67_n17;
  t67_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t67_n10;
  t67_n9: return 0.0163692869246006f;
  t67_n10: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t67_n12;
  t67_n11: return 0.035363126546144485f;
  t67_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t67_n14;
  t67_n13: return 0.04185652732849121f;
  t67_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t67_n16;
  t67_n15: return 0.09703364968299866f;
  t67_n16: return 0.0966697707772255f;
  t67_n17: return -0.07345451414585114f;
  t67_n18: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t67_n36;
  t67_n19: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t67_n21;
  t67_n20: return 0.011517041362822056f;
  t67_n21: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t67_n35;
  t67_n22: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t67_n30;
  t67_n23: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t67_n29;
  t67_n24: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t67_n26;
  t67_n25: return 0.09969880431890488f;
  t67_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t67_n28;
  t67_n27: return 0.12089645862579346f;
  t67_n28: return -0.11811241507530212f;
  t67_n29: return 0.09598399698734283f;
  t67_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t67_n32;
  t67_n31: return -0.03865477815270424f;
  t67_n32: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t67_n34;
  t67_n33: return 0.13631458580493927f;
  t67_n34: return 0.007129849400371313f;
  t67_n35: return 0.026663780212402344f;
  t67_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t67_n52;
  t67_n37: if (E.getNumReferences() >= 3308015616 /*2757.0*/) goto t67_n43;
  t67_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t67_n40;
  t67_n39: return -0.020692946389317513f;
  t67_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t67_n42;
  t67_n41: return -0.07657191902399063f;
  t67_n42: return 0.03567282110452652f;
  t67_n43: if (E.getFileProximityDistance() >= 3252682752 /*28.0*/) goto t67_n51;
  t67_n44: if (E.getNumReferences() >= 3344616064 /*56010.5*/) goto t67_n50;
  t67_n45: if (E.getNumReferences() >= 3343638400 /*52191.5*/) goto t67_n49;
  t67_n46: if (E.getNumReferences() >= 3308064768 /*2769.0*/) goto t67_n48;
  t67_n47: return 0.4499160945415497f;
  t67_n48: return 0.04811074212193489f;
  t67_n49: return 0.11136644333600998f;
  t67_n50: return -0.07923044264316559f;
  t67_n51: return 0.11621426790952682f;
  t67_n52: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t67_n54;
  t67_n53: return 0.034643713384866714f;
  t67_n54: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t67_n56;
  t67_n55: return 0.05268236994743347f;
  t67_n56: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t67_n58;
  t67_n57: return 0.062459975481033325f;
  t67_n58: if (E.getNumReferences() >= 3275587584 /*189.5*/) goto t67_n70;
  t67_n59: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t67_n65;
  t67_n60: if (E.getNumReferences() >= 3274539008 /*173.5*/) goto t67_n62;
  t67_n61: return 0.08290256559848785f;
  t67_n62: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t67_n64;
  t67_n63: return 0.08220699429512024f;
  t67_n64: return 0.1085018739104271f;
  t67_n65: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t67_n69;
  t67_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t67_n68;
  t67_n67: return 0.008421097882091999f;
  t67_n68: return 0.11113648861646652f;
  t67_n69: return 0.021165786311030388f;
  t67_n70: return 0.046010758727788925f;
  t67_n71: return -0.017132315784692764f;
  t67_n72: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t67_n74;
  t67_n73: return -0.01071810070425272f;
  t67_n74: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t67_n108;
  t67_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t67_n77;
  t67_n76: return 0.03751387819647789f;
  t67_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t67_n85;
  t67_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t67_n80;
  t67_n79: return -0.047588370740413666f;
  t67_n80: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t67_n84;
  t67_n81: if (E.getNumReferences() >= 3351141632 /*97466.0*/) goto t67_n83;
  t67_n82: return -0.14807723462581635f;
  t67_n83: return 0.10902814567089081f;
  t67_n84: return 0.0594976544380188f;
  t67_n85: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t67_n105;
  t67_n86: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t67_n96;
  t67_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t67_n89;
  t67_n88: return -0.10485631972551346f;
  t67_n89: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t67_n95;
  t67_n90: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t67_n92;
  t67_n91: return 0.1243896484375f;
  t67_n92: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t67_n94;
  t67_n93: return 0.14163093268871307f;
  t67_n94: return 0.13496699929237366f;
  t67_n95: return 0.12013469636440277f;
  t67_n96: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t67_n102;
  t67_n97: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t67_n99;
  t67_n98: return 0.14182718098163605f;
  t67_n99: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t67_n101;
  t67_n100: return 0.12153052538633347f;
  t67_n101: return 0.09193392097949982f;
  t67_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t67_n104;
  t67_n103: return 0.12077051401138306f;
  t67_n104: return 0.018772177398204803f;
  t67_n105: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t67_n107;
  t67_n106: return 0.08782532066106796f;
  t67_n107: return 0.08170706778764725f;
  t67_n108: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t67_n110;
  t67_n109: return 0.022977396845817566f;
  t67_n110: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t67_n118;
  t67_n111: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t67_n115;
  t67_n112: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t67_n114;
  t67_n113: return 0.08706554025411606f;
  t67_n114: return -0.02031710185110569f;
  t67_n115: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t67_n117;
  t67_n116: return 0.08103953301906586f;
  t67_n117: return 0.10367194563150406f;
  t67_n118: return -0.3576662242412567f;
  t67_n119: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t67_n199;
  t67_n120: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t67_n196;
  t67_n121: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t67_n191;
  t67_n122: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t67_n128;
  t67_n123: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t67_n125;
  t67_n124: return 0.008369600400328636f;
  t67_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t67_n127;
  t67_n126: return -0.020130710676312447f;
  t67_n127: return 0.10882770270109177f;
  t67_n128: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t67_n168;
  t67_n129: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t67_n167;
  t67_n130: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t67_n132;
  t67_n131: return -0.0023860647343099117f;
  t67_n132: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t67_n154;
  t67_n133: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t67_n141;
  t67_n134: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t67_n136;
  t67_n135: return 0.044651683419942856f;
  t67_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t67_n138;
  t67_n137: return 0.06313769519329071f;
  t67_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t67_n140;
  t67_n139: return 0.007315473631024361f;
  t67_n140: return 0.0900426134467125f;
  t67_n141: if (E.getNumReferences() >= 3257008128 /*40.5*/) goto t67_n153;
  t67_n142: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t67_n144;
  t67_n143: return 0.08902759850025177f;
  t67_n144: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t67_n146;
  t67_n145: return 0.12232035398483276f;
  t67_n146: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t67_n152;
  t67_n147: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t67_n149;
  t67_n148: return 0.21589675545692444f;
  t67_n149: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t67_n151;
  t67_n150: return 0.12003444880247116f;
  t67_n151: return 0.137354776263237f;
  t67_n152: return -0.10158539563417435f;
  t67_n153: return 0.10908053815364838f;
  t67_n154: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t67_n156;
  t67_n155: return -0.10950176417827606f;
  t67_n156: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t67_n164;
  t67_n157: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t67_n161;
  t67_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t67_n160;
  t67_n159: return -0.04713987559080124f;
  t67_n160: return 0.10012225806713104f;
  t67_n161: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t67_n163;
  t67_n162: return 0.12958543002605438f;
  t67_n163: return 0.15641790628433228f;
  t67_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t67_n166;
  t67_n165: return 0.11389359086751938f;
  t67_n166: return 0.12464550137519836f;
  t67_n167: return -0.034434426575899124f;
  t67_n168: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t67_n184;
  t67_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t67_n171;
  t67_n170: return -0.055301204323768616f;
  t67_n171: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t67_n173;
  t67_n172: return -0.015765829011797905f;
  t67_n173: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t67_n175;
  t67_n174: return 0.0016754899406805634f;
  t67_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t67_n177;
  t67_n176: return 0.006111158523708582f;
  t67_n177: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t67_n179;
  t67_n178: return 0.02913856692612171f;
  t67_n179: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t67_n181;
  t67_n180: return 0.027897372841835022f;
  t67_n181: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t67_n183;
  t67_n182: return 0.12689617276191711f;
  t67_n183: return 0.04372962936758995f;
  t67_n184: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t67_n186;
  t67_n185: return 0.029515095055103302f;
  t67_n186: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t67_n188;
  t67_n187: return 0.051933713257312775f;
  t67_n188: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t67_n190;
  t67_n189: return 0.14096103608608246f;
  t67_n190: return 0.12712721526622772f;
  t67_n191: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t67_n195;
  t67_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t67_n194;
  t67_n193: return -0.008596131578087807f;
  t67_n194: return 0.026463842019438744f;
  t67_n195: return 0.001998779596760869f;
  t67_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t67_n198;
  t67_n197: return -0.11607865989208221f;
  t67_n198: return -0.05848148837685585f;
  t67_n199: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t67_n231;
  t67_n200: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t67_n226;
  t67_n201: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t67_n203;
  t67_n202: return 0.012747850269079208f;
  t67_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t67_n211;
  t67_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t67_n206;
  t67_n205: return 0.025067737326025963f;
  t67_n206: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t67_n208;
  t67_n207: return 0.06364329159259796f;
  t67_n208: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t67_n210;
  t67_n209: return -0.08331967145204544f;
  t67_n210: return 0.12799899280071259f;
  t67_n211: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t67_n213;
  t67_n212: return 0.04635084047913551f;
  t67_n213: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t67_n215;
  t67_n214: return 0.0577244758605957f;
  t67_n215: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t67_n225;
  t67_n216: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t67_n224;
  t67_n217: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t67_n219;
  t67_n218: return 0.11240410804748535f;
  t67_n219: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t67_n223;
  t67_n220: if (E.getNumReferences() >= 3272736768 /*146.0*/) goto t67_n222;
  t67_n221: return 0.12577706575393677f;
  t67_n222: return 0.16796688735485077f;
  t67_n223: return 0.12004683166742325f;
  t67_n224: return -0.1562257707118988f;
  t67_n225: return -0.0007054847665131092f;
  t67_n226: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t67_n230;
  t67_n227: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t67_n229;
  t67_n228: return 0.11018694192171097f;
  t67_n229: return 0.09571418166160583f;
  t67_n230: return 0.0318695530295372f;
  t67_n231: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t67_n233;
  t67_n232: return 0.013318215496838093f;
  t67_n233: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t67_n247;
  t67_n234: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t67_n242;
  t67_n235: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t67_n237;
  t67_n236: return 0.0662451982498169f;
  t67_n237: if (E.getNumReferences() >= 3305310208 /*2096.5*/) goto t67_n239;
  t67_n238: return 0.04646610468626022f;
  t67_n239: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t67_n241;
  t67_n240: return 0.04449908062815666f;
  t67_n241: return 0.09425174444913864f;
  t67_n242: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t67_n246;
  t67_n243: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t67_n245;
  t67_n244: return 0.08063844591379166f;
  t67_n245: return 0.1394778937101364f;
  t67_n246: return 0.08212748169898987f;
  t67_n247: return 0.07392704486846924f;
  t67_n248: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t67_n254;
  t67_n249: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t67_n253;
  t67_n250: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t67_n252;
  t67_n251: return 0.0025754442904144526f;
  t67_n252: return 0.022154033184051514f;
  t67_n253: return 0.025756968185305595f;
  t67_n254: return -0.23959071934223175f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree68(const Example& E) {
  t68_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t68_n248;
  t68_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t68_n91;
  t68_n2: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t68_n32;
  t68_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t68_n31;
  t68_n4: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t68_n6;
  t68_n5: return -0.0020145257003605366f;
  t68_n6: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n8;
  t68_n7: return 0.01500996295362711f;
  t68_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t68_n10;
  t68_n9: return 0.0298269372433424f;
  t68_n10: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t68_n14;
  t68_n11: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t68_n13;
  t68_n12: return 0.03600062057375908f;
  t68_n13: return 0.06277875602245331f;
  t68_n14: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t68_n16;
  t68_n15: return 0.052683450281620026f;
  t68_n16: if (E.getNumReferences() >= 3275587584 /*189.5*/) goto t68_n30;
  t68_n17: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t68_n23;
  t68_n18: if (E.getNumReferences() >= 3274539008 /*173.5*/) goto t68_n20;
  t68_n19: return 0.08169077336788177f;
  t68_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t68_n22;
  t68_n21: return 0.07977677881717682f;
  t68_n22: return 0.10723293572664261f;
  t68_n23: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t68_n29;
  t68_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t68_n26;
  t68_n25: return 0.006517632864415646f;
  t68_n26: if (E.getNumReferences() >= 3272146944 /*137.0*/) goto t68_n28;
  t68_n27: return 0.10958486050367355f;
  t68_n28: return 0.10841625183820724f;
  t68_n29: return 0.020605482161045074f;
  t68_n30: return 0.044069111347198486f;
  t68_n31: return -0.0167688075453043f;
  t68_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t68_n34;
  t68_n33: return -0.014454500749707222f;
  t68_n34: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t68_n72;
  t68_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t68_n47;
  t68_n36: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t68_n46;
  t68_n37: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t68_n39;
  t68_n38: return 0.1358901411294937f;
  t68_n39: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t68_n41;
  t68_n40: return -0.034369152039289474f;
  t68_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n43;
  t68_n42: return 0.11978143453598022f;
  t68_n43: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t68_n45;
  t68_n44: return 0.11303748190402985f;
  t68_n45: return 0.13804137706756592f;
  t68_n46: return 0.032467588782310486f;
  t68_n47: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t68_n49;
  t68_n48: return -0.04295014962553978f;
  t68_n49: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n69;
  t68_n50: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t68_n60;
  t68_n51: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t68_n59;
  t68_n52: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t68_n56;
  t68_n53: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t68_n55;
  t68_n54: return 0.11728635430335999f;
  t68_n55: return 0.1272069364786148f;
  t68_n56: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t68_n58;
  t68_n57: return 0.12874849140644073f;
  t68_n58: return 0.13138364255428314f;
  t68_n59: return 0.11707079410552979f;
  t68_n60: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t68_n66;
  t68_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t68_n63;
  t68_n62: return 0.06378869712352753f;
  t68_n63: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t68_n65;
  t68_n64: return 0.11539120227098465f;
  t68_n65: return 0.11159248650074005f;
  t68_n66: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t68_n68;
  t68_n67: return 0.11450060456991196f;
  t68_n68: return 0.016993671655654907f;
  t68_n69: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t68_n71;
  t68_n70: return 0.08575695753097534f;
  t68_n71: return 0.07965527474880219f;
  t68_n72: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t68_n74;
  t68_n73: return 0.020015807822346687f;
  t68_n74: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t68_n90;
  t68_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t68_n89;
  t68_n76: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t68_n88;
  t68_n77: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t68_n87;
  t68_n78: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t68_n80;
  t68_n79: return 0.07411079853773117f;
  t68_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t68_n86;
  t68_n81: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t68_n85;
  t68_n82: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t68_n84;
  t68_n83: return 0.12258957326412201f;
  t68_n84: return -0.007292285095900297f;
  t68_n85: return 0.0810539647936821f;
  t68_n86: return 0.1066562756896019f;
  t68_n87: return -0.5175366997718811f;
  t68_n88: return -0.05384524166584015f;
  t68_n89: return 0.1653703898191452f;
  t68_n90: return 0.0025908525567501783f;
  t68_n91: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t68_n191;
  t68_n92: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t68_n102;
  t68_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n99;
  t68_n94: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t68_n96;
  t68_n95: return 0.01011196244508028f;
  t68_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t68_n98;
  t68_n97: return -0.02397749572992325f;
  t68_n98: return 0.09569049626588821f;
  t68_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t68_n101;
  t68_n100: return -0.007826769724488258f;
  t68_n101: return 0.006734339985996485f;
  t68_n102: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t68_n168;
  t68_n103: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n135;
  t68_n104: if (E.getNumReferences() >= 3340847232 /*41288.5*/) goto t68_n110;
  t68_n105: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t68_n107;
  t68_n106: return 0.01664680987596512f;
  t68_n107: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t68_n109;
  t68_n108: return -0.02954082004725933f;
  t68_n109: return 0.1888871192932129f;
  t68_n110: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t68_n112;
  t68_n111: return 0.002787626115605235f;
  t68_n112: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t68_n134;
  t68_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t68_n129;
  t68_n114: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t68_n128;
  t68_n115: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t68_n121;
  t68_n116: if (E.getNumReferences() >= 3349201152 /*82306.0*/) goto t68_n118;
  t68_n117: return 0.07073832303285599f;
  t68_n118: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t68_n120;
  t68_n119: return 0.09613853693008423f;
  t68_n120: return 0.05098113790154457f;
  t68_n121: if (E.getNumReferences() >= 3361098688 /*219439.0*/) goto t68_n123;
  t68_n122: return -0.22378501296043396f;
  t68_n123: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t68_n127;
  t68_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t68_n126;
  t68_n125: return 0.09981808811426163f;
  t68_n126: return 0.09663739055395126f;
  t68_n127: return 0.043120790272951126f;
  t68_n128: return -0.05336586385965347f;
  t68_n129: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t68_n131;
  t68_n130: return -0.09416690468788147f;
  t68_n131: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t68_n133;
  t68_n132: return 0.12235146760940552f;
  t68_n133: return -0.007233771029859781f;
  t68_n134: return -0.038146745413541794f;
  t68_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t68_n141;
  t68_n136: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t68_n138;
  t68_n137: return 0.031826939433813095f;
  t68_n138: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t68_n140;
  t68_n139: return 0.10671888291835785f;
  t68_n140: return 0.12375158816576004f;
  t68_n141: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t68_n143;
  t68_n142: return 0.03809057176113129f;
  t68_n143: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t68_n157;
  t68_n144: if (E.getNumReferences() >= 3266379776 /*88.5*/) goto t68_n156;
  t68_n145: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t68_n153;
  t68_n146: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t68_n152;
  t68_n147: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t68_n151;
  t68_n148: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t68_n150;
  t68_n149: return 0.12838122248649597f;
  t68_n150: return 0.11331497132778168f;
  t68_n151: return -0.18465907871723175f;
  t68_n152: return 0.12081503868103027f;
  t68_n153: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t68_n155;
  t68_n154: return -0.08041463047266006f;
  t68_n155: return 0.1165381595492363f;
  t68_n156: return 0.046753931790590286f;
  t68_n157: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t68_n167;
  t68_n158: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t68_n166;
  t68_n159: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t68_n161;
  t68_n160: return 0.11042331904172897f;
  t68_n161: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t68_n165;
  t68_n162: if (E.getNumReferences() >= 3272736768 /*146.0*/) goto t68_n164;
  t68_n163: return 0.12394537031650543f;
  t68_n164: return 0.16934902966022491f;
  t68_n165: return 0.11837195605039597f;
  t68_n166: return -0.12137780338525772f;
  t68_n167: return 0.01024016086012125f;
  t68_n168: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t68_n170;
  t68_n169: return 0.011776783503592014f;
  t68_n170: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t68_n180;
  t68_n171: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t68_n179;
  t68_n172: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t68_n174;
  t68_n173: return 0.05621746927499771f;
  t68_n174: if (E.getNumReferences() >= 3364747568 /*290761.5*/) goto t68_n176;
  t68_n175: return -0.00878042820841074f;
  t68_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t68_n178;
  t68_n177: return 0.10131554305553436f;
  t68_n178: return 0.11074429005384445f;
  t68_n179: return 0.06374325603246689f;
  t68_n180: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t68_n190;
  t68_n181: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t68_n189;
  t68_n182: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t68_n186;
  t68_n183: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t68_n185;
  t68_n184: return 0.11387677490711212f;
  t68_n185: return 0.07365266978740692f;
  t68_n186: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t68_n188;
  t68_n187: return 0.08971330523490906f;
  t68_n188: return 0.12909723818302155f;
  t68_n189: return -0.1555570811033249f;
  t68_n190: return 0.0658809170126915f;
  t68_n191: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t68_n231;
  t68_n192: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t68_n228;
  t68_n193: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t68_n197;
  t68_n194: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n196;
  t68_n195: return 0.03894732519984245f;
  t68_n196: return 0.012082746252417564f;
  t68_n197: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t68_n221;
  t68_n198: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t68_n200;
  t68_n199: return 0.055730726569890976f;
  t68_n200: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t68_n212;
  t68_n201: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t68_n209;
  t68_n202: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t68_n208;
  t68_n203: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t68_n207;
  t68_n204: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t68_n206;
  t68_n205: return 0.11539093405008316f;
  t68_n206: return -0.2334531843662262f;
  t68_n207: return -0.10386870056390762f;
  t68_n208: return 0.11889412999153137f;
  t68_n209: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t68_n211;
  t68_n210: return 0.050038132816553116f;
  t68_n211: return 0.11191999912261963f;
  t68_n212: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t68_n214;
  t68_n213: return -0.0015543807530775666f;
  t68_n214: if (E.getNumReferences() >= 3272015872 /*135.0*/) goto t68_n220;
  t68_n215: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t68_n219;
  t68_n216: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t68_n218;
  t68_n217: return -0.40477117896080017f;
  t68_n218: return 0.10543566942214966f;
  t68_n219: return 0.12859974801540375f;
  t68_n220: return 0.028195302933454514f;
  t68_n221: if (E.getNumReferences() >= 3332892672 /*21492.0*/) goto t68_n227;
  t68_n222: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t68_n224;
  t68_n223: return 0.03240234777331352f;
  t68_n224: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t68_n226;
  t68_n225: return 0.11099480837583542f;
  t68_n226: return 0.058351870626211166f;
  t68_n227: return -0.057366643100976944f;
  t68_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t68_n230;
  t68_n229: return -0.0036178368609398603f;
  t68_n230: return 0.023398438468575478f;
  t68_n231: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t68_n243;
  t68_n232: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t68_n234;
  t68_n233: return -0.023281170055270195f;
  t68_n234: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n236;
  t68_n235: return -0.018865074962377548f;
  t68_n236: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t68_n240;
  t68_n237: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t68_n239;
  t68_n238: return -0.4377630054950714f;
  t68_n239: return 0.12402839213609695f;
  t68_n240: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t68_n242;
  t68_n241: return -0.1092768982052803f;
  t68_n242: return 0.15977884829044342f;
  t68_n243: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t68_n245;
  t68_n244: return 0.017906438559293747f;
  t68_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t68_n247;
  t68_n246: return 0.08959035575389862f;
  t68_n247: return 0.019849667325615883f;
  t68_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t68_n254;
  t68_n249: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t68_n253;
  t68_n250: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n252;
  t68_n251: return 0.0028531907591968775f;
  t68_n252: return 0.020819077268242836f;
  t68_n253: return -0.20470532774925232f;
  t68_n254: return 0.02444259077310562f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree69(const Example& E) {
  t69_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t69_n202;
  t69_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t69_n75;
  t69_n2: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t69_n4;
  t69_n3: return -0.015544342808425426f;
  t69_n4: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t69_n24;
  t69_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t69_n7;
  t69_n6: return -0.024449076503515244f;
  t69_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t69_n21;
  t69_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t69_n10;
  t69_n9: return 0.012174037285149097f;
  t69_n10: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t69_n14;
  t69_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t69_n13;
  t69_n12: return -0.023337550461292267f;
  t69_n13: return 0.019014600664377213f;
  t69_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t69_n18;
  t69_n15: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t69_n17;
  t69_n16: return 0.024934133514761925f;
  t69_n17: return -0.19417835772037506f;
  t69_n18: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t69_n20;
  t69_n19: return 0.04017289727926254f;
  t69_n20: return 0.06071893498301506f;
  t69_n21: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t69_n23;
  t69_n22: return -0.039346348494291306f;
  t69_n23: return 0.03863472864031792f;
  t69_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t69_n32;
  t69_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t69_n27;
  t69_n26: return 0.00724259065464139f;
  t69_n27: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t69_n31;
  t69_n28: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t69_n30;
  t69_n29: return 0.09443435817956924f;
  t69_n30: return -0.12026329338550568f;
  t69_n31: return -0.1209329217672348f;
  t69_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t69_n34;
  t69_n33: return 0.013683815486729145f;
  t69_n34: if (E.getNumReferences() >= 3292643328 /*775.0*/) goto t69_n38;
  t69_n35: if (E.getNumReferences() >= 3291799552 /*723.5*/) goto t69_n37;
  t69_n36: return 0.02155354805290699f;
  t69_n37: return -0.14349070191383362f;
  t69_n38: if (E.getNumReferences() >= 3292733440 /*780.5*/) goto t69_n40;
  t69_n39: return 0.10801546275615692f;
  t69_n40: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t69_n70;
  t69_n41: if (E.getNumReferences() >= 3333936384 /*23530.5*/) goto t69_n57;
  t69_n42: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t69_n54;
  t69_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t69_n45;
  t69_n44: return -0.13923320174217224f;
  t69_n45: if (E.getNumReferences() >= 3317871616 /*6230.5*/) goto t69_n47;
  t69_n46: return -0.13479682803153992f;
  t69_n47: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t69_n49;
  t69_n48: return 0.11531852930784225f;
  t69_n49: if (E.getNumReferences() >= 3320366080 /*7448.5*/) goto t69_n53;
  t69_n50: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t69_n52;
  t69_n51: return 0.11418786644935608f;
  t69_n52: return 0.12181486934423447f;
  t69_n53: return 0.024196133017539978f;
  t69_n54: if (E.getNumReferences() >= 3308169216 /*2794.5*/) goto t69_n56;
  t69_n55: return -0.14476528763771057f;
  t69_n56: return 0.13535234332084656f;
  t69_n57: if (E.getNumReferences() >= 3334006272 /*23667.0*/) goto t69_n59;
  t69_n58: return 0.14434629678726196f;
  t69_n59: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t69_n65;
  t69_n60: if (E.getNumReferences() >= 3338301440 /*32056.0*/) goto t69_n64;
  t69_n61: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t69_n63;
  t69_n62: return 0.1192256510257721f;
  t69_n63: return 0.09571520239114761f;
  t69_n64: return 0.12055348604917526f;
  t69_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t69_n67;
  t69_n66: return -0.2883565127849579f;
  t69_n67: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t69_n69;
  t69_n68: return 0.08981603384017944f;
  t69_n69: return 0.06422528624534607f;
  t69_n70: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t69_n72;
  t69_n71: return 0.02705262415111065f;
  t69_n72: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t69_n74;
  t69_n73: return 0.0873253121972084f;
  t69_n74: return 0.10517210513353348f;
  t69_n75: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t69_n199;
  t69_n76: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t69_n122;
  t69_n77: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t69_n119;
  t69_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t69_n82;
  t69_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t69_n81;
  t69_n80: return -0.02119724079966545f;
  t69_n81: return 0.003244561143219471f;
  t69_n82: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t69_n118;
  t69_n83: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t69_n89;
  t69_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t69_n86;
  t69_n85: return -0.10121028125286102f;
  t69_n86: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t69_n88;
  t69_n87: return -0.0738721638917923f;
  t69_n88: return 0.0004659640835598111f;
  t69_n89: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t69_n95;
  t69_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t69_n92;
  t69_n91: return 0.014401696622371674f;
  t69_n92: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t69_n94;
  t69_n93: return 0.022489653900265694f;
  t69_n94: return 0.06562147289514542f;
  t69_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t69_n97;
  t69_n96: return -0.039746761322021484f;
  t69_n97: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t69_n111;
  t69_n98: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t69_n100;
  t69_n99: return -0.21001489460468292f;
  t69_n100: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t69_n110;
  t69_n101: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t69_n103;
  t69_n102: return -0.1617063581943512f;
  t69_n103: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t69_n105;
  t69_n104: return 0.015985073521733284f;
  t69_n105: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t69_n107;
  t69_n106: return 0.04053780809044838f;
  t69_n107: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t69_n109;
  t69_n108: return 0.119108647108078f;
  t69_n109: return 0.10935937613248825f;
  t69_n110: return 0.10712576657533646f;
  t69_n111: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t69_n113;
  t69_n112: return 0.05723436921834946f;
  t69_n113: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t69_n117;
  t69_n114: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t69_n116;
  t69_n115: return 0.14048679172992706f;
  t69_n116: return 0.11434081941843033f;
  t69_n117: return 0.03581104055047035f;
  t69_n118: return -0.10020574182271957f;
  t69_n119: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t69_n121;
  t69_n120: return -0.02940702624619007f;
  t69_n121: return 0.046753812581300735f;
  t69_n122: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t69_n186;
  t69_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t69_n127;
  t69_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol))) goto t69_n126;
  t69_n125: return -0.031097490340471268f;
  t69_n126: return 0.03352880850434303f;
  t69_n127: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t69_n153;
  t69_n128: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t69_n130;
  t69_n129: return 0.027775418013334274f;
  t69_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t69_n132;
  t69_n131: return 0.03760238364338875f;
  t69_n132: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t69_n136;
  t69_n133: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t69_n135;
  t69_n134: return 0.0343426875770092f;
  t69_n135: return 0.07331434637308121f;
  t69_n136: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t69_n152;
  t69_n137: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t69_n139;
  t69_n138: return 0.06361561268568039f;
  t69_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t69_n149;
  t69_n140: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t69_n142;
  t69_n141: return 0.11945488303899765f;
  t69_n142: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t69_n144;
  t69_n143: return -0.09277991205453873f;
  t69_n144: if (E.getNumReferences() >= 3244294144 /*14.0*/) goto t69_n146;
  t69_n145: return 0.12394702434539795f;
  t69_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t69_n148;
  t69_n147: return 0.0591760016977787f;
  t69_n148: return 0.10589127242565155f;
  t69_n149: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t69_n151;
  t69_n150: return 0.14429406821727753f;
  t69_n151: return 0.10297191143035889f;
  t69_n152: return 0.07154969871044159f;
  t69_n153: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t69_n185;
  t69_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t69_n156;
  t69_n155: return -0.023147333413362503f;
  t69_n156: if (E.getNumReferences() >= 3332634624 /*20988.0*/) goto t69_n184;
  t69_n157: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t69_n179;
  t69_n158: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t69_n160;
  t69_n159: return 0.07304459065198898f;
  t69_n160: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t69_n166;
  t69_n161: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t69_n165;
  t69_n162: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t69_n164;
  t69_n163: return 0.0829138532280922f;
  t69_n164: return -0.08565860241651535f;
  t69_n165: return 0.021680733188986778f;
  t69_n166: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t69_n178;
  t69_n167: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t69_n173;
  t69_n168: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t69_n170;
  t69_n169: return 0.08045249432325363f;
  t69_n170: if (E.getNumReferences() >= 3238002688 /*8.0*/) goto t69_n172;
  t69_n171: return 0.1259634643793106f;
  t69_n172: return 0.14283542335033417f;
  t69_n173: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t69_n177;
  t69_n174: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t69_n176;
  t69_n175: return 0.10620424151420593f;
  t69_n176: return 0.12684877216815948f;
  t69_n177: return -0.15904909372329712f;
  t69_n178: return 0.1786331832408905f;
  t69_n179: if (E.getNumReferences() >= 3285991424 /*440.5*/) goto t69_n183;
  t69_n180: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t69_n182;
  t69_n181: return 0.1540772169828415f;
  t69_n182: return -0.18208588659763336f;
  t69_n183: return 0.12885071337223053f;
  t69_n184: return 0.11773129552602768f;
  t69_n185: return -0.09996062517166138f;
  t69_n186: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t69_n198;
  t69_n187: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t69_n189;
  t69_n188: return 0.016802683472633362f;
  t69_n189: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t69_n197;
  t69_n190: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t69_n194;
  t69_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t69_n193;
  t69_n192: return -0.22249038517475128f;
  t69_n193: return 0.10637980699539185f;
  t69_n194: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t69_n196;
  t69_n195: return 0.11896109580993652f;
  t69_n196: return 0.17372801899909973f;
  t69_n197: return 0.030504964292049408f;
  t69_n198: return -0.005267179571092129f;
  t69_n199: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t69_n201;
  t69_n200: return 0.0004981762613169849f;
  t69_n201: return 0.014840417541563511f;
  t69_n202: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t69_n250;
  t69_n203: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t69_n207;
  t69_n204: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t69_n206;
  t69_n205: return 0.013844478875398636f;
  t69_n206: return -0.030674273148179054f;
  t69_n207: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t69_n211;
  t69_n208: if (E.getNumReferences() >= 3309795328 /*3191.5*/) goto t69_n210;
  t69_n209: return 0.0812092125415802f;
  t69_n210: return -0.07231363654136658f;
  t69_n211: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t69_n245;
  t69_n212: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t69_n244;
  t69_n213: if (E.getNumReferences() >= 3349739392 /*86511.0*/) goto t69_n243;
  t69_n214: if (E.getNumReferences() >= 3343006592 /*49723.5*/) goto t69_n242;
  t69_n215: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t69_n217;
  t69_n216: return 0.0073492564260959625f;
  t69_n217: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t69_n225;
  t69_n218: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t69_n222;
  t69_n219: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t69_n221;
  t69_n220: return 0.07450775057077408f;
  t69_n221: return 0.10822183638811111f;
  t69_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t69_n224;
  t69_n223: return 0.12345010042190552f;
  t69_n224: return 0.1145351380109787f;
  t69_n225: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t69_n233;
  t69_n226: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t69_n232;
  t69_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t69_n229;
  t69_n228: return 0.04781106859445572f;
  t69_n229: if (E.getNumReferences() >= 3328774656 /*14916.5*/) goto t69_n231;
  t69_n230: return 0.11811117082834244f;
  t69_n231: return 0.08887248486280441f;
  t69_n232: return -0.018858255818486214f;
  t69_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t69_n239;
  t69_n234: if (E.getNumReferences() >= 3340675072 /*40616.0*/) goto t69_n236;
  t69_n235: return 0.030212854966521263f;
  t69_n236: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t69_n238;
  t69_n237: return 0.12234195321798325f;
  t69_n238: return 0.047480542212724686f;
  t69_n239: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t69_n241;
  t69_n240: return 0.08750468492507935f;
  t69_n241: return 0.05908535420894623f;
  t69_n242: return -0.10799582302570343f;
  t69_n243: return 0.06492332369089127f;
  t69_n244: return -0.2588992118835449f;
  t69_n245: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t69_n249;
  t69_n246: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t69_n248;
  t69_n247: return 0.03714810684323311f;
  t69_n248: return 0.08337713778018951f;
  t69_n249: return -0.004713030532002449f;
  t69_n250: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t69_n254;
  t69_n251: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t69_n253;
  t69_n252: return -0.013078194111585617f;
  t69_n253: return 0.028148211538791656f;
  t69_n254: return 0.024932047352194786f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree70(const Example& E) {
  t70_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t70_n198;
  t70_n1: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t70_n155;
  t70_n2: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t70_n114;
  t70_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t70_n51;
  t70_n4: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t70_n22;
  t70_n5: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t70_n11;
  t70_n6: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t70_n10;
  t70_n7: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t70_n9;
  t70_n8: return -0.06393836438655853f;
  t70_n9: return -0.2769813537597656f;
  t70_n10: return 0.025071797892451286f;
  t70_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t70_n21;
  t70_n12: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t70_n16;
  t70_n13: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t70_n15;
  t70_n14: return 0.10513582825660706f;
  t70_n15: return 0.03727031871676445f;
  t70_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t70_n18;
  t70_n17: return 0.01906544342637062f;
  t70_n18: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t70_n20;
  t70_n19: return 0.05453125387430191f;
  t70_n20: return -0.14930739998817444f;
  t70_n21: return -0.01830182410776615f;
  t70_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t70_n32;
  t70_n23: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t70_n31;
  t70_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t70_n26;
  t70_n25: return -0.024630950763821602f;
  t70_n26: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t70_n30;
  t70_n27: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t70_n29;
  t70_n28: return 0.05623319000005722f;
  t70_n29: return 0.1377417892217636f;
  t70_n30: return -0.048747718334198f;
  t70_n31: return -0.11888182908296585f;
  t70_n32: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t70_n34;
  t70_n33: return 0.0037025443743914366f;
  t70_n34: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t70_n44;
  t70_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t70_n37;
  t70_n36: return 0.14131785929203033f;
  t70_n37: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t70_n43;
  t70_n38: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t70_n40;
  t70_n39: return 0.125909686088562f;
  t70_n40: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t70_n42;
  t70_n41: return 0.12965866923332214f;
  t70_n42: return 0.11375121772289276f;
  t70_n43: return 0.09418949484825134f;
  t70_n44: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t70_n50;
  t70_n45: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t70_n49;
  t70_n46: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t70_n48;
  t70_n47: return 0.09829194843769073f;
  t70_n48: return 0.11408577859401703f;
  t70_n49: return 0.08111788332462311f;
  t70_n50: return 0.08441198617219925f;
  t70_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t70_n53;
  t70_n52: return -0.09004230797290802f;
  t70_n53: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t70_n91;
  t70_n54: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t70_n64;
  t70_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t70_n57;
  t70_n56: return -0.11771337687969208f;
  t70_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t70_n59;
  t70_n58: return -0.003041570307686925f;
  t70_n59: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t70_n63;
  t70_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t70_n62;
  t70_n61: return 0.05273665487766266f;
  t70_n62: return 0.10905246436595917f;
  t70_n63: return 0.04070732370018959f;
  t70_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t70_n74;
  t70_n65: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t70_n71;
  t70_n66: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t70_n70;
  t70_n67: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t70_n69;
  t70_n68: return 0.014699332416057587f;
  t70_n69: return -0.07581270486116409f;
  t70_n70: return -0.16283321380615234f;
  t70_n71: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t70_n73;
  t70_n72: return -0.033651094883680344f;
  t70_n73: return 0.04221935570240021f;
  t70_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t70_n76;
  t70_n75: return 0.004875708371400833f;
  t70_n76: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t70_n78;
  t70_n77: return 0.06244855746626854f;
  t70_n78: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t70_n80;
  t70_n79: return 0.06262879073619843f;
  t70_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t70_n90;
  t70_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t70_n83;
  t70_n82: return 0.0840410590171814f;
  t70_n83: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t70_n85;
  t70_n84: return 0.034009356051683426f;
  t70_n85: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t70_n87;
  t70_n86: return 0.11890413612127304f;
  t70_n87: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t70_n89;
  t70_n88: return 0.11353887617588043f;
  t70_n89: return 0.11748731136322021f;
  t70_n90: return 0.05953654646873474f;
  t70_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t70_n95;
  t70_n92: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t70_n94;
  t70_n93: return 0.10905759036540985f;
  t70_n94: return -0.06586934626102448f;
  t70_n95: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t70_n101;
  t70_n96: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t70_n100;
  t70_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t70_n99;
  t70_n98: return -0.047443047165870667f;
  t70_n99: return 0.00563888531178236f;
  t70_n100: return -0.10860873013734818f;
  t70_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t70_n105;
  t70_n102: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t70_n104;
  t70_n103: return -0.10809887945652008f;
  t70_n104: return 0.11018995940685272f;
  t70_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t70_n111;
  t70_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t70_n108;
  t70_n107: return -0.00615696469321847f;
  t70_n108: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t70_n110;
  t70_n109: return 0.06737449765205383f;
  t70_n110: return -0.13489142060279846f;
  t70_n111: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t70_n113;
  t70_n112: return 0.02489509806036949f;
  t70_n113: return 0.005357701797038317f;
  t70_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t70_n122;
  t70_n115: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t70_n117;
  t70_n116: return 0.010357639752328396f;
  t70_n117: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t70_n119;
  t70_n118: return 0.034748468548059464f;
  t70_n119: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t70_n121;
  t70_n120: return 0.1083119586110115f;
  t70_n121: return 0.0489652119576931f;
  t70_n122: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t70_n124;
  t70_n123: return 0.014650074765086174f;
  t70_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t70_n138;
  t70_n125: if (E.getNumReferences() >= 3319035904 /*6799.0*/) goto t70_n133;
  t70_n126: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t70_n132;
  t70_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t70_n129;
  t70_n128: return 0.014695430174469948f;
  t70_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t70_n131;
  t70_n130: return -0.1366117298603058f;
  t70_n131: return 0.04063120856881142f;
  t70_n132: return -0.03012598305940628f;
  t70_n133: if (E.getNumReferences() >= 3319090176 /*6825.5*/) goto t70_n135;
  t70_n134: return 0.11659260094165802f;
  t70_n135: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t70_n137;
  t70_n136: return 0.040470946580171585f;
  t70_n137: return 0.11269339174032211f;
  t70_n138: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t70_n142;
  t70_n139: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t70_n141;
  t70_n140: return -0.010308235883712769f;
  t70_n141: return 0.05221347138285637f;
  t70_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t70_n144;
  t70_n143: return 0.03795795142650604f;
  t70_n144: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t70_n154;
  t70_n145: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t70_n151;
  t70_n146: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t70_n148;
  t70_n147: return 0.07916240394115448f;
  t70_n148: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t70_n150;
  t70_n149: return 0.12110298126935959f;
  t70_n150: return 0.09691213071346283f;
  t70_n151: if (E.getNumReferences() >= 3267952640 /*100.5*/) goto t70_n153;
  t70_n152: return 0.029391996562480927f;
  t70_n153: return 0.058081552386283875f;
  t70_n154: return 0.08302424848079681f;
  t70_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t70_n159;
  t70_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t70_n158;
  t70_n157: return -0.0981256514787674f;
  t70_n158: return -0.021154211834073067f;
  t70_n159: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t70_n161;
  t70_n160: return 0.009758093394339085f;
  t70_n161: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t70_n163;
  t70_n162: return -0.026531832292675972f;
  t70_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t70_n165;
  t70_n164: return -0.008384274318814278f;
  t70_n165: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t70_n167;
  t70_n166: return -0.021777698770165443f;
  t70_n167: if (E.getNumReferences() >= 3328274432 /*14428.0*/) goto t70_n193;
  t70_n168: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t70_n170;
  t70_n169: return 0.005263220984488726f;
  t70_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t70_n172;
  t70_n171: return -0.0025292886421084404f;
  t70_n172: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t70_n186;
  t70_n173: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t70_n185;
  t70_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t70_n180;
  t70_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t70_n177;
  t70_n176: return 0.010880619287490845f;
  t70_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t70_n179;
  t70_n178: return 0.05877949297428131f;
  t70_n179: return 0.11024724692106247f;
  t70_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t70_n182;
  t70_n181: return -0.10780923068523407f;
  t70_n182: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t70_n184;
  t70_n183: return 0.10818133503198624f;
  t70_n184: return 0.1201925054192543f;
  t70_n185: return -0.13213950395584106f;
  t70_n186: if (E.getNumReferences() >= 3307763712 /*2695.5*/) goto t70_n188;
  t70_n187: return -0.025603123009204865f;
  t70_n188: if (E.getNumReferences() >= 3308333056 /*2834.5*/) goto t70_n192;
  t70_n189: if (E.getNumReferences() >= 3308244992 /*2813.0*/) goto t70_n191;
  t70_n190: return 0.09034326672554016f;
  t70_n191: return 0.11743861436843872f;
  t70_n192: return 0.07359103113412857f;
  t70_n193: if (E.getNumReferences() >= 3328853504 /*14993.5*/) goto t70_n197;
  t70_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t70_n196;
  t70_n195: return -0.029311276972293854f;
  t70_n196: return 0.1153416857123375f;
  t70_n197: return 0.03924862667918205f;
  t70_n198: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t70_n246;
  t70_n199: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t70_n245;
  t70_n200: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t70_n222;
  t70_n201: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t70_n213;
  t70_n202: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t70_n204;
  t70_n203: return -0.253995805978775f;
  t70_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t70_n208;
  t70_n205: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t70_n207;
  t70_n206: return 0.019093185663223267f;
  t70_n207: return -0.06069076061248779f;
  t70_n208: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t70_n210;
  t70_n209: return 0.05025263875722885f;
  t70_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t70_n212;
  t70_n211: return -0.05528486147522926f;
  t70_n212: return 0.08311339467763901f;
  t70_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t70_n219;
  t70_n214: if (E.getNumReferences() >= 3319784448 /*7164.5*/) goto t70_n216;
  t70_n215: return 0.08792520314455032f;
  t70_n216: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t70_n218;
  t70_n217: return 0.023995770141482353f;
  t70_n218: return 0.07465754449367523f;
  t70_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t70_n221;
  t70_n220: return 0.11514711380004883f;
  t70_n221: return -0.01215172279626131f;
  t70_n222: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t70_n224;
  t70_n223: return 0.018043527379631996f;
  t70_n224: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t70_n230;
  t70_n225: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t70_n227;
  t70_n226: return -0.043908242136240005f;
  t70_n227: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t70_n229;
  t70_n228: return 0.035363949835300446f;
  t70_n229: return 0.05633464455604553f;
  t70_n230: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t70_n240;
  t70_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t70_n239;
  t70_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t70_n234;
  t70_n233: return 0.05207102373242378f;
  t70_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t70_n238;
  t70_n235: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t70_n237;
  t70_n236: return 0.10757286846637726f;
  t70_n237: return 0.10584382712841034f;
  t70_n238: return 0.08393877744674683f;
  t70_n239: return 0.036318182945251465f;
  t70_n240: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t70_n242;
  t70_n241: return 0.059091079980134964f;
  t70_n242: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t70_n244;
  t70_n243: return 0.09826172888278961f;
  t70_n244: return 0.052359405905008316f;
  t70_n245: return -0.00023903977125883102f;
  t70_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t70_n252;
  t70_n247: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t70_n251;
  t70_n248: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t70_n250;
  t70_n249: return -0.021166905760765076f;
  t70_n250: return 0.05560905486345291f;
  t70_n251: return 0.025796886533498764f;
  t70_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t70_n254;
  t70_n253: return -0.046842310577631f;
  t70_n254: return 0.025598300620913506f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree71(const Example& E) {
  t71_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t71_n236;
  t71_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t71_n129;
  t71_n2: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t71_n76;
  t71_n3: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t71_n25;
  t71_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t71_n16;
  t71_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t71_n7;
  t71_n6: return -0.024788713082671165f;
  t71_n7: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t71_n9;
  t71_n8: return -0.03742305934429169f;
  t71_n9: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t71_n11;
  t71_n10: return 0.006377519574016333f;
  t71_n11: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t71_n13;
  t71_n12: return 0.031871650367975235f;
  t71_n13: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t71_n15;
  t71_n14: return 0.11959243565797806f;
  t71_n15: return 0.04609619453549385f;
  t71_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t71_n18;
  t71_n17: return -0.016104796901345253f;
  t71_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t71_n20;
  t71_n19: return 0.011657556518912315f;
  t71_n20: if (E.getNumReferences() >= 3340461952 /*39783.5*/) goto t71_n22;
  t71_n21: return -0.05409432202577591f;
  t71_n22: if (E.getNumReferences() >= 3340710656 /*40755.0*/) goto t71_n24;
  t71_n23: return 0.12041553109884262f;
  t71_n24: return -0.10135450959205627f;
  t71_n25: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t71_n27;
  t71_n26: return -0.009753072634339333f;
  t71_n27: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t71_n61;
  t71_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t71_n38;
  t71_n29: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t71_n37;
  t71_n30: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n32;
  t71_n31: return 0.14600452780723572f;
  t71_n32: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t71_n34;
  t71_n33: return -0.031003408133983612f;
  t71_n34: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t71_n36;
  t71_n35: return 0.11836861819028854f;
  t71_n36: return 0.11377279460430145f;
  t71_n37: return 0.030413158237934113f;
  t71_n38: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t71_n40;
  t71_n39: return -0.037628334015607834f;
  t71_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t71_n60;
  t71_n41: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t71_n51;
  t71_n42: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n50;
  t71_n43: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t71_n47;
  t71_n44: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t71_n46;
  t71_n45: return 0.11390656977891922f;
  t71_n46: return 0.14339077472686768f;
  t71_n47: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t71_n49;
  t71_n48: return 0.1268949955701828f;
  t71_n49: return 0.1157807931303978f;
  t71_n50: return 0.11875981092453003f;
  t71_n51: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t71_n57;
  t71_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n54;
  t71_n53: return 0.03436379134654999f;
  t71_n54: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t71_n56;
  t71_n55: return 0.11414231359958649f;
  t71_n56: return 0.11086170375347137f;
  t71_n57: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n59;
  t71_n58: return 0.11113474518060684f;
  t71_n59: return 0.0109631372615695f;
  t71_n60: return 0.08171099424362183f;
  t71_n61: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t71_n63;
  t71_n62: return 0.0183603186160326f;
  t71_n63: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t71_n75;
  t71_n64: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t71_n74;
  t71_n65: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t71_n67;
  t71_n66: return 0.07230564951896667f;
  t71_n67: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t71_n73;
  t71_n68: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n72;
  t71_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t71_n71;
  t71_n70: return 0.11932650208473206f;
  t71_n71: return 0.13078798353672028f;
  t71_n72: return 0.06601675599813461f;
  t71_n73: return 0.08826518803834915f;
  t71_n74: return 0.02906121499836445f;
  t71_n75: return 0.0020279965829104185f;
  t71_n76: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t71_n126;
  t71_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t71_n115;
  t71_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t71_n110;
  t71_n79: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t71_n81;
  t71_n80: return 0.004455329850316048f;
  t71_n81: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t71_n85;
  t71_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t71_n84;
  t71_n83: return -0.12386781722307205f;
  t71_n84: return 0.02124555967748165f;
  t71_n85: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t71_n91;
  t71_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t71_n88;
  t71_n87: return -0.0572894923388958f;
  t71_n88: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t71_n90;
  t71_n89: return 0.027612388134002686f;
  t71_n90: return -0.18022732436656952f;
  t71_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t71_n99;
  t71_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t71_n94;
  t71_n93: return -0.012002633884549141f;
  t71_n94: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t71_n98;
  t71_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n97;
  t71_n96: return 0.0805961936712265f;
  t71_n97: return 0.08329617232084274f;
  t71_n98: return 0.0175457876175642f;
  t71_n99: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t71_n109;
  t71_n100: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t71_n108;
  t71_n101: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t71_n105;
  t71_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n104;
  t71_n103: return 0.11906526237726212f;
  t71_n104: return 0.13948683440685272f;
  t71_n105: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t71_n107;
  t71_n106: return 0.1284082531929016f;
  t71_n107: return 0.11395497620105743f;
  t71_n108: return 0.09122718125581741f;
  t71_n109: return -0.08568167686462402f;
  t71_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t71_n112;
  t71_n111: return 0.02706010639667511f;
  t71_n112: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t71_n114;
  t71_n113: return -0.03982410207390785f;
  t71_n114: return 0.07837499678134918f;
  t71_n115: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t71_n119;
  t71_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t71_n118;
  t71_n117: return 0.03912839666008949f;
  t71_n118: return 0.07490584999322891f;
  t71_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t71_n121;
  t71_n120: return 0.06800539791584015f;
  t71_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t71_n125;
  t71_n122: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t71_n124;
  t71_n123: return 0.17750845849514008f;
  t71_n124: return 0.19549372792243958f;
  t71_n125: return -0.10518208891153336f;
  t71_n126: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t71_n128;
  t71_n127: return -0.0349697582423687f;
  t71_n128: return 0.03188036382198334f;
  t71_n129: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t71_n235;
  t71_n130: if (E.getNumReferences() >= 3306424320 /*2368.5*/) goto t71_n228;
  t71_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t71_n157;
  t71_n132: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t71_n142;
  t71_n133: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t71_n137;
  t71_n134: if (E.getNumReferences() >= 3290472448 /*642.5*/) goto t71_n136;
  t71_n135: return -0.026269210502505302f;
  t71_n136: return 0.11676861345767975f;
  t71_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n139;
  t71_n138: return -0.286746621131897f;
  t71_n139: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t71_n141;
  t71_n140: return -0.10727464407682419f;
  t71_n141: return 0.013095499947667122f;
  t71_n142: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t71_n146;
  t71_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t71_n145;
  t71_n144: return -0.015538513660430908f;
  t71_n145: return 0.008450224995613098f;
  t71_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t71_n154;
  t71_n147: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t71_n153;
  t71_n148: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t71_n150;
  t71_n149: return 0.048384372144937515f;
  t71_n150: if (E.getNumReferences() >= 3292962816 /*794.5*/) goto t71_n152;
  t71_n151: return 0.12886157631874084f;
  t71_n152: return 0.039975449442863464f;
  t71_n153: return 0.012619270011782646f;
  t71_n154: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t71_n156;
  t71_n155: return -0.15206214785575867f;
  t71_n156: return -0.012818785384297371f;
  t71_n157: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t71_n209;
  t71_n158: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t71_n172;
  t71_n159: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t71_n171;
  t71_n160: if (E.getNumReferences() >= 3293822976 /*847.0*/) goto t71_n168;
  t71_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t71_n163;
  t71_n162: return -0.03913263976573944f;
  t71_n163: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t71_n165;
  t71_n164: return 0.04420272633433342f;
  t71_n165: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t71_n167;
  t71_n166: return 0.09802037477493286f;
  t71_n167: return 0.11237724125385284f;
  t71_n168: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t71_n170;
  t71_n169: return 0.10167111456394196f;
  t71_n170: return 0.06991651654243469f;
  t71_n171: return -0.1371055394411087f;
  t71_n172: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t71_n180;
  t71_n173: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t71_n179;
  t71_n174: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t71_n176;
  t71_n175: return -0.00958522129803896f;
  t71_n176: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t71_n178;
  t71_n177: return 0.04209195077419281f;
  t71_n178: return 0.014762339182198048f;
  t71_n179: return 0.0026591450441628695f;
  t71_n180: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t71_n184;
  t71_n181: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t71_n183;
  t71_n182: return 0.008033058606088161f;
  t71_n183: return -0.04337010905146599f;
  t71_n184: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t71_n186;
  t71_n185: return 0.040926430374383926f;
  t71_n186: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t71_n202;
  t71_n187: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t71_n189;
  t71_n188: return 0.06841433793306351f;
  t71_n189: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t71_n197;
  t71_n190: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t71_n194;
  t71_n191: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t71_n193;
  t71_n192: return 0.12053702771663666f;
  t71_n193: return -0.10048949718475342f;
  t71_n194: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t71_n196;
  t71_n195: return 0.08318018913269043f;
  t71_n196: return 0.14366912841796875f;
  t71_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t71_n199;
  t71_n198: return 0.06903650611639023f;
  t71_n199: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t71_n201;
  t71_n200: return -0.08626771718263626f;
  t71_n201: return 0.11745902895927429f;
  t71_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t71_n208;
  t71_n203: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t71_n207;
  t71_n204: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t71_n206;
  t71_n205: return 0.19516704976558685f;
  t71_n206: return 0.11492402106523514f;
  t71_n207: return 0.0834699496626854f;
  t71_n208: return 0.12686562538146973f;
  t71_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t71_n217;
  t71_n210: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t71_n216;
  t71_n211: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t71_n213;
  t71_n212: return 0.017947712913155556f;
  t71_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t71_n215;
  t71_n214: return 0.025970231741666794f;
  t71_n215: return 0.05614982172846794f;
  t71_n216: return -0.0003852247609756887f;
  t71_n217: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t71_n227;
  t71_n218: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t71_n226;
  t71_n219: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t71_n223;
  t71_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t71_n222;
  t71_n221: return -0.2111499309539795f;
  t71_n222: return -0.08509495854377747f;
  t71_n223: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t71_n225;
  t71_n224: return 0.0724131315946579f;
  t71_n225: return 0.10395810753107071f;
  t71_n226: return -0.020591989159584045f;
  t71_n227: return -0.0004031365388073027f;
  t71_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t71_n230;
  t71_n229: return 0.01145070232450962f;
  t71_n230: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t71_n234;
  t71_n231: if (E.getNumReferences() >= 3311878144 /*3700.0*/) goto t71_n233;
  t71_n232: return 0.11831936985254288f;
  t71_n233: return 0.05520329996943474f;
  t71_n234: return 0.026131825521588326f;
  t71_n235: return 0.00633607804775238f;
  t71_n236: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t71_n248;
  t71_n237: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t71_n239;
  t71_n238: return 0.009919838048517704f;
  t71_n239: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t71_n245;
  t71_n240: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t71_n242;
  t71_n241: return 0.04844263195991516f;
  t71_n242: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t71_n244;
  t71_n243: return 0.01473129354417324f;
  t71_n244: return 0.07034698128700256f;
  t71_n245: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t71_n247;
  t71_n246: return -0.0012175880838185549f;
  t71_n247: return 0.04449552670121193f;
  t71_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t71_n252;
  t71_n249: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t71_n251;
  t71_n250: return 0.012419442646205425f;
  t71_n251: return -0.02751644141972065f;
  t71_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t71_n254;
  t71_n253: return -0.04832860454916954f;
  t71_n254: return 0.024103645235300064f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree72(const Example& E) {
  t72_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t72_n190;
  t72_n1: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t72_n145;
  t72_n2: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t72_n120;
  t72_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t72_n5;
  t72_n4: return -0.09145243465900421f;
  t72_n5: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t72_n69;
  t72_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t72_n26;
  t72_n7: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t72_n25;
  t72_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t72_n22;
  t72_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t72_n11;
  t72_n10: return 0.008974392898380756f;
  t72_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n13;
  t72_n12: return -0.05956672132015228f;
  t72_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n17;
  t72_n14: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n16;
  t72_n15: return 0.09748180955648422f;
  t72_n16: return 0.05406728386878967f;
  t72_n17: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t72_n19;
  t72_n18: return 0.058034222573041916f;
  t72_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t72_n21;
  t72_n20: return 0.09540093690156937f;
  t72_n21: return 0.08967337757349014f;
  t72_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n24;
  t72_n23: return 0.11320774257183075f;
  t72_n24: return 0.04846633970737457f;
  t72_n25: return -0.018643783405423164f;
  t72_n26: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t72_n28;
  t72_n27: return 0.006740173324942589f;
  t72_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n34;
  t72_n29: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t72_n33;
  t72_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n32;
  t72_n31: return 0.11389374732971191f;
  t72_n32: return 0.0587376169860363f;
  t72_n33: return -0.03579071909189224f;
  t72_n34: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t72_n56;
  t72_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t72_n39;
  t72_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t72_n38;
  t72_n37: return -0.005326257552951574f;
  t72_n38: return 0.010928434319794178f;
  t72_n39: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t72_n55;
  t72_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n52;
  t72_n41: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n43;
  t72_n42: return 0.09452398866415024f;
  t72_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t72_n51;
  t72_n44: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t72_n46;
  t72_n45: return 0.052776679396629333f;
  t72_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t72_n48;
  t72_n47: return -0.3180740177631378f;
  t72_n48: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t72_n50;
  t72_n49: return 0.11182691901922226f;
  t72_n50: return -0.1659499853849411f;
  t72_n51: return 0.09760354459285736f;
  t72_n52: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n54;
  t72_n53: return 0.07730898261070251f;
  t72_n54: return 0.03350843861699104f;
  t72_n55: return 0.026163123548030853f;
  t72_n56: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t72_n58;
  t72_n57: return -0.10288795083761215f;
  t72_n58: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t72_n60;
  t72_n59: return -0.12407217919826508f;
  t72_n60: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t72_n68;
  t72_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n63;
  t72_n62: return -0.044928573071956635f;
  t72_n63: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n65;
  t72_n64: return 0.13260389864444733f;
  t72_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n67;
  t72_n66: return -0.051145702600479126f;
  t72_n67: return 0.03302215039730072f;
  t72_n68: return -0.037298403680324554f;
  t72_n69: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t72_n73;
  t72_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n72;
  t72_n71: return -0.13034644722938538f;
  t72_n72: return 0.005058859474956989f;
  t72_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t72_n101;
  t72_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t72_n84;
  t72_n75: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n77;
  t72_n76: return -0.018655981868505478f;
  t72_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t72_n83;
  t72_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t72_n80;
  t72_n79: return -0.011648215353488922f;
  t72_n80: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t72_n82;
  t72_n81: return 0.05912117287516594f;
  t72_n82: return -0.05899897590279579f;
  t72_n83: return 0.022947708144783974f;
  t72_n84: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n88;
  t72_n85: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t72_n87;
  t72_n86: return 0.027786988765001297f;
  t72_n87: return 0.16629987955093384f;
  t72_n88: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t72_n100;
  t72_n89: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t72_n91;
  t72_n90: return 0.049610961228609085f;
  t72_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t72_n93;
  t72_n92: return 0.0837985947728157f;
  t72_n93: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t72_n95;
  t72_n94: return 0.08851328492164612f;
  t72_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t72_n97;
  t72_n96: return 0.14277717471122742f;
  t72_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n99;
  t72_n98: return 0.11460921168327332f;
  t72_n99: return 0.11027269065380096f;
  t72_n100: return 0.00778938177973032f;
  t72_n101: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n113;
  t72_n102: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t72_n112;
  t72_n103: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t72_n111;
  t72_n104: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n106;
  t72_n105: return 0.14816047251224518f;
  t72_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t72_n110;
  t72_n107: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t72_n109;
  t72_n108: return 0.11732891201972961f;
  t72_n109: return 0.13654188811779022f;
  t72_n110: return 0.12750226259231567f;
  t72_n111: return 0.11318790912628174f;
  t72_n112: return 0.09435859322547913f;
  t72_n113: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t72_n119;
  t72_n114: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t72_n118;
  t72_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t72_n117;
  t72_n116: return 0.08530531823635101f;
  t72_n117: return 0.11478248238563538f;
  t72_n118: return 0.07781799882650375f;
  t72_n119: return 0.08476965874433517f;
  t72_n120: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t72_n128;
  t72_n121: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t72_n123;
  t72_n122: return 0.011153722181916237f;
  t72_n123: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t72_n125;
  t72_n124: return 0.030557140707969666f;
  t72_n125: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n127;
  t72_n126: return 0.1031181663274765f;
  t72_n127: return 0.04582836106419563f;
  t72_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t72_n140;
  t72_n129: if (E.getNumReferences() >= 3308015616 /*2757.0*/) goto t72_n137;
  t72_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t72_n132;
  t72_n131: return -0.0008745536906644702f;
  t72_n132: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t72_n136;
  t72_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n135;
  t72_n134: return -0.11665480583906174f;
  t72_n135: return 0.03801236301660538f;
  t72_n136: return -0.025694632902741432f;
  t72_n137: if (E.getNumReferences() >= 3308064768 /*2769.0*/) goto t72_n139;
  t72_n138: return 0.28164324164390564f;
  t72_n139: return 0.041999075561761856f;
  t72_n140: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t72_n142;
  t72_n141: return 0.0346807986497879f;
  t72_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t72_n144;
  t72_n143: return 0.03549237549304962f;
  t72_n144: return 0.05586666613817215f;
  t72_n145: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t72_n189;
  t72_n146: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t72_n148;
  t72_n147: return -0.013309022411704063f;
  t72_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n150;
  t72_n149: return -0.037582967430353165f;
  t72_n150: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t72_n154;
  t72_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t72_n153;
  t72_n152: return -0.0780198946595192f;
  t72_n153: return -0.01575368642807007f;
  t72_n154: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n156;
  t72_n155: return 0.008684852160513401f;
  t72_n156: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t72_n176;
  t72_n157: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t72_n161;
  t72_n158: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t72_n160;
  t72_n159: return 0.0034120315685868263f;
  t72_n160: return -0.06326930224895477f;
  t72_n161: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t72_n167;
  t72_n162: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t72_n166;
  t72_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t72_n165;
  t72_n164: return -0.011600787751376629f;
  t72_n165: return 0.06358610838651657f;
  t72_n166: return 0.013687360100448132f;
  t72_n167: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t72_n175;
  t72_n168: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t72_n170;
  t72_n169: return 0.03070611134171486f;
  t72_n170: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t72_n172;
  t72_n171: return 0.0800175815820694f;
  t72_n172: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t72_n174;
  t72_n173: return 0.12355715036392212f;
  t72_n174: return 0.08318299055099487f;
  t72_n175: return -0.051322996616363525f;
  t72_n176: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t72_n186;
  t72_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n183;
  t72_n178: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t72_n180;
  t72_n179: return -0.29601192474365234f;
  t72_n180: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t72_n182;
  t72_n181: return 0.11283493041992188f;
  t72_n182: return 0.09719756245613098f;
  t72_n183: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t72_n185;
  t72_n184: return 0.11159912496805191f;
  t72_n185: return 0.1013784185051918f;
  t72_n186: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t72_n188;
  t72_n187: return 0.038963038474321365f;
  t72_n188: return -0.011967112310230732f;
  t72_n189: return -0.06786329299211502f;
  t72_n190: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t72_n248;
  t72_n191: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t72_n203;
  t72_n192: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t72_n196;
  t72_n193: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t72_n195;
  t72_n194: return 0.040552400052547455f;
  t72_n195: return 0.02123742736876011f;
  t72_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n198;
  t72_n197: return 0.013917717151343822f;
  t72_n198: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t72_n202;
  t72_n199: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t72_n201;
  t72_n200: return -0.13424617052078247f;
  t72_n201: return 0.08269128203392029f;
  t72_n202: return 3.588245090213604e-05f;
  t72_n203: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t72_n205;
  t72_n204: return 0.005311501212418079f;
  t72_n205: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t72_n213;
  t72_n206: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t72_n210;
  t72_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n209;
  t72_n208: return 0.0708945170044899f;
  t72_n209: return 0.10704824328422546f;
  t72_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t72_n212;
  t72_n211: return 0.12170860916376114f;
  t72_n212: return 0.11348661035299301f;
  t72_n213: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t72_n221;
  t72_n214: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t72_n220;
  t72_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t72_n217;
  t72_n216: return 0.04138105735182762f;
  t72_n217: if (E.getNumReferences() >= 3328774656 /*14916.5*/) goto t72_n219;
  t72_n218: return 0.11547242850065231f;
  t72_n219: return 0.08458447456359863f;
  t72_n220: return -0.01776696927845478f;
  t72_n221: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t72_n247;
  t72_n222: if (E.getNumReferences() >= 3329614848 /*15737.0*/) goto t72_n244;
  t72_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t72_n225;
  t72_n224: return 0.04295714199542999f;
  t72_n225: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t72_n233;
  t72_n226: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t72_n232;
  t72_n227: if (E.getNumReferences() >= 3324040704 /*10293.5*/) goto t72_n231;
  t72_n228: if (E.getNumReferences() >= 3319294976 /*6925.5*/) goto t72_n230;
  t72_n229: return 0.1124882698059082f;
  t72_n230: return 0.11234139651060104f;
  t72_n231: return -0.14325794577598572f;
  t72_n232: return 0.035000476986169815f;
  t72_n233: if (E.getNumReferences() >= 3321964544 /*8266.0*/) goto t72_n235;
  t72_n234: return 0.04626661539077759f;
  t72_n235: if (E.getNumReferences() >= 3322966016 /*9244.0*/) goto t72_n243;
  t72_n236: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t72_n238;
  t72_n237: return 0.09011195600032806f;
  t72_n238: if (E.getNumReferences() >= 3322565632 /*8853.0*/) goto t72_n242;
  t72_n239: if (E.getNumReferences() >= 3322286592 /*8580.5*/) goto t72_n241;
  t72_n240: return 0.12733455002307892f;
  t72_n241: return 0.08314336836338043f;
  t72_n242: return 0.11338017135858536f;
  t72_n243: return 0.07785721868276596f;
  t72_n244: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t72_n246;
  t72_n245: return 0.1161368265748024f;
  t72_n246: return 0.10774865001440048f;
  t72_n247: return 0.04852414131164551f;
  t72_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t72_n250;
  t72_n249: return -0.7045518755912781f;
  t72_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n252;
  t72_n251: return -0.038162097334861755f;
  t72_n252: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t72_n254;
  t72_n253: return 0.01822161115705967f;
  t72_n254: return 0.056333646178245544f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree73(const Example& E) {
  t73_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t73_n234;
  t73_n1: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t73_n33;
  t73_n2: if (E.getNumReferences() >= 3324968960 /*11200.0*/) goto t73_n26;
  t73_n3: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t73_n5;
  t73_n4: return 0.0008211841341108084f;
  t73_n5: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t73_n7;
  t73_n6: return 0.003174439538270235f;
  t73_n7: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t73_n19;
  t73_n8: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t73_n10;
  t73_n9: return 0.009691997431218624f;
  t73_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t73_n12;
  t73_n11: return 0.0238500963896513f;
  t73_n12: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t73_n18;
  t73_n13: if (E.getNumReferences() >= 3272966144 /*149.5*/) goto t73_n15;
  t73_n14: return -0.013926979154348373f;
  t73_n15: if (E.getNumReferences() >= 3273555968 /*158.5*/) goto t73_n17;
  t73_n16: return 0.09764174371957779f;
  t73_n17: return 0.03844006359577179f;
  t73_n18: return 0.046041641384363174f;
  t73_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t73_n23;
  t73_n20: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t73_n22;
  t73_n21: return 0.04186335206031799f;
  t73_n22: return -0.08391193300485611f;
  t73_n23: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t73_n25;
  t73_n24: return 0.05231378600001335f;
  t73_n25: return 0.06990315020084381f;
  t73_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t73_n32;
  t73_n27: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t73_n29;
  t73_n28: return 0.017125073820352554f;
  t73_n29: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t73_n31;
  t73_n30: return 0.022571494802832603f;
  t73_n31: return 0.09802475571632385f;
  t73_n32: return 0.0437740720808506f;
  t73_n33: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t73_n109;
  t73_n34: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t73_n36;
  t73_n35: return -0.006144518498331308f;
  t73_n36: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t73_n94;
  t73_n37: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t73_n93;
  t73_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t73_n40;
  t73_n39: return -0.010236942209303379f;
  t73_n40: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t73_n74;
  t73_n41: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t73_n73;
  t73_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t73_n66;
  t73_n43: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t73_n45;
  t73_n44: return 0.03182004764676094f;
  t73_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t73_n47;
  t73_n46: return 0.08048950880765915f;
  t73_n47: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t73_n49;
  t73_n48: return 0.021176116541028023f;
  t73_n49: if (E.getNumReferences() >= 3275980800 /*195.5*/) goto t73_n61;
  t73_n50: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t73_n58;
  t73_n51: if (E.getNumReferences() >= 3264020480 /*70.5*/) goto t73_n57;
  t73_n52: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t73_n54;
  t73_n53: return 0.12377680838108063f;
  t73_n54: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t73_n56;
  t73_n55: return -0.11567174643278122f;
  t73_n56: return 0.11979330331087112f;
  t73_n57: return 0.13334359228610992f;
  t73_n58: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t73_n60;
  t73_n59: return 0.10386400669813156f;
  t73_n60: return -0.12275438755750656f;
  t73_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n65;
  t73_n62: if (E.getNumReferences() >= 3290087424 /*619.0*/) goto t73_n64;
  t73_n63: return 0.08322305232286453f;
  t73_n64: return 0.1320677101612091f;
  t73_n65: return 0.12306267023086548f;
  t73_n66: if (E.getNumReferences() >= 3280977920 /*287.5*/) goto t73_n68;
  t73_n67: return 0.05800643563270569f;
  t73_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t73_n70;
  t73_n69: return 0.09877585619688034f;
  t73_n70: if (E.getNumReferences() >= 3293446144 /*824.0*/) goto t73_n72;
  t73_n71: return 0.13195809721946716f;
  t73_n72: return 0.09473424404859543f;
  t73_n73: return 0.02450399287045002f;
  t73_n74: if (E.getNumReferences() >= 3294625792 /*896.0*/) goto t73_n82;
  t73_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t73_n77;
  t73_n76: return -0.02800241857767105f;
  t73_n77: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t73_n81;
  t73_n78: if (E.getNumReferences() >= 3241148416 /*11.0*/) goto t73_n80;
  t73_n79: return -0.5452554821968079f;
  t73_n80: return 0.11183785647153854f;
  t73_n81: return 0.02417987771332264f;
  t73_n82: if (E.getNumReferences() >= 3294732288 /*902.5*/) goto t73_n86;
  t73_n83: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n85;
  t73_n84: return -0.013579671271145344f;
  t73_n85: return 0.10317739844322205f;
  t73_n86: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t73_n90;
  t73_n87: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n89;
  t73_n88: return 0.041663188487291336f;
  t73_n89: return -0.040039412677288055f;
  t73_n90: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t73_n92;
  t73_n91: return 0.10250308364629745f;
  t73_n92: return 0.059279367327690125f;
  t73_n93: return -0.1793050765991211f;
  t73_n94: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t73_n100;
  t73_n95: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t73_n97;
  t73_n96: return 0.05240543559193611f;
  t73_n97: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t73_n99;
  t73_n98: return 0.06449808180332184f;
  t73_n99: return 0.08775494992733002f;
  t73_n100: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t73_n104;
  t73_n101: if (E.getNumReferences() >= 3306219520 /*2318.5*/) goto t73_n103;
  t73_n102: return 0.06275279074907303f;
  t73_n103: return 0.05540318414568901f;
  t73_n104: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t73_n108;
  t73_n105: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n107;
  t73_n106: return -0.10832421481609344f;
  t73_n107: return 0.15652334690093994f;
  t73_n108: return 0.048748914152383804f;
  t73_n109: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t73_n115;
  t73_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t73_n114;
  t73_n111: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t73_n113;
  t73_n112: return -0.0962938740849495f;
  t73_n113: return -0.5757347345352173f;
  t73_n114: return -0.037100695073604584f;
  t73_n115: if (E.getNumReferences() >= 3288997888 /*552.5*/) goto t73_n145;
  t73_n116: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t73_n144;
  t73_n117: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t73_n119;
  t73_n118: return -0.020698558539152145f;
  t73_n119: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t73_n143;
  t73_n120: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t73_n122;
  t73_n121: return -0.008240621536970139f;
  t73_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t73_n124;
  t73_n123: return 0.015198169276118279f;
  t73_n124: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t73_n126;
  t73_n125: return -0.02821389026939869f;
  t73_n126: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t73_n128;
  t73_n127: return 0.05930671840906143f;
  t73_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t73_n132;
  t73_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t73_n131;
  t73_n130: return -0.012629859149456024f;
  t73_n131: return 0.05939529836177826f;
  t73_n132: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t73_n136;
  t73_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t73_n135;
  t73_n134: return 0.0951073169708252f;
  t73_n135: return 0.11659520864486694f;
  t73_n136: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t73_n142;
  t73_n137: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t73_n139;
  t73_n138: return 0.13254790008068085f;
  t73_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t73_n141;
  t73_n140: return -0.05656004324555397f;
  t73_n141: return 0.17463083565235138f;
  t73_n142: return 0.03182118758559227f;
  t73_n143: return -0.13886532187461853f;
  t73_n144: return -0.060955073684453964f;
  t73_n145: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t73_n147;
  t73_n146: return -0.00032504519913345575f;
  t73_n147: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t73_n197;
  t73_n148: if (E.getNumReferences() >= 3313939456 /*4310.5*/) goto t73_n150;
  t73_n149: return 0.0047228457406163216f;
  t73_n150: if (E.getNumReferences() >= 3313967104 /*4324.0*/) goto t73_n154;
  t73_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t73_n153;
  t73_n152: return 0.11537405848503113f;
  t73_n153: return -0.10170615464448929f;
  t73_n154: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t73_n196;
  t73_n155: if (E.getNumReferences() >= 3341306880 /*43084.0*/) goto t73_n189;
  t73_n156: if (E.getNumReferences() >= 3334608896 /*24844.0*/) goto t73_n184;
  t73_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t73_n173;
  t73_n158: if (E.getNumReferences() >= 3319769088 /*7157.0*/) goto t73_n160;
  t73_n159: return 0.04834446310997009f;
  t73_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t73_n162;
  t73_n161: return 0.0496232733130455f;
  t73_n162: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t73_n164;
  t73_n163: return 0.07504616677761078f;
  t73_n164: if (E.getNumReferences() >= 3325492736 /*11711.5*/) goto t73_n172;
  t73_n165: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t73_n167;
  t73_n166: return 0.0898984968662262f;
  t73_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n171;
  t73_n168: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t73_n170;
  t73_n169: return 0.11282537132501602f;
  t73_n170: return 0.11807354539632797f;
  t73_n171: return -0.12991268932819366f;
  t73_n172: return 0.053681761026382446f;
  t73_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t73_n183;
  t73_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t73_n182;
  t73_n175: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t73_n177;
  t73_n176: return 0.14996445178985596f;
  t73_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n181;
  t73_n178: if (E.getNumReferences() >= 3317499904 /*6049.0*/) goto t73_n180;
  t73_n179: return 0.11532872915267944f;
  t73_n180: return 0.09969661384820938f;
  t73_n181: return 0.11130837351083755f;
  t73_n182: return -0.1635984182357788f;
  t73_n183: return 0.11843398213386536f;
  t73_n184: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t73_n188;
  t73_n185: if (E.getNumReferences() >= 3335106048 /*25815.0*/) goto t73_n187;
  t73_n186: return -0.8965163230895996f;
  t73_n187: return -0.04644164443016052f;
  t73_n188: return 0.030947793275117874f;
  t73_n189: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t73_n195;
  t73_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t73_n192;
  t73_n191: return 0.014394156634807587f;
  t73_n192: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t73_n194;
  t73_n193: return 0.09624797850847244f;
  t73_n194: return 0.11269960552453995f;
  t73_n195: return 0.048959892243146896f;
  t73_n196: return -0.016717178747057915f;
  t73_n197: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t73_n221;
  t73_n198: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t73_n200;
  t73_n199: return 0.04176165163516998f;
  t73_n200: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t73_n202;
  t73_n201: return 0.1198195293545723f;
  t73_n202: if (E.getNumReferences() >= 3334377216 /*24391.5*/) goto t73_n220;
  t73_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t73_n215;
  t73_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t73_n208;
  t73_n205: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t73_n207;
  t73_n206: return -0.009411809034645557f;
  t73_n207: return 0.09196814149618149f;
  t73_n208: if (E.getNumReferences() >= 3332719104 /*21153.0*/) goto t73_n210;
  t73_n209: return -0.1204800009727478f;
  t73_n210: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n214;
  t73_n211: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t73_n213;
  t73_n212: return 0.12123578041791916f;
  t73_n213: return 0.103324294090271f;
  t73_n214: return 0.11644239723682404f;
  t73_n215: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t73_n219;
  t73_n216: if (E.getNumReferences() >= 3332878080 /*21463.5*/) goto t73_n218;
  t73_n217: return 0.07331069558858871f;
  t73_n218: return 0.10499155521392822f;
  t73_n219: return 0.10958490520715714f;
  t73_n220: return 0.031035684049129486f;
  t73_n221: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t73_n227;
  t73_n222: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t73_n226;
  t73_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t73_n225;
  t73_n224: return 0.018565984442830086f;
  t73_n225: return 0.06920643895864487f;
  t73_n226: return 0.05073300749063492f;
  t73_n227: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t73_n233;
  t73_n228: if (E.getNumReferences() >= 3325197824 /*11423.5*/) goto t73_n230;
  t73_n229: return 0.12783001363277435f;
  t73_n230: if (E.getNumReferences() >= 3333374720 /*22433.5*/) goto t73_n232;
  t73_n231: return 0.10907315462827682f;
  t73_n232: return 0.09658346325159073f;
  t73_n233: return 0.06496864557266235f;
  t73_n234: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t73_n246;
  t73_n235: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t73_n237;
  t73_n236: return 0.008465767838060856f;
  t73_n237: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t73_n243;
  t73_n238: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t73_n240;
  t73_n239: return -0.11773887276649475f;
  t73_n240: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t73_n242;
  t73_n241: return 0.04938792437314987f;
  t73_n242: return 0.02383885160088539f;
  t73_n243: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t73_n245;
  t73_n244: return -0.0031014145351946354f;
  t73_n245: return 0.045542068779468536f;
  t73_n246: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t73_n254;
  t73_n247: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t73_n253;
  t73_n248: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t73_n252;
  t73_n249: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t73_n251;
  t73_n250: return -0.1978420466184616f;
  t73_n251: return 0.01674613542854786f;
  t73_n252: return 0.020139407366514206f;
  t73_n253: return -0.015019124373793602f;
  t73_n254: return 0.054418738931417465f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree74(const Example& E) {
  t74_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t74_n230;
  t74_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t74_n181;
  t74_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t74_n32;
  t74_n3: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t74_n5;
  t74_n4: return 0.0006696001510135829f;
  t74_n5: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t74_n7;
  t74_n6: return 0.006410025525838137f;
  t74_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t74_n11;
  t74_n8: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t74_n10;
  t74_n9: return -0.10695401579141617f;
  t74_n10: return 0.05760873481631279f;
  t74_n11: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t74_n25;
  t74_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t74_n24;
  t74_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t74_n15;
  t74_n14: return 0.028919130563735962f;
  t74_n15: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t74_n17;
  t74_n16: return 0.02903536520898342f;
  t74_n17: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t74_n23;
  t74_n18: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t74_n20;
  t74_n19: return 0.04199433699250221f;
  t74_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t74_n22;
  t74_n21: return 0.03763628751039505f;
  t74_n22: return 0.06198114529252052f;
  t74_n23: return 0.03653471916913986f;
  t74_n24: return 0.012991616502404213f;
  t74_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t74_n29;
  t74_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t74_n28;
  t74_n27: return -0.17730110883712769f;
  t74_n28: return -0.018087340518832207f;
  t74_n29: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t74_n31;
  t74_n30: return -0.0013212681515142322f;
  t74_n31: return 0.04323635995388031f;
  t74_n32: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t74_n72;
  t74_n33: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t74_n35;
  t74_n34: return -0.005686386954039335f;
  t74_n35: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t74_n37;
  t74_n36: return 0.02216263674199581f;
  t74_n37: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t74_n41;
  t74_n38: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t74_n40;
  t74_n39: return 0.06332841515541077f;
  t74_n40: return 0.07976129651069641f;
  t74_n41: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t74_n43;
  t74_n42: return 0.06747472286224365f;
  t74_n43: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t74_n57;
  t74_n44: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t74_n52;
  t74_n45: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t74_n51;
  t74_n46: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t74_n48;
  t74_n47: return -0.01289917528629303f;
  t74_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t74_n50;
  t74_n49: return -0.10096262395381927f;
  t74_n50: return 0.12590235471725464f;
  t74_n51: return 0.15692441165447235f;
  t74_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t74_n54;
  t74_n53: return 0.038714636117219925f;
  t74_n54: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t74_n56;
  t74_n55: return -0.42555931210517883f;
  t74_n56: return 0.11302125453948975f;
  t74_n57: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t74_n59;
  t74_n58: return 0.06526617705821991f;
  t74_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t74_n61;
  t74_n60: return 0.050306592136621475f;
  t74_n61: if (E.getNumReferences() >= 3243245568 /*13.0*/) goto t74_n67;
  t74_n62: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t74_n64;
  t74_n63: return 0.09368803352117538f;
  t74_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t74_n66;
  t74_n65: return 0.16691552102565765f;
  t74_n66: return 0.15957945585250854f;
  t74_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t74_n69;
  t74_n68: return 0.1562146544456482f;
  t74_n69: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t74_n71;
  t74_n70: return 0.12559424340724945f;
  t74_n71: return 0.11416976898908615f;
  t74_n72: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t74_n150;
  t74_n73: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t74_n81;
  t74_n74: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t74_n76;
  t74_n75: return -0.04475809633731842f;
  t74_n76: if (E.getNumReferences() >= 3322163200 /*8460.0*/) goto t74_n80;
  t74_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t74_n79;
  t74_n78: return -0.26731985807418823f;
  t74_n79: return -0.06397204846143723f;
  t74_n80: return 0.052483025938272476f;
  t74_n81: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t74_n83;
  t74_n82: return -0.06090843304991722f;
  t74_n83: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t74_n149;
  t74_n84: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t74_n126;
  t74_n85: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t74_n117;
  t74_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t74_n88;
  t74_n87: return -0.13053588569164276f;
  t74_n88: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t74_n90;
  t74_n89: return -0.0047847554087638855f;
  t74_n90: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t74_n114;
  t74_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t74_n95;
  t74_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t74_n94;
  t74_n93: return -0.010925321839749813f;
  t74_n94: return 0.06024845689535141f;
  t74_n95: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t74_n97;
  t74_n96: return 0.042515333741903305f;
  t74_n97: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t74_n107;
  t74_n98: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t74_n100;
  t74_n99: return 0.030341768637299538f;
  t74_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t74_n102;
  t74_n101: return 0.06044192612171173f;
  t74_n102: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t74_n104;
  t74_n103: return -0.7695448398590088f;
  t74_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t74_n106;
  t74_n105: return -0.10762564092874527f;
  t74_n106: return 0.11905276775360107f;
  t74_n107: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t74_n113;
  t74_n108: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t74_n112;
  t74_n109: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t74_n111;
  t74_n110: return 0.1082824096083641f;
  t74_n111: return 0.07735010236501694f;
  t74_n112: return 0.048418715596199036f;
  t74_n113: return 0.06573942303657532f;
  t74_n114: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t74_n116;
  t74_n115: return 0.06807728856801987f;
  t74_n116: return 0.10545092821121216f;
  t74_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t74_n119;
  t74_n118: return 0.04913511127233505f;
  t74_n119: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t74_n125;
  t74_n120: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t74_n124;
  t74_n121: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t74_n123;
  t74_n122: return 0.08614400029182434f;
  t74_n123: return 0.15072163939476013f;
  t74_n124: return -0.09726296365261078f;
  t74_n125: return 0.05654335767030716f;
  t74_n126: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t74_n128;
  t74_n127: return 0.1084766685962677f;
  t74_n128: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t74_n130;
  t74_n129: return 0.041226983070373535f;
  t74_n130: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t74_n140;
  t74_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t74_n133;
  t74_n132: return 0.07294178754091263f;
  t74_n133: if (E.getNumReferences() >= 3291119616 /*682.0*/) goto t74_n139;
  t74_n134: if (E.getNumReferences() >= 3212836864 /*1.0*/) goto t74_n138;
  t74_n135: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t74_n137;
  t74_n136: return 0.13879667222499847f;
  t74_n137: return 0.08501172065734863f;
  t74_n138: return -1.5767089128494263f;
  t74_n139: return 0.10978098213672638f;
  t74_n140: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t74_n146;
  t74_n141: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t74_n143;
  t74_n142: return 0.06383686512708664f;
  t74_n143: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t74_n145;
  t74_n144: return -0.28153613209724426f;
  t74_n145: return 0.14795951545238495f;
  t74_n146: if (E.getNumReferences() >= 3316710400 /*5663.5*/) goto t74_n148;
  t74_n147: return 0.05006154254078865f;
  t74_n148: return 0.08966038376092911f;
  t74_n149: return 0.003335708985105157f;
  t74_n150: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t74_n180;
  t74_n151: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t74_n153;
  t74_n152: return -0.007726233918219805f;
  t74_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t74_n157;
  t74_n154: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t74_n156;
  t74_n155: return 0.019109180197119713f;
  t74_n156: return -0.1109665036201477f;
  t74_n157: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t74_n163;
  t74_n158: if (E.getNumReferences() >= 3338840320 /*33449.0*/) goto t74_n160;
  t74_n159: return 0.021148880943655968f;
  t74_n160: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t74_n162;
  t74_n161: return 0.13034231960773468f;
  t74_n162: return 0.08481350541114807f;
  t74_n163: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t74_n179;
  t74_n164: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t74_n168;
  t74_n165: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t74_n167;
  t74_n166: return -0.0013734424719586968f;
  t74_n167: return 0.10229814797639847f;
  t74_n168: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t74_n176;
  t74_n169: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t74_n175;
  t74_n170: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t74_n172;
  t74_n171: return 0.09541306644678116f;
  t74_n172: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t74_n174;
  t74_n173: return 0.11198475956916809f;
  t74_n174: return 0.0873652920126915f;
  t74_n175: return 0.09910009801387787f;
  t74_n176: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t74_n178;
  t74_n177: return 0.11495780199766159f;
  t74_n178: return -0.10331443697214127f;
  t74_n179: return 0.03751181811094284f;
  t74_n180: return -0.0640980452299118f;
  t74_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t74_n183;
  t74_n182: return -0.00822228193283081f;
  t74_n183: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t74_n211;
  t74_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t74_n186;
  t74_n185: return 0.03469590097665787f;
  t74_n186: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t74_n188;
  t74_n187: return 0.0027367197908461094f;
  t74_n188: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t74_n210;
  t74_n189: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t74_n201;
  t74_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t74_n192;
  t74_n191: return -0.1036909893155098f;
  t74_n192: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t74_n200;
  t74_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t74_n199;
  t74_n194: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t74_n196;
  t74_n195: return 0.11961387097835541f;
  t74_n196: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t74_n198;
  t74_n197: return 0.1246563121676445f;
  t74_n198: return 0.11510356515645981f;
  t74_n199: return 0.11569403111934662f;
  t74_n200: return -0.4182620048522949f;
  t74_n201: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t74_n207;
  t74_n202: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t74_n204;
  t74_n203: return 0.045310404151678085f;
  t74_n204: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t74_n206;
  t74_n205: return 0.11771708726882935f;
  t74_n206: return 0.07892005890607834f;
  t74_n207: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t74_n209;
  t74_n208: return 0.1141238734126091f;
  t74_n209: return 0.00949164293706417f;
  t74_n210: return 0.08011465519666672f;
  t74_n211: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t74_n213;
  t74_n212: return 0.015622173435986042f;
  t74_n213: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t74_n229;
  t74_n214: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t74_n228;
  t74_n215: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t74_n221;
  t74_n216: if (E.getNumReferences() >= 3353810176 /*118314.0*/) goto t74_n220;
  t74_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t74_n219;
  t74_n218: return 0.08048352599143982f;
  t74_n219: return 0.11520245671272278f;
  t74_n220: return -0.10766060650348663f;
  t74_n221: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t74_n227;
  t74_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t74_n226;
  t74_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t74_n225;
  t74_n224: return 0.11547364294528961f;
  t74_n225: return 0.1278180181980133f;
  t74_n226: return 0.08025994896888733f;
  t74_n227: return 0.08944357931613922f;
  t74_n228: return 0.012987065128982067f;
  t74_n229: return -0.0021319251973181963f;
  t74_n230: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t74_n254;
  t74_n231: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t74_n253;
  t74_n232: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t74_n238;
  t74_n233: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t74_n235;
  t74_n234: return -0.2127716839313507f;
  t74_n235: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t74_n237;
  t74_n236: return 0.028126386925578117f;
  t74_n237: return 0.06867407262325287f;
  t74_n238: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t74_n240;
  t74_n239: return 0.015755824744701385f;
  t74_n240: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t74_n242;
  t74_n241: return 0.027938485145568848f;
  t74_n242: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t74_n252;
  t74_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t74_n251;
  t74_n244: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t74_n246;
  t74_n245: return 0.12208757549524307f;
  t74_n246: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t74_n250;
  t74_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t74_n249;
  t74_n248: return 0.10642676055431366f;
  t74_n249: return 0.09177760034799576f;
  t74_n250: return 0.0304380152374506f;
  t74_n251: return 0.03105471283197403f;
  t74_n252: return 0.055319253355264664f;
  t74_n253: return -0.00011407351848902181f;
  t74_n254: return 0.015552625991404057f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree75(const Example& E) {
  t75_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t75_n208;
  t75_n1: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t75_n189;
  t75_n2: if (E.getNumReferences() >= 3324968960 /*11200.0*/) goto t75_n168;
  t75_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t75_n5;
  t75_n4: return -0.0904168039560318f;
  t75_n5: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t75_n167;
  t75_n6: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t75_n102;
  t75_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t75_n19;
  t75_n8: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t75_n18;
  t75_n9: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t75_n11;
  t75_n10: return -0.008241844363510609f;
  t75_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n15;
  t75_n12: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n14;
  t75_n13: return 0.09463326632976532f;
  t75_n14: return 0.02485729567706585f;
  t75_n15: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t75_n17;
  t75_n16: return 0.05097726732492447f;
  t75_n17: return 0.08411869406700134f;
  t75_n18: return -0.09184373915195465f;
  t75_n19: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t75_n51;
  t75_n20: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t75_n22;
  t75_n21: return -0.000567403098102659f;
  t75_n22: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t75_n24;
  t75_n23: return 0.0008690996328368783f;
  t75_n24: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t75_n42;
  t75_n25: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t75_n27;
  t75_n26: return 0.026369882747530937f;
  t75_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t75_n31;
  t75_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t75_n30;
  t75_n29: return -0.0005937865353189409f;
  t75_n30: return 0.05716024711728096f;
  t75_n31: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t75_n41;
  t75_n32: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t75_n34;
  t75_n33: return 0.013069610111415386f;
  t75_n34: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t75_n36;
  t75_n35: return 0.06787335127592087f;
  t75_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t75_n38;
  t75_n37: return 0.08706019073724747f;
  t75_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t75_n40;
  t75_n39: return -0.10381922870874405f;
  t75_n40: return 0.11365028470754623f;
  t75_n41: return 0.07800186425447464f;
  t75_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t75_n48;
  t75_n43: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t75_n45;
  t75_n44: return 0.10784222930669785f;
  t75_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t75_n47;
  t75_n46: return -0.1737380474805832f;
  t75_n47: return -0.022171664983034134f;
  t75_n48: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t75_n50;
  t75_n49: return -0.002333443844690919f;
  t75_n50: return 0.041177406907081604f;
  t75_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t75_n65;
  t75_n52: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t75_n62;
  t75_n53: if (E.getNumReferences() >= 3316676608 /*5647.0*/) goto t75_n61;
  t75_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t75_n56;
  t75_n55: return 0.04708545655012131f;
  t75_n56: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t75_n60;
  t75_n57: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n59;
  t75_n58: return 0.11300810426473618f;
  t75_n59: return -0.15542390942573547f;
  t75_n60: return 0.04877963662147522f;
  t75_n61: return 0.10285380482673645f;
  t75_n62: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t75_n64;
  t75_n63: return -0.06423246115446091f;
  t75_n64: return -0.01710072159767151f;
  t75_n65: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t75_n89;
  t75_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t75_n70;
  t75_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t75_n69;
  t75_n68: return -0.003474958473816514f;
  t75_n69: return 0.010449814610183239f;
  t75_n70: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t75_n88;
  t75_n71: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n85;
  t75_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n74;
  t75_n73: return 0.14308597147464752f;
  t75_n74: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t75_n80;
  t75_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t75_n79;
  t75_n76: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t75_n78;
  t75_n77: return -0.005901901517063379f;
  t75_n78: return 0.08669430762529373f;
  t75_n79: return 0.09717860072851181f;
  t75_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t75_n82;
  t75_n81: return -0.11569187045097351f;
  t75_n82: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t75_n84;
  t75_n83: return 0.10867325961589813f;
  t75_n84: return -0.16820934414863586f;
  t75_n85: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n87;
  t75_n86: return 0.08036213368177414f;
  t75_n87: return 0.03233272209763527f;
  t75_n88: return 0.02207236737012863f;
  t75_n89: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t75_n91;
  t75_n90: return -0.09781377017498016f;
  t75_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t75_n93;
  t75_n92: return -0.11868148297071457f;
  t75_n93: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t75_n101;
  t75_n94: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n96;
  t75_n95: return -0.04217727109789848f;
  t75_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t75_n98;
  t75_n97: return -0.026103336364030838f;
  t75_n98: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n100;
  t75_n99: return 0.1372128576040268f;
  t75_n100: return 0.029331211000680923f;
  t75_n101: return -0.03129812702536583f;
  t75_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t75_n126;
  t75_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t75_n105;
  t75_n104: return -0.03806176781654358f;
  t75_n105: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t75_n121;
  t75_n106: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n112;
  t75_n107: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n109;
  t75_n108: return 0.02906663715839386f;
  t75_n109: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t75_n111;
  t75_n110: return 0.027569977566599846f;
  t75_n111: return -0.1762150228023529f;
  t75_n112: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t75_n114;
  t75_n113: return -0.005810008849948645f;
  t75_n114: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t75_n120;
  t75_n115: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n119;
  t75_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t75_n118;
  t75_n117: return 0.095738984644413f;
  t75_n118: return 0.095374695956707f;
  t75_n119: return 0.05364629626274109f;
  t75_n120: return 0.01009997259825468f;
  t75_n121: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t75_n123;
  t75_n122: return -0.022261643782258034f;
  t75_n123: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t75_n125;
  t75_n124: return 0.07842114567756653f;
  t75_n125: return 0.016845285892486572f;
  t75_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t75_n148;
  t75_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t75_n131;
  t75_n128: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n130;
  t75_n129: return -0.019480399787425995f;
  t75_n130: return 0.02602410688996315f;
  t75_n131: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n133;
  t75_n132: return 0.024207694455981255f;
  t75_n133: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t75_n147;
  t75_n134: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t75_n136;
  t75_n135: return 0.04599772021174431f;
  t75_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t75_n138;
  t75_n137: return 0.07901700586080551f;
  t75_n138: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t75_n140;
  t75_n139: return 0.08518686145544052f;
  t75_n140: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t75_n142;
  t75_n141: return 0.13856889307498932f;
  t75_n142: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n144;
  t75_n143: return 0.11222730576992035f;
  t75_n144: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t75_n146;
  t75_n145: return -0.10706224292516708f;
  t75_n146: return 0.1202009841799736f;
  t75_n147: return 0.0061248852871358395f;
  t75_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n160;
  t75_n149: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t75_n159;
  t75_n150: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t75_n158;
  t75_n151: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n153;
  t75_n152: return 0.13111086189746857f;
  t75_n153: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t75_n157;
  t75_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t75_n156;
  t75_n155: return 0.11409441381692886f;
  t75_n156: return 0.13106076419353485f;
  t75_n157: return 0.1275779902935028f;
  t75_n158: return 0.11062607169151306f;
  t75_n159: return 0.08939637243747711f;
  t75_n160: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t75_n166;
  t75_n161: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t75_n165;
  t75_n162: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t75_n164;
  t75_n163: return 0.08152207732200623f;
  t75_n164: return 0.11376751959323883f;
  t75_n165: return 0.07686042040586472f;
  t75_n166: return 0.08305396139621735f;
  t75_n167: return -0.08605776727199554f;
  t75_n168: if (E.getNumReferences() >= 3325080064 /*11308.5*/) goto t75_n182;
  t75_n169: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t75_n175;
  t75_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n172;
  t75_n171: return 0.3320293426513672f;
  t75_n172: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t75_n174;
  t75_n173: return 0.007333116605877876f;
  t75_n174: return 0.17811445891857147f;
  t75_n175: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t75_n177;
  t75_n176: return 0.025862064212560654f;
  t75_n177: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t75_n181;
  t75_n178: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n180;
  t75_n179: return 0.14313814043998718f;
  t75_n180: return 0.07834864407777786f;
  t75_n181: return -0.025416487827897072f;
  t75_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n188;
  t75_n183: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t75_n185;
  t75_n184: return 0.017386402934789658f;
  t75_n185: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t75_n187;
  t75_n186: return 0.021359283477067947f;
  t75_n187: return 0.0961955264210701f;
  t75_n188: return 0.04206709936261177f;
  t75_n189: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t75_n207;
  t75_n190: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t75_n192;
  t75_n191: return -0.057283490896224976f;
  t75_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t75_n204;
  t75_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n197;
  t75_n194: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t75_n196;
  t75_n195: return -0.007521668449044228f;
  t75_n196: return -0.1148671880364418f;
  t75_n197: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t75_n199;
  t75_n198: return 0.017947833985090256f;
  t75_n199: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t75_n203;
  t75_n200: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t75_n202;
  t75_n201: return -0.11005115509033203f;
  t75_n202: return 0.09606858342885971f;
  t75_n203: return -0.058628056198358536f;
  t75_n204: if (E.getNumReferences() >= 3346496384 /*63355.5*/) goto t75_n206;
  t75_n205: return 0.027053629979491234f;
  t75_n206: return 0.13659057021141052f;
  t75_n207: return -0.0038868889678269625f;
  t75_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t75_n252;
  t75_n209: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t75_n213;
  t75_n210: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t75_n212;
  t75_n211: return 0.02525823749601841f;
  t75_n212: return 0.041260696947574615f;
  t75_n213: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t75_n231;
  t75_n214: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t75_n226;
  t75_n215: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t75_n217;
  t75_n216: return 0.0027727577835321426f;
  t75_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t75_n221;
  t75_n218: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n220;
  t75_n219: return 0.02124938741326332f;
  t75_n220: return -0.0004779496230185032f;
  t75_n221: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t75_n223;
  t75_n222: return 0.04227396100759506f;
  t75_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t75_n225;
  t75_n224: return 0.038583628833293915f;
  t75_n225: return 0.07122763246297836f;
  t75_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t75_n228;
  t75_n227: return -0.059455111622810364f;
  t75_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n230;
  t75_n229: return -0.01669161207973957f;
  t75_n230: return 0.04630691930651665f;
  t75_n231: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t75_n239;
  t75_n232: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t75_n236;
  t75_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n235;
  t75_n234: return 0.06534349918365479f;
  t75_n235: return 0.10557905584573746f;
  t75_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t75_n238;
  t75_n237: return 0.12125342339277267f;
  t75_n238: return 0.11220629513263702f;
  t75_n239: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t75_n247;
  t75_n240: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t75_n246;
  t75_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t75_n243;
  t75_n242: return 0.041039399802684784f;
  t75_n243: if (E.getNumReferences() >= 3328774656 /*14916.5*/) goto t75_n245;
  t75_n244: return 0.11428388953208923f;
  t75_n245: return 0.08217563480138779f;
  t75_n246: return -0.018885938450694084f;
  t75_n247: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t75_n251;
  t75_n248: if (E.getNumReferences() >= 3327475712 /*13648.0*/) goto t75_n250;
  t75_n249: return 0.0672244057059288f;
  t75_n250: return 0.112042136490345f;
  t75_n251: return 0.04681795835494995f;
  t75_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t75_n254;
  t75_n253: return -0.03795398399233818f;
  t75_n254: return 0.0163880567997694f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree76(const Example& E) {
  t76_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t76_n230;
  t76_n1: if (E.getNumReferences() >= 3304779776 /*2007.5*/) goto t76_n133;
  t76_n2: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t76_n82;
  t76_n3: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t76_n49;
  t76_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t76_n44;
  t76_n5: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t76_n7;
  t76_n6: return 0.0005468350718729198f;
  t76_n7: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t76_n15;
  t76_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t76_n10;
  t76_n9: return 0.008156634867191315f;
  t76_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t76_n14;
  t76_n11: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t76_n13;
  t76_n12: return 0.023986244574189186f;
  t76_n13: return 0.055791549384593964f;
  t76_n14: return 0.03874659910798073f;
  t76_n15: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t76_n21;
  t76_n16: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t76_n18;
  t76_n17: return 0.06513924896717072f;
  t76_n18: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t76_n20;
  t76_n19: return 0.07777409255504608f;
  t76_n20: return 0.08924373239278793f;
  t76_n21: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t76_n23;
  t76_n22: return 0.04000730812549591f;
  t76_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t76_n25;
  t76_n24: return 0.06563470512628555f;
  t76_n25: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t76_n35;
  t76_n26: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t76_n28;
  t76_n27: return 0.09320685267448425f;
  t76_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t76_n30;
  t76_n29: return 0.05607953667640686f;
  t76_n30: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t76_n34;
  t76_n31: if (E.getFilterLength() >= 3242196992 /*12.0*/) goto t76_n33;
  t76_n32: return 0.11426982283592224f;
  t76_n33: return 0.1661926507949829f;
  t76_n34: return 0.10719461739063263f;
  t76_n35: if (E.getFilterLength() >= 3245867008 /*15.5*/) goto t76_n37;
  t76_n36: return 0.10584205389022827f;
  t76_n37: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t76_n41;
  t76_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t76_n40;
  t76_n39: return 0.059271037578582764f;
  t76_n40: return 0.11059929430484772f;
  t76_n41: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t76_n43;
  t76_n42: return 0.12595206499099731f;
  t76_n43: return 0.15139897167682648f;
  t76_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t76_n46;
  t76_n45: return 0.034818727523088455f;
  t76_n46: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t76_n48;
  t76_n47: return 0.0344441793859005f;
  t76_n48: return 0.06550610065460205f;
  t76_n49: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t76_n69;
  t76_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t76_n52;
  t76_n51: return -0.049524303525686264f;
  t76_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t76_n54;
  t76_n53: return -0.007647773716598749f;
  t76_n54: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t76_n56;
  t76_n55: return -0.0023124851286411285f;
  t76_n56: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t76_n58;
  t76_n57: return 0.008214760571718216f;
  t76_n58: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t76_n68;
  t76_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t76_n61;
  t76_n60: return 0.047842223197221756f;
  t76_n61: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t76_n63;
  t76_n62: return -1.745175541145727e-05f;
  t76_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t76_n67;
  t76_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t76_n66;
  t76_n65: return -0.11949720233678818f;
  t76_n66: return 0.11334889382123947f;
  t76_n67: return 0.10318152606487274f;
  t76_n68: return -0.11774799227714539f;
  t76_n69: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t76_n71;
  t76_n70: return -0.05266650393605232f;
  t76_n71: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t76_n73;
  t76_n72: return -0.07096695154905319f;
  t76_n73: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t76_n75;
  t76_n74: return -0.016733642667531967f;
  t76_n75: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t76_n77;
  t76_n76: return 0.04817560315132141f;
  t76_n77: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t76_n79;
  t76_n78: return 0.06850282847881317f;
  t76_n79: if (E.getNumReferences() >= 3286564864 /*458.0*/) goto t76_n81;
  t76_n80: return 0.13051718473434448f;
  t76_n81: return 0.07547803968191147f;
  t76_n82: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t76_n96;
  t76_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Other))) goto t76_n87;
  t76_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t76_n86;
  t76_n85: return -0.04712958633899689f;
  t76_n86: return -0.02028624527156353f;
  t76_n87: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t76_n95;
  t76_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t76_n92;
  t76_n89: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t76_n91;
  t76_n90: return 0.09227734804153442f;
  t76_n91: return 0.01670435443520546f;
  t76_n92: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t76_n94;
  t76_n93: return 0.041397031396627426f;
  t76_n94: return 0.07887017726898193f;
  t76_n95: return -0.06624539196491241f;
  t76_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t76_n98;
  t76_n97: return 0.0001914749591378495f;
  t76_n98: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t76_n102;
  t76_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t76_n101;
  t76_n100: return -0.0173349529504776f;
  t76_n101: return 0.01196307223290205f;
  t76_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t76_n120;
  t76_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t76_n105;
  t76_n104: return 0.0035209027118980885f;
  t76_n105: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t76_n107;
  t76_n106: return 0.02448834665119648f;
  t76_n107: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t76_n119;
  t76_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t76_n110;
  t76_n109: return 0.04353887960314751f;
  t76_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t76_n112;
  t76_n111: return 0.07347958534955978f;
  t76_n112: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t76_n114;
  t76_n113: return 0.08201462030410767f;
  t76_n114: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t76_n118;
  t76_n115: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t76_n117;
  t76_n116: return 0.12249799072742462f;
  t76_n117: return 0.11830440163612366f;
  t76_n118: return 0.09563586860895157f;
  t76_n119: return 0.006577915512025356f;
  t76_n120: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t76_n132;
  t76_n121: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t76_n131;
  t76_n122: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t76_n130;
  t76_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t76_n127;
  t76_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t76_n126;
  t76_n125: return 0.12409568578004837f;
  t76_n126: return 0.1284111589193344f;
  t76_n127: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t76_n129;
  t76_n128: return 0.12791672348976135f;
  t76_n129: return 0.10949837416410446f;
  t76_n130: return 0.09228067100048065f;
  t76_n131: return 0.09290014207363129f;
  t76_n132: return -0.061394624412059784f;
  t76_n133: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t76_n139;
  t76_n134: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t76_n138;
  t76_n135: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t76_n137;
  t76_n136: return 0.014106810092926025f;
  t76_n137: return 0.04287667199969292f;
  t76_n138: return -0.0062354435212910175f;
  t76_n139: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t76_n229;
  t76_n140: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t76_n218;
  t76_n141: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t76_n145;
  t76_n142: if (E.getNumReferences() >= 3319614464 /*7081.5*/) goto t76_n144;
  t76_n143: return 0.028523892164230347f;
  t76_n144: return -0.3700868785381317f;
  t76_n145: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t76_n159;
  t76_n146: if (E.getNumReferences() >= 3334111488 /*23872.5*/) goto t76_n148;
  t76_n147: return 0.039904747158288956f;
  t76_n148: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t76_n154;
  t76_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t76_n151;
  t76_n150: return 0.05078556761145592f;
  t76_n151: if (E.getNumReferences() >= 3334260992 /*24164.5*/) goto t76_n153;
  t76_n152: return 0.11504463851451874f;
  t76_n153: return -0.10250594466924667f;
  t76_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t76_n156;
  t76_n155: return -0.08146880567073822f;
  t76_n156: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t76_n158;
  t76_n157: return 0.10701030492782593f;
  t76_n158: return 0.08765628188848495f;
  t76_n159: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t76_n197;
  t76_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t76_n162;
  t76_n161: return 0.04619299992918968f;
  t76_n162: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t76_n164;
  t76_n163: return 0.06540583819150925f;
  t76_n164: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t76_n176;
  t76_n165: if (E.getNumReferences() >= 3328404480 /*14555.0*/) goto t76_n167;
  t76_n166: return 0.08137495070695877f;
  t76_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t76_n169;
  t76_n168: return 0.10808650404214859f;
  t76_n169: if (E.getNumReferences() >= 3331176192 /*18139.5*/) goto t76_n175;
  t76_n170: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t76_n172;
  t76_n171: return -0.11415302008390427f;
  t76_n172: if (E.getNumReferences() >= 3330760192 /*17327.0*/) goto t76_n174;
  t76_n173: return 0.11429555714130402f;
  t76_n174: return 0.12086668610572815f;
  t76_n175: return -0.10728286951780319f;
  t76_n176: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t76_n180;
  t76_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t76_n179;
  t76_n178: return 0.0745239183306694f;
  t76_n179: return 0.12240078300237656f;
  t76_n180: if (E.getNumReferences() >= 3325383680 /*11605.0*/) goto t76_n196;
  t76_n181: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t76_n195;
  t76_n182: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t76_n188;
  t76_n183: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t76_n185;
  t76_n184: return 0.11119896918535233f;
  t76_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t76_n187;
  t76_n186: return 0.08336123824119568f;
  t76_n187: return 0.10835311561822891f;
  t76_n188: if (E.getNumReferences() >= 3321878528 /*8187.0*/) goto t76_n190;
  t76_n189: return -0.002903086831793189f;
  t76_n190: if (E.getNumReferences() >= 3321964032 /*8265.5*/) goto t76_n192;
  t76_n191: return 0.11369460821151733f;
  t76_n192: if (E.getNumReferences() >= 3322210304 /*8506.0*/) goto t76_n194;
  t76_n193: return -0.15736214816570282f;
  t76_n194: return 0.11055117100477219f;
  t76_n195: return 0.11044168472290039f;
  t76_n196: return 0.033564455807209015f;
  t76_n197: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t76_n213;
  t76_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t76_n210;
  t76_n199: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t76_n209;
  t76_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t76_n202;
  t76_n201: return 0.11588437855243683f;
  t76_n202: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t76_n206;
  t76_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t76_n205;
  t76_n204: return 0.13231933116912842f;
  t76_n205: return 0.14669111371040344f;
  t76_n206: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t76_n208;
  t76_n207: return 0.11785533279180527f;
  t76_n208: return 0.10628580302000046f;
  t76_n209: return -0.13264977931976318f;
  t76_n210: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t76_n212;
  t76_n211: return 0.0974397137761116f;
  t76_n212: return 0.10611044615507126f;
  t76_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t76_n215;
  t76_n214: return 0.05326658859848976f;
  t76_n215: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t76_n217;
  t76_n216: return 0.11808077245950699f;
  t76_n217: return 0.059845615178346634f;
  t76_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t76_n228;
  t76_n219: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t76_n227;
  t76_n220: if (E.getNumReferences() >= 3369273984 /*432212.0*/) goto t76_n224;
  t76_n221: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t76_n223;
  t76_n222: return -0.03851113095879555f;
  t76_n223: return -0.1399393081665039f;
  t76_n224: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t76_n226;
  t76_n225: return 0.039518777281045914f;
  t76_n226: return -0.33262401819229126f;
  t76_n227: return 0.014135392382740974f;
  t76_n228: return 0.011370310559868813f;
  t76_n229: return 0.0895376205444336f;
  t76_n230: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t76_n236;
  t76_n231: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t76_n233;
  t76_n232: return 0.00724938465282321f;
  t76_n233: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t76_n235;
  t76_n234: return 0.06697653979063034f;
  t76_n235: return 0.012712503783404827f;
  t76_n236: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t76_n240;
  t76_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t76_n239;
  t76_n238: return -0.011384723708033562f;
  t76_n239: return 0.014218645170331001f;
  t76_n240: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t76_n252;
  t76_n241: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t76_n243;
  t76_n242: return -0.02376498281955719f;
  t76_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t76_n245;
  t76_n244: return -0.013304667547345161f;
  t76_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t76_n249;
  t76_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t76_n248;
  t76_n247: return -0.2673211693763733f;
  t76_n248: return 0.12102676182985306f;
  t76_n249: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t76_n251;
  t76_n250: return -0.1068832278251648f;
  t76_n251: return 0.16028663516044617f;
  t76_n252: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t76_n254;
  t76_n253: return 0.02255217730998993f;
  t76_n254: return 0.08638183027505875f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree77(const Example& E) {
  t77_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t77_n200;
  t77_n1: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t77_n121;
  t77_n2: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t77_n60;
  t77_n3: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t77_n5;
  t77_n4: return 0.0002227326767751947f;
  t77_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t77_n13;
  t77_n6: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t77_n8;
  t77_n7: return -0.002932087518274784f;
  t77_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t77_n10;
  t77_n9: return 0.1653481423854828f;
  t77_n10: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t77_n12;
  t77_n11: return 0.10770446062088013f;
  t77_n12: return -0.17813318967819214f;
  t77_n13: if (E.getNumReferences() >= 3354076032 /*120391.0*/) goto t77_n45;
  t77_n14: if (E.getNumReferences() >= 3308374016 /*2844.5*/) goto t77_n20;
  t77_n15: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t77_n19;
  t77_n16: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t77_n18;
  t77_n17: return 0.02501790225505829f;
  t77_n18: return 0.04458343982696533f;
  t77_n19: return 0.00771256722509861f;
  t77_n20: if (E.getNumReferences() >= 3308460032 /*2865.5*/) goto t77_n24;
  t77_n21: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t77_n23;
  t77_n22: return 0.12180040031671524f;
  t77_n23: return -0.006039645057171583f;
  t77_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t77_n26;
  t77_n25: return 0.010592574253678322f;
  t77_n26: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t77_n28;
  t77_n27: return 0.04352768510580063f;
  t77_n28: if (E.getNumReferences() >= 3309135872 /*3030.5*/) goto t77_n32;
  t77_n29: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t77_n31;
  t77_n30: return 0.1007986068725586f;
  t77_n31: return 0.12183598428964615f;
  t77_n32: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t77_n34;
  t77_n33: return 0.03603222966194153f;
  t77_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t77_n36;
  t77_n35: return 0.060881588608026505f;
  t77_n36: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t77_n40;
  t77_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t77_n39;
  t77_n38: return 0.0946098268032074f;
  t77_n39: return 0.1363314539194107f;
  t77_n40: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t77_n42;
  t77_n41: return -0.04612359404563904f;
  t77_n42: if (E.getNumReferences() >= 3333697280 /*23063.5*/) goto t77_n44;
  t77_n43: return -0.05037100985646248f;
  t77_n44: return 0.11862793564796448f;
  t77_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t77_n47;
  t77_n46: return -0.03776627033948898f;
  t77_n47: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t77_n59;
  t77_n48: if (E.getNumReferences() >= 3355447552 /*131140.0*/) goto t77_n56;
  t77_n49: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t77_n51;
  t77_n50: return 0.11325450241565704f;
  t77_n51: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t77_n53;
  t77_n52: return 0.1221337541937828f;
  t77_n53: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t77_n55;
  t77_n54: return 0.11825942993164062f;
  t77_n55: return 0.10818924754858017f;
  t77_n56: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t77_n58;
  t77_n57: return 0.08203589171171188f;
  t77_n58: return 0.10320436954498291f;
  t77_n59: return 0.07125776261091232f;
  t77_n60: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t77_n64;
  t77_n61: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t77_n63;
  t77_n62: return 0.005505015607923269f;
  t77_n63: return -0.06371573358774185f;
  t77_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t77_n66;
  t77_n65: return -0.006132381036877632f;
  t77_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t77_n96;
  t77_n67: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t77_n95;
  t77_n68: if (E.getNumReferences() >= 3325698048 /*11912.0*/) goto t77_n76;
  t77_n69: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t77_n75;
  t77_n70: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t77_n72;
  t77_n71: return 0.0528707318007946f;
  t77_n72: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t77_n74;
  t77_n73: return -0.10251528024673462f;
  t77_n74: return 0.11728756129741669f;
  t77_n75: return 0.008440650068223476f;
  t77_n76: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t77_n94;
  t77_n77: if (E.getNumReferences() >= 3348327104 /*75477.5*/) goto t77_n79;
  t77_n78: return 0.05645914748311043f;
  t77_n79: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t77_n93;
  t77_n80: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t77_n92;
  t77_n81: if (E.getNumReferences() >= 3350105536 /*89371.5*/) goto t77_n87;
  t77_n82: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t77_n86;
  t77_n83: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t77_n85;
  t77_n84: return 0.1789778172969818f;
  t77_n85: return 0.017442164942622185f;
  t77_n86: return 0.11542760580778122f;
  t77_n87: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t77_n91;
  t77_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t77_n90;
  t77_n89: return -0.10612571984529495f;
  t77_n90: return 0.12468650937080383f;
  t77_n91: return 0.11610791087150574f;
  t77_n92: return 0.04038776457309723f;
  t77_n93: return 0.153207927942276f;
  t77_n94: return -0.08317742496728897f;
  t77_n95: return -0.3591793179512024f;
  t77_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t77_n110;
  t77_n97: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t77_n109;
  t77_n98: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t77_n100;
  t77_n99: return 0.05330626294016838f;
  t77_n100: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t77_n102;
  t77_n101: return 0.016417235136032104f;
  t77_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t77_n104;
  t77_n103: return -0.019600864499807358f;
  t77_n104: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t77_n108;
  t77_n105: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t77_n107;
  t77_n106: return 0.08395574241876602f;
  t77_n107: return 0.12297366559505463f;
  t77_n108: return 0.04332993924617767f;
  t77_n109: return 0.08033515512943268f;
  t77_n110: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t77_n114;
  t77_n111: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t77_n113;
  t77_n112: return 0.061129167675971985f;
  t77_n113: return 0.0993603989481926f;
  t77_n114: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t77_n120;
  t77_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t77_n117;
  t77_n116: return 0.13015080988407135f;
  t77_n117: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t77_n119;
  t77_n118: return 0.07647211104631424f;
  t77_n119: return 0.13591215014457703f;
  t77_n120: return 0.0947161540389061f;
  t77_n121: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t77_n159;
  t77_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t77_n132;
  t77_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t77_n125;
  t77_n124: return 0.12412501871585846f;
  t77_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t77_n127;
  t77_n126: return -0.17893339693546295f;
  t77_n127: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t77_n129;
  t77_n128: return 0.08231890201568604f;
  t77_n129: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t77_n131;
  t77_n130: return 0.1273864209651947f;
  t77_n131: return 0.11954725533723831f;
  t77_n132: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t77_n144;
  t77_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t77_n139;
  t77_n134: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t77_n138;
  t77_n135: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t77_n137;
  t77_n136: return 0.08160386979579926f;
  t77_n137: return 0.09538482129573822f;
  t77_n138: return -0.011293618008494377f;
  t77_n139: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t77_n141;
  t77_n140: return 0.1248968094587326f;
  t77_n141: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t77_n143;
  t77_n142: return 0.10518518090248108f;
  t77_n143: return 0.09965753555297852f;
  t77_n144: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t77_n150;
  t77_n145: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t77_n147;
  t77_n146: return 0.04512179642915726f;
  t77_n147: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t77_n149;
  t77_n148: return 0.1229669526219368f;
  t77_n149: return 0.09272880852222443f;
  t77_n150: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t77_n152;
  t77_n151: return -0.2761431932449341f;
  t77_n152: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t77_n156;
  t77_n153: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t77_n155;
  t77_n154: return 0.08654813468456268f;
  t77_n155: return 0.04840891808271408f;
  t77_n156: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t77_n158;
  t77_n157: return 0.10971719771623611f;
  t77_n158: return 0.057571012526750565f;
  t77_n159: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t77_n173;
  t77_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t77_n162;
  t77_n161: return 0.03365654870867729f;
  t77_n162: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t77_n170;
  t77_n163: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t77_n165;
  t77_n164: return 0.010189978405833244f;
  t77_n165: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t77_n169;
  t77_n166: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t77_n168;
  t77_n167: return -0.11514341086149216f;
  t77_n168: return 0.11851023882627487f;
  t77_n169: return 0.30719491839408875f;
  t77_n170: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t77_n172;
  t77_n171: return -0.11061277240514755f;
  t77_n172: return 0.08744392544031143f;
  t77_n173: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t77_n177;
  t77_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t77_n176;
  t77_n175: return -0.43231233954429626f;
  t77_n176: return -0.047518130391836166f;
  t77_n177: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t77_n183;
  t77_n178: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t77_n180;
  t77_n179: return 0.024593517184257507f;
  t77_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t77_n182;
  t77_n181: return 0.03696778044104576f;
  t77_n182: return 0.1269340068101883f;
  t77_n183: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t77_n185;
  t77_n184: return -0.0013560170773416758f;
  t77_n185: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t77_n199;
  t77_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t77_n188;
  t77_n187: return 0.022188421338796616f;
  t77_n188: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t77_n194;
  t77_n189: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t77_n191;
  t77_n190: return 0.01993466354906559f;
  t77_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t77_n193;
  t77_n192: return 0.10006901621818542f;
  t77_n193: return 0.12283138930797577f;
  t77_n194: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t77_n198;
  t77_n195: if (E.getNumReferences() >= 3365914464 /*327227.0*/) goto t77_n197;
  t77_n196: return 0.03467216342687607f;
  t77_n197: return 0.10226493328809738f;
  t77_n198: return 0.0034738928079605103f;
  t77_n199: return 0.10356961935758591f;
  t77_n200: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t77_n252;
  t77_n201: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t77_n245;
  t77_n202: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t77_n244;
  t77_n203: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t77_n237;
  t77_n204: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t77_n232;
  t77_n205: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t77_n211;
  t77_n206: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t77_n210;
  t77_n207: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t77_n209;
  t77_n208: return 0.027055658400058746f;
  t77_n209: return 0.0547906830906868f;
  t77_n210: return 0.008605257607996464f;
  t77_n211: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t77_n219;
  t77_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t77_n214;
  t77_n213: return -0.09721001982688904f;
  t77_n214: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t77_n216;
  t77_n215: return -0.04578853398561478f;
  t77_n216: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t77_n218;
  t77_n217: return 0.027807150036096573f;
  t77_n218: return 0.05125279352068901f;
  t77_n219: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t77_n231;
  t77_n220: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t77_n224;
  t77_n221: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t77_n223;
  t77_n222: return -0.0417315810918808f;
  t77_n223: return 0.0513664074242115f;
  t77_n224: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t77_n226;
  t77_n225: return 0.10115622729063034f;
  t77_n226: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t77_n230;
  t77_n227: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t77_n229;
  t77_n228: return 0.10325681418180466f;
  t77_n229: return 0.08065369725227356f;
  t77_n230: return -0.025118399411439896f;
  t77_n231: return 0.06033611670136452f;
  t77_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t77_n234;
  t77_n233: return -0.006880889646708965f;
  t77_n234: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t77_n236;
  t77_n235: return 0.0056487214751541615f;
  t77_n236: return -0.10072097927331924f;
  t77_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t77_n239;
  t77_n238: return 0.007536064833402634f;
  t77_n239: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t77_n241;
  t77_n240: return 0.02795519307255745f;
  t77_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t77_n243;
  t77_n242: return 0.038604360073804855f;
  t77_n243: return 0.06774892657995224f;
  t77_n244: return -0.0278407521545887f;
  t77_n245: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t77_n251;
  t77_n246: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t77_n250;
  t77_n247: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t77_n249;
  t77_n248: return 0.12966704368591309f;
  t77_n249: return 0.07028959691524506f;
  t77_n250: return 0.06156446039676666f;
  t77_n251: return 0.016222042962908745f;
  t77_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t77_n254;
  t77_n253: return -0.0377466194331646f;
  t77_n254: return 0.015222183428704739f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree78(const Example& E) {
  t78_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t78_n220;
  t78_n1: if (E.getNumReferences() >= 3348227392 /*74698.5*/) goto t78_n97;
  t78_n2: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t78_n12;
  t78_n3: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t78_n11;
  t78_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t78_n6;
  t78_n5: return 0.012124607339501381f;
  t78_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t78_n8;
  t78_n7: return 0.03886092081665993f;
  t78_n8: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t78_n10;
  t78_n9: return 0.0846586525440216f;
  t78_n10: return 0.05885821953415871f;
  t78_n11: return -0.01681201532483101f;
  t78_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t78_n32;
  t78_n13: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t78_n31;
  t78_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag))) goto t78_n16;
  t78_n15: return 0.013967829756438732f;
  t78_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n26;
  t78_n17: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t78_n25;
  t78_n18: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t78_n20;
  t78_n19: return 0.05879083648324013f;
  t78_n20: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t78_n24;
  t78_n21: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t78_n23;
  t78_n22: return 0.0986100286245346f;
  t78_n23: return 0.08323410153388977f;
  t78_n24: return 0.08226409554481506f;
  t78_n25: return 0.009345168247818947f;
  t78_n26: if (E.getNumReferences() >= 3322196992 /*8493.0*/) goto t78_n28;
  t78_n27: return 0.019718071445822716f;
  t78_n28: if (E.getNumReferences() >= 3322410496 /*8701.5*/) goto t78_n30;
  t78_n29: return 0.12600693106651306f;
  t78_n30: return 0.07238571345806122f;
  t78_n31: return -0.02551882527768612f;
  t78_n32: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t78_n84;
  t78_n33: if (E.getNumReferences() >= 3305154560 /*2058.5*/) goto t78_n41;
  t78_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t78_n38;
  t78_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t78_n37;
  t78_n36: return 0.013387041166424751f;
  t78_n37: return 0.10083679109811783f;
  t78_n38: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t78_n40;
  t78_n39: return 0.01450202614068985f;
  t78_n40: return -0.03487382084131241f;
  t78_n41: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t78_n47;
  t78_n42: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t78_n44;
  t78_n43: return 0.025837615132331848f;
  t78_n44: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t78_n46;
  t78_n45: return -0.4604669511318207f;
  t78_n46: return -0.1104644387960434f;
  t78_n47: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t78_n81;
  t78_n48: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t78_n70;
  t78_n49: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t78_n69;
  t78_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t78_n52;
  t78_n51: return 0.07595030963420868f;
  t78_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t78_n58;
  t78_n53: if (E.getNumReferences() >= 3345992448 /*61387.0*/) goto t78_n55;
  t78_n54: return 0.04710274934768677f;
  t78_n55: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t78_n57;
  t78_n56: return -0.40766119956970215f;
  t78_n57: return 0.11491192132234573f;
  t78_n58: if (E.getNumReferences() >= 3317255168 /*5929.5*/) goto t78_n60;
  t78_n59: return -0.17713280022144318f;
  t78_n60: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t78_n64;
  t78_n61: if (E.getNumReferences() >= 3320085504 /*7311.5*/) goto t78_n63;
  t78_n62: return 0.11686693876981735f;
  t78_n63: return 0.10276421904563904f;
  t78_n64: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t78_n68;
  t78_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t78_n67;
  t78_n66: return 0.1271827518939972f;
  t78_n67: return 0.11510835587978363f;
  t78_n68: return 0.042568791657686234f;
  t78_n69: return -0.004879108630120754f;
  t78_n70: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t78_n80;
  t78_n71: if (E.getNumReferences() >= 3333558528 /*22792.5*/) goto t78_n75;
  t78_n72: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t78_n74;
  t78_n73: return 0.11546960473060608f;
  t78_n74: return 0.07441685348749161f;
  t78_n75: if (E.getNumReferences() >= 3334368512 /*24374.5*/) goto t78_n77;
  t78_n76: return 0.12723033130168915f;
  t78_n77: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t78_n79;
  t78_n78: return -0.2746266722679138f;
  t78_n79: return 0.1828867793083191f;
  t78_n80: return 0.04824136570096016f;
  t78_n81: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t78_n83;
  t78_n82: return 0.03334589675068855f;
  t78_n83: return 0.1438121646642685f;
  t78_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t78_n86;
  t78_n85: return -0.06396342813968658f;
  t78_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n88;
  t78_n87: return 0.010714899748563766f;
  t78_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t78_n90;
  t78_n89: return 0.02989281341433525f;
  t78_n90: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t78_n96;
  t78_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t78_n93;
  t78_n92: return 0.08426232635974884f;
  t78_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t78_n95;
  t78_n94: return 0.1158699169754982f;
  t78_n95: return 0.06609336286783218f;
  t78_n96: return 0.015894591808319092f;
  t78_n97: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t78_n99;
  t78_n98: return -0.0064721787348389626f;
  t78_n99: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t78_n133;
  t78_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t78_n102;
  t78_n101: return 0.030760420486330986f;
  t78_n102: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t78_n110;
  t78_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t78_n105;
  t78_n104: return -0.030436193570494652f;
  t78_n105: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t78_n109;
  t78_n106: if (E.getNumReferences() >= 3351141632 /*97466.0*/) goto t78_n108;
  t78_n107: return -0.1482658088207245f;
  t78_n108: return 0.10775597393512726f;
  t78_n109: return 0.055174145847558975f;
  t78_n110: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t78_n132;
  t78_n111: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t78_n121;
  t78_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t78_n114;
  t78_n113: return -0.10334983468055725f;
  t78_n114: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t78_n116;
  t78_n115: return 0.11224214732646942f;
  t78_n116: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t78_n120;
  t78_n117: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n119;
  t78_n118: return 0.11921567469835281f;
  t78_n119: return 0.11621260643005371f;
  t78_n120: return 0.10606135427951813f;
  t78_n121: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t78_n129;
  t78_n122: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t78_n124;
  t78_n123: return 0.11584791541099548f;
  t78_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n126;
  t78_n125: return -0.03521697595715523f;
  t78_n126: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t78_n128;
  t78_n127: return 0.11524003744125366f;
  t78_n128: return 0.07562145590782166f;
  t78_n129: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n131;
  t78_n130: return 0.11042357236146927f;
  t78_n131: return 0.00036272304714657366f;
  t78_n132: return 0.07739751785993576f;
  t78_n133: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t78_n219;
  t78_n134: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t78_n200;
  t78_n135: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t78_n171;
  t78_n136: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t78_n168;
  t78_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n139;
  t78_n138: return 0.013728059828281403f;
  t78_n139: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t78_n165;
  t78_n140: if (E.getNumReferences() >= 3353767936 /*117984.0*/) goto t78_n164;
  t78_n141: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t78_n163;
  t78_n142: if (E.getNumReferences() >= 3352615936 /*108984.0*/) goto t78_n160;
  t78_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t78_n145;
  t78_n144: return 0.04885426536202431f;
  t78_n145: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t78_n147;
  t78_n146: return 0.0532398521900177f;
  t78_n147: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t78_n149;
  t78_n148: return 0.0410345084965229f;
  t78_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t78_n151;
  t78_n150: return -0.10716181248426437f;
  t78_n151: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t78_n159;
  t78_n152: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t78_n158;
  t78_n153: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t78_n155;
  t78_n154: return 0.07885532081127167f;
  t78_n155: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t78_n157;
  t78_n156: return 0.11988192051649094f;
  t78_n157: return 0.09200350940227509f;
  t78_n158: return -0.07779654860496521f;
  t78_n159: return 0.10819052904844284f;
  t78_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t78_n162;
  t78_n161: return 0.02147352695465088f;
  t78_n162: return 0.11747898906469345f;
  t78_n163: return 0.01827598176896572f;
  t78_n164: return -0.04510018229484558f;
  t78_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t78_n167;
  t78_n166: return -0.2130347490310669f;
  t78_n167: return 0.10661912709474564f;
  t78_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t78_n170;
  t78_n169: return -0.054119233042001724f;
  t78_n170: return 0.18074509501457214f;
  t78_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t78_n185;
  t78_n172: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t78_n174;
  t78_n173: return 0.08267640322446823f;
  t78_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t78_n184;
  t78_n175: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t78_n183;
  t78_n176: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n182;
  t78_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t78_n181;
  t78_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t78_n180;
  t78_n179: return 0.11987292766571045f;
  t78_n180: return 0.12072662264108658f;
  t78_n181: return 0.12095407396554947f;
  t78_n182: return 0.06725556403398514f;
  t78_n183: return 0.04104802384972572f;
  t78_n184: return -0.017223643139004707f;
  t78_n185: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t78_n191;
  t78_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t78_n188;
  t78_n187: return 0.0032719627488404512f;
  t78_n188: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t78_n190;
  t78_n189: return 0.11958421766757965f;
  t78_n190: return 0.10148710012435913f;
  t78_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t78_n193;
  t78_n192: return -0.12070313096046448f;
  t78_n193: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t78_n199;
  t78_n194: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t78_n198;
  t78_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t78_n197;
  t78_n196: return 0.08773238211870193f;
  t78_n197: return 0.1119827926158905f;
  t78_n198: return 0.1061350628733635f;
  t78_n199: return 0.019974706694483757f;
  t78_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t78_n204;
  t78_n201: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t78_n203;
  t78_n202: return -0.16796249151229858f;
  t78_n203: return -0.32428252696990967f;
  t78_n204: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t78_n206;
  t78_n205: return -0.06190063804388046f;
  t78_n206: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t78_n216;
  t78_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t78_n211;
  t78_n208: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t78_n210;
  t78_n209: return -0.14019200205802917f;
  t78_n210: return -1.0884262323379517f;
  t78_n211: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t78_n213;
  t78_n212: return 0.12444748729467392f;
  t78_n213: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t78_n215;
  t78_n214: return -0.13667242228984833f;
  t78_n215: return 0.08178090304136276f;
  t78_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t78_n218;
  t78_n217: return 0.014580471441149712f;
  t78_n218: return -0.05097613483667374f;
  t78_n219: return 0.05997221916913986f;
  t78_n220: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t78_n228;
  t78_n221: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t78_n225;
  t78_n222: if (E.getNumReferences() >= 3306149888 /*2301.5*/) goto t78_n224;
  t78_n223: return 0.004419982898980379f;
  t78_n224: return 0.014720641076564789f;
  t78_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t78_n227;
  t78_n226: return -0.021000143140554428f;
  t78_n227: return 0.1067826896905899f;
  t78_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t78_n230;
  t78_n229: return -0.012265131808817387f;
  t78_n230: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t78_n254;
  t78_n231: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n233;
  t78_n232: return 0.0229963269084692f;
  t78_n233: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t78_n247;
  t78_n234: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t78_n246;
  t78_n235: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t78_n241;
  t78_n236: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t78_n238;
  t78_n237: return -0.01723775453865528f;
  t78_n238: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t78_n240;
  t78_n239: return 0.03088224120438099f;
  t78_n240: return 0.007305405102670193f;
  t78_n241: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t78_n243;
  t78_n242: return -0.10071002691984177f;
  t78_n243: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t78_n245;
  t78_n244: return 0.01871163584291935f;
  t78_n245: return 0.09378086775541306f;
  t78_n246: return 0.01858401671051979f;
  t78_n247: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t78_n251;
  t78_n248: if (E.getNumReferences() >= 3270836224 /*122.5*/) goto t78_n250;
  t78_n249: return 0.13287925720214844f;
  t78_n250: return 0.06485482305288315f;
  t78_n251: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t78_n253;
  t78_n252: return 0.012407969683408737f;
  t78_n253: return 0.07150706648826599f;
  t78_n254: return 0.02605646476149559f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree79(const Example& E) {
  t79_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t79_n220;
  t79_n1: if (E.getNumReferences() >= 3304824832 /*2013.0*/) goto t79_n93;
  t79_n2: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t79_n22;
  t79_n3: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t79_n21;
  t79_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t79_n16;
  t79_n5: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t79_n7;
  t79_n6: return -0.002789352321997285f;
  t79_n7: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t79_n9;
  t79_n8: return 0.020721709355711937f;
  t79_n9: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t79_n13;
  t79_n10: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t79_n12;
  t79_n11: return 0.04231167212128639f;
  t79_n12: return 0.07773824781179428f;
  t79_n13: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t79_n15;
  t79_n14: return 0.0641339048743248f;
  t79_n15: return 0.07891016453504562f;
  t79_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t79_n18;
  t79_n17: return 0.025531373918056488f;
  t79_n18: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t79_n20;
  t79_n19: return 0.07012762874364853f;
  t79_n20: return 0.01668235845863819f;
  t79_n21: return -0.020884381607174873f;
  t79_n22: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t79_n38;
  t79_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Other))) goto t79_n27;
  t79_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t79_n26;
  t79_n25: return -0.04421335831284523f;
  t79_n26: return -0.01858322136104107f;
  t79_n27: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t79_n37;
  t79_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t79_n32;
  t79_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n31;
  t79_n30: return 0.08948705345392227f;
  t79_n31: return 0.015359980054199696f;
  t79_n32: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t79_n34;
  t79_n33: return 0.040612783282995224f;
  t79_n34: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t79_n36;
  t79_n35: return 0.0843447595834732f;
  t79_n36: return -0.3640061318874359f;
  t79_n37: return -0.057473812252283096f;
  t79_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t79_n40;
  t79_n39: return 0.0001373049453832209f;
  t79_n40: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t79_n62;
  t79_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t79_n43;
  t79_n42: return -0.016626683995127678f;
  t79_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n45;
  t79_n44: return 0.011555218137800694f;
  t79_n45: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t79_n49;
  t79_n46: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t79_n48;
  t79_n47: return 0.04512559995055199f;
  t79_n48: return -0.02048751711845398f;
  t79_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t79_n51;
  t79_n50: return -0.04695618897676468f;
  t79_n51: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t79_n53;
  t79_n52: return 0.020107341930270195f;
  t79_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t79_n61;
  t79_n54: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t79_n56;
  t79_n55: return -0.34607475996017456f;
  t79_n56: if (E.getNumReferences() >= 3260547072 /*54.0*/) goto t79_n58;
  t79_n57: return -0.026681138202548027f;
  t79_n58: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t79_n60;
  t79_n59: return 0.0657273381948471f;
  t79_n60: return 0.104324571788311f;
  t79_n61: return 0.0052857547998428345f;
  t79_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t79_n80;
  t79_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t79_n65;
  t79_n64: return 0.004450944717973471f;
  t79_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t79_n67;
  t79_n66: return 0.021564926952123642f;
  t79_n67: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t79_n79;
  t79_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n70;
  t79_n69: return 0.03830990940332413f;
  t79_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t79_n72;
  t79_n71: return 0.07131318002939224f;
  t79_n72: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t79_n74;
  t79_n73: return 0.07922372967004776f;
  t79_n74: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n78;
  t79_n75: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t79_n77;
  t79_n76: return 0.11807162314653397f;
  t79_n77: return 0.11578259617090225f;
  t79_n78: return 0.09607616066932678f;
  t79_n79: return 0.004684169311076403f;
  t79_n80: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t79_n92;
  t79_n81: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n91;
  t79_n82: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t79_n90;
  t79_n83: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t79_n87;
  t79_n84: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t79_n86;
  t79_n85: return 0.1225782185792923f;
  t79_n86: return 0.12581218779087067f;
  t79_n87: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t79_n89;
  t79_n88: return 0.12780897319316864f;
  t79_n89: return 0.1095169186592102f;
  t79_n90: return 0.0806216225028038f;
  t79_n91: return 0.0907345712184906f;
  t79_n92: return -0.048389632254838943f;
  t79_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t79_n99;
  t79_n94: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t79_n98;
  t79_n95: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t79_n97;
  t79_n96: return 0.01353180781006813f;
  t79_n97: return 0.039960604161024094f;
  t79_n98: return -0.004733403213322163f;
  t79_n99: if (E.getNumReferences() >= 3304845312 /*2015.5*/) goto t79_n101;
  t79_n100: return 0.12933818995952606f;
  t79_n101: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t79_n219;
  t79_n102: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t79_n200;
  t79_n103: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t79_n107;
  t79_n104: if (E.getNumReferences() >= 3319614464 /*7081.5*/) goto t79_n106;
  t79_n105: return 0.025745665654540062f;
  t79_n106: return -0.273457795381546f;
  t79_n107: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t79_n119;
  t79_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t79_n118;
  t79_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t79_n111;
  t79_n110: return -0.04512675106525421f;
  t79_n111: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t79_n113;
  t79_n112: return 0.035124797374010086f;
  t79_n113: if (E.getNumReferences() >= 3337313280 /*30126.0*/) goto t79_n115;
  t79_n114: return 0.11146797984838486f;
  t79_n115: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n117;
  t79_n116: return 0.09128059446811676f;
  t79_n117: return 0.10617195814847946f;
  t79_n118: return 0.03932145982980728f;
  t79_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t79_n169;
  t79_n120: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t79_n156;
  t79_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t79_n125;
  t79_n122: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t79_n124;
  t79_n123: return -0.04911450669169426f;
  t79_n124: return 0.09380879253149033f;
  t79_n125: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t79_n149;
  t79_n126: if (E.getNumReferences() >= 3333934848 /*23527.5*/) goto t79_n148;
  t79_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t79_n141;
  t79_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t79_n132;
  t79_n129: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t79_n131;
  t79_n130: return 0.05140407010912895f;
  t79_n131: return 0.07490140199661255f;
  t79_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n140;
  t79_n133: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t79_n139;
  t79_n134: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t79_n136;
  t79_n135: return 0.21850866079330444f;
  t79_n136: if (E.getNumReferences() >= 3325483008 /*11702.0*/) goto t79_n138;
  t79_n137: return 0.12848113477230072f;
  t79_n138: return -0.1046375259757042f;
  t79_n139: return 0.10410760343074799f;
  t79_n140: return 0.05357908084988594f;
  t79_n141: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n147;
  t79_n142: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n146;
  t79_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t79_n145;
  t79_n144: return 0.14129230380058289f;
  t79_n145: return 0.11222623288631439f;
  t79_n146: return 0.1135098785161972f;
  t79_n147: return -0.19664224982261658f;
  t79_n148: return -0.03479449823498726f;
  t79_n149: if (E.getNumReferences() >= 3338968320 /*33949.0*/) goto t79_n155;
  t79_n150: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t79_n154;
  t79_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n153;
  t79_n152: return 0.06705186516046524f;
  t79_n153: return 0.12250497937202454f;
  t79_n154: return 0.12022699415683746f;
  t79_n155: return 0.054379794746637344f;
  t79_n156: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t79_n166;
  t79_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t79_n159;
  t79_n158: return 0.04636991024017334f;
  t79_n159: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t79_n163;
  t79_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t79_n162;
  t79_n161: return -0.1497158706188202f;
  t79_n162: return 0.0972176119685173f;
  t79_n163: if (E.getNumReferences() >= 3331729664 /*19220.5*/) goto t79_n165;
  t79_n164: return 0.11561378091573715f;
  t79_n165: return -0.21993780136108398f;
  t79_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n168;
  t79_n167: return 0.07061014324426651f;
  t79_n168: return 0.12453475594520569f;
  t79_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t79_n173;
  t79_n170: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t79_n172;
  t79_n171: return 0.1221412792801857f;
  t79_n172: return 0.06176665797829628f;
  t79_n173: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t79_n189;
  t79_n174: if (E.getNumReferences() >= 3332440064 /*20608.0*/) goto t79_n184;
  t79_n175: if (E.getNumReferences() >= 3332338944 /*20410.5*/) goto t79_n181;
  t79_n176: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t79_n180;
  t79_n177: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t79_n179;
  t79_n178: return -0.10434170067310333f;
  t79_n179: return 0.12069585919380188f;
  t79_n180: return 0.06893905997276306f;
  t79_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t79_n183;
  t79_n182: return 0.10027848929166794f;
  t79_n183: return 0.11053047329187393f;
  t79_n184: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n186;
  t79_n185: return -0.06636503338813782f;
  t79_n186: if (E.getNumReferences() >= 3342897920 /*49299.0*/) goto t79_n188;
  t79_n187: return -0.1319546401500702f;
  t79_n188: return 0.11022043973207474f;
  t79_n189: if (E.getNumReferences() >= 3319788544 /*7166.5*/) goto t79_n193;
  t79_n190: if (E.getNumReferences() >= 3319744512 /*7145.0*/) goto t79_n192;
  t79_n191: return 0.20014412701129913f;
  t79_n192: return 0.11289793998003006f;
  t79_n193: if (E.getNumReferences() >= 3322110464 /*8408.5*/) goto t79_n195;
  t79_n194: return 0.019152894616127014f;
  t79_n195: if (E.getNumReferences() >= 3322180096 /*8476.5*/) goto t79_n199;
  t79_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t79_n198;
  t79_n197: return -0.1595335602760315f;
  t79_n198: return 0.11628075689077377f;
  t79_n199: return 0.07592881470918655f;
  t79_n200: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t79_n212;
  t79_n201: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t79_n203;
  t79_n202: return -0.027667861431837082f;
  t79_n203: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t79_n207;
  t79_n204: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n206;
  t79_n205: return -0.009118026122450829f;
  t79_n206: return 0.12332145124673843f;
  t79_n207: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n209;
  t79_n208: return -0.4166484773159027f;
  t79_n209: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t79_n211;
  t79_n210: return -0.346941739320755f;
  t79_n211: return 0.06394219398498535f;
  t79_n212: if (E.getNumReferences() >= 3345974912 /*61318.5*/) goto t79_n214;
  t79_n213: return 0.10863428562879562f;
  t79_n214: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t79_n216;
  t79_n215: return -0.006593164522200823f;
  t79_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t79_n218;
  t79_n217: return -0.11647643893957138f;
  t79_n218: return 0.033034548163414f;
  t79_n219: return 0.08531233668327332f;
  t79_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t79_n222;
  t79_n221: return -0.010983777232468128f;
  t79_n222: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t79_n234;
  t79_n223: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t79_n233;
  t79_n224: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t79_n232;
  t79_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t79_n231;
  t79_n226: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t79_n228;
  t79_n227: return 0.08274255692958832f;
  t79_n228: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t79_n230;
  t79_n229: return 0.01574854366481304f;
  t79_n230: return -0.07371587306261063f;
  t79_n231: return 0.028692355379462242f;
  t79_n232: return 0.017206978052854538f;
  t79_n233: return 0.0319412536919117f;
  t79_n234: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t79_n254;
  t79_n235: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t79_n237;
  t79_n236: return 0.005348753184080124f;
  t79_n237: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t79_n253;
  t79_n238: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t79_n240;
  t79_n239: return 0.02018781192600727f;
  t79_n240: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t79_n252;
  t79_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t79_n243;
  t79_n242: return 0.046314626932144165f;
  t79_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t79_n251;
  t79_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n250;
  t79_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t79_n247;
  t79_n246: return 0.079247385263443f;
  t79_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t79_n249;
  t79_n248: return 0.10471045970916748f;
  t79_n249: return 0.0905570536851883f;
  t79_n250: return 0.1127360463142395f;
  t79_n251: return -0.017158769071102142f;
  t79_n252: return 0.05817131698131561f;
  t79_n253: return 0.014192401431500912f;
  t79_n254: return -0.1996075063943863f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree80(const Example& E) {
  t80_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t80_n174;
  t80_n1: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t80_n87;
  t80_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t80_n26;
  t80_n3: if (E.getFileProximityDistance() >= 3212836864 /*1.0*/) goto t80_n5;
  t80_n4: return 0.10804293304681778f;
  t80_n5: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t80_n7;
  t80_n6: return -0.009724891744554043f;
  t80_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t80_n25;
  t80_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t80_n20;
  t80_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t80_n11;
  t80_n10: return 0.012032714672386646f;
  t80_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t80_n13;
  t80_n12: return 0.02128901518881321f;
  t80_n13: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t80_n15;
  t80_n14: return -0.04718570038676262f;
  t80_n15: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t80_n17;
  t80_n16: return 0.0752057135105133f;
  t80_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t80_n19;
  t80_n18: return 0.08269169181585312f;
  t80_n19: return 0.010968293063342571f;
  t80_n20: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t80_n24;
  t80_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t80_n23;
  t80_n22: return 0.05455932393670082f;
  t80_n23: return 0.12384967505931854f;
  t80_n24: return 0.01238090917468071f;
  t80_n25: return -0.02093484252691269f;
  t80_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t80_n86;
  t80_n27: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t80_n73;
  t80_n28: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t80_n42;
  t80_n29: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t80_n33;
  t80_n30: if (E.getNumReferences() >= 3290472448 /*642.5*/) goto t80_n32;
  t80_n31: return -0.02861838974058628f;
  t80_n32: return 0.1118425652384758f;
  t80_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t80_n35;
  t80_n34: return -0.18952351808547974f;
  t80_n35: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t80_n41;
  t80_n36: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t80_n38;
  t80_n37: return -0.11049740016460419f;
  t80_n38: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t80_n40;
  t80_n39: return 0.12378106266260147f;
  t80_n40: return 0.027988947927951813f;
  t80_n41: return 0.02779395319521427f;
  t80_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t80_n58;
  t80_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t80_n45;
  t80_n44: return -0.009397591464221478f;
  t80_n45: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t80_n57;
  t80_n46: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t80_n52;
  t80_n47: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t80_n51;
  t80_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t80_n50;
  t80_n49: return 0.04574039578437805f;
  t80_n50: return 0.09228396415710449f;
  t80_n51: return 0.023183384910225868f;
  t80_n52: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t80_n56;
  t80_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t80_n55;
  t80_n54: return -0.07267352938652039f;
  t80_n55: return 0.14352332055568695f;
  t80_n56: return 0.02379699796438217f;
  t80_n57: return 0.006918361876159906f;
  t80_n58: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t80_n64;
  t80_n59: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t80_n61;
  t80_n60: return 0.03939148783683777f;
  t80_n61: if (E.getNumReferences() >= 3292602368 /*772.5*/) goto t80_n63;
  t80_n62: return 0.12576648592948914f;
  t80_n63: return 0.05271639674901962f;
  t80_n64: if (E.getNumReferences() >= 3324791296 /*11026.5*/) goto t80_n66;
  t80_n65: return 0.01208366546779871f;
  t80_n66: if (E.getNumReferences() >= 3326378496 /*12576.5*/) goto t80_n68;
  t80_n67: return 0.12794028222560883f;
  t80_n68: if (E.getNumReferences() >= 3329918464 /*16033.5*/) goto t80_n72;
  t80_n69: if (E.getNumReferences() >= 3329426944 /*15553.5*/) goto t80_n71;
  t80_n70: return 0.049553919583559036f;
  t80_n71: return 0.11202451586723328f;
  t80_n72: return -0.023699894547462463f;
  t80_n73: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t80_n79;
  t80_n74: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t80_n78;
  t80_n75: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t80_n77;
  t80_n76: return -0.2522695064544678f;
  t80_n77: return -0.11833084374666214f;
  t80_n78: return -0.01764434576034546f;
  t80_n79: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t80_n81;
  t80_n80: return -0.1840236932039261f;
  t80_n81: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t80_n85;
  t80_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t80_n84;
  t80_n83: return 0.1313660889863968f;
  t80_n84: return 0.06182263791561127f;
  t80_n85: return -0.023582441732287407f;
  t80_n86: return 0.00610074307769537f;
  t80_n87: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t80_n89;
  t80_n88: return -0.00872153788805008f;
  t80_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t80_n153;
  t80_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t80_n128;
  t80_n91: if (E.getNumReferences() >= 3338616320 /*32671.0*/) goto t80_n95;
  t80_n92: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t80_n94;
  t80_n93: return 0.14319466054439545f;
  t80_n94: return 0.10099197924137115f;
  t80_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t80_n99;
  t80_n96: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t80_n98;
  t80_n97: return 0.024190492928028107f;
  t80_n98: return -0.10278269648551941f;
  t80_n99: if (E.getNumReferences() >= 3359435680 /*193454.5*/) goto t80_n111;
  t80_n100: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t80_n110;
  t80_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t80_n103;
  t80_n102: return -0.3840232491493225f;
  t80_n103: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t80_n105;
  t80_n104: return 0.05782601609826088f;
  t80_n105: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t80_n107;
  t80_n106: return 0.0885034054517746f;
  t80_n107: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t80_n109;
  t80_n108: return 0.1426907181739807f;
  t80_n109: return 0.021658822894096375f;
  t80_n110: return -0.05766738951206207f;
  t80_n111: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t80_n119;
  t80_n112: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t80_n114;
  t80_n113: return 0.09260090440511703f;
  t80_n114: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t80_n118;
  t80_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t80_n117;
  t80_n116: return 0.09781865775585175f;
  t80_n117: return 0.09149586409330368f;
  t80_n118: return 0.05324823781847954f;
  t80_n119: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t80_n121;
  t80_n120: return -0.08669420331716537f;
  t80_n121: if (E.getNumReferences() >= 3375821112 /*749331.5*/) goto t80_n123;
  t80_n122: return 0.08360887318849564f;
  t80_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t80_n125;
  t80_n124: return -0.2875328063964844f;
  t80_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t80_n127;
  t80_n126: return -0.4047398865222931f;
  t80_n127: return 0.048165977001190186f;
  t80_n128: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t80_n130;
  t80_n129: return 0.006486658006906509f;
  t80_n130: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t80_n144;
  t80_n131: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t80_n143;
  t80_n132: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t80_n138;
  t80_n133: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t80_n135;
  t80_n134: return 0.10914255678653717f;
  t80_n135: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t80_n137;
  t80_n136: return 0.11962917447090149f;
  t80_n137: return 0.11391232907772064f;
  t80_n138: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t80_n140;
  t80_n139: return 0.11725358664989471f;
  t80_n140: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t80_n142;
  t80_n141: return -0.1588388979434967f;
  t80_n142: return 0.12389513850212097f;
  t80_n143: return 0.09240482747554779f;
  t80_n144: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t80_n152;
  t80_n145: if (E.getNumReferences() >= 3359238848 /*190379.0*/) goto t80_n151;
  t80_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t80_n148;
  t80_n147: return -0.10209174454212189f;
  t80_n148: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t80_n150;
  t80_n149: return 0.11123050004243851f;
  t80_n150: return 0.04829201474785805f;
  t80_n151: return -0.004018864594399929f;
  t80_n152: return 0.07443921267986298f;
  t80_n153: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t80_n155;
  t80_n154: return 0.015606660395860672f;
  t80_n155: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t80_n167;
  t80_n156: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t80_n166;
  t80_n157: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t80_n159;
  t80_n158: return 0.0713287889957428f;
  t80_n159: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t80_n165;
  t80_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t80_n162;
  t80_n161: return 0.09646614640951157f;
  t80_n162: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t80_n164;
  t80_n163: return 0.11880388110876083f;
  t80_n164: return 0.07808496057987213f;
  t80_n165: return 0.08300144970417023f;
  t80_n166: return -0.006212947890162468f;
  t80_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t80_n169;
  t80_n168: return -0.02508707530796528f;
  t80_n169: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t80_n171;
  t80_n170: return -0.1240813285112381f;
  t80_n171: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t80_n173;
  t80_n172: return 0.13038551807403564f;
  t80_n173: return 0.18201309442520142f;
  t80_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t80_n176;
  t80_n175: return -0.010363410227000713f;
  t80_n176: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t80_n234;
  t80_n177: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t80_n191;
  t80_n178: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t80_n186;
  t80_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t80_n185;
  t80_n180: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t80_n182;
  t80_n181: return 0.08347325026988983f;
  t80_n182: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t80_n184;
  t80_n183: return 0.014627008698880672f;
  t80_n184: return -0.07454022020101547f;
  t80_n185: return 0.02779490500688553f;
  t80_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t80_n190;
  t80_n187: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t80_n189;
  t80_n188: return -0.15154536068439484f;
  t80_n189: return 0.01066802442073822f;
  t80_n190: return 0.020192885771393776f;
  t80_n191: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t80_n233;
  t80_n192: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t80_n194;
  t80_n193: return -0.3578667640686035f;
  t80_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t80_n196;
  t80_n195: return 0.022568078711628914f;
  t80_n196: if (E.getNumReferences() >= 3324623872 /*10863.0*/) goto t80_n230;
  t80_n197: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t80_n199;
  t80_n198: return 0.030223509296774864f;
  t80_n199: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t80_n229;
  t80_n200: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t80_n214;
  t80_n201: if (E.getNumReferences() >= 3282272256 /*327.0*/) goto t80_n211;
  t80_n202: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t80_n204;
  t80_n203: return 0.03621279448270798f;
  t80_n204: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t80_n210;
  t80_n205: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t80_n207;
  t80_n206: return 0.18350866436958313f;
  t80_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t80_n209;
  t80_n208: return 0.11368590593338013f;
  t80_n209: return -0.08548647910356522f;
  t80_n210: return 0.04957890510559082f;
  t80_n211: if (E.getNumReferences() >= 3285565440 /*427.5*/) goto t80_n213;
  t80_n212: return 0.11220376938581467f;
  t80_n213: return 0.08536221086978912f;
  t80_n214: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t80_n228;
  t80_n215: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t80_n227;
  t80_n216: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t80_n224;
  t80_n217: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t80_n223;
  t80_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t80_n220;
  t80_n219: return -0.10415113717317581f;
  t80_n220: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t80_n222;
  t80_n221: return 0.14708401262760162f;
  t80_n222: return -0.4223143756389618f;
  t80_n223: return -0.10295672714710236f;
  t80_n224: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t80_n226;
  t80_n225: return 0.11435553431510925f;
  t80_n226: return 0.007711535785347223f;
  t80_n227: return 0.13899430632591248f;
  t80_n228: return 0.024445977061986923f;
  t80_n229: return 0.03871970996260643f;
  t80_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t80_n232;
  t80_n231: return 0.11151157319545746f;
  t80_n232: return 0.004408429376780987f;
  t80_n233: return 0.06808024644851685f;
  t80_n234: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t80_n254;
  t80_n235: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t80_n237;
  t80_n236: return 0.004922512453049421f;
  t80_n237: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t80_n253;
  t80_n238: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t80_n240;
  t80_n239: return 0.01806282438337803f;
  t80_n240: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t80_n252;
  t80_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t80_n243;
  t80_n242: return 0.04848923161625862f;
  t80_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t80_n251;
  t80_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t80_n250;
  t80_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t80_n247;
  t80_n246: return 0.09717953205108643f;
  t80_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t80_n249;
  t80_n248: return 0.1038350984454155f;
  t80_n249: return 0.09595806896686554f;
  t80_n250: return 0.1172543466091156f;
  t80_n251: return -0.05095802992582321f;
  t80_n252: return 0.05164337158203125f;
  t80_n253: return 0.014055776409804821f;
  t80_n254: return -0.1332462579011917f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree81(const Example& E) {
  t81_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t81_n200;
  t81_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t81_n33;
  t81_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t81_n6;
  t81_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n5;
  t81_n4: return -0.014507715590298176f;
  t81_n5: return -0.03606438636779785f;
  t81_n6: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t81_n8;
  t81_n7: return -0.013494818471372128f;
  t81_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n10;
  t81_n9: return 0.0008899254025891423f;
  t81_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t81_n12;
  t81_n11: return -0.1322566419839859f;
  t81_n12: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t81_n16;
  t81_n13: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t81_n15;
  t81_n14: return -0.03214407339692116f;
  t81_n15: return 0.012208306230604649f;
  t81_n16: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t81_n32;
  t81_n17: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n19;
  t81_n18: return 0.03301555663347244f;
  t81_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t81_n21;
  t81_n20: return 0.06701027601957321f;
  t81_n21: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t81_n23;
  t81_n22: return 0.0716828927397728f;
  t81_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t81_n25;
  t81_n24: return 0.12637177109718323f;
  t81_n25: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n29;
  t81_n26: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t81_n28;
  t81_n27: return 0.10282764583826065f;
  t81_n28: return 0.11595622450113297f;
  t81_n29: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t81_n31;
  t81_n30: return -0.11272714287042618f;
  t81_n31: return 0.11447829753160477f;
  t81_n32: return 0.012724822387099266f;
  t81_n33: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t81_n199;
  t81_n34: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t81_n150;
  t81_n35: if (E.getFileProximityDistance() >= 3212836864 /*1.0*/) goto t81_n37;
  t81_n36: return 0.10691174119710922f;
  t81_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t81_n97;
  t81_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t81_n72;
  t81_n39: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t81_n41;
  t81_n40: return -0.017166145145893097f;
  t81_n41: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t81_n71;
  t81_n42: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n64;
  t81_n43: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t81_n55;
  t81_n44: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n46;
  t81_n45: return 0.053303658962249756f;
  t81_n46: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t81_n52;
  t81_n47: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t81_n49;
  t81_n48: return 0.10659977793693542f;
  t81_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n51;
  t81_n50: return 0.07618407905101776f;
  t81_n51: return 0.03261910378932953f;
  t81_n52: if (E.getNumReferences() >= 3347570176 /*69564.0*/) goto t81_n54;
  t81_n53: return -0.0015654595335945487f;
  t81_n54: return -0.4305429458618164f;
  t81_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n57;
  t81_n56: return 0.10009314119815826f;
  t81_n57: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t81_n63;
  t81_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n62;
  t81_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t81_n61;
  t81_n60: return -0.10612674057483673f;
  t81_n61: return 0.10750653594732285f;
  t81_n62: return 0.1539601981639862f;
  t81_n63: return -0.057793643325567245f;
  t81_n64: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t81_n66;
  t81_n65: return 0.013890981674194336f;
  t81_n66: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t81_n70;
  t81_n67: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t81_n69;
  t81_n68: return -0.003961089998483658f;
  t81_n69: return 0.10965045541524887f;
  t81_n70: return -0.05553411319851875f;
  t81_n71: return -0.11752330511808395f;
  t81_n72: if (E.getNumReferences() >= 3363872672 /*263421.0*/) goto t81_n88;
  t81_n73: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n75;
  t81_n74: return 0.0037271936889737844f;
  t81_n75: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n77;
  t81_n76: return 0.04468134418129921f;
  t81_n77: if (E.getNumReferences() >= 3318719488 /*6644.5*/) goto t81_n83;
  t81_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t81_n80;
  t81_n79: return 0.051201362162828445f;
  t81_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n82;
  t81_n81: return 0.07965259253978729f;
  t81_n82: return 0.029125092551112175f;
  t81_n83: if (E.getNumReferences() >= 3318872064 /*6719.0*/) goto t81_n87;
  t81_n84: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t81_n86;
  t81_n85: return 0.10687073320150375f;
  t81_n86: return 0.14223125576972961f;
  t81_n87: return 0.059216514229774475f;
  t81_n88: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t81_n96;
  t81_n89: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n91;
  t81_n90: return 0.060733988881111145f;
  t81_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n93;
  t81_n92: return 0.036832358688116074f;
  t81_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t81_n95;
  t81_n94: return 0.08945021033287048f;
  t81_n95: return 0.04933464527130127f;
  t81_n96: return -0.011062785051763058f;
  t81_n97: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t81_n99;
  t81_n98: return 0.008107968606054783f;
  t81_n99: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t81_n101;
  t81_n100: return -0.006712046917527914f;
  t81_n101: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t81_n133;
  t81_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t81_n104;
  t81_n103: return 0.0354640893638134f;
  t81_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t81_n116;
  t81_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t81_n107;
  t81_n106: return -0.15891118347644806f;
  t81_n107: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t81_n109;
  t81_n108: return 0.060997530817985535f;
  t81_n109: if (E.getNumReferences() >= 3349616960 /*85554.5*/) goto t81_n115;
  t81_n110: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t81_n112;
  t81_n111: return 0.12430063635110855f;
  t81_n112: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n114;
  t81_n113: return 0.07110124826431274f;
  t81_n114: return 0.10925406217575073f;
  t81_n115: return -0.01046582031995058f;
  t81_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t81_n118;
  t81_n117: return 0.02011762745678425f;
  t81_n118: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t81_n130;
  t81_n119: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t81_n123;
  t81_n120: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t81_n122;
  t81_n121: return 0.07632116973400116f;
  t81_n122: return 0.03673330321907997f;
  t81_n123: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t81_n125;
  t81_n124: return 0.021261192858219147f;
  t81_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t81_n127;
  t81_n126: return 0.09120655804872513f;
  t81_n127: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t81_n129;
  t81_n128: return 0.11755393445491791f;
  t81_n129: return 0.11072497814893723f;
  t81_n130: if (E.getNumReferences() >= 3359032704 /*187158.0*/) goto t81_n132;
  t81_n131: return 0.01687467284500599f;
  t81_n132: return 0.07880914211273193f;
  t81_n133: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t81_n135;
  t81_n134: return -0.1289965808391571f;
  t81_n135: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t81_n147;
  t81_n136: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t81_n142;
  t81_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t81_n141;
  t81_n138: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n140;
  t81_n139: return 0.022876271978020668f;
  t81_n140: return -0.2578778862953186f;
  t81_n141: return 0.06598395109176636f;
  t81_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t81_n144;
  t81_n143: return 0.04936535283923149f;
  t81_n144: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t81_n146;
  t81_n145: return 0.11701102554798126f;
  t81_n146: return 0.030393358319997787f;
  t81_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t81_n149;
  t81_n148: return -0.16632439196109772f;
  t81_n149: return 0.00725763663649559f;
  t81_n150: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t81_n164;
  t81_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t81_n157;
  t81_n152: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t81_n154;
  t81_n153: return -0.020351102575659752f;
  t81_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t81_n156;
  t81_n155: return -0.16240444779396057f;
  t81_n156: return -0.12530675530433655f;
  t81_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n159;
  t81_n158: return 0.005556175950914621f;
  t81_n159: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t81_n161;
  t81_n160: return 0.05111529678106308f;
  t81_n161: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t81_n163;
  t81_n162: return 0.013476116582751274f;
  t81_n163: return 0.07646924257278442f;
  t81_n164: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t81_n198;
  t81_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t81_n171;
  t81_n166: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t81_n168;
  t81_n167: return 0.13654464483261108f;
  t81_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t81_n170;
  t81_n169: return -0.07791402190923691f;
  t81_n170: return 0.10330379009246826f;
  t81_n171: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t81_n187;
  t81_n172: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n184;
  t81_n173: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t81_n179;
  t81_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t81_n176;
  t81_n175: return 0.061248764395713806f;
  t81_n176: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t81_n178;
  t81_n177: return 0.11762837320566177f;
  t81_n178: return 0.08512867987155914f;
  t81_n179: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t81_n181;
  t81_n180: return 0.054514698684215546f;
  t81_n181: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t81_n183;
  t81_n182: return 0.12089163064956665f;
  t81_n183: return 0.030597034841775894f;
  t81_n184: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t81_n186;
  t81_n185: return 0.07961930334568024f;
  t81_n186: return 0.03936902806162834f;
  t81_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t81_n193;
  t81_n188: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n190;
  t81_n189: return 0.08788397908210754f;
  t81_n190: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n192;
  t81_n191: return 0.10548625141382217f;
  t81_n192: return 0.05411136522889137f;
  t81_n193: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t81_n197;
  t81_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t81_n196;
  t81_n195: return 0.11726599931716919f;
  t81_n196: return 0.10746300220489502f;
  t81_n197: return -0.10103780776262283f;
  t81_n198: return -0.07901834696531296f;
  t81_n199: return -0.11495991796255112f;
  t81_n200: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t81_n252;
  t81_n201: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t81_n251;
  t81_n202: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t81_n238;
  t81_n203: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t81_n233;
  t81_n204: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t81_n226;
  t81_n205: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t81_n225;
  t81_n206: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t81_n212;
  t81_n207: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t81_n209;
  t81_n208: return -0.15626581013202667f;
  t81_n209: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t81_n211;
  t81_n210: return 0.01924777589738369f;
  t81_n211: return 0.03734108805656433f;
  t81_n212: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t81_n214;
  t81_n213: return 0.010595511645078659f;
  t81_n214: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t81_n216;
  t81_n215: return 0.02208452671766281f;
  t81_n216: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t81_n224;
  t81_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t81_n223;
  t81_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t81_n220;
  t81_n219: return 0.0961068719625473f;
  t81_n220: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n222;
  t81_n221: return 0.10290994495153427f;
  t81_n222: return 0.08371914178133011f;
  t81_n223: return 0.016124555841088295f;
  t81_n224: return 0.05426621809601784f;
  t81_n225: return -0.014947880990803242f;
  t81_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t81_n228;
  t81_n227: return 0.008944462053477764f;
  t81_n228: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t81_n230;
  t81_n229: return 0.022722214460372925f;
  t81_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t81_n232;
  t81_n231: return 0.03216971084475517f;
  t81_n232: return 0.06426052004098892f;
  t81_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t81_n235;
  t81_n234: return -0.05558621510863304f;
  t81_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n237;
  t81_n236: return -0.013693063519895077f;
  t81_n237: return 0.044690247625112534f;
  t81_n238: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t81_n244;
  t81_n239: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t81_n243;
  t81_n240: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t81_n242;
  t81_n241: return 0.10489927977323532f;
  t81_n242: return 0.12427271902561188f;
  t81_n243: return 0.06150725483894348f;
  t81_n244: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t81_n246;
  t81_n245: return 0.01005419623106718f;
  t81_n246: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t81_n248;
  t81_n247: return 0.045386798679828644f;
  t81_n248: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t81_n250;
  t81_n249: return 0.0801817923784256f;
  t81_n250: return 0.11682413518428802f;
  t81_n251: return -0.08937713503837585f;
  t81_n252: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t81_n254;
  t81_n253: return 0.0001837198797147721f;
  t81_n254: return 0.016702953726053238f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree82(const Example& E) {
  t82_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t82_n210;
  t82_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t82_n49;
  t82_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t82_n26;
  t82_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n5;
  t82_n4: return -0.01548166386783123f;
  t82_n5: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t82_n7;
  t82_n6: return -0.04332064837217331f;
  t82_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t82_n9;
  t82_n8: return -0.10716072469949722f;
  t82_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t82_n15;
  t82_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t82_n12;
  t82_n11: return 0.007705328520387411f;
  t82_n12: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t82_n14;
  t82_n13: return 0.03594211861491203f;
  t82_n14: return -0.012259744107723236f;
  t82_n15: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t82_n25;
  t82_n16: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t82_n24;
  t82_n17: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n21;
  t82_n18: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n20;
  t82_n19: return 0.11450190842151642f;
  t82_n20: return 0.10680568963289261f;
  t82_n21: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t82_n23;
  t82_n22: return 0.12118831276893616f;
  t82_n23: return 0.09538585692644119f;
  t82_n24: return 0.08017583936452866f;
  t82_n25: return -0.06519264727830887f;
  t82_n26: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t82_n28;
  t82_n27: return -0.013377374969422817f;
  t82_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n30;
  t82_n29: return 0.0009384581935591996f;
  t82_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t82_n32;
  t82_n31: return -0.13102269172668457f;
  t82_n32: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t82_n36;
  t82_n33: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t82_n35;
  t82_n34: return -0.02795409969985485f;
  t82_n35: return 0.010966116562485695f;
  t82_n36: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t82_n48;
  t82_n37: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t82_n39;
  t82_n38: return 0.02998708002269268f;
  t82_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t82_n41;
  t82_n40: return 0.06353985518217087f;
  t82_n41: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t82_n43;
  t82_n42: return 0.06566102802753448f;
  t82_n43: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n45;
  t82_n44: return 0.1214480772614479f;
  t82_n45: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n47;
  t82_n46: return 0.10414449870586395f;
  t82_n47: return 0.09244261682033539f;
  t82_n48: return 0.011982697993516922f;
  t82_n49: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t82_n209;
  t82_n50: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t82_n122;
  t82_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t82_n109;
  t82_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t82_n96;
  t82_n53: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t82_n55;
  t82_n54: return -0.015826666727662086f;
  t82_n55: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t82_n95;
  t82_n56: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t82_n88;
  t82_n57: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t82_n79;
  t82_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n60;
  t82_n59: return 0.04853120446205139f;
  t82_n60: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t82_n76;
  t82_n61: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t82_n65;
  t82_n62: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n64;
  t82_n63: return 0.0716937705874443f;
  t82_n64: return 0.029415879398584366f;
  t82_n65: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n75;
  t82_n66: if (E.getNumReferences() >= 3266576384 /*90.0*/) goto t82_n74;
  t82_n67: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t82_n69;
  t82_n68: return 0.14385080337524414f;
  t82_n69: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t82_n71;
  t82_n70: return 0.08985763043165207f;
  t82_n71: if (E.getNumReferences() >= 3261333504 /*57.0*/) goto t82_n73;
  t82_n72: return 0.1404128223657608f;
  t82_n73: return 0.09375040978193283f;
  t82_n74: return -0.20269225537776947f;
  t82_n75: return 0.11361376941204071f;
  t82_n76: if (E.getNumReferences() >= 3347570176 /*69564.0*/) goto t82_n78;
  t82_n77: return 0.0005488388705998659f;
  t82_n78: return -0.34375324845314026f;
  t82_n79: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n81;
  t82_n80: return 0.09585534781217575f;
  t82_n81: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t82_n87;
  t82_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n86;
  t82_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t82_n85;
  t82_n84: return -0.10550494492053986f;
  t82_n85: return 0.10423329472541809f;
  t82_n86: return 0.14521050453186035f;
  t82_n87: return -0.057488758116960526f;
  t82_n88: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t82_n90;
  t82_n89: return 0.011724439449608326f;
  t82_n90: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t82_n94;
  t82_n91: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t82_n93;
  t82_n92: return -0.024949977174401283f;
  t82_n93: return 0.10834012180566788f;
  t82_n94: return -0.04885396733880043f;
  t82_n95: return -0.11656895279884338f;
  t82_n96: if (E.getNumReferences() >= 3363872672 /*263421.0*/) goto t82_n100;
  t82_n97: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t82_n99;
  t82_n98: return 0.01683053933084011f;
  t82_n99: return -0.035294245928525925f;
  t82_n100: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t82_n108;
  t82_n101: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n103;
  t82_n102: return 0.03924889490008354f;
  t82_n103: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t82_n105;
  t82_n104: return 0.03326618671417236f;
  t82_n105: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n107;
  t82_n106: return 0.08594009280204773f;
  t82_n107: return 0.0467476025223732f;
  t82_n108: return -0.010314283892512321f;
  t82_n109: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t82_n111;
  t82_n110: return 0.007605336140841246f;
  t82_n111: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t82_n113;
  t82_n112: return -0.007912864908576012f;
  t82_n113: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t82_n117;
  t82_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n116;
  t82_n115: return 0.0328800231218338f;
  t82_n116: return 0.048753056675195694f;
  t82_n117: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t82_n119;
  t82_n118: return -0.11767002940177917f;
  t82_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t82_n121;
  t82_n120: return 0.0010233648354187608f;
  t82_n121: return 0.032615721225738525f;
  t82_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t82_n154;
  t82_n123: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t82_n125;
  t82_n124: return -0.020620618015527725f;
  t82_n125: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t82_n153;
  t82_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t82_n130;
  t82_n127: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n129;
  t82_n128: return 0.1466289460659027f;
  t82_n129: return 0.09506255388259888f;
  t82_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t82_n144;
  t82_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t82_n133;
  t82_n132: return 0.06923183053731918f;
  t82_n133: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t82_n141;
  t82_n134: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t82_n140;
  t82_n135: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n137;
  t82_n136: return 0.06432972103357315f;
  t82_n137: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n139;
  t82_n138: return 0.09460094571113586f;
  t82_n139: return 0.08159423619508743f;
  t82_n140: return 0.021624360233545303f;
  t82_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n143;
  t82_n142: return 0.10494249314069748f;
  t82_n143: return 0.0488741435110569f;
  t82_n144: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t82_n152;
  t82_n145: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n149;
  t82_n146: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t82_n148;
  t82_n147: return 0.11116784811019897f;
  t82_n148: return 0.11553255468606949f;
  t82_n149: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t82_n151;
  t82_n150: return 0.10384050011634827f;
  t82_n151: return 0.07769101113080978f;
  t82_n152: return -0.13762132823467255f;
  t82_n153: return -0.10557188093662262f;
  t82_n154: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t82_n208;
  t82_n155: if (E.getNumReferences() >= 3352190016 /*105656.5*/) goto t82_n187;
  t82_n156: if (E.getNumReferences() >= 3282223104 /*325.5*/) goto t82_n160;
  t82_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n159;
  t82_n158: return 0.018434183672070503f;
  t82_n159: return 0.02283564582467079f;
  t82_n160: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n162;
  t82_n161: return 0.053169041872024536f;
  t82_n162: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t82_n182;
  t82_n163: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t82_n165;
  t82_n164: return 0.1357036530971527f;
  t82_n165: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t82_n177;
  t82_n166: if (E.getNumReferences() >= 3310379008 /*3334.0*/) goto t82_n168;
  t82_n167: return 0.09511519223451614f;
  t82_n168: if (E.getNumReferences() >= 3313898496 /*4290.5*/) goto t82_n176;
  t82_n169: if (E.getNumReferences() >= 3313839104 /*4261.5*/) goto t82_n175;
  t82_n170: if (E.getNumReferences() >= 3313203200 /*4023.5*/) goto t82_n174;
  t82_n171: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t82_n173;
  t82_n172: return -0.10851377248764038f;
  t82_n173: return 0.11336667090654373f;
  t82_n174: return -0.14925332367420197f;
  t82_n175: return 0.15969248116016388f;
  t82_n176: return 0.0943632647395134f;
  t82_n177: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t82_n179;
  t82_n178: return 0.11336550861597061f;
  t82_n179: if (E.getNumReferences() >= 3289817088 /*602.5*/) goto t82_n181;
  t82_n180: return 0.12456053495407104f;
  t82_n181: return 0.10664474964141846f;
  t82_n182: if (E.getNumReferences() >= 3292733440 /*780.5*/) goto t82_n186;
  t82_n183: if (E.getNumReferences() >= 3290030080 /*615.5*/) goto t82_n185;
  t82_n184: return 0.03743361681699753f;
  t82_n185: return 0.10947438329458237f;
  t82_n186: return 0.06522759795188904f;
  t82_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n189;
  t82_n188: return 0.5832801461219788f;
  t82_n189: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n207;
  t82_n190: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t82_n198;
  t82_n191: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t82_n193;
  t82_n192: return 0.10781931132078171f;
  t82_n193: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t82_n195;
  t82_n194: return 0.11702177673578262f;
  t82_n195: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n197;
  t82_n196: return 0.11223107576370239f;
  t82_n197: return 0.10086531937122345f;
  t82_n198: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t82_n204;
  t82_n199: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t82_n201;
  t82_n200: return 0.11302413046360016f;
  t82_n201: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n203;
  t82_n202: return -0.006916820537298918f;
  t82_n203: return 0.10650277137756348f;
  t82_n204: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n206;
  t82_n205: return 0.10965774953365326f;
  t82_n206: return 0.012773687951266766f;
  t82_n207: return 0.07222352921962738f;
  t82_n208: return -0.015856510028243065f;
  t82_n209: return -0.11399387568235397f;
  t82_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t82_n212;
  t82_n211: return -0.010329888202250004f;
  t82_n212: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t82_n230;
  t82_n213: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t82_n227;
  t82_n214: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t82_n222;
  t82_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n217;
  t82_n216: return 0.03461311757564545f;
  t82_n217: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t82_n221;
  t82_n218: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t82_n220;
  t82_n219: return -0.07553571462631226f;
  t82_n220: return 0.032699476927518845f;
  t82_n221: return 0.016848981380462646f;
  t82_n222: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n224;
  t82_n223: return 0.008776834234595299f;
  t82_n224: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t82_n226;
  t82_n225: return -0.12636466324329376f;
  t82_n226: return 0.0208554919809103f;
  t82_n227: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t82_n229;
  t82_n228: return 0.027581846341490746f;
  t82_n229: return 0.06857681274414062f;
  t82_n230: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t82_n254;
  t82_n231: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t82_n233;
  t82_n232: return 0.00550473527982831f;
  t82_n233: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t82_n253;
  t82_n234: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t82_n238;
  t82_n235: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n237;
  t82_n236: return 0.054479245096445084f;
  t82_n237: return -0.08088043332099915f;
  t82_n238: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t82_n240;
  t82_n239: return 0.024388333782553673f;
  t82_n240: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t82_n252;
  t82_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t82_n243;
  t82_n242: return 0.05173017084598541f;
  t82_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n251;
  t82_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n250;
  t82_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t82_n247;
  t82_n246: return 0.147722989320755f;
  t82_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t82_n249;
  t82_n248: return 0.10236550867557526f;
  t82_n249: return 0.08806188404560089f;
  t82_n250: return 0.12738679349422455f;
  t82_n251: return 0.025183066725730896f;
  t82_n252: return 0.048918597400188446f;
  t82_n253: return 0.011226381175220013f;
  t82_n254: return -0.16856133937835693f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree83(const Example& E) {
  t83_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t83_n196;
  t83_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t83_n11;
  t83_n2: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t83_n4;
  t83_n3: return -0.014602585695683956f;
  t83_n4: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t83_n6;
  t83_n5: return -0.033047690987586975f;
  t83_n6: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t83_n8;
  t83_n7: return -0.08326694369316101f;
  t83_n8: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t83_n10;
  t83_n9: return -0.02605581097304821f;
  t83_n10: return 0.10069455951452255f;
  t83_n11: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t83_n59;
  t83_n12: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t83_n14;
  t83_n13: return 0.0067834872752428055f;
  t83_n14: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t83_n18;
  t83_n15: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t83_n17;
  t83_n16: return 0.11832141876220703f;
  t83_n17: return 0.009153135120868683f;
  t83_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t83_n38;
  t83_n19: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t83_n21;
  t83_n20: return 0.005359038710594177f;
  t83_n21: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t83_n37;
  t83_n22: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t83_n24;
  t83_n23: return 0.0689048022031784f;
  t83_n24: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t83_n34;
  t83_n25: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t83_n33;
  t83_n26: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t83_n32;
  t83_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t83_n29;
  t83_n28: return 0.06651009619235992f;
  t83_n29: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t83_n31;
  t83_n30: return 0.09025805443525314f;
  t83_n31: return 0.07548262178897858f;
  t83_n32: return 0.045940954238176346f;
  t83_n33: return 0.04294333606958389f;
  t83_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t83_n36;
  t83_n35: return 0.10133904218673706f;
  t83_n36: return 0.05208778381347656f;
  t83_n37: return -0.04955887049436569f;
  t83_n38: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t83_n40;
  t83_n39: return 0.4045504927635193f;
  t83_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t83_n58;
  t83_n41: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t83_n49;
  t83_n42: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t83_n44;
  t83_n43: return 0.10706435889005661f;
  t83_n44: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t83_n48;
  t83_n45: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t83_n47;
  t83_n46: return 0.11503367871046066f;
  t83_n47: return 0.1130182221531868f;
  t83_n48: return 0.09775012731552124f;
  t83_n49: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t83_n51;
  t83_n50: return 0.1029408723115921f;
  t83_n51: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t83_n55;
  t83_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t83_n54;
  t83_n53: return 0.017561836168169975f;
  t83_n54: return 0.10333742946386337f;
  t83_n55: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t83_n57;
  t83_n56: return 0.10551965236663818f;
  t83_n57: return 0.05784045532345772f;
  t83_n58: return 0.06816952675580978f;
  t83_n59: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t83_n61;
  t83_n60: return -0.03316879644989967f;
  t83_n61: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t83_n63;
  t83_n62: return -0.006083586718887091f;
  t83_n63: if (E.getNumReferences() >= 3299295232 /*1338.0*/) goto t83_n151;
  t83_n64: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t83_n100;
  t83_n65: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t83_n91;
  t83_n66: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t83_n68;
  t83_n67: return 0.001484749955125153f;
  t83_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t83_n72;
  t83_n69: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t83_n71;
  t83_n70: return 0.027355976402759552f;
  t83_n71: return 0.13347220420837402f;
  t83_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t83_n76;
  t83_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t83_n75;
  t83_n74: return -0.08022787421941757f;
  t83_n75: return 0.14234286546707153f;
  t83_n76: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t83_n90;
  t83_n77: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t83_n79;
  t83_n78: return 0.06132744997739792f;
  t83_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t83_n81;
  t83_n80: return 0.028782865032553673f;
  t83_n81: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t83_n87;
  t83_n82: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t83_n84;
  t83_n83: return -0.10004149377346039f;
  t83_n84: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t83_n86;
  t83_n85: return 0.1365996152162552f;
  t83_n86: return 0.14797350764274597f;
  t83_n87: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t83_n89;
  t83_n88: return 0.04807942360639572f;
  t83_n89: return 0.12224933505058289f;
  t83_n90: return -0.11934079229831696f;
  t83_n91: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t83_n99;
  t83_n92: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t83_n98;
  t83_n93: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t83_n95;
  t83_n94: return 0.05232779681682587f;
  t83_n95: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t83_n97;
  t83_n96: return 0.10125166177749634f;
  t83_n97: return 0.07975462824106216f;
  t83_n98: return -0.0029069846495985985f;
  t83_n99: return -0.012662793509662151f;
  t83_n100: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t83_n118;
  t83_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t83_n103;
  t83_n102: return 0.05221688002347946f;
  t83_n103: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t83_n115;
  t83_n104: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t83_n106;
  t83_n105: return 0.07716834545135498f;
  t83_n106: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t83_n114;
  t83_n107: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t83_n113;
  t83_n108: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t83_n110;
  t83_n109: return 0.10285953432321548f;
  t83_n110: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t83_n112;
  t83_n111: return 0.12145843356847763f;
  t83_n112: return 0.09967140853404999f;
  t83_n113: return 0.0311103668063879f;
  t83_n114: return 0.06928569823503494f;
  t83_n115: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t83_n117;
  t83_n116: return 0.1007390022277832f;
  t83_n117: return 0.10795661807060242f;
  t83_n118: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t83_n120;
  t83_n119: return -0.0664248913526535f;
  t83_n120: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t83_n130;
  t83_n121: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t83_n123;
  t83_n122: return 0.11828433722257614f;
  t83_n123: if (E.getNumReferences() >= 3287203840 /*477.5*/) goto t83_n125;
  t83_n124: return 0.08903247117996216f;
  t83_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t83_n129;
  t83_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t83_n128;
  t83_n127: return 0.0721789300441742f;
  t83_n128: return 0.12546072900295258f;
  t83_n129: return 0.13028088212013245f;
  t83_n130: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t83_n138;
  t83_n131: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t83_n133;
  t83_n132: return 0.025409357622265816f;
  t83_n133: if (E.getNumReferences() >= 3297042432 /*1063.0*/) goto t83_n135;
  t83_n134: return 0.04461882263422012f;
  t83_n135: if (E.getNumReferences() >= 3297943552 /*1173.0*/) goto t83_n137;
  t83_n136: return 0.10247526317834854f;
  t83_n137: return 0.11451691389083862f;
  t83_n138: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t83_n146;
  t83_n139: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t83_n145;
  t83_n140: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t83_n144;
  t83_n141: if (E.getNumReferences() >= 3264348160 /*73.0*/) goto t83_n143;
  t83_n142: return -0.10033196955919266f;
  t83_n143: return 0.14036323130130768f;
  t83_n144: return 0.14327941834926605f;
  t83_n145: return 0.0893532782793045f;
  t83_n146: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t83_n150;
  t83_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t83_n149;
  t83_n148: return -0.08475448936223984f;
  t83_n149: return 0.11880559474229813f;
  t83_n150: return 0.07555035501718521f;
  t83_n151: if (E.getNumReferences() >= 3355687776 /*134893.5*/) goto t83_n193;
  t83_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t83_n154;
  t83_n153: return -0.012040579691529274f;
  t83_n154: if (E.getNumReferences() >= 3299307520 /*1339.5*/) goto t83_n156;
  t83_n155: return 0.11503124982118607f;
  t83_n156: if (E.getNumReferences() >= 3316608000 /*5613.5*/) goto t83_n158;
  t83_n157: return 0.042888931930065155f;
  t83_n158: if (E.getNumReferences() >= 3327202816 /*13381.5*/) goto t83_n192;
  t83_n159: if (E.getNumReferences() >= 3320417280 /*7473.5*/) goto t83_n165;
  t83_n160: if (E.getNumReferences() >= 3316660224 /*5639.0*/) goto t83_n164;
  t83_n161: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t83_n163;
  t83_n162: return 0.10875387489795685f;
  t83_n163: return 0.1982704997062683f;
  t83_n164: return 0.05240587517619133f;
  t83_n165: if (E.getNumReferences() >= 3322356224 /*8648.5*/) goto t83_n177;
  t83_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t83_n176;
  t83_n167: if (E.getNumReferences() >= 3321306112 /*7907.5*/) goto t83_n169;
  t83_n168: return 0.08589472621679306f;
  t83_n169: if (E.getNumReferences() >= 3321602048 /*8052.0*/) goto t83_n171;
  t83_n170: return 0.12749911844730377f;
  t83_n171: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t83_n173;
  t83_n172: return 0.0954146608710289f;
  t83_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t83_n175;
  t83_n174: return 0.09295118600130081f;
  t83_n175: return 0.1161971315741539f;
  t83_n176: return 0.11862608045339584f;
  t83_n177: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t83_n183;
  t83_n178: if (E.getNumReferences() >= 3326796288 /*12984.5*/) goto t83_n180;
  t83_n179: return 0.04924769699573517f;
  t83_n180: if (E.getNumReferences() >= 3326878720 /*13065.0*/) goto t83_n182;
  t83_n181: return 0.11431295424699783f;
  t83_n182: return 0.07848555594682693f;
  t83_n183: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t83_n185;
  t83_n184: return 0.0758550688624382f;
  t83_n185: if (E.getNumReferences() >= 3324699136 /*10936.5*/) goto t83_n187;
  t83_n186: return 0.09861699491739273f;
  t83_n187: if (E.getNumReferences() >= 3325492736 /*11711.5*/) goto t83_n191;
  t83_n188: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t83_n190;
  t83_n189: return 0.11090420186519623f;
  t83_n190: return 0.09686630219221115f;
  t83_n191: return 0.07055792957544327f;
  t83_n192: return 0.03483198210597038f;
  t83_n193: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t83_n195;
  t83_n194: return -1.0459266901016235f;
  t83_n195: return -0.03309917077422142f;
  t83_n196: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t83_n236;
  t83_n197: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t83_n233;
  t83_n198: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t83_n232;
  t83_n199: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t83_n229;
  t83_n200: if (E.getNumReferences() >= 3334339584 /*24318.0*/) goto t83_n220;
  t83_n201: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t83_n213;
  t83_n202: if (E.getNumReferences() >= 3295674368 /*960.0*/) goto t83_n210;
  t83_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t83_n205;
  t83_n204: return -0.03738189861178398f;
  t83_n205: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t83_n207;
  t83_n206: return 0.053538139909505844f;
  t83_n207: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t83_n209;
  t83_n208: return 0.08568163216114044f;
  t83_n209: return 0.11837257444858551f;
  t83_n210: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t83_n212;
  t83_n211: return 0.10287932306528091f;
  t83_n212: return -0.08127401769161224f;
  t83_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t83_n219;
  t83_n214: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t83_n216;
  t83_n215: return -0.21586070954799652f;
  t83_n216: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t83_n218;
  t83_n217: return 0.12401336431503296f;
  t83_n218: return 0.02951006591320038f;
  t83_n219: return -0.08082114160060883f;
  t83_n220: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t83_n226;
  t83_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t83_n223;
  t83_n222: return 0.07701389491558075f;
  t83_n223: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t83_n225;
  t83_n224: return 0.017160529270768166f;
  t83_n225: return 0.11642176657915115f;
  t83_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t83_n228;
  t83_n227: return -0.004902319051325321f;
  t83_n228: return 0.10159864276647568f;
  t83_n229: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t83_n231;
  t83_n230: return -0.08448465913534164f;
  t83_n231: return -0.004745012149214745f;
  t83_n232: return 0.0052828602492809296f;
  t83_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t83_n235;
  t83_n234: return -0.021253082901239395f;
  t83_n235: return 0.10316027700901031f;
  t83_n236: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t83_n242;
  t83_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol))) goto t83_n241;
  t83_n238: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t83_n240;
  t83_n239: return 0.01767251268029213f;
  t83_n240: return -0.007127881515771151f;
  t83_n241: return 0.017696114256978035f;
  t83_n242: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t83_n254;
  t83_n243: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t83_n245;
  t83_n244: return -0.02462395653128624f;
  t83_n245: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t83_n247;
  t83_n246: return 0.0014464674750342965f;
  t83_n247: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t83_n251;
  t83_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t83_n250;
  t83_n249: return -0.12482620775699615f;
  t83_n250: return 0.12040341645479202f;
  t83_n251: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t83_n253;
  t83_n252: return -0.0918249785900116f;
  t83_n253: return 0.23776139318943024f;
  t83_n254: return 0.017733745276927948f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree84(const Example& E) {
  t84_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t84_n98;
  t84_n1: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t84_n9;
  t84_n2: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t84_n4;
  t84_n3: return -0.009383740834891796f;
  t84_n4: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t84_n6;
  t84_n5: return 0.008689966052770615f;
  t84_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t84_n8;
  t84_n7: return -0.030240662395954132f;
  t84_n8: return 0.02819407917559147f;
  t84_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t84_n15;
  t84_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t84_n14;
  t84_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t84_n13;
  t84_n12: return 0.018327239900827408f;
  t84_n13: return 0.04681963101029396f;
  t84_n14: return -0.006251648999750614f;
  t84_n15: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t84_n91;
  t84_n16: if (E.getNumReferences() >= 3359435680 /*193454.5*/) goto t84_n80;
  t84_n17: if (E.getNumReferences() >= 3358365376 /*176731.0*/) goto t84_n79;
  t84_n18: if (E.getNumReferences() >= 3358250528 /*174936.5*/) goto t84_n74;
  t84_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t84_n35;
  t84_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t84_n24;
  t84_n21: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t84_n23;
  t84_n22: return -0.006807259749621153f;
  t84_n23: return -0.09474243968725204f;
  t84_n24: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t84_n26;
  t84_n25: return 0.024136044085025787f;
  t84_n26: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t84_n28;
  t84_n27: return 0.0030552095267921686f;
  t84_n28: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t84_n30;
  t84_n29: return 0.09613671153783798f;
  t84_n30: if (E.getNumReferences() >= 3341641728 /*44392.0*/) goto t84_n34;
  t84_n31: if (E.getNumReferences() >= 3338617856 /*32674.0*/) goto t84_n33;
  t84_n32: return -0.16813907027244568f;
  t84_n33: return 0.09304960072040558f;
  t84_n34: return 0.027543196454644203f;
  t84_n35: if (E.getNumReferences() >= 3327105024 /*13286.0*/) goto t84_n51;
  t84_n36: if (E.getNumReferences() >= 3327053312 /*13235.5*/) goto t84_n48;
  t84_n37: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t84_n47;
  t84_n38: if (E.getNumReferences() >= 3326734336 /*12924.0*/) goto t84_n40;
  t84_n39: return 0.10856101661920547f;
  t84_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t84_n42;
  t84_n41: return 0.08216260373592377f;
  t84_n42: if (E.getNumReferences() >= 3327008768 /*13192.0*/) goto t84_n46;
  t84_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t84_n45;
  t84_n44: return 0.10485021024942398f;
  t84_n45: return 0.11518270522356033f;
  t84_n46: return -0.28609707951545715f;
  t84_n47: return 0.051534153521060944f;
  t84_n48: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t84_n50;
  t84_n49: return 0.12363641709089279f;
  t84_n50: return 0.07794139534235f;
  t84_n51: if (E.getNumReferences() >= 3334350336 /*24339.0*/) goto t84_n73;
  t84_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t84_n54;
  t84_n53: return 0.04212542623281479f;
  t84_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion))) goto t84_n56;
  t84_n55: return 0.06196891888976097f;
  t84_n56: if (E.getNumReferences() >= 3331378176 /*18534.0*/) goto t84_n66;
  t84_n57: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t84_n63;
  t84_n58: if (E.getNumReferences() >= 3329585664 /*15708.5*/) goto t84_n60;
  t84_n59: return 0.007343273144215345f;
  t84_n60: if (E.getNumReferences() >= 3330116608 /*16227.0*/) goto t84_n62;
  t84_n61: return 0.11493513733148575f;
  t84_n62: return -0.13028055429458618f;
  t84_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t84_n65;
  t84_n64: return 0.04679002985358238f;
  t84_n65: return 0.11379911005496979f;
  t84_n66: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t84_n70;
  t84_n67: if (E.getNumReferences() >= 3331808000 /*19373.5*/) goto t84_n69;
  t84_n68: return 0.28200554847717285f;
  t84_n69: return 0.11039309948682785f;
  t84_n70: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t84_n72;
  t84_n71: return 0.10866213589906693f;
  t84_n72: return 0.023726141080260277f;
  t84_n73: return 0.015632594004273415f;
  t84_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t84_n76;
  t84_n75: return -0.201684832572937f;
  t84_n76: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t84_n78;
  t84_n77: return 0.1230851262807846f;
  t84_n78: return 0.04872918501496315f;
  t84_n79: return -0.10569055378437042f;
  t84_n80: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t84_n86;
  t84_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t84_n83;
  t84_n82: return 0.07845914363861084f;
  t84_n83: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t84_n85;
  t84_n84: return 0.10145487636327744f;
  t84_n85: return 0.08450423181056976f;
  t84_n86: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t84_n88;
  t84_n87: return -0.3567558825016022f;
  t84_n88: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t84_n90;
  t84_n89: return 0.06937139481306076f;
  t84_n90: return 0.07335144281387329f;
  t84_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t84_n95;
  t84_n92: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t84_n94;
  t84_n93: return -0.08655750006437302f;
  t84_n94: return -0.46008795499801636f;
  t84_n95: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t84_n97;
  t84_n96: return -0.044042449444532394f;
  t84_n97: return 0.015986865386366844f;
  t84_n98: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t84_n250;
  t84_n99: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t84_n227;
  t84_n100: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t84_n224;
  t84_n101: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t84_n157;
  t84_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t84_n128;
  t84_n103: if (E.getNumReferences() >= 3298205696 /*1205.0*/) goto t84_n127;
  t84_n104: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t84_n120;
  t84_n105: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t84_n119;
  t84_n106: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t84_n116;
  t84_n107: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t84_n115;
  t84_n108: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t84_n110;
  t84_n109: return -0.11069086939096451f;
  t84_n110: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t84_n112;
  t84_n111: return -0.11851025372743607f;
  t84_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t84_n114;
  t84_n113: return -0.06212635710835457f;
  t84_n114: return 0.05814635753631592f;
  t84_n115: return -0.1942962408065796f;
  t84_n116: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t84_n118;
  t84_n117: return 0.11501388996839523f;
  t84_n118: return 0.057540904730558395f;
  t84_n119: return 0.08777084201574326f;
  t84_n120: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t84_n122;
  t84_n121: return 0.0057294913567602634f;
  t84_n122: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t84_n126;
  t84_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t84_n125;
  t84_n124: return -0.1584426611661911f;
  t84_n125: return -0.05909976735711098f;
  t84_n126: return -0.11157297343015671f;
  t84_n127: return 0.10407000035047531f;
  t84_n128: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t84_n152;
  t84_n129: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t84_n135;
  t84_n130: if (E.getNumReferences() >= 3296526336 /*1012.0*/) goto t84_n132;
  t84_n131: return -0.05854639410972595f;
  t84_n132: if (E.getNumReferences() >= 3298254848 /*1211.0*/) goto t84_n134;
  t84_n133: return 0.09093716740608215f;
  t84_n134: return -0.015593823045492172f;
  t84_n135: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t84_n137;
  t84_n136: return -0.010137274861335754f;
  t84_n137: if (E.getNumReferences() >= 3264086016 /*71.0*/) goto t84_n151;
  t84_n138: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t84_n150;
  t84_n139: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t84_n141;
  t84_n140: return 0.026409391313791275f;
  t84_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t84_n143;
  t84_n142: return -0.025919266045093536f;
  t84_n143: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t84_n149;
  t84_n144: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t84_n146;
  t84_n145: return 0.13025374710559845f;
  t84_n146: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t84_n148;
  t84_n147: return -0.060143545269966125f;
  t84_n148: return 0.10721609741449356f;
  t84_n149: return 0.13769814372062683f;
  t84_n150: return 0.12292664498090744f;
  t84_n151: return -0.06571249663829803f;
  t84_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t84_n156;
  t84_n153: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function))) goto t84_n155;
  t84_n154: return -0.020671159029006958f;
  t84_n155: return 0.036052439361810684f;
  t84_n156: return -0.015702322125434875f;
  t84_n157: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t84_n159;
  t84_n158: return 0.007516422308981419f;
  t84_n159: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t84_n217;
  t84_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t84_n166;
  t84_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t84_n165;
  t84_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t84_n164;
  t84_n163: return -0.09655643999576569f;
  t84_n164: return -0.11684924364089966f;
  t84_n165: return -0.022714626044034958f;
  t84_n166: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t84_n190;
  t84_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t84_n173;
  t84_n168: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t84_n172;
  t84_n169: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t84_n171;
  t84_n170: return -0.03374127298593521f;
  t84_n171: return -0.01356183085590601f;
  t84_n172: return 0.009083997458219528f;
  t84_n173: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t84_n181;
  t84_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t84_n176;
  t84_n175: return -0.006602647714316845f;
  t84_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t84_n178;
  t84_n177: return -0.11662982404232025f;
  t84_n178: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t84_n180;
  t84_n179: return 0.09708821773529053f;
  t84_n180: return -0.027854278683662415f;
  t84_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t84_n185;
  t84_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t84_n184;
  t84_n183: return -0.09550648927688599f;
  t84_n184: return 0.004520157352089882f;
  t84_n185: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t84_n189;
  t84_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t84_n188;
  t84_n187: return 0.030500654131174088f;
  t84_n188: return 0.027494490146636963f;
  t84_n189: return -0.11158162355422974f;
  t84_n190: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t84_n192;
  t84_n191: return 0.02695772796869278f;
  t84_n192: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t84_n216;
  t84_n193: if (E.getNumReferences() >= 3307921408 /*2734.0*/) goto t84_n213;
  t84_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t84_n196;
  t84_n195: return 0.032116666436195374f;
  t84_n196: if (E.getNumReferences() >= 3257008128 /*40.5*/) goto t84_n198;
  t84_n197: return 0.06865250319242477f;
  t84_n198: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t84_n212;
  t84_n199: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t84_n211;
  t84_n200: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t84_n208;
  t84_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t84_n207;
  t84_n202: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t84_n204;
  t84_n203: return 0.10786628723144531f;
  t84_n204: if (E.getNumReferences() >= 3258974208 /*48.0*/) goto t84_n206;
  t84_n205: return 0.02510826289653778f;
  t84_n206: return 0.12145481258630753f;
  t84_n207: return 0.060176920145750046f;
  t84_n208: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t84_n210;
  t84_n209: return -0.17328450083732605f;
  t84_n210: return 0.12136198580265045f;
  t84_n211: return 0.14608028531074524f;
  t84_n212: return 0.0675099790096283f;
  t84_n213: if (E.getNumReferences() >= 3308165120 /*2793.5*/) goto t84_n215;
  t84_n214: return 0.11173368245363235f;
  t84_n215: return -0.030927347019314766f;
  t84_n216: return 0.006117547396570444f;
  t84_n217: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t84_n223;
  t84_n218: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t84_n220;
  t84_n219: return 0.019355997443199158f;
  t84_n220: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t84_n222;
  t84_n221: return 0.07845385372638702f;
  t84_n222: return 0.016595080494880676f;
  t84_n223: return -0.5566332340240479f;
  t84_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t84_n226;
  t84_n225: return 0.008615506812930107f;
  t84_n226: return 0.0234302319586277f;
  t84_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t84_n229;
  t84_n228: return -0.005631088744848967f;
  t84_n229: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t84_n249;
  t84_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t84_n232;
  t84_n231: return 0.027154888957738876f;
  t84_n232: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t84_n244;
  t84_n233: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t84_n235;
  t84_n234: return -0.015141594223678112f;
  t84_n235: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t84_n243;
  t84_n236: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t84_n242;
  t84_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t84_n239;
  t84_n238: return -0.021443016827106476f;
  t84_n239: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t84_n241;
  t84_n240: return 0.06603620201349258f;
  t84_n241: return 0.025172824040055275f;
  t84_n242: return 0.03792133182287216f;
  t84_n243: return 0.008086701855063438f;
  t84_n244: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t84_n246;
  t84_n245: return -0.10062400251626968f;
  t84_n246: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t84_n248;
  t84_n247: return 0.02066684141755104f;
  t84_n248: return 0.0896696075797081f;
  t84_n249: return 0.015345647931098938f;
  t84_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t84_n254;
  t84_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t84_n253;
  t84_n252: return -0.05204370617866516f;
  t84_n253: return -0.0004056215693708509f;
  t84_n254: return 0.09905215352773666f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree85(const Example& E) {
  t85_n0: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t85_n180;
  t85_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t85_n103;
  t85_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t85_n66;
  t85_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t85_n9;
  t85_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t85_n6;
  t85_n5: return -0.015542824752628803f;
  t85_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t85_n8;
  t85_n7: return -0.07604283839464188f;
  t85_n8: return -0.021360863000154495f;
  t85_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t85_n17;
  t85_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t85_n12;
  t85_n11: return -0.017611874267458916f;
  t85_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t85_n14;
  t85_n13: return 0.00018556686700321734f;
  t85_n14: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t85_n16;
  t85_n15: return 0.006269518285989761f;
  t85_n16: return 0.014626646414399147f;
  t85_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t85_n19;
  t85_n18: return -0.09656775742769241f;
  t85_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t85_n55;
  t85_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t85_n34;
  t85_n21: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n25;
  t85_n22: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t85_n24;
  t85_n23: return -0.03614649921655655f;
  t85_n24: return 0.037311144173145294f;
  t85_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t85_n27;
  t85_n26: return -0.019942631945014f;
  t85_n27: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t85_n31;
  t85_n28: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t85_n30;
  t85_n29: return 0.05281674489378929f;
  t85_n30: return 0.003408469259738922f;
  t85_n31: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t85_n33;
  t85_n32: return 0.054175324738025665f;
  t85_n33: return -0.1320701688528061f;
  t85_n34: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t85_n52;
  t85_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t85_n37;
  t85_n36: return 0.02310745231807232f;
  t85_n37: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t85_n51;
  t85_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t85_n42;
  t85_n39: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n41;
  t85_n40: return 0.04897391051054001f;
  t85_n41: return 0.010466992855072021f;
  t85_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t85_n44;
  t85_n43: return 0.060808759182691574f;
  t85_n44: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t85_n46;
  t85_n45: return 0.06817863136529922f;
  t85_n46: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t85_n48;
  t85_n47: return 0.11968647688627243f;
  t85_n48: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n50;
  t85_n49: return 0.10182957351207733f;
  t85_n50: return 0.08944956213235855f;
  t85_n51: return 0.0032805593218654394f;
  t85_n52: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n54;
  t85_n53: return 0.07440938800573349f;
  t85_n54: return 0.027999527752399445f;
  t85_n55: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t85_n65;
  t85_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n64;
  t85_n57: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t85_n63;
  t85_n58: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t85_n60;
  t85_n59: return 0.11848317086696625f;
  t85_n60: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t85_n62;
  t85_n61: return 0.12606890499591827f;
  t85_n62: return 0.10898932069540024f;
  t85_n63: return 0.08283797651529312f;
  t85_n64: return 0.08835535496473312f;
  t85_n65: return -0.05761202052235603f;
  t85_n66: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t85_n102;
  t85_n67: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t85_n101;
  t85_n68: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t85_n100;
  t85_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t85_n99;
  t85_n70: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t85_n98;
  t85_n71: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t85_n97;
  t85_n72: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t85_n92;
  t85_n73: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t85_n75;
  t85_n74: return -5.609936488326639e-05f;
  t85_n75: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t85_n77;
  t85_n76: return 0.019254712387919426f;
  t85_n77: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t85_n81;
  t85_n78: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t85_n80;
  t85_n79: return 0.024164322763681412f;
  t85_n80: return -0.034485019743442535f;
  t85_n81: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t85_n83;
  t85_n82: return 0.038324348628520966f;
  t85_n83: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n91;
  t85_n84: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t85_n86;
  t85_n85: return 0.05150885134935379f;
  t85_n86: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t85_n90;
  t85_n87: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t85_n89;
  t85_n88: return 0.0875178873538971f;
  t85_n89: return -0.0593934990465641f;
  t85_n90: return 0.013491070829331875f;
  t85_n91: return 0.03078744374215603f;
  t85_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t85_n94;
  t85_n93: return -0.024977784603834152f;
  t85_n94: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t85_n96;
  t85_n95: return 0.0021273980382829905f;
  t85_n96: return 0.04817595332860947f;
  t85_n97: return 0.03112807869911194f;
  t85_n98: return -0.041530925780534744f;
  t85_n99: return 0.011040485464036465f;
  t85_n100: return -0.08357851952314377f;
  t85_n101: return -0.11404133588075638f;
  t85_n102: return -0.024975204840302467f;
  t85_n103: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t85_n111;
  t85_n104: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t85_n106;
  t85_n105: return -0.07177554816007614f;
  t85_n106: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t85_n108;
  t85_n107: return -0.13698218762874603f;
  t85_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t85_n110;
  t85_n109: return -0.21385513246059418f;
  t85_n110: return 0.11469583213329315f;
  t85_n111: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t85_n179;
  t85_n112: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t85_n178;
  t85_n113: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t85_n127;
  t85_n114: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t85_n116;
  t85_n115: return 0.00651297764852643f;
  t85_n116: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t85_n118;
  t85_n117: return 0.03376302495598793f;
  t85_n118: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t85_n120;
  t85_n119: return 0.11050157248973846f;
  t85_n120: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t85_n122;
  t85_n121: return -0.14729788899421692f;
  t85_n122: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t85_n124;
  t85_n123: return 0.0649547204375267f;
  t85_n124: if (E.getNumReferences() >= 3259498496 /*50.0*/) goto t85_n126;
  t85_n125: return 0.1279321312904358f;
  t85_n126: return -0.148782879114151f;
  t85_n127: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t85_n131;
  t85_n128: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t85_n130;
  t85_n129: return 0.04061449319124222f;
  t85_n130: return -0.002144545316696167f;
  t85_n131: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t85_n157;
  t85_n132: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t85_n134;
  t85_n133: return 0.004929039627313614f;
  t85_n134: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t85_n136;
  t85_n135: return 0.0645354688167572f;
  t85_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t85_n138;
  t85_n137: return -0.0791751891374588f;
  t85_n138: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t85_n140;
  t85_n139: return 0.08006951212882996f;
  t85_n140: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t85_n148;
  t85_n141: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n143;
  t85_n142: return -0.06731564551591873f;
  t85_n143: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t85_n147;
  t85_n144: if (E.getFilterLength() >= 3242196992 /*12.0*/) goto t85_n146;
  t85_n145: return 0.11082581430673599f;
  t85_n146: return 0.15652871131896973f;
  t85_n147: return 0.09919018298387527f;
  t85_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t85_n150;
  t85_n149: return -0.12512187659740448f;
  t85_n150: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t85_n154;
  t85_n151: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t85_n153;
  t85_n152: return 0.10832832008600235f;
  t85_n153: return -0.11848624050617218f;
  t85_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n156;
  t85_n155: return 0.1630907505750656f;
  t85_n156: return 0.1113179475069046f;
  t85_n157: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t85_n175;
  t85_n158: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t85_n160;
  t85_n159: return 0.06304684281349182f;
  t85_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t85_n162;
  t85_n161: return -0.0051230210810899734f;
  t85_n162: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t85_n168;
  t85_n163: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t85_n165;
  t85_n164: return -0.10022890567779541f;
  t85_n165: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t85_n167;
  t85_n166: return 0.1591312140226364f;
  t85_n167: return 0.12354361265897751f;
  t85_n168: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t85_n174;
  t85_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n171;
  t85_n170: return 0.11606702953577042f;
  t85_n171: if (E.getSymbolScopeDistance() >= 3229614080 /*4.0*/) goto t85_n173;
  t85_n172: return 0.16553561389446259f;
  t85_n173: return 0.11816012114286423f;
  t85_n174: return 0.07860857993364334f;
  t85_n175: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t85_n177;
  t85_n176: return 0.1464824676513672f;
  t85_n177: return -0.009175068698823452f;
  t85_n178: return 0.02731511741876602f;
  t85_n179: return -0.04696986451745033f;
  t85_n180: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t85_n232;
  t85_n181: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t85_n231;
  t85_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t85_n184;
  t85_n183: return 0.005967679433524609f;
  t85_n184: if (E.getNumReferences() >= 3317228544 /*5916.5*/) goto t85_n226;
  t85_n185: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t85_n223;
  t85_n186: if (E.getNumReferences() >= 3285057536 /*412.0*/) goto t85_n196;
  t85_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t85_n189;
  t85_n188: return 0.019475573673844337f;
  t85_n189: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t85_n191;
  t85_n190: return 0.06506606936454773f;
  t85_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t85_n195;
  t85_n192: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t85_n194;
  t85_n193: return 0.13125775754451752f;
  t85_n194: return 0.3566650152206421f;
  t85_n195: return 0.054847683757543564f;
  t85_n196: if (E.getNumReferences() >= 3288604672 /*528.5*/) goto t85_n216;
  t85_n197: if (E.getNumReferences() >= 3288506368 /*522.5*/) goto t85_n211;
  t85_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t85_n210;
  t85_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t85_n207;
  t85_n200: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t85_n206;
  t85_n201: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t85_n205;
  t85_n202: if (E.getNumReferences() >= 3287220224 /*478.0*/) goto t85_n204;
  t85_n203: return 0.09429962933063507f;
  t85_n204: return 0.12187453359365463f;
  t85_n205: return -0.30139365792274475f;
  t85_n206: return 0.06909742951393127f;
  t85_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n209;
  t85_n208: return 0.13080105185508728f;
  t85_n209: return -0.2311224341392517f;
  t85_n210: return 0.10969620943069458f;
  t85_n211: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t85_n213;
  t85_n212: return -0.11810654401779175f;
  t85_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t85_n215;
  t85_n214: return -0.1379636824131012f;
  t85_n215: return 0.17864273488521576f;
  t85_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t85_n218;
  t85_n217: return 0.03309042006731033f;
  t85_n218: if (E.getNumReferences() >= 3292446720 /*763.0*/) goto t85_n222;
  t85_n219: if (E.getNumReferences() >= 3291512832 /*706.0*/) goto t85_n221;
  t85_n220: return 0.059592969715595245f;
  t85_n221: return 0.1210116297006607f;
  t85_n222: return 0.07565879821777344f;
  t85_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t85_n225;
  t85_n224: return -0.0008300002082251012f;
  t85_n225: return 0.024334469810128212f;
  t85_n226: if (E.getNumReferences() >= 3317296128 /*5949.5*/) goto t85_n230;
  t85_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t85_n229;
  t85_n228: return 0.062056198716163635f;
  t85_n229: return 0.1106129139661789f;
  t85_n230: return 0.04088205099105835f;
  t85_n231: return 0.0007354388944804668f;
  t85_n232: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t85_n246;
  t85_n233: if (E.getNumReferences() >= 3313614848 /*4152.0*/) goto t85_n243;
  t85_n234: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t85_n236;
  t85_n235: return -0.03341435641050339f;
  t85_n236: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t85_n238;
  t85_n237: return 0.04875978082418442f;
  t85_n238: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t85_n240;
  t85_n239: return 0.04381747171282768f;
  t85_n240: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t85_n242;
  t85_n241: return 0.04694843664765358f;
  t85_n242: return 0.09913903474807739f;
  t85_n243: if (E.getNumReferences() >= 3313630208 /*4159.5*/) goto t85_n245;
  t85_n244: return 0.11507496237754822f;
  t85_n245: return 0.03592969849705696f;
  t85_n246: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t85_n252;
  t85_n247: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t85_n249;
  t85_n248: return 0.03979099541902542f;
  t85_n249: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t85_n251;
  t85_n250: return 0.0696120336651802f;
  t85_n251: return 0.03876448795199394f;
  t85_n252: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t85_n254;
  t85_n253: return 0.12205598503351212f;
  t85_n254: return -0.16799412667751312f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree86(const Example& E) {
  t86_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t86_n222;
  t86_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t86_n33;
  t86_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t86_n32;
  t86_n3: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t86_n25;
  t86_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t86_n24;
  t86_n5: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t86_n11;
  t86_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t86_n8;
  t86_n7: return -0.014901822432875633f;
  t86_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t86_n10;
  t86_n9: return -0.03921071067452431f;
  t86_n10: return 0.06309624016284943f;
  t86_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t86_n13;
  t86_n12: return -0.004372728522866964f;
  t86_n13: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t86_n17;
  t86_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t86_n16;
  t86_n15: return 0.05612543225288391f;
  t86_n16: return -0.04221540316939354f;
  t86_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n23;
  t86_n18: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t86_n22;
  t86_n19: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t86_n21;
  t86_n20: return 0.11984872817993164f;
  t86_n21: return 0.10750753432512283f;
  t86_n22: return 0.08492794632911682f;
  t86_n23: return 0.08461099863052368f;
  t86_n24: return 0.0026814586017280817f;
  t86_n25: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t86_n27;
  t86_n26: return 0.009963863529264927f;
  t86_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t86_n29;
  t86_n28: return 0.0257763359695673f;
  t86_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t86_n31;
  t86_n30: return -0.08343840390443802f;
  t86_n31: return 0.029688145965337753f;
  t86_n32: return -0.008136586286127567f;
  t86_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t86_n35;
  t86_n34: return -0.005581398960202932f;
  t86_n35: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t86_n81;
  t86_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t86_n56;
  t86_n37: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t86_n45;
  t86_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t86_n40;
  t86_n39: return 0.12495332956314087f;
  t86_n40: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t86_n42;
  t86_n41: return -0.07598315924406052f;
  t86_n42: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t86_n44;
  t86_n43: return 0.11774074286222458f;
  t86_n44: return 0.11347357928752899f;
  t86_n45: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n49;
  t86_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t86_n48;
  t86_n47: return -0.0026366624515503645f;
  t86_n48: return 0.046492259949445724f;
  t86_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t86_n51;
  t86_n50: return 0.041892506182193756f;
  t86_n51: if (E.getNumReferences() >= 3366869888 /*357084.0*/) goto t86_n53;
  t86_n52: return 0.03621353581547737f;
  t86_n53: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t86_n55;
  t86_n54: return 0.14077933132648468f;
  t86_n55: return 0.005459258332848549f;
  t86_n56: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t86_n60;
  t86_n57: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t86_n59;
  t86_n58: return -0.0655016154050827f;
  t86_n59: return 0.046225108206272125f;
  t86_n60: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t86_n72;
  t86_n61: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t86_n71;
  t86_n62: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t86_n68;
  t86_n63: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t86_n67;
  t86_n64: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t86_n66;
  t86_n65: return 0.10998072475194931f;
  t86_n66: return 0.07007722556591034f;
  t86_n67: return -0.1334874927997589f;
  t86_n68: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t86_n70;
  t86_n69: return 0.11380952596664429f;
  t86_n70: return 0.11952745914459229f;
  t86_n71: return 0.08088698238134384f;
  t86_n72: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t86_n80;
  t86_n73: if (E.getNumReferences() >= 3359238848 /*190379.0*/) goto t86_n79;
  t86_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t86_n76;
  t86_n75: return -0.10156150907278061f;
  t86_n76: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t86_n78;
  t86_n77: return 0.1060749739408493f;
  t86_n78: return 0.03898996114730835f;
  t86_n79: return 0.0032315836288034916f;
  t86_n80: return 0.06463178992271423f;
  t86_n81: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t86_n199;
  t86_n82: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t86_n136;
  t86_n83: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t86_n131;
  t86_n84: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t86_n112;
  t86_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t86_n99;
  t86_n86: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t86_n88;
  t86_n87: return 0.016658395528793335f;
  t86_n88: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t86_n94;
  t86_n89: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t86_n93;
  t86_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t86_n92;
  t86_n91: return -0.13075308501720428f;
  t86_n92: return 0.11736086010932922f;
  t86_n93: return -0.04811609536409378f;
  t86_n94: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t86_n96;
  t86_n95: return 0.7134833931922913f;
  t86_n96: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n98;
  t86_n97: return 0.13981030881404877f;
  t86_n98: return 0.18995285034179688f;
  t86_n99: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t86_n111;
  t86_n100: if (E.getNumReferences() >= 3350124096 /*89516.5*/) goto t86_n108;
  t86_n101: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t86_n103;
  t86_n102: return 0.046591538935899734f;
  t86_n103: if (E.getNumReferences() >= 3348896192 /*79923.5*/) goto t86_n107;
  t86_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t86_n106;
  t86_n105: return -0.22179043292999268f;
  t86_n106: return 0.13202279806137085f;
  t86_n107: return -0.05155754089355469f;
  t86_n108: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t86_n110;
  t86_n109: return 0.1233953982591629f;
  t86_n110: return 0.10910964012145996f;
  t86_n111: return 0.008303452283143997f;
  t86_n112: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t86_n116;
  t86_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t86_n115;
  t86_n114: return -0.06151549518108368f;
  t86_n115: return 0.1118842288851738f;
  t86_n116: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t86_n118;
  t86_n117: return -0.00945724081248045f;
  t86_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t86_n124;
  t86_n119: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t86_n121;
  t86_n120: return -0.028524456545710564f;
  t86_n121: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t86_n123;
  t86_n122: return -0.2677353620529175f;
  t86_n123: return 0.07398351281881332f;
  t86_n124: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t86_n130;
  t86_n125: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t86_n129;
  t86_n126: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t86_n128;
  t86_n127: return -0.07490992546081543f;
  t86_n128: return 0.09776517003774643f;
  t86_n129: return 0.07099756598472595f;
  t86_n130: return 0.015354830771684647f;
  t86_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t86_n135;
  t86_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t86_n134;
  t86_n133: return -0.022295678034424782f;
  t86_n134: return 0.03345656767487526f;
  t86_n135: return -0.18300673365592957f;
  t86_n136: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t86_n144;
  t86_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t86_n139;
  t86_n138: return -0.348863810300827f;
  t86_n139: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t86_n141;
  t86_n140: return 0.11525668948888779f;
  t86_n141: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n143;
  t86_n142: return 0.10738355666399002f;
  t86_n143: return -0.16689898073673248f;
  t86_n144: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t86_n196;
  t86_n145: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t86_n151;
  t86_n146: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t86_n148;
  t86_n147: return 0.003938344307243824f;
  t86_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t86_n150;
  t86_n149: return -0.03133254498243332f;
  t86_n150: return 0.10747141391038895f;
  t86_n151: if (E.getNumReferences() >= 3346880384 /*64855.5*/) goto t86_n155;
  t86_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t86_n154;
  t86_n153: return -0.21179643273353577f;
  t86_n154: return -0.033725619316101074f;
  t86_n155: if (E.getNumReferences() >= 3355504736 /*132033.5*/) goto t86_n171;
  t86_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t86_n158;
  t86_n157: return -0.02715246193110943f;
  t86_n158: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t86_n168;
  t86_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t86_n161;
  t86_n160: return -0.062438081949949265f;
  t86_n161: if (E.getNumReferences() >= 3349697792 /*86186.0*/) goto t86_n167;
  t86_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n164;
  t86_n163: return 0.008589815348386765f;
  t86_n164: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t86_n166;
  t86_n165: return 0.1095663458108902f;
  t86_n166: return 0.07346916198730469f;
  t86_n167: return 0.10189205408096313f;
  t86_n168: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t86_n170;
  t86_n169: return 0.05346772074699402f;
  t86_n170: return 0.11650291830301285f;
  t86_n171: if (E.getNumReferences() >= 3358250528 /*174936.5*/) goto t86_n177;
  t86_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t86_n174;
  t86_n173: return -2.070903778076172f;
  t86_n174: if (E.getNumReferences() >= 3357701696 /*166361.0*/) goto t86_n176;
  t86_n175: return -0.08307034522294998f;
  t86_n176: return -0.5219283103942871f;
  t86_n177: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t86_n189;
  t86_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t86_n180;
  t86_n179: return -0.03606041893362999f;
  t86_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t86_n182;
  t86_n181: return -0.06333442777395248f;
  t86_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t86_n184;
  t86_n183: return 0.04635797068476677f;
  t86_n184: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t86_n188;
  t86_n185: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t86_n187;
  t86_n186: return 0.11455372720956802f;
  t86_n187: return 0.06255797296762466f;
  t86_n188: return 0.07654829323291779f;
  t86_n189: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t86_n195;
  t86_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t86_n194;
  t86_n191: if (E.getNumReferences() >= 3364686096 /*288840.5*/) goto t86_n193;
  t86_n192: return -0.46236273646354675f;
  t86_n193: return -0.6314000487327576f;
  t86_n194: return -0.10784579813480377f;
  t86_n195: return 0.012188334949314594f;
  t86_n196: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t86_n198;
  t86_n197: return 0.005771809257566929f;
  t86_n198: return 0.06031012535095215f;
  t86_n199: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t86_n215;
  t86_n200: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t86_n214;
  t86_n201: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t86_n207;
  t86_n202: if (E.getNumReferences() >= 3353810176 /*118314.0*/) goto t86_n206;
  t86_n203: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n205;
  t86_n204: return 0.07712389528751373f;
  t86_n205: return 0.11336848139762878f;
  t86_n206: return -0.07334688305854797f;
  t86_n207: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t86_n213;
  t86_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t86_n212;
  t86_n209: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t86_n211;
  t86_n210: return 0.09264495968818665f;
  t86_n211: return 0.11788507550954819f;
  t86_n212: return 0.060460858047008514f;
  t86_n213: return 0.07946082949638367f;
  t86_n214: return -0.004051030147820711f;
  t86_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t86_n217;
  t86_n216: return -0.016884129494428635f;
  t86_n217: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t86_n219;
  t86_n218: return -0.12051382660865784f;
  t86_n219: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t86_n221;
  t86_n220: return 0.12943081557750702f;
  t86_n221: return 0.15910527110099792f;
  t86_n222: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n238;
  t86_n223: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t86_n233;
  t86_n224: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t86_n228;
  t86_n225: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t86_n227;
  t86_n226: return -0.14771823585033417f;
  t86_n227: return -0.09828212112188339f;
  t86_n228: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t86_n230;
  t86_n229: return 0.05361367389559746f;
  t86_n230: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t86_n232;
  t86_n231: return 0.12988892197608948f;
  t86_n232: return 0.08947324007749557f;
  t86_n233: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t86_n235;
  t86_n234: return 0.002482177224010229f;
  t86_n235: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t86_n237;
  t86_n236: return 0.05718285217881203f;
  t86_n237: return 0.009992234408855438f;
  t86_n238: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t86_n240;
  t86_n239: return 0.007579066790640354f;
  t86_n240: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t86_n252;
  t86_n241: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t86_n243;
  t86_n242: return -0.01450575701892376f;
  t86_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t86_n245;
  t86_n244: return 0.005504683591425419f;
  t86_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t86_n249;
  t86_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t86_n248;
  t86_n247: return -0.1195109561085701f;
  t86_n248: return 0.11849839985370636f;
  t86_n249: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t86_n251;
  t86_n250: return -0.09384829550981522f;
  t86_n251: return 0.15181852877140045f;
  t86_n252: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t86_n254;
  t86_n253: return 0.013866784051060677f;
  t86_n254: return 0.07809092104434967f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree87(const Example& E) {
  t87_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t87_n196;
  t87_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t87_n125;
  t87_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t87_n4;
  t87_n3: return -0.11628775298595428f;
  t87_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t87_n14;
  t87_n5: if (E.getFileProximityDistance() >= 3212836864 /*1.0*/) goto t87_n7;
  t87_n6: return 0.1057330071926117f;
  t87_n7: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t87_n9;
  t87_n8: return -0.008813121356070042f;
  t87_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other))) goto t87_n13;
  t87_n10: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t87_n12;
  t87_n11: return 0.0076848724856972694f;
  t87_n12: return -0.019063960760831833f;
  t87_n13: return 0.03308931365609169f;
  t87_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t87_n70;
  t87_n15: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t87_n65;
  t87_n16: if (E.getNumReferences() >= 3341062528 /*42129.5*/) goto t87_n64;
  t87_n17: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t87_n35;
  t87_n18: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t87_n22;
  t87_n19: if (E.getNumReferences() >= 3273195520 /*153.0*/) goto t87_n21;
  t87_n20: return -0.030490517616271973f;
  t87_n21: return 0.07135670632123947f;
  t87_n22: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t87_n28;
  t87_n23: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t87_n25;
  t87_n24: return -0.22776134312152863f;
  t87_n25: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t87_n27;
  t87_n26: return 0.08167427778244019f;
  t87_n27: return -0.08915475755929947f;
  t87_n28: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t87_n34;
  t87_n29: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t87_n31;
  t87_n30: return -0.09956569969654083f;
  t87_n31: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t87_n33;
  t87_n32: return 0.11937577277421951f;
  t87_n33: return 0.019082440063357353f;
  t87_n34: return 0.028979215770959854f;
  t87_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t87_n47;
  t87_n36: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t87_n38;
  t87_n37: return -0.01118216197937727f;
  t87_n38: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t87_n46;
  t87_n39: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t87_n43;
  t87_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n42;
  t87_n41: return 0.09292887896299362f;
  t87_n42: return 0.019500430673360825f;
  t87_n43: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t87_n45;
  t87_n44: return 0.13720329105854034f;
  t87_n45: return 0.05126666650176048f;
  t87_n46: return 0.003968892153352499f;
  t87_n47: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t87_n53;
  t87_n48: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t87_n50;
  t87_n49: return 0.03480007126927376f;
  t87_n50: if (E.getNumReferences() >= 3292602368 /*772.5*/) goto t87_n52;
  t87_n51: return 0.11955268681049347f;
  t87_n52: return 0.044035524129867554f;
  t87_n53: if (E.getNumReferences() >= 3324791296 /*11026.5*/) goto t87_n55;
  t87_n54: return 0.007562835235148668f;
  t87_n55: if (E.getNumReferences() >= 3326378496 /*12576.5*/) goto t87_n57;
  t87_n56: return 0.12028569728136063f;
  t87_n57: if (E.getNumReferences() >= 3329918464 /*16033.5*/) goto t87_n63;
  t87_n58: if (E.getNumReferences() >= 3329426944 /*15553.5*/) goto t87_n62;
  t87_n59: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t87_n61;
  t87_n60: return -0.0315476730465889f;
  t87_n61: return 0.10553552955389023f;
  t87_n62: return 0.10914351046085358f;
  t87_n63: return -0.051981035619974136f;
  t87_n64: return 0.09598565101623535f;
  t87_n65: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t87_n69;
  t87_n66: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n68;
  t87_n67: return -0.08942768722772598f;
  t87_n68: return -0.03278869763016701f;
  t87_n69: return 0.03731226921081543f;
  t87_n70: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t87_n124;
  t87_n71: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t87_n99;
  t87_n72: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t87_n76;
  t87_n73: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n75;
  t87_n74: return 0.010031315498054028f;
  t87_n75: return 0.043676409870386124f;
  t87_n76: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t87_n78;
  t87_n77: return -0.0016155883204191923f;
  t87_n78: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t87_n80;
  t87_n79: return 0.03199528157711029f;
  t87_n80: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t87_n92;
  t87_n81: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t87_n91;
  t87_n82: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t87_n86;
  t87_n83: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t87_n85;
  t87_n84: return 0.6076871752738953f;
  t87_n85: return 0.15731285512447357f;
  t87_n86: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t87_n88;
  t87_n87: return -0.17192815244197845f;
  t87_n88: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t87_n90;
  t87_n89: return 0.1389112025499344f;
  t87_n90: return -0.1223527044057846f;
  t87_n91: return 0.13791482150554657f;
  t87_n92: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t87_n98;
  t87_n93: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t87_n95;
  t87_n94: return 0.07837001234292984f;
  t87_n95: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t87_n97;
  t87_n96: return 0.12223285436630249f;
  t87_n97: return 0.2066696286201477f;
  t87_n98: return 0.09307120740413666f;
  t87_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t87_n111;
  t87_n100: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t87_n106;
  t87_n101: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t87_n105;
  t87_n102: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t87_n104;
  t87_n103: return -0.042409759014844894f;
  t87_n104: return -0.0023053751792758703f;
  t87_n105: return 0.0372106172144413f;
  t87_n106: if (E.getNumReferences() >= 3310428160 /*3346.0*/) goto t87_n108;
  t87_n107: return -0.19197282195091248f;
  t87_n108: if (E.getNumReferences() >= 3320318976 /*7425.5*/) goto t87_n110;
  t87_n109: return 0.11022191494703293f;
  t87_n110: return -0.4107034206390381f;
  t87_n111: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t87_n113;
  t87_n112: return -0.015368728898465633f;
  t87_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t87_n115;
  t87_n114: return -0.011141096241772175f;
  t87_n115: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t87_n123;
  t87_n116: if (E.getNumReferences() >= 3294732288 /*902.5*/) goto t87_n122;
  t87_n117: if (E.getNumReferences() >= 3294625792 /*896.0*/) goto t87_n121;
  t87_n118: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t87_n120;
  t87_n119: return 0.06533105671405792f;
  t87_n120: return -0.03829217329621315f;
  t87_n121: return 0.10123725235462189f;
  t87_n122: return -0.0644921138882637f;
  t87_n123: return -0.028211770579218864f;
  t87_n124: return 0.002810490084812045f;
  t87_n125: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n129;
  t87_n126: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t87_n128;
  t87_n127: return 0.01770184375345707f;
  t87_n128: return -0.046288687735795975f;
  t87_n129: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t87_n175;
  t87_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t87_n140;
  t87_n131: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t87_n139;
  t87_n132: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t87_n134;
  t87_n133: return 0.11155658960342407f;
  t87_n134: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t87_n136;
  t87_n135: return -0.06173698604106903f;
  t87_n136: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t87_n138;
  t87_n137: return 0.11639665812253952f;
  t87_n138: return 0.11226838827133179f;
  t87_n139: return 0.02394901029765606f;
  t87_n140: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t87_n152;
  t87_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t87_n143;
  t87_n142: return -0.034080829471349716f;
  t87_n143: if (E.getNumReferences() >= 3351141632 /*97466.0*/) goto t87_n145;
  t87_n144: return -0.2733260691165924f;
  t87_n145: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t87_n147;
  t87_n146: return 0.10914500802755356f;
  t87_n147: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t87_n149;
  t87_n148: return -0.018672971054911613f;
  t87_n149: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t87_n151;
  t87_n150: return 0.11269985884428024f;
  t87_n151: return 0.08672671020030975f;
  t87_n152: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t87_n166;
  t87_n153: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t87_n165;
  t87_n154: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t87_n160;
  t87_n155: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t87_n159;
  t87_n156: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t87_n158;
  t87_n157: return 0.10816220939159393f;
  t87_n158: return 0.0665724128484726f;
  t87_n159: return -0.1278628259897232f;
  t87_n160: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t87_n162;
  t87_n161: return 0.11802761256694794f;
  t87_n162: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t87_n164;
  t87_n163: return 0.11014766246080399f;
  t87_n164: return 0.09785891324281693f;
  t87_n165: return 0.08020705729722977f;
  t87_n166: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t87_n174;
  t87_n167: if (E.getNumReferences() >= 3359238848 /*190379.0*/) goto t87_n173;
  t87_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t87_n170;
  t87_n169: return -0.10151039063930511f;
  t87_n170: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t87_n172;
  t87_n171: return 0.10457836836576462f;
  t87_n172: return 0.03513401746749878f;
  t87_n173: return 0.0029950204771012068f;
  t87_n174: return 0.06180323660373688f;
  t87_n175: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t87_n177;
  t87_n176: return 0.013550016097724438f;
  t87_n177: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t87_n189;
  t87_n178: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t87_n188;
  t87_n179: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t87_n181;
  t87_n180: return 0.06772007793188095f;
  t87_n181: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t87_n187;
  t87_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t87_n184;
  t87_n183: return 0.08255258202552795f;
  t87_n184: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t87_n186;
  t87_n185: return 0.11635338515043259f;
  t87_n186: return 0.07400606572628021f;
  t87_n187: return 0.07563205808401108f;
  t87_n188: return -0.00704483687877655f;
  t87_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t87_n191;
  t87_n190: return -0.01489521935582161f;
  t87_n191: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t87_n193;
  t87_n192: return -0.11848245561122894f;
  t87_n193: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t87_n195;
  t87_n194: return 0.1270388960838318f;
  t87_n195: return 0.17390106618404388f;
  t87_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t87_n198;
  t87_n197: return -0.009208745323121548f;
  t87_n198: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t87_n248;
  t87_n199: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t87_n237;
  t87_n200: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t87_n228;
  t87_n201: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t87_n225;
  t87_n202: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t87_n222;
  t87_n203: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n205;
  t87_n204: return 0.05467723309993744f;
  t87_n205: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t87_n209;
  t87_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t87_n208;
  t87_n207: return -0.05254213511943817f;
  t87_n208: return 0.018022621050477028f;
  t87_n209: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t87_n221;
  t87_n210: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t87_n212;
  t87_n211: return -0.1325269341468811f;
  t87_n212: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t87_n214;
  t87_n213: return -0.03378302603960037f;
  t87_n214: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t87_n220;
  t87_n215: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t87_n217;
  t87_n216: return -0.09474018216133118f;
  t87_n217: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t87_n219;
  t87_n218: return 0.11489252001047134f;
  t87_n219: return -0.09392505139112473f;
  t87_n220: return 0.0020563064608722925f;
  t87_n221: return 0.01829403266310692f;
  t87_n222: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t87_n224;
  t87_n223: return 0.024965614080429077f;
  t87_n224: return 0.026654548943042755f;
  t87_n225: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t87_n227;
  t87_n226: return -0.017781270667910576f;
  t87_n227: return -0.20119620859622955f;
  t87_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t87_n232;
  t87_n229: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t87_n231;
  t87_n230: return -0.14481323957443237f;
  t87_n231: return 0.009740496054291725f;
  t87_n232: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n236;
  t87_n233: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t87_n235;
  t87_n234: return 0.0016646413132548332f;
  t87_n235: return 0.08628743141889572f;
  t87_n236: return 0.03244130685925484f;
  t87_n237: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t87_n241;
  t87_n238: if (E.getNumReferences() >= 3290382336 /*637.0*/) goto t87_n240;
  t87_n239: return 0.030123943462967873f;
  t87_n240: return -0.022763114422559738f;
  t87_n241: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t87_n243;
  t87_n242: return 0.11538082361221313f;
  t87_n243: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t87_n245;
  t87_n244: return 0.035427525639534f;
  t87_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n247;
  t87_n246: return 0.10907746106386185f;
  t87_n247: return 0.010225612670183182f;
  t87_n248: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t87_n254;
  t87_n249: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t87_n251;
  t87_n250: return -0.0002573787060100585f;
  t87_n251: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t87_n253;
  t87_n252: return 0.04091113060712814f;
  t87_n253: return 0.011085816659033298f;
  t87_n254: return -0.1339544802904129f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree88(const Example& E) {
  t88_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t88_n222;
  t88_n1: if (E.getNumReferences() >= 3305279488 /*2089.0*/) goto t88_n3;
  t88_n2: return -0.0019331062212586403f;
  t88_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t88_n9;
  t88_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t88_n8;
  t88_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t88_n7;
  t88_n6: return 0.013066159561276436f;
  t88_n7: return 0.036648016422986984f;
  t88_n8: return -0.004229486919939518f;
  t88_n9: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t88_n91;
  t88_n10: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t88_n20;
  t88_n11: if (E.getNumReferences() >= 3319614464 /*7081.5*/) goto t88_n19;
  t88_n12: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t88_n16;
  t88_n13: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t88_n15;
  t88_n14: return 0.016373395919799805f;
  t88_n15: return 0.03305162861943245f;
  t88_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t88_n18;
  t88_n17: return 0.11941665410995483f;
  t88_n18: return 0.10877404361963272f;
  t88_n19: return -0.23268960416316986f;
  t88_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t88_n44;
  t88_n21: if (E.getNumReferences() >= 3334111488 /*23872.5*/) goto t88_n35;
  t88_n22: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t88_n30;
  t88_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t88_n25;
  t88_n24: return 0.02682199329137802f;
  t88_n25: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t88_n27;
  t88_n26: return 0.0781576856970787f;
  t88_n27: if (E.getNumReferences() >= 3321802752 /*8150.0*/) goto t88_n29;
  t88_n28: return 0.12235121428966522f;
  t88_n29: return 0.09662851691246033f;
  t88_n30: if (E.getNumReferences() >= 3331599872 /*18967.0*/) goto t88_n32;
  t88_n31: return 0.02399316057562828f;
  t88_n32: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t88_n34;
  t88_n33: return 0.1149120032787323f;
  t88_n34: return 0.07038096338510513f;
  t88_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t88_n37;
  t88_n36: return 0.05915047600865364f;
  t88_n37: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n41;
  t88_n38: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t88_n40;
  t88_n39: return 0.07722964882850647f;
  t88_n40: return 0.10718347132205963f;
  t88_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t88_n43;
  t88_n42: return -0.0241363737732172f;
  t88_n43: return 0.11518587917089462f;
  t88_n44: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t88_n68;
  t88_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t88_n53;
  t88_n46: if (E.getNumReferences() >= 3319705600 /*7126.0*/) goto t88_n52;
  t88_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t88_n51;
  t88_n48: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t88_n50;
  t88_n49: return 0.11610724031925201f;
  t88_n50: return 0.11346647888422012f;
  t88_n51: return 0.09196876734495163f;
  t88_n52: return 0.037682611495256424f;
  t88_n53: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t88_n55;
  t88_n54: return 0.059955623000860214f;
  t88_n55: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t88_n61;
  t88_n56: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t88_n60;
  t88_n57: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n59;
  t88_n58: return -0.10862762480974197f;
  t88_n59: return 0.11845000088214874f;
  t88_n60: return 0.06913544237613678f;
  t88_n61: if (E.getNumReferences() >= 3319788544 /*7166.5*/) goto t88_n63;
  t88_n62: return 0.10987668484449387f;
  t88_n63: if (E.getNumReferences() >= 3322584576 /*8871.5*/) goto t88_n65;
  t88_n64: return -0.0625702366232872f;
  t88_n65: if (E.getNumReferences() >= 3322934784 /*9213.5*/) goto t88_n67;
  t88_n66: return 0.13229703903198242f;
  t88_n67: return 0.10043883323669434f;
  t88_n68: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t88_n86;
  t88_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t88_n83;
  t88_n70: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t88_n76;
  t88_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t88_n73;
  t88_n72: return 0.056730277836322784f;
  t88_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n75;
  t88_n74: return 0.13039585947990417f;
  t88_n75: return 0.12754791975021362f;
  t88_n76: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t88_n78;
  t88_n77: return 0.05046508088707924f;
  t88_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t88_n80;
  t88_n79: return 0.11771417409181595f;
  t88_n80: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t88_n82;
  t88_n81: return 0.1108623668551445f;
  t88_n82: return -0.10089197009801865f;
  t88_n83: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t88_n85;
  t88_n84: return 0.09522618353366852f;
  t88_n85: return 0.10524334758520126f;
  t88_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t88_n88;
  t88_n87: return 0.045019928365945816f;
  t88_n88: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t88_n90;
  t88_n89: return 0.11753499507904053f;
  t88_n90: return 0.05308033525943756f;
  t88_n91: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t88_n221;
  t88_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t88_n128;
  t88_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t88_n113;
  t88_n94: if (E.getNumReferences() >= 3369273984 /*432212.0*/) goto t88_n104;
  t88_n95: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t88_n101;
  t88_n96: if (E.getNumReferences() >= 3335106048 /*25815.0*/) goto t88_n100;
  t88_n97: if (E.getNumReferences() >= 3334899200 /*25411.0*/) goto t88_n99;
  t88_n98: return -0.2342379093170166f;
  t88_n99: return -0.5293570160865784f;
  t88_n100: return -0.06391661614179611f;
  t88_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t88_n103;
  t88_n102: return 0.04596942290663719f;
  t88_n103: return 0.1093929186463356f;
  t88_n104: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t88_n110;
  t88_n105: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t88_n109;
  t88_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t88_n108;
  t88_n107: return -0.23768188059329987f;
  t88_n108: return 0.07575423270463943f;
  t88_n109: return -0.3871825337409973f;
  t88_n110: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t88_n112;
  t88_n111: return 0.021476713940501213f;
  t88_n112: return 0.10897155851125717f;
  t88_n113: if (E.getNumReferences() >= 3336214528 /*27980.0*/) goto t88_n115;
  t88_n114: return -0.13653625547885895f;
  t88_n115: if (E.getNumReferences() >= 3339846528 /*37379.5*/) goto t88_n127;
  t88_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t88_n122;
  t88_n117: if (E.getNumReferences() >= 3339141760 /*34626.5*/) goto t88_n119;
  t88_n118: return 0.032722488045692444f;
  t88_n119: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n121;
  t88_n120: return 0.11435133963823318f;
  t88_n121: return 0.027848633006215096f;
  t88_n122: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t88_n124;
  t88_n123: return -0.13918714225292206f;
  t88_n124: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t88_n126;
  t88_n125: return 0.10476019978523254f;
  t88_n126: return 0.10773727297782898f;
  t88_n127: return 0.007035726681351662f;
  t88_n128: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t88_n130;
  t88_n129: return -0.02428918145596981f;
  t88_n130: if (E.getNumReferences() >= 3338881664 /*33610.5*/) goto t88_n142;
  t88_n131: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t88_n135;
  t88_n132: if (E.getNumReferences() >= 3338727808 /*33009.5*/) goto t88_n134;
  t88_n133: return 0.10497194528579712f;
  t88_n134: return -0.1241740956902504f;
  t88_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t88_n139;
  t88_n136: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t88_n138;
  t88_n137: return 0.1099093034863472f;
  t88_n138: return 0.12273116409778595f;
  t88_n139: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t88_n141;
  t88_n140: return 0.11190260946750641f;
  t88_n141: return 0.1273903250694275f;
  t88_n142: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t88_n178;
  t88_n143: if (E.getNumReferences() >= 3341381632 /*43376.0*/) goto t88_n145;
  t88_n144: return -0.016191232949495316f;
  t88_n145: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t88_n159;
  t88_n146: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t88_n148;
  t88_n147: return 0.11207404732704163f;
  t88_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t88_n152;
  t88_n149: if (E.getNumReferences() >= 3341684224 /*44558.0*/) goto t88_n151;
  t88_n150: return 0.069486603140831f;
  t88_n151: return 0.11058168113231659f;
  t88_n152: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t88_n154;
  t88_n153: return 0.09273581206798553f;
  t88_n154: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t88_n158;
  t88_n155: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t88_n157;
  t88_n156: return 0.11125440150499344f;
  t88_n157: return 0.10440949350595474f;
  t88_n158: return 0.09163620322942734f;
  t88_n159: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t88_n173;
  t88_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t88_n166;
  t88_n161: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t88_n163;
  t88_n162: return -0.053489070385694504f;
  t88_n163: if (E.getNumReferences() >= 3342583296 /*48070.0*/) goto t88_n165;
  t88_n164: return 0.09598264843225479f;
  t88_n165: return -0.0037742946296930313f;
  t88_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t88_n168;
  t88_n167: return -0.28468555212020874f;
  t88_n168: if (E.getNumReferences() >= 3343171712 /*50368.5*/) goto t88_n170;
  t88_n169: return -0.11519620567560196f;
  t88_n170: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n172;
  t88_n171: return 0.10907400399446487f;
  t88_n172: return 0.10131342709064484f;
  t88_n173: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t88_n175;
  t88_n174: return -0.10549720376729965f;
  t88_n175: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t88_n177;
  t88_n176: return -0.12050549685955048f;
  t88_n177: return 0.12100321054458618f;
  t88_n178: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t88_n188;
  t88_n179: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t88_n181;
  t88_n180: return -0.010635670274496078f;
  t88_n181: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t88_n183;
  t88_n182: return 0.09564999490976334f;
  t88_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t88_n185;
  t88_n184: return -0.3434999883174896f;
  t88_n185: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n187;
  t88_n186: return -0.2591334879398346f;
  t88_n187: return 0.05697208270430565f;
  t88_n188: if (E.getNumReferences() >= 3345974912 /*61318.5*/) goto t88_n190;
  t88_n189: return 0.10973823815584183f;
  t88_n190: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t88_n216;
  t88_n191: if (E.getNumReferences() >= 3362054368 /*234371.5*/) goto t88_n213;
  t88_n192: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t88_n204;
  t88_n193: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t88_n203;
  t88_n194: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t88_n196;
  t88_n195: return -0.019143179059028625f;
  t88_n196: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t88_n200;
  t88_n197: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t88_n199;
  t88_n198: return 0.10705012828111649f;
  t88_n199: return 0.0575571171939373f;
  t88_n200: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t88_n202;
  t88_n201: return 0.11975093930959702f;
  t88_n202: return 0.10168440639972687f;
  t88_n203: return -0.07567106932401657f;
  t88_n204: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t88_n206;
  t88_n205: return 0.012577020563185215f;
  t88_n206: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t88_n208;
  t88_n207: return 0.07843604683876038f;
  t88_n208: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t88_n210;
  t88_n209: return 0.03099081665277481f;
  t88_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n212;
  t88_n211: return 0.11205422133207321f;
  t88_n212: return 0.1086130142211914f;
  t88_n213: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t88_n215;
  t88_n214: return -0.1367592066526413f;
  t88_n215: return 0.01713823899626732f;
  t88_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t88_n220;
  t88_n217: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t88_n219;
  t88_n218: return 0.11292009800672531f;
  t88_n219: return 0.011175904422998428f;
  t88_n220: return 0.06272812932729721f;
  t88_n221: return 0.08221212774515152f;
  t88_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t88_n224;
  t88_n223: return -0.008496902883052826f;
  t88_n224: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t88_n234;
  t88_n225: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t88_n227;
  t88_n226: return 0.012493439950048923f;
  t88_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t88_n231;
  t88_n228: if (E.getNumReferences() >= 3319676928 /*7112.0*/) goto t88_n230;
  t88_n229: return 0.07888499647378922f;
  t88_n230: return 0.033925026655197144f;
  t88_n231: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t88_n233;
  t88_n232: return 0.10946422070264816f;
  t88_n233: return -0.03800981491804123f;
  t88_n234: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t88_n254;
  t88_n235: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t88_n237;
  t88_n236: return 0.003587705083191395f;
  t88_n237: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t88_n253;
  t88_n238: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t88_n240;
  t88_n239: return 0.013412882573902607f;
  t88_n240: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t88_n252;
  t88_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t88_n243;
  t88_n242: return 0.02536408230662346f;
  t88_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t88_n251;
  t88_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t88_n250;
  t88_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t88_n247;
  t88_n246: return 0.14960120618343353f;
  t88_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t88_n249;
  t88_n248: return 0.10195866972208023f;
  t88_n249: return 0.10008913278579712f;
  t88_n250: return 0.10985641181468964f;
  t88_n251: return -0.014676832593977451f;
  t88_n252: return 0.04904639720916748f;
  t88_n253: return 0.012395542114973068f;
  t88_n254: return -0.1517466902732849f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree89(const Example& E) {
  t89_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t89_n234;
  t89_n1: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t89_n47;
  t89_n2: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t89_n12;
  t89_n3: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t89_n5;
  t89_n4: return -0.0013932842994108796f;
  t89_n5: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t89_n7;
  t89_n6: return 0.013302811421453953f;
  t89_n7: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t89_n9;
  t89_n8: return 0.032376479357481f;
  t89_n9: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t89_n11;
  t89_n10: return 0.04370465129613876f;
  t89_n11: return 0.0591544583439827f;
  t89_n12: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t89_n14;
  t89_n13: return -0.014443906955420971f;
  t89_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t89_n24;
  t89_n15: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t89_n17;
  t89_n16: return -0.0012911359081044793f;
  t89_n17: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t89_n23;
  t89_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t89_n20;
  t89_n19: return -0.10082975029945374f;
  t89_n20: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n22;
  t89_n21: return 0.11656443774700165f;
  t89_n22: return 0.10888804495334625f;
  t89_n23: return -0.21046681702136993f;
  t89_n24: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t89_n32;
  t89_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t89_n27;
  t89_n26: return -0.014010416343808174f;
  t89_n27: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n29;
  t89_n28: return 0.00863976962864399f;
  t89_n29: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t89_n31;
  t89_n30: return 0.0021820913534611464f;
  t89_n31: return 0.03534537926316261f;
  t89_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t89_n36;
  t89_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t89_n35;
  t89_n34: return 0.004169144667685032f;
  t89_n35: return 0.024154052138328552f;
  t89_n36: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t89_n46;
  t89_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n45;
  t89_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t89_n44;
  t89_n39: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t89_n41;
  t89_n40: return 0.11448563635349274f;
  t89_n41: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t89_n43;
  t89_n42: return 0.12266288697719574f;
  t89_n43: return 0.10746205598115921f;
  t89_n44: return 0.08609066158533096f;
  t89_n45: return 0.0832735076546669f;
  t89_n46: return -0.05329224839806557f;
  t89_n47: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t89_n63;
  t89_n48: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t89_n50;
  t89_n49: return -0.0103424321860075f;
  t89_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t89_n58;
  t89_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t89_n53;
  t89_n52: return 0.11376003175973892f;
  t89_n53: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t89_n57;
  t89_n54: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t89_n56;
  t89_n55: return 0.07986650615930557f;
  t89_n56: return -0.0852760449051857f;
  t89_n57: return 0.053016677498817444f;
  t89_n58: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t89_n60;
  t89_n59: return 0.10637388378381729f;
  t89_n60: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t89_n62;
  t89_n61: return 0.07459811121225357f;
  t89_n62: return -0.43355345726013184f;
  t89_n63: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t89_n195;
  t89_n64: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t89_n186;
  t89_n65: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t89_n173;
  t89_n66: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t89_n170;
  t89_n67: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t89_n141;
  t89_n68: if (E.getNumReferences() >= 3355504736 /*132033.5*/) goto t89_n136;
  t89_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t89_n105;
  t89_n70: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t89_n72;
  t89_n71: return 0.008188581094145775f;
  t89_n72: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t89_n80;
  t89_n73: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t89_n75;
  t89_n74: return -0.04972122237086296f;
  t89_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t89_n77;
  t89_n76: return 0.07616344094276428f;
  t89_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t89_n79;
  t89_n78: return 0.13423706591129303f;
  t89_n79: return 0.09807059168815613f;
  t89_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t89_n82;
  t89_n81: return 0.020908555015921593f;
  t89_n82: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t89_n94;
  t89_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t89_n85;
  t89_n84: return -0.14218737185001373f;
  t89_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t89_n91;
  t89_n86: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t89_n90;
  t89_n87: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t89_n89;
  t89_n88: return 0.10389479994773865f;
  t89_n89: return 0.11176566034555435f;
  t89_n90: return 0.08990396559238434f;
  t89_n91: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t89_n93;
  t89_n92: return 0.1028042733669281f;
  t89_n93: return 0.07266785204410553f;
  t89_n94: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t89_n96;
  t89_n95: return 0.01721895858645439f;
  t89_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t89_n98;
  t89_n97: return -0.15233644843101501f;
  t89_n98: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t89_n104;
  t89_n99: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t89_n103;
  t89_n100: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t89_n102;
  t89_n101: return 0.15126611292362213f;
  t89_n102: return 0.11078572273254395f;
  t89_n103: return 0.1379106342792511f;
  t89_n104: return 0.09415178000926971f;
  t89_n105: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t89_n107;
  t89_n106: return 0.11246531456708908f;
  t89_n107: if (E.getNumReferences() >= 3344616064 /*56010.5*/) goto t89_n109;
  t89_n108: return 0.011042041704058647f;
  t89_n109: if (E.getNumReferences() >= 3350198272 /*90096.0*/) goto t89_n131;
  t89_n110: if (E.getNumReferences() >= 3350105536 /*89371.5*/) goto t89_n128;
  t89_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t89_n113;
  t89_n112: return -0.041147999465465546f;
  t89_n113: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t89_n115;
  t89_n114: return 0.07656379789113998f;
  t89_n115: if (E.getNumReferences() >= 3348896192 /*79923.5*/) goto t89_n127;
  t89_n116: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t89_n126;
  t89_n117: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t89_n121;
  t89_n118: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t89_n120;
  t89_n119: return 0.11539280414581299f;
  t89_n120: return 0.12057202309370041f;
  t89_n121: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t89_n125;
  t89_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n124;
  t89_n123: return 0.07725638896226883f;
  t89_n124: return 0.10585633665323257f;
  t89_n125: return 0.14829492568969727f;
  t89_n126: return -0.4393380284309387f;
  t89_n127: return -0.02223432995378971f;
  t89_n128: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t89_n130;
  t89_n129: return 0.11816740036010742f;
  t89_n130: return 0.10554343461990356f;
  t89_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n133;
  t89_n132: return -0.025664135813713074f;
  t89_n133: if (E.getNumReferences() >= 3350665472 /*93746.0*/) goto t89_n135;
  t89_n134: return -0.3605574667453766f;
  t89_n135: return 0.09625992923974991f;
  t89_n136: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t89_n138;
  t89_n137: return -0.032794274389743805f;
  t89_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t89_n140;
  t89_n139: return -0.4087933599948883f;
  t89_n140: return -0.11341601610183716f;
  t89_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t89_n157;
  t89_n142: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t89_n144;
  t89_n143: return 0.011381156742572784f;
  t89_n144: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t89_n156;
  t89_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t89_n147;
  t89_n146: return -0.12228679656982422f;
  t89_n147: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t89_n149;
  t89_n148: return 0.12217558175325394f;
  t89_n149: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t89_n151;
  t89_n150: return 0.07143720984458923f;
  t89_n151: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t89_n153;
  t89_n152: return 0.05527637526392937f;
  t89_n153: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t89_n155;
  t89_n154: return 0.1143098920583725f;
  t89_n155: return 0.10860484838485718f;
  t89_n156: return 0.02283373475074768f;
  t89_n157: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t89_n163;
  t89_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t89_n160;
  t89_n159: return 0.016740091145038605f;
  t89_n160: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t89_n162;
  t89_n161: return 0.10408038645982742f;
  t89_n162: return 0.07885202765464783f;
  t89_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t89_n165;
  t89_n164: return -0.12119932472705841f;
  t89_n165: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t89_n167;
  t89_n166: return 0.08818630129098892f;
  t89_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t89_n169;
  t89_n168: return -0.09497532993555069f;
  t89_n169: return 0.06353402137756348f;
  t89_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t89_n172;
  t89_n171: return -0.04333725944161415f;
  t89_n172: return -0.18325291574001312f;
  t89_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t89_n175;
  t89_n174: return 0.031017020344734192f;
  t89_n175: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n177;
  t89_n176: return 0.05815437063574791f;
  t89_n177: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t89_n185;
  t89_n178: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t89_n184;
  t89_n179: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t89_n181;
  t89_n180: return 0.16016143560409546f;
  t89_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t89_n183;
  t89_n182: return 0.14304210245609283f;
  t89_n183: return 0.17072182893753052f;
  t89_n184: return -0.07953408360481262f;
  t89_n185: return -0.023030830547213554f;
  t89_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t89_n194;
  t89_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t89_n191;
  t89_n188: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t89_n190;
  t89_n189: return 0.04135977849364281f;
  t89_n190: return -0.06907347589731216f;
  t89_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t89_n193;
  t89_n192: return -0.17768962681293488f;
  t89_n193: return 0.034727275371551514f;
  t89_n194: return -0.24480852484703064f;
  t89_n195: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t89_n221;
  t89_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t89_n214;
  t89_n197: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t89_n203;
  t89_n198: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t89_n202;
  t89_n199: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t89_n201;
  t89_n200: return 0.09666161984205246f;
  t89_n201: return 0.021892733871936798f;
  t89_n202: return 0.07517735660076141f;
  t89_n203: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t89_n213;
  t89_n204: if (E.getNumReferences() >= 3338840960 /*33451.5*/) goto t89_n206;
  t89_n205: return -0.11908424645662308f;
  t89_n206: if (E.getNumReferences() >= 3338968320 /*33949.0*/) goto t89_n210;
  t89_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n209;
  t89_n208: return 0.1290256828069687f;
  t89_n209: return 0.15128837525844574f;
  t89_n210: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t89_n212;
  t89_n211: return -0.02609185129404068f;
  t89_n212: return 0.18150347471237183f;
  t89_n213: return 0.06184552237391472f;
  t89_n214: if (E.getNumReferences() >= 3338736000 /*33041.5*/) goto t89_n216;
  t89_n215: return 0.11677627265453339f;
  t89_n216: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t89_n220;
  t89_n217: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t89_n219;
  t89_n218: return 0.12260795384645462f;
  t89_n219: return -0.3108482360839844f;
  t89_n220: return 0.041516054421663284f;
  t89_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t89_n229;
  t89_n222: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t89_n226;
  t89_n223: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t89_n225;
  t89_n224: return 0.04237937182188034f;
  t89_n225: return 0.11047250777482986f;
  t89_n226: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t89_n228;
  t89_n227: return 0.08285442739725113f;
  t89_n228: return -0.03728536143898964f;
  t89_n229: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t89_n231;
  t89_n230: return -0.1029222160577774f;
  t89_n231: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t89_n233;
  t89_n232: return 0.10821566730737686f;
  t89_n233: return 0.024359581992030144f;
  t89_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t89_n236;
  t89_n235: return -0.008312092162668705f;
  t89_n236: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t89_n254;
  t89_n237: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t89_n249;
  t89_n238: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t89_n248;
  t89_n239: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t89_n243;
  t89_n240: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t89_n242;
  t89_n241: return 0.05020986497402191f;
  t89_n242: return -0.026255596429109573f;
  t89_n243: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t89_n245;
  t89_n244: return 0.024695435538887978f;
  t89_n245: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t89_n247;
  t89_n246: return -0.018348129466176033f;
  t89_n247: return -0.2151045948266983f;
  t89_n248: return 0.013299467973411083f;
  t89_n249: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t89_n251;
  t89_n250: return 0.02374059148132801f;
  t89_n251: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t89_n253;
  t89_n252: return 0.093622587621212f;
  t89_n253: return 0.031102754175662994f;
  t89_n254: return 0.005307594779878855f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree90(const Example& E) {
  t90_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t90_n144;
  t90_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t90_n85;
  t90_n2: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t90_n4;
  t90_n3: return -0.013580617494881153f;
  t90_n4: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t90_n66;
  t90_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t90_n7;
  t90_n6: return -0.059374257922172546f;
  t90_n7: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t90_n49;
  t90_n8: if (E.getNumReferences() >= 3290275840 /*630.5*/) goto t90_n10;
  t90_n9: return -0.035215526819229126f;
  t90_n10: if (E.getNumReferences() >= 3290652672 /*653.5*/) goto t90_n16;
  t90_n11: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t90_n15;
  t90_n12: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t90_n14;
  t90_n13: return 0.19147568941116333f;
  t90_n14: return -0.10127517580986023f;
  t90_n15: return 0.12894918024539948f;
  t90_n16: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t90_n18;
  t90_n17: return -0.012752394191920757f;
  t90_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t90_n42;
  t90_n19: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t90_n23;
  t90_n20: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t90_n22;
  t90_n21: return 0.11819326877593994f;
  t90_n22: return 0.09578695148229599f;
  t90_n23: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t90_n39;
  t90_n24: if (E.getNumReferences() >= 3335799808 /*27170.0*/) goto t90_n38;
  t90_n25: if (E.getNumReferences() >= 3313870848 /*4277.0*/) goto t90_n31;
  t90_n26: if (E.getNumReferences() >= 3291906048 /*730.0*/) goto t90_n30;
  t90_n27: if (E.getNumReferences() >= 3291078656 /*679.5*/) goto t90_n29;
  t90_n28: return 0.9211122393608093f;
  t90_n29: return 0.1883297562599182f;
  t90_n30: return 0.0985427126288414f;
  t90_n31: if (E.getNumReferences() >= 3317499904 /*6049.0*/) goto t90_n37;
  t90_n32: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t90_n36;
  t90_n33: if (E.getNumReferences() >= 3316636672 /*5627.5*/) goto t90_n35;
  t90_n34: return 0.12644195556640625f;
  t90_n35: return 0.1107402890920639f;
  t90_n36: return 0.18488024175167084f;
  t90_n37: return 0.10645310580730438f;
  t90_n38: return -0.002886181930080056f;
  t90_n39: if (E.getNumReferences() >= 3308324864 /*2832.5*/) goto t90_n41;
  t90_n40: return 0.11613450199365616f;
  t90_n41: return 0.09608709067106247f;
  t90_n42: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t90_n44;
  t90_n43: return -0.01831178367137909f;
  t90_n44: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t90_n48;
  t90_n45: if (E.getNumReferences() >= 3342540544 /*47903.0*/) goto t90_n47;
  t90_n46: return -0.1540508270263672f;
  t90_n47: return 0.14355674386024475f;
  t90_n48: return 0.059776149690151215f;
  t90_n49: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t90_n51;
  t90_n50: return 0.006201054435223341f;
  t90_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t90_n53;
  t90_n52: return -0.11050742864608765f;
  t90_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t90_n57;
  t90_n54: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t90_n56;
  t90_n55: return 0.05747659131884575f;
  t90_n56: return 0.008104918524622917f;
  t90_n57: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t90_n65;
  t90_n58: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t90_n64;
  t90_n59: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t90_n61;
  t90_n60: return 0.11586341261863708f;
  t90_n61: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t90_n63;
  t90_n62: return 0.11935010552406311f;
  t90_n63: return 0.09404871612787247f;
  t90_n64: return 0.08846642076969147f;
  t90_n65: return -0.04923927038908005f;
  t90_n66: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t90_n74;
  t90_n67: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t90_n73;
  t90_n68: if (E.getNumReferences() >= 3282698240 /*340.0*/) goto t90_n70;
  t90_n69: return -0.10822812467813492f;
  t90_n70: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t90_n72;
  t90_n71: return -0.056660041213035583f;
  t90_n72: return 0.09581486880779266f;
  t90_n73: return 0.012565921992063522f;
  t90_n74: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t90_n84;
  t90_n75: if (E.getNumReferences() >= 3309207552 /*3048.0*/) goto t90_n79;
  t90_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t90_n78;
  t90_n77: return -0.2446068376302719f;
  t90_n78: return -0.02512669749557972f;
  t90_n79: if (E.getNumReferences() >= 3315111936 /*4883.0*/) goto t90_n83;
  t90_n80: if (E.getNumReferences() >= 3312928768 /*3956.5*/) goto t90_n82;
  t90_n81: return 0.15614217519760132f;
  t90_n82: return 0.12262754887342453f;
  t90_n83: return 0.042528651654720306f;
  t90_n84: return 0.09625217318534851f;
  t90_n85: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t90_n143;
  t90_n86: if (E.getNumReferences() >= 3324968960 /*11200.0*/) goto t90_n116;
  t90_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t90_n113;
  t90_n88: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t90_n90;
  t90_n89: return 0.0040460205636918545f;
  t90_n90: if (E.getNumReferences() >= 3314489344 /*4579.0*/) goto t90_n112;
  t90_n91: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t90_n99;
  t90_n92: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t90_n94;
  t90_n93: return -0.04241906851530075f;
  t90_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t90_n96;
  t90_n95: return -0.011248396709561348f;
  t90_n96: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t90_n98;
  t90_n97: return 0.06944935768842697f;
  t90_n98: return 0.09185092151165009f;
  t90_n99: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t90_n111;
  t90_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t90_n104;
  t90_n101: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t90_n103;
  t90_n102: return 0.09248754382133484f;
  t90_n103: return -0.043285686522722244f;
  t90_n104: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t90_n110;
  t90_n105: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t90_n107;
  t90_n106: return 0.08801829814910889f;
  t90_n107: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t90_n109;
  t90_n108: return 0.016699358820915222f;
  t90_n109: return 0.0593419224023819f;
  t90_n110: return 0.01918037422001362f;
  t90_n111: return -0.11933251470327377f;
  t90_n112: return 0.10553932189941406f;
  t90_n113: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t90_n115;
  t90_n114: return 0.0230697114020586f;
  t90_n115: return 0.07310432940721512f;
  t90_n116: if (E.getNumReferences() >= 3325080064 /*11308.5*/) goto t90_n128;
  t90_n117: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t90_n123;
  t90_n118: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t90_n120;
  t90_n119: return 0.26612141728401184f;
  t90_n120: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t90_n122;
  t90_n121: return -0.014952074736356735f;
  t90_n122: return 0.17621654272079468f;
  t90_n123: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t90_n125;
  t90_n124: return 0.06439662724733353f;
  t90_n125: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t90_n127;
  t90_n126: return 0.14220748841762543f;
  t90_n127: return -0.15012559294700623f;
  t90_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t90_n130;
  t90_n129: return 0.01756623201072216f;
  t90_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t90_n134;
  t90_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t90_n133;
  t90_n132: return 0.019044263288378716f;
  t90_n133: return -0.11388136446475983f;
  t90_n134: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t90_n136;
  t90_n135: return 0.04712429642677307f;
  t90_n136: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t90_n138;
  t90_n137: return 0.06395644694566727f;
  t90_n138: if (E.getNumReferences() >= 3334014720 /*23683.5*/) goto t90_n142;
  t90_n139: if (E.getNumReferences() >= 3333541888 /*22760.0*/) goto t90_n141;
  t90_n140: return -0.1415024846792221f;
  t90_n141: return 0.1214585080742836f;
  t90_n142: return 0.08007388561964035f;
  t90_n143: return -0.004380796104669571f;
  t90_n144: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t90_n194;
  t90_n145: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t90_n191;
  t90_n146: if (E.getNumReferences() >= 3309051904 /*3010.0*/) goto t90_n188;
  t90_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t90_n183;
  t90_n148: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t90_n178;
  t90_n149: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t90_n167;
  t90_n150: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t90_n154;
  t90_n151: if (E.getNumReferences() >= 3290472448 /*642.5*/) goto t90_n153;
  t90_n152: return -0.027084017172455788f;
  t90_n153: return 0.10651377588510513f;
  t90_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t90_n160;
  t90_n155: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t90_n157;
  t90_n156: return -0.231122687458992f;
  t90_n157: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t90_n159;
  t90_n158: return 0.06391453742980957f;
  t90_n159: return -0.07855476438999176f;
  t90_n160: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t90_n166;
  t90_n161: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t90_n163;
  t90_n162: return -0.09007439017295837f;
  t90_n163: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t90_n165;
  t90_n164: return 0.1156340166926384f;
  t90_n165: return 0.017258236184716225f;
  t90_n166: return 0.024787049740552902f;
  t90_n167: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t90_n169;
  t90_n168: return -0.08947516232728958f;
  t90_n169: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t90_n177;
  t90_n170: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t90_n174;
  t90_n171: if (E.getNumReferences() >= 3274866688 /*178.5*/) goto t90_n173;
  t90_n172: return 0.03210261091589928f;
  t90_n173: return -0.1845853477716446f;
  t90_n174: if (E.getNumReferences() >= 3292962816 /*794.5*/) goto t90_n176;
  t90_n175: return 0.11707337200641632f;
  t90_n176: return 0.00515561830252409f;
  t90_n177: return 0.007754121441394091f;
  t90_n178: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t90_n180;
  t90_n179: return -0.05402359366416931f;
  t90_n180: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t90_n182;
  t90_n181: return 0.10104937106370926f;
  t90_n182: return 0.022429220378398895f;
  t90_n183: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t90_n185;
  t90_n184: return 0.004281580913811922f;
  t90_n185: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t90_n187;
  t90_n186: return -0.08631466329097748f;
  t90_n187: return -0.16351714730262756f;
  t90_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t90_n190;
  t90_n189: return 0.007555847521871328f;
  t90_n190: return 0.02082991413772106f;
  t90_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t90_n193;
  t90_n192: return -0.019192008301615715f;
  t90_n193: return 0.09920475631952286f;
  t90_n194: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t90_n242;
  t90_n195: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t90_n197;
  t90_n196: return 0.005613702815026045f;
  t90_n197: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t90_n235;
  t90_n198: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t90_n200;
  t90_n199: return 0.027857426553964615f;
  t90_n200: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t90_n232;
  t90_n201: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t90_n207;
  t90_n202: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t90_n204;
  t90_n203: return 0.06003290042281151f;
  t90_n204: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t90_n206;
  t90_n205: return 0.11324705928564072f;
  t90_n206: return 0.050521232187747955f;
  t90_n207: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t90_n209;
  t90_n208: return -0.12928232550621033f;
  t90_n209: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t90_n213;
  t90_n210: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t90_n212;
  t90_n211: return -0.306574285030365f;
  t90_n212: return 0.12535779178142548f;
  t90_n213: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t90_n221;
  t90_n214: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t90_n220;
  t90_n215: if (E.getNumReferences() >= 3283632128 /*368.5*/) goto t90_n217;
  t90_n216: return 0.05132370814681053f;
  t90_n217: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t90_n219;
  t90_n218: return 0.12759526073932648f;
  t90_n219: return 0.09645063430070877f;
  t90_n220: return -0.17243677377700806f;
  t90_n221: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t90_n231;
  t90_n222: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t90_n228;
  t90_n223: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t90_n225;
  t90_n224: return -0.3752436935901642f;
  t90_n225: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t90_n227;
  t90_n226: return 0.11670508235692978f;
  t90_n227: return 0.022201359272003174f;
  t90_n228: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t90_n230;
  t90_n229: return 0.05531039834022522f;
  t90_n230: return 0.12048698216676712f;
  t90_n231: return 0.12163485586643219f;
  t90_n232: if (E.getNumReferences() >= 3304148992 /*1930.5*/) goto t90_n234;
  t90_n233: return -0.039114974439144135f;
  t90_n234: return 0.10105887055397034f;
  t90_n235: if (E.getNumReferences() >= 3335803904 /*27178.0*/) goto t90_n241;
  t90_n236: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t90_n240;
  t90_n237: if (E.getNumReferences() >= 3273981952 /*165.0*/) goto t90_n239;
  t90_n238: return 0.047741279006004333f;
  t90_n239: return 0.1576385796070099f;
  t90_n240: return 0.014117667451500893f;
  t90_n241: return -0.11150164157152176f;
  t90_n242: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t90_n254;
  t90_n243: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t90_n245;
  t90_n244: return -0.013865823857486248f;
  t90_n245: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t90_n247;
  t90_n246: return 0.013182873837649822f;
  t90_n247: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t90_n251;
  t90_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t90_n250;
  t90_n249: return -0.12743327021598816f;
  t90_n250: return 0.11295319348573685f;
  t90_n251: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t90_n253;
  t90_n252: return -0.08899533003568649f;
  t90_n253: return 0.24194617569446564f;
  t90_n254: return 0.01101274136453867f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree91(const Example& E) {
  t91_n0: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t91_n152;
  t91_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t91_n123;
  t91_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t91_n72;
  t91_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t91_n9;
  t91_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t91_n6;
  t91_n5: return -0.013788510113954544f;
  t91_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t91_n8;
  t91_n7: return -0.07296206057071686f;
  t91_n8: return -0.01847437210381031f;
  t91_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t91_n21;
  t91_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t91_n12;
  t91_n11: return -0.014842238277196884f;
  t91_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t91_n18;
  t91_n13: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t91_n15;
  t91_n14: return -0.0009304710547439754f;
  t91_n15: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t91_n17;
  t91_n16: return -0.04397441819310188f;
  t91_n17: return 0.08637034147977829f;
  t91_n18: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t91_n20;
  t91_n19: return 0.004317864775657654f;
  t91_n20: return 0.013207209296524525f;
  t91_n21: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t91_n23;
  t91_n22: return -0.09412462264299393f;
  t91_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t91_n61;
  t91_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t91_n26;
  t91_n25: return 0.004148660693317652f;
  t91_n26: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t91_n58;
  t91_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t91_n43;
  t91_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t91_n36;
  t91_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t91_n31;
  t91_n30: return 0.05443843826651573f;
  t91_n31: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t91_n35;
  t91_n32: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n34;
  t91_n33: return 0.17290598154067993f;
  t91_n34: return 0.07825901359319687f;
  t91_n35: return -0.05948074162006378f;
  t91_n36: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n38;
  t91_n37: return 0.01617380790412426f;
  t91_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t91_n42;
  t91_n39: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t91_n41;
  t91_n40: return -0.02141495607793331f;
  t91_n41: return -0.23517319560050964f;
  t91_n42: return -0.02945588156580925f;
  t91_n43: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n57;
  t91_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t91_n50;
  t91_n45: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t91_n47;
  t91_n46: return 0.04692159593105316f;
  t91_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t91_n49;
  t91_n48: return -0.023437751457095146f;
  t91_n49: return 0.019360411912202835f;
  t91_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t91_n52;
  t91_n51: return 0.054665274918079376f;
  t91_n52: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t91_n54;
  t91_n53: return 0.06286381930112839f;
  t91_n54: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t91_n56;
  t91_n55: return 0.11745084822177887f;
  t91_n56: return 0.09734552353620529f;
  t91_n57: return 0.0027284855023026466f;
  t91_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t91_n60;
  t91_n59: return 0.07462718337774277f;
  t91_n60: return 0.026147127151489258f;
  t91_n61: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t91_n71;
  t91_n62: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t91_n70;
  t91_n63: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n69;
  t91_n64: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t91_n66;
  t91_n65: return 0.1128472164273262f;
  t91_n66: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t91_n68;
  t91_n67: return 0.11674876511096954f;
  t91_n68: return 0.10526645183563232f;
  t91_n69: return 0.0825088769197464f;
  t91_n70: return 0.08388973772525787f;
  t91_n71: return -0.06385532021522522f;
  t91_n72: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t91_n122;
  t91_n73: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t91_n121;
  t91_n74: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t91_n112;
  t91_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t91_n111;
  t91_n76: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t91_n110;
  t91_n77: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t91_n109;
  t91_n78: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n98;
  t91_n79: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t91_n81;
  t91_n80: return 0.0004479917697608471f;
  t91_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t91_n83;
  t91_n82: return 0.016367824748158455f;
  t91_n83: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t91_n87;
  t91_n84: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t91_n86;
  t91_n85: return 0.02869129739701748f;
  t91_n86: return -0.009382812306284904f;
  t91_n87: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t91_n89;
  t91_n88: return 0.03665570542216301f;
  t91_n89: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t91_n91;
  t91_n90: return 0.03806177154183388f;
  t91_n91: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t91_n97;
  t91_n92: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t91_n96;
  t91_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t91_n95;
  t91_n94: return 0.08450638502836227f;
  t91_n95: return 0.07180760055780411f;
  t91_n96: return 0.008426203392446041f;
  t91_n97: return -0.08247287571430206f;
  t91_n98: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t91_n106;
  t91_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t91_n103;
  t91_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t91_n102;
  t91_n101: return -0.12166129052639008f;
  t91_n102: return -0.008546290919184685f;
  t91_n103: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t91_n105;
  t91_n104: return -0.14248333871364594f;
  t91_n105: return 0.002229274483397603f;
  t91_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t91_n108;
  t91_n107: return -0.023260897025465965f;
  t91_n108: return 0.043338533490896225f;
  t91_n109: return 0.02839268557727337f;
  t91_n110: return -0.039403729140758514f;
  t91_n111: return 0.009895702823996544f;
  t91_n112: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n114;
  t91_n113: return -0.027316134423017502f;
  t91_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t91_n116;
  t91_n115: return 0.0019222995033487678f;
  t91_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t91_n120;
  t91_n117: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t91_n119;
  t91_n118: return -0.22237035632133484f;
  t91_n119: return 0.07396245002746582f;
  t91_n120: return 0.0128756333142519f;
  t91_n121: return -0.10856451094150543f;
  t91_n122: return -0.0834413543343544f;
  t91_n123: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t91_n151;
  t91_n124: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t91_n128;
  t91_n125: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n127;
  t91_n126: return -0.05008958280086517f;
  t91_n127: return -0.1557602733373642f;
  t91_n128: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t91_n130;
  t91_n129: return 0.005000901874154806f;
  t91_n130: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t91_n132;
  t91_n131: return 0.029894618317484856f;
  t91_n132: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t91_n142;
  t91_n133: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t91_n137;
  t91_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t91_n136;
  t91_n135: return 0.03750036284327507f;
  t91_n136: return 0.09393113851547241f;
  t91_n137: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t91_n139;
  t91_n138: return 0.014793389476835728f;
  t91_n139: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t91_n141;
  t91_n140: return 0.14446255564689636f;
  t91_n141: return 0.13567596673965454f;
  t91_n142: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t91_n144;
  t91_n143: return 0.010547094978392124f;
  t91_n144: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t91_n150;
  t91_n145: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t91_n147;
  t91_n146: return 0.056524112820625305f;
  t91_n147: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t91_n149;
  t91_n148: return -0.0048543307930231094f;
  t91_n149: return 0.13118448853492737f;
  t91_n150: return -0.01330609992146492f;
  t91_n151: return -0.057167090475559235f;
  t91_n152: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t91_n208;
  t91_n153: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t91_n207;
  t91_n154: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t91_n156;
  t91_n155: return 0.006293418351560831f;
  t91_n156: if (E.getNumReferences() >= 3314682880 /*4673.5*/) goto t91_n202;
  t91_n157: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t91_n201;
  t91_n158: if (E.getNumReferences() >= 3285057536 /*412.0*/) goto t91_n174;
  t91_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t91_n167;
  t91_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t91_n162;
  t91_n161: return 0.015309490263462067f;
  t91_n162: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t91_n166;
  t91_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t91_n165;
  t91_n164: return -0.02468269318342209f;
  t91_n165: return 0.1160602942109108f;
  t91_n166: return 0.023896263912320137f;
  t91_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t91_n173;
  t91_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t91_n170;
  t91_n169: return 0.07298608869314194f;
  t91_n170: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t91_n172;
  t91_n171: return 0.12685294449329376f;
  t91_n172: return -0.024814728647470474f;
  t91_n173: return 0.03173251450061798f;
  t91_n174: if (E.getNumReferences() >= 3288604672 /*528.5*/) goto t91_n194;
  t91_n175: if (E.getNumReferences() >= 3288506368 /*522.5*/) goto t91_n191;
  t91_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t91_n190;
  t91_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t91_n185;
  t91_n178: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t91_n184;
  t91_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t91_n181;
  t91_n180: return 0.04546434432268143f;
  t91_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t91_n183;
  t91_n182: return 0.026340385898947716f;
  t91_n183: return 0.11230157315731049f;
  t91_n184: return 0.05320980027318001f;
  t91_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t91_n189;
  t91_n186: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t91_n188;
  t91_n187: return 0.12928026914596558f;
  t91_n188: return -0.10333424061536789f;
  t91_n189: return -0.14461694657802582f;
  t91_n190: return 0.10618496686220169f;
  t91_n191: if (E.getNumReferences() >= 3288522752 /*523.5*/) goto t91_n193;
  t91_n192: return 0.16305261850357056f;
  t91_n193: return 0.06639331579208374f;
  t91_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t91_n196;
  t91_n195: return 0.021786028519272804f;
  t91_n196: if (E.getNumReferences() >= 3292446720 /*763.0*/) goto t91_n200;
  t91_n197: if (E.getNumReferences() >= 3291512832 /*706.0*/) goto t91_n199;
  t91_n198: return 0.06128747761249542f;
  t91_n199: return 0.11121194064617157f;
  t91_n200: return 0.05753231421113014f;
  t91_n201: return 0.014706859365105629f;
  t91_n202: if (E.getNumReferences() >= 3315159040 /*4906.0*/) goto t91_n206;
  t91_n203: if (E.getNumReferences() >= 3315124224 /*4889.0*/) goto t91_n205;
  t91_n204: return 0.09167957305908203f;
  t91_n205: return 0.14827631413936615f;
  t91_n206: return 0.037234168499708176f;
  t91_n207: return -0.000315913581289351f;
  t91_n208: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t91_n224;
  t91_n209: if (E.getNumReferences() >= 3313614848 /*4152.0*/) goto t91_n221;
  t91_n210: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t91_n212;
  t91_n211: return 0.04092763736844063f;
  t91_n212: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n214;
  t91_n213: return 0.032671455293893814f;
  t91_n214: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t91_n216;
  t91_n215: return 0.0392797477543354f;
  t91_n216: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t91_n220;
  t91_n217: if (E.getNumReferences() >= 3294593024 /*894.0*/) goto t91_n219;
  t91_n218: return 0.11028211563825607f;
  t91_n219: return 0.10276346653699875f;
  t91_n220: return 0.06535892933607101f;
  t91_n221: if (E.getNumReferences() >= 3313630208 /*4159.5*/) goto t91_n223;
  t91_n222: return 0.11298196762800217f;
  t91_n223: return 0.03309589996933937f;
  t91_n224: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t91_n252;
  t91_n225: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t91_n227;
  t91_n226: return 0.05822230875492096f;
  t91_n227: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t91_n229;
  t91_n228: return 0.029945772141218185f;
  t91_n229: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t91_n237;
  t91_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t91_n232;
  t91_n231: return -0.0203792043030262f;
  t91_n232: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t91_n236;
  t91_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t91_n235;
  t91_n234: return 0.3065938353538513f;
  t91_n235: return 0.12786810100078583f;
  t91_n236: return 0.11946596205234528f;
  t91_n237: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t91_n241;
  t91_n238: if (E.getFilterLength() >= 3250323456 /*23.5*/) goto t91_n240;
  t91_n239: return 0.07541675865650177f;
  t91_n240: return 0.11407490819692612f;
  t91_n241: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t91_n251;
  t91_n242: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t91_n248;
  t91_n243: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t91_n245;
  t91_n244: return 0.030088525265455246f;
  t91_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t91_n247;
  t91_n246: return 0.12218082696199417f;
  t91_n247: return 0.12657605111598969f;
  t91_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t91_n250;
  t91_n249: return -0.11574426293373108f;
  t91_n250: return 0.13077184557914734f;
  t91_n251: return 0.05406547337770462f;
  t91_n252: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t91_n254;
  t91_n253: return -0.0024476961698383093f;
  t91_n254: return 0.12647342681884766f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree92(const Example& E) {
  t92_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t92_n254;
  t92_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t92_n191;
  t92_n2: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t92_n96;
  t92_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t92_n95;
  t92_n4: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t92_n6;
  t92_n5: return 0.0008949688635766506f;
  t92_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t92_n14;
  t92_n7: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t92_n9;
  t92_n8: return -0.0015973967965692282f;
  t92_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t92_n11;
  t92_n10: return 0.04060117155313492f;
  t92_n11: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t92_n13;
  t92_n12: return 0.10576030611991882f;
  t92_n13: return 0.10061360150575638f;
  t92_n14: if (E.getNumReferences() >= 3314682880 /*4673.5*/) goto t92_n88;
  t92_n15: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t92_n71;
  t92_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t92_n18;
  t92_n17: return 0.013841344974935055f;
  t92_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t92_n20;
  t92_n19: return -0.1486656814813614f;
  t92_n20: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t92_n22;
  t92_n21: return 0.02331731654703617f;
  t92_n22: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t92_n56;
  t92_n23: if (E.getNumReferences() >= 3285680128 /*431.0*/) goto t92_n31;
  t92_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t92_n26;
  t92_n25: return 0.030328065156936646f;
  t92_n26: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t92_n28;
  t92_n27: return 0.049231063574552536f;
  t92_n28: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t92_n30;
  t92_n29: return 0.12178874015808105f;
  t92_n30: return 0.36823225021362305f;
  t92_n31: if (E.getNumReferences() >= 3288621056 /*529.5*/) goto t92_n43;
  t92_n32: if (E.getNumReferences() >= 3288489984 /*521.5*/) goto t92_n42;
  t92_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t92_n39;
  t92_n34: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t92_n38;
  t92_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t92_n37;
  t92_n36: return -0.21081885695457458f;
  t92_n37: return 0.10641514509916306f;
  t92_n38: return 0.08570070564746857f;
  t92_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t92_n41;
  t92_n40: return 0.11364197731018066f;
  t92_n41: return 0.21358664333820343f;
  t92_n42: return 0.14609740674495697f;
  t92_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t92_n45;
  t92_n44: return 0.048064108937978745f;
  t92_n45: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t92_n51;
  t92_n46: if (E.getNumReferences() >= 3301322752 /*1585.5*/) goto t92_n48;
  t92_n47: return 0.07421763241291046f;
  t92_n48: if (E.getNumReferences() >= 3302969344 /*1786.5*/) goto t92_n50;
  t92_n49: return 0.11553750932216644f;
  t92_n50: return -0.037890203297138214f;
  t92_n51: if (E.getNumReferences() >= 3291078656 /*679.5*/) goto t92_n53;
  t92_n52: return -0.2679949998855591f;
  t92_n53: if (E.getNumReferences() >= 3293175808 /*807.5*/) goto t92_n55;
  t92_n54: return 0.11529235541820526f;
  t92_n55: return 0.11342808604240417f;
  t92_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t92_n58;
  t92_n57: return 0.02562674507498741f;
  t92_n58: if (E.getNumReferences() >= 3281567744 /*305.5*/) goto t92_n64;
  t92_n59: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t92_n63;
  t92_n60: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t92_n62;
  t92_n61: return -0.1309720277786255f;
  t92_n62: return 0.11345963180065155f;
  t92_n63: return 0.04883890599012375f;
  t92_n64: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t92_n70;
  t92_n65: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t92_n69;
  t92_n66: if (E.getNumReferences() >= 3286056960 /*442.5*/) goto t92_n68;
  t92_n67: return 0.15797710418701172f;
  t92_n68: return 0.30161672830581665f;
  t92_n69: return 0.07054007053375244f;
  t92_n70: return 0.08094429969787598f;
  t92_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t92_n73;
  t92_n72: return -0.03526553884148598f;
  t92_n73: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t92_n75;
  t92_n74: return -0.003446470480412245f;
  t92_n75: if (E.getNumReferences() >= 3278733312 /*237.5*/) goto t92_n87;
  t92_n76: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t92_n78;
  t92_n77: return 0.006171420216560364f;
  t92_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t92_n80;
  t92_n79: return 0.05520699545741081f;
  t92_n80: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t92_n86;
  t92_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t92_n83;
  t92_n82: return -0.1994556337594986f;
  t92_n83: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t92_n85;
  t92_n84: return 0.0663532242178917f;
  t92_n85: return 0.1434716433286667f;
  t92_n86: return 0.14762425422668457f;
  t92_n87: return -0.05013703554868698f;
  t92_n88: if (E.getNumReferences() >= 3315159040 /*4906.0*/) goto t92_n94;
  t92_n89: if (E.getNumReferences() >= 3315124224 /*4889.0*/) goto t92_n91;
  t92_n90: return 0.09191864728927612f;
  t92_n91: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t92_n93;
  t92_n92: return 0.11484480649232864f;
  t92_n93: return 0.14864832162857056f;
  t92_n94: return 0.04288038611412048f;
  t92_n95: return -0.006895779632031918f;
  t92_n96: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t92_n98;
  t92_n97: return -0.005131830461323261f;
  t92_n98: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t92_n154;
  t92_n99: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t92_n153;
  t92_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t92_n124;
  t92_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t92_n105;
  t92_n102: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t92_n104;
  t92_n103: return 0.015305396169424057f;
  t92_n104: return -0.13180115818977356f;
  t92_n105: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t92_n111;
  t92_n106: if (E.getNumReferences() >= 3375821112 /*749331.5*/) goto t92_n110;
  t92_n107: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t92_n109;
  t92_n108: return 0.022459961473941803f;
  t92_n109: return 0.07916975021362305f;
  t92_n110: return -0.06784339994192123f;
  t92_n111: if (E.getNumReferences() >= 3342384384 /*47293.0*/) goto t92_n113;
  t92_n112: return 0.17121289670467377f;
  t92_n113: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t92_n115;
  t92_n114: return 0.01501610316336155f;
  t92_n115: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t92_n123;
  t92_n116: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t92_n120;
  t92_n117: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t92_n119;
  t92_n118: return 0.07536257803440094f;
  t92_n119: return 0.0629354864358902f;
  t92_n120: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t92_n122;
  t92_n121: return -0.11853931844234467f;
  t92_n122: return 0.10356291383504868f;
  t92_n123: return 0.037342410534620285f;
  t92_n124: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t92_n136;
  t92_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t92_n127;
  t92_n126: return -0.04245072603225708f;
  t92_n127: if (E.getNumReferences() >= 3351141632 /*97466.0*/) goto t92_n129;
  t92_n128: return -0.2978592813014984f;
  t92_n129: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t92_n131;
  t92_n130: return 0.10778249800205231f;
  t92_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t92_n133;
  t92_n132: return -0.023327196016907692f;
  t92_n133: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t92_n135;
  t92_n134: return 0.11287417262792587f;
  t92_n135: return 0.08378361910581589f;
  t92_n136: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t92_n150;
  t92_n137: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t92_n149;
  t92_n138: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t92_n144;
  t92_n139: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t92_n143;
  t92_n140: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t92_n142;
  t92_n141: return 0.09376145899295807f;
  t92_n142: return 0.11354996263980865f;
  t92_n143: return -0.12357831746339798f;
  t92_n144: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t92_n146;
  t92_n145: return 0.11772530525922775f;
  t92_n146: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t92_n148;
  t92_n147: return 0.10801851004362106f;
  t92_n148: return 0.09457523375749588f;
  t92_n149: return 0.0681813508272171f;
  t92_n150: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t92_n152;
  t92_n151: return 0.08415437489748001f;
  t92_n152: return 0.058708351105451584f;
  t92_n153: return 0.013351869769394398f;
  t92_n154: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t92_n184;
  t92_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t92_n183;
  t92_n156: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t92_n182;
  t92_n157: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t92_n181;
  t92_n158: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t92_n170;
  t92_n159: if (E.getNumReferences() >= 3347859008 /*71820.5*/) goto t92_n165;
  t92_n160: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t92_n164;
  t92_n161: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t92_n163;
  t92_n162: return -0.26450130343437195f;
  t92_n163: return 0.14861264824867249f;
  t92_n164: return -0.1390078067779541f;
  t92_n165: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t92_n169;
  t92_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t92_n168;
  t92_n167: return -0.014729561284184456f;
  t92_n168: return 0.11354831606149673f;
  t92_n169: return -0.09384661167860031f;
  t92_n170: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t92_n176;
  t92_n171: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t92_n173;
  t92_n172: return -0.3974955081939697f;
  t92_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t92_n175;
  t92_n174: return 0.08551622927188873f;
  t92_n175: return 0.11142509430646896f;
  t92_n176: if (E.getNumReferences() >= 3354468928 /*123460.5*/) goto t92_n180;
  t92_n177: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t92_n179;
  t92_n178: return 0.1122080460190773f;
  t92_n179: return 0.1399553418159485f;
  t92_n180: return 0.09439373016357422f;
  t92_n181: return 0.05195832625031471f;
  t92_n182: return -0.11558577418327332f;
  t92_n183: return -0.022721845656633377f;
  t92_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t92_n186;
  t92_n185: return 0.0074759372510015965f;
  t92_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t92_n190;
  t92_n187: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t92_n189;
  t92_n188: return 0.12917599081993103f;
  t92_n189: return 0.06629759073257446f;
  t92_n190: return 0.16931694746017456f;
  t92_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t92_n203;
  t92_n192: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t92_n198;
  t92_n193: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t92_n195;
  t92_n194: return 0.04457317292690277f;
  t92_n195: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t92_n197;
  t92_n196: return 0.1280643194913864f;
  t92_n197: return 0.05860201269388199f;
  t92_n198: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t92_n200;
  t92_n199: return 0.002833856036886573f;
  t92_n200: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t92_n202;
  t92_n201: return 0.05684596672654152f;
  t92_n202: return -0.21018655598163605f;
  t92_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t92_n205;
  t92_n204: return -0.00521433399990201f;
  t92_n205: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t92_n253;
  t92_n206: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t92_n210;
  t92_n207: if (E.getNumReferences() >= 3332892672 /*21492.0*/) goto t92_n209;
  t92_n208: return 0.025125563144683838f;
  t92_n209: return -0.09967195242643356f;
  t92_n210: if (E.getNumReferences() >= 3315746816 /*5193.0*/) goto t92_n246;
  t92_n211: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t92_n245;
  t92_n212: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t92_n244;
  t92_n213: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t92_n243;
  t92_n214: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t92_n220;
  t92_n215: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t92_n217;
  t92_n216: return -0.008467103354632854f;
  t92_n217: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t92_n219;
  t92_n218: return 0.0585981085896492f;
  t92_n219: return 0.01362426858395338f;
  t92_n220: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t92_n222;
  t92_n221: return 0.02888283133506775f;
  t92_n222: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t92_n236;
  t92_n223: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t92_n225;
  t92_n224: return 0.09818050265312195f;
  t92_n225: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t92_n231;
  t92_n226: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t92_n230;
  t92_n227: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t92_n229;
  t92_n228: return 0.11051346361637115f;
  t92_n229: return 0.012475227005779743f;
  t92_n230: return 0.11439338326454163f;
  t92_n231: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t92_n235;
  t92_n232: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t92_n234;
  t92_n233: return 0.042005907744169235f;
  t92_n234: return 0.1427599936723709f;
  t92_n235: return -0.18130718171596527f;
  t92_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t92_n238;
  t92_n237: return -0.25049540400505066f;
  t92_n238: if (E.getNumReferences() >= 3303845888 /*1893.5*/) goto t92_n242;
  t92_n239: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t92_n241;
  t92_n240: return 0.039611320942640305f;
  t92_n241: return 0.11415833979845047f;
  t92_n242: return 0.10892347991466522f;
  t92_n243: return -0.009709601290524006f;
  t92_n244: return -0.10027007013559341f;
  t92_n245: return 0.028247559443116188f;
  t92_n246: if (E.getNumReferences() >= 3325685760 /*11900.0*/) goto t92_n252;
  t92_n247: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t92_n251;
  t92_n248: if (E.getNumReferences() >= 3318914048 /*6739.5*/) goto t92_n250;
  t92_n249: return 0.07772092521190643f;
  t92_n250: return 0.10242249816656113f;
  t92_n251: return 0.07754348963499069f;
  t92_n252: return 0.04283998906612396f;
  t92_n253: return 0.014021537266671658f;
  t92_n254: return -0.07212435454130173f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree93(const Example& E) {
  t93_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t93_n164;
  t93_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t93_n73;
  t93_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t93_n4;
  t93_n3: return -0.11479852348566055f;
  t93_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t93_n6;
  t93_n5: return -0.003721044398844242f;
  t93_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t93_n72;
  t93_n7: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t93_n15;
  t93_n8: if (E.getNumReferences() >= 3334339584 /*24318.0*/) goto t93_n14;
  t93_n9: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t93_n13;
  t93_n10: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t93_n12;
  t93_n11: return -0.0673687756061554f;
  t93_n12: return 0.09403929859399796f;
  t93_n13: return -0.026617877185344696f;
  t93_n14: return 0.09740018099546432f;
  t93_n15: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t93_n23;
  t93_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t93_n22;
  t93_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type))) goto t93_n19;
  t93_n18: return -0.01167472917586565f;
  t93_n19: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t93_n21;
  t93_n20: return -0.004734032321721315f;
  t93_n21: return 0.02650802582502365f;
  t93_n22: return 0.00517780939117074f;
  t93_n23: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t93_n39;
  t93_n24: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t93_n38;
  t93_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t93_n27;
  t93_n26: return -0.10258501768112183f;
  t93_n27: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t93_n37;
  t93_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t93_n36;
  t93_n29: if (E.getNumReferences() >= 3291078656 /*679.5*/) goto t93_n33;
  t93_n30: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t93_n32;
  t93_n31: return -0.011980799958109856f;
  t93_n32: return 0.07872717827558517f;
  t93_n33: if (E.getNumReferences() >= 3293175808 /*807.5*/) goto t93_n35;
  t93_n34: return 0.11637800931930542f;
  t93_n35: return 0.052517808973789215f;
  t93_n36: return 0.04334212839603424f;
  t93_n37: return 0.01847490668296814f;
  t93_n38: return -0.006807100493460894f;
  t93_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t93_n67;
  t93_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t93_n42;
  t93_n41: return -0.07523392140865326f;
  t93_n42: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t93_n62;
  t93_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t93_n49;
  t93_n44: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t93_n48;
  t93_n45: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t93_n47;
  t93_n46: return -0.004315524827688932f;
  t93_n47: return -0.09695594757795334f;
  t93_n48: return 0.032706450670957565f;
  t93_n49: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t93_n53;
  t93_n50: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t93_n52;
  t93_n51: return -0.1666632890701294f;
  t93_n52: return 0.10973430424928665f;
  t93_n53: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t93_n59;
  t93_n54: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t93_n56;
  t93_n55: return 0.06388328969478607f;
  t93_n56: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t93_n58;
  t93_n57: return 0.10021292418241501f;
  t93_n58: return 0.11040150374174118f;
  t93_n59: if (E.getNumReferences() >= 3334173440 /*23993.5*/) goto t93_n61;
  t93_n60: return -0.0037071772385388613f;
  t93_n61: return 0.12210948020219803f;
  t93_n62: if (E.getNumReferences() >= 3261333504 /*57.0*/) goto t93_n64;
  t93_n63: return -0.33195704221725464f;
  t93_n64: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t93_n66;
  t93_n65: return 0.10930117219686508f;
  t93_n66: return -0.042171068489551544f;
  t93_n67: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t93_n71;
  t93_n68: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t93_n70;
  t93_n69: return 0.24892652034759521f;
  t93_n70: return 0.12371934205293655f;
  t93_n71: return 0.04119263216853142f;
  t93_n72: return 0.006216792855411768f;
  t93_n73: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t93_n89;
  t93_n74: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t93_n88;
  t93_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t93_n87;
  t93_n76: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t93_n86;
  t93_n77: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t93_n85;
  t93_n78: if (E.getNumReferences() >= 3349315712 /*83201.0*/) goto t93_n84;
  t93_n79: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t93_n83;
  t93_n80: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t93_n82;
  t93_n81: return -0.03760174289345741f;
  t93_n82: return 0.0919179692864418f;
  t93_n83: return -0.11926604807376862f;
  t93_n84: return 0.07218517363071442f;
  t93_n85: return -0.37309083342552185f;
  t93_n86: return -0.4272361397743225f;
  t93_n87: return 0.019578425213694572f;
  t93_n88: return -0.041837263852357864f;
  t93_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t93_n139;
  t93_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t93_n110;
  t93_n91: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t93_n103;
  t93_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t93_n98;
  t93_n93: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t93_n95;
  t93_n94: return -0.0947510376572609f;
  t93_n95: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t93_n97;
  t93_n96: return -0.04582762345671654f;
  t93_n97: return 0.02239491231739521f;
  t93_n98: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t93_n102;
  t93_n99: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t93_n101;
  t93_n100: return 0.0607384517788887f;
  t93_n101: return 0.16467615962028503f;
  t93_n102: return 0.0266953743994236f;
  t93_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t93_n105;
  t93_n104: return 0.03793978691101074f;
  t93_n105: if (E.getNumReferences() >= 3366869888 /*357084.0*/) goto t93_n107;
  t93_n106: return 0.020924510434269905f;
  t93_n107: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t93_n109;
  t93_n108: return 0.1380591243505478f;
  t93_n109: return -0.011907950043678284f;
  t93_n110: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t93_n124;
  t93_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t93_n115;
  t93_n112: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t93_n114;
  t93_n113: return -0.21339188516139984f;
  t93_n114: return 0.03693077340722084f;
  t93_n115: if (E.getNumReferences() >= 3351141632 /*97466.0*/) goto t93_n117;
  t93_n116: return -0.19001269340515137f;
  t93_n117: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t93_n119;
  t93_n118: return 0.10599879175424576f;
  t93_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t93_n121;
  t93_n120: return -0.020268820226192474f;
  t93_n121: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t93_n123;
  t93_n122: return 0.11180479824542999f;
  t93_n123: return 0.08106808364391327f;
  t93_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t93_n136;
  t93_n125: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t93_n135;
  t93_n126: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t93_n132;
  t93_n127: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t93_n131;
  t93_n128: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t93_n130;
  t93_n129: return 0.09414543956518173f;
  t93_n130: return 0.11162246763706207f;
  t93_n131: return -0.12437767535448074f;
  t93_n132: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t93_n134;
  t93_n133: return 0.11594954878091812f;
  t93_n134: return 0.10197126865386963f;
  t93_n135: return 0.0649259015917778f;
  t93_n136: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t93_n138;
  t93_n137: return 0.08366193622350693f;
  t93_n138: return 0.05586916580796242f;
  t93_n139: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t93_n141;
  t93_n140: return 0.012182624079287052f;
  t93_n141: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t93_n163;
  t93_n142: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t93_n154;
  t93_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t93_n153;
  t93_n144: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t93_n152;
  t93_n145: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t93_n147;
  t93_n146: return 0.059667471796274185f;
  t93_n147: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t93_n151;
  t93_n148: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t93_n150;
  t93_n149: return 0.10397393256425858f;
  t93_n150: return -0.2402770072221756f;
  t93_n151: return 0.053517699241638184f;
  t93_n152: return -0.23234470188617706f;
  t93_n153: return -0.1325404942035675f;
  t93_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t93_n158;
  t93_n155: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t93_n157;
  t93_n156: return 0.11582250893115997f;
  t93_n157: return -0.020317936316132545f;
  t93_n158: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t93_n160;
  t93_n159: return -0.0044329483062028885f;
  t93_n160: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t93_n162;
  t93_n161: return 0.12358897179365158f;
  t93_n162: return -0.0047945487312972546f;
  t93_n163: return 0.16070875525474548f;
  t93_n164: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t93_n232;
  t93_n165: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t93_n227;
  t93_n166: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t93_n222;
  t93_n167: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t93_n209;
  t93_n168: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t93_n170;
  t93_n169: return 0.017966443672776222f;
  t93_n170: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t93_n200;
  t93_n171: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t93_n173;
  t93_n172: return 0.0024528319481760263f;
  t93_n173: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t93_n183;
  t93_n174: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t93_n176;
  t93_n175: return -0.10025440901517868f;
  t93_n176: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t93_n178;
  t93_n177: return 0.021292079240083694f;
  t93_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t93_n180;
  t93_n179: return -0.1054961159825325f;
  t93_n180: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t93_n182;
  t93_n181: return 0.03797357156872749f;
  t93_n182: return -0.15282666683197021f;
  t93_n183: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t93_n191;
  t93_n184: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t93_n190;
  t93_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t93_n189;
  t93_n186: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t93_n188;
  t93_n187: return -0.06940817087888718f;
  t93_n188: return 0.08258143067359924f;
  t93_n189: return 0.021273138001561165f;
  t93_n190: return -0.12247439473867416f;
  t93_n191: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t93_n197;
  t93_n192: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t93_n194;
  t93_n193: return 0.0032313379924744368f;
  t93_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t93_n196;
  t93_n195: return -0.1152707114815712f;
  t93_n196: return 0.10931168496608734f;
  t93_n197: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t93_n199;
  t93_n198: return -0.038751691579818726f;
  t93_n199: return 0.13066869974136353f;
  t93_n200: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t93_n208;
  t93_n201: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t93_n207;
  t93_n202: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t93_n206;
  t93_n203: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t93_n205;
  t93_n204: return -0.017695019021630287f;
  t93_n205: return -0.16398310661315918f;
  t93_n206: return 0.01671292446553707f;
  t93_n207: return 0.0258172620087862f;
  t93_n208: return 0.032268330454826355f;
  t93_n209: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t93_n219;
  t93_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Expression))) goto t93_n218;
  t93_n211: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t93_n213;
  t93_n212: return -0.08867473155260086f;
  t93_n213: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t93_n217;
  t93_n214: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t93_n216;
  t93_n215: return 0.019763600081205368f;
  t93_n216: return -0.127643883228302f;
  t93_n217: return -0.0015345849096775055f;
  t93_n218: return 0.013349982909858227f;
  t93_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t93_n221;
  t93_n220: return 0.08511164784431458f;
  t93_n221: return -0.04264364764094353f;
  t93_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t93_n224;
  t93_n223: return -0.04332830011844635f;
  t93_n224: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t93_n226;
  t93_n225: return 0.00985138863325119f;
  t93_n226: return 0.04874538257718086f;
  t93_n227: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t93_n231;
  t93_n228: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t93_n230;
  t93_n229: return 0.1368129402399063f;
  t93_n230: return -0.09389715641736984f;
  t93_n231: return 0.029042167589068413f;
  t93_n232: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t93_n234;
  t93_n233: return -0.0035300496965646744f;
  t93_n234: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t93_n252;
  t93_n235: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t93_n237;
  t93_n236: return 0.03294902667403221f;
  t93_n237: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t93_n251;
  t93_n238: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t93_n240;
  t93_n239: return -0.05720536783337593f;
  t93_n240: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t93_n244;
  t93_n241: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t93_n243;
  t93_n242: return -0.009075917303562164f;
  t93_n243: return 0.1075400784611702f;
  t93_n244: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t93_n250;
  t93_n245: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t93_n247;
  t93_n246: return 0.07813188433647156f;
  t93_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t93_n249;
  t93_n248: return 0.13047564029693604f;
  t93_n249: return 0.15127810835838318f;
  t93_n250: return 0.05395945906639099f;
  t93_n251: return 0.028056930750608444f;
  t93_n252: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t93_n254;
  t93_n253: return 0.010475507006049156f;
  t93_n254: return -0.1477426439523697f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree94(const Example& E) {
  t94_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t94_n208;
  t94_n1: if (E.getNumReferences() >= 3304779776 /*2007.5*/) goto t94_n3;
  t94_n2: return -0.001733004697598517f;
  t94_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t94_n9;
  t94_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t94_n8;
  t94_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t94_n7;
  t94_n6: return 0.012366735376417637f;
  t94_n7: return 0.034616198390722275f;
  t94_n8: return -0.0038749519735574722f;
  t94_n9: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t94_n145;
  t94_n10: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t94_n24;
  t94_n11: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t94_n21;
  t94_n12: if (E.getNumReferences() >= 3319614464 /*7081.5*/) goto t94_n20;
  t94_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t94_n19;
  t94_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t94_n18;
  t94_n15: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t94_n17;
  t94_n16: return 0.09912141412496567f;
  t94_n17: return -0.09034749120473862f;
  t94_n18: return 0.009906149469316006f;
  t94_n19: return 0.025331659242510796f;
  t94_n20: return -0.18725897371768951f;
  t94_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t94_n23;
  t94_n22: return 0.11671770364046097f;
  t94_n23: return 0.10756128281354904f;
  t94_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t94_n92;
  t94_n25: if (E.getNumReferences() >= 3334111488 /*23872.5*/) goto t94_n83;
  t94_n26: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t94_n72;
  t94_n27: if (E.getNumReferences() >= 3321819136 /*8158.0*/) goto t94_n59;
  t94_n28: if (E.getNumReferences() >= 3321606144 /*8054.0*/) goto t94_n50;
  t94_n29: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t94_n31;
  t94_n30: return 0.03603930398821831f;
  t94_n31: if (E.getNumReferences() >= 3321408512 /*7957.5*/) goto t94_n47;
  t94_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t94_n44;
  t94_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t94_n37;
  t94_n34: if (E.getNumReferences() >= 3319740416 /*7143.0*/) goto t94_n36;
  t94_n35: return 0.07714928686618805f;
  t94_n36: return 0.018831027671694756f;
  t94_n37: if (E.getNumReferences() >= 3320593408 /*7559.5*/) goto t94_n39;
  t94_n38: return -0.24910682439804077f;
  t94_n39: if (E.getNumReferences() >= 3321062400 /*7788.5*/) goto t94_n43;
  t94_n40: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t94_n42;
  t94_n41: return 0.0871027484536171f;
  t94_n42: return 0.11215271800756454f;
  t94_n43: return 0.07329431921243668f;
  t94_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t94_n46;
  t94_n45: return 0.10354229062795639f;
  t94_n46: return 0.12285251170396805f;
  t94_n47: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t94_n49;
  t94_n48: return 0.03598320856690407f;
  t94_n49: return 0.12536191940307617f;
  t94_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t94_n58;
  t94_n51: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t94_n53;
  t94_n52: return 0.11929729580879211f;
  t94_n53: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t94_n55;
  t94_n54: return 0.11232106387615204f;
  t94_n55: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t94_n57;
  t94_n56: return 0.11930999904870987f;
  t94_n57: return 0.1648404449224472f;
  t94_n58: return 0.1250365972518921f;
  t94_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t94_n61;
  t94_n60: return -0.035964928567409515f;
  t94_n61: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t94_n63;
  t94_n62: return 0.00816901121288538f;
  t94_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t94_n65;
  t94_n64: return 0.039648860692977905f;
  t94_n65: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t94_n71;
  t94_n66: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t94_n70;
  t94_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t94_n69;
  t94_n68: return 0.13949017226696014f;
  t94_n69: return 0.10902387648820877f;
  t94_n70: return 0.11238811910152435f;
  t94_n71: return -0.18886145949363708f;
  t94_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t94_n74;
  t94_n73: return 0.0334390252828598f;
  t94_n74: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t94_n80;
  t94_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t94_n77;
  t94_n76: return -0.05816281586885452f;
  t94_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t94_n79;
  t94_n78: return -0.10110381990671158f;
  t94_n79: return 0.09806295484304428f;
  t94_n80: if (E.getNumReferences() >= 3331729664 /*19220.5*/) goto t94_n82;
  t94_n81: return 0.11477609723806381f;
  t94_n82: return 0.07282514870166779f;
  t94_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t94_n85;
  t94_n84: return 0.056231867522001266f;
  t94_n85: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t94_n91;
  t94_n86: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t94_n88;
  t94_n87: return 0.10072491317987442f;
  t94_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t94_n90;
  t94_n89: return 0.026594502851366997f;
  t94_n90: return 0.11430656164884567f;
  t94_n91: return -0.05467826500535011f;
  t94_n92: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t94_n122;
  t94_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t94_n101;
  t94_n94: if (E.getNumReferences() >= 3319705600 /*7126.0*/) goto t94_n100;
  t94_n95: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t94_n99;
  t94_n96: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t94_n98;
  t94_n97: return 0.11134249716997147f;
  t94_n98: return 0.11514506489038467f;
  t94_n99: return 0.07033044844865799f;
  t94_n100: return 0.03460197523236275f;
  t94_n101: if (E.getNumReferences() >= 3319966720 /*7253.5*/) goto t94_n115;
  t94_n102: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t94_n104;
  t94_n103: return 0.11249333620071411f;
  t94_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t94_n110;
  t94_n105: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t94_n107;
  t94_n106: return 0.05990714952349663f;
  t94_n107: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t94_n109;
  t94_n108: return 0.11016251891851425f;
  t94_n109: return -0.014143023639917374f;
  t94_n110: if (E.getNumReferences() >= 3319788544 /*7166.5*/) goto t94_n114;
  t94_n111: if (E.getNumReferences() >= 3319744512 /*7145.0*/) goto t94_n113;
  t94_n112: return 0.03922208026051521f;
  t94_n113: return 0.10993486642837524f;
  t94_n114: return -0.10464143753051758f;
  t94_n115: if (E.getNumReferences() >= 3321896960 /*8200.0*/) goto t94_n117;
  t94_n116: return 0.013363952748477459f;
  t94_n117: if (E.getNumReferences() >= 3321991168 /*8292.0*/) goto t94_n121;
  t94_n118: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t94_n120;
  t94_n119: return 0.11601654440164566f;
  t94_n120: return 0.11864498257637024f;
  t94_n121: return 0.06609463691711426f;
  t94_n122: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t94_n140;
  t94_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t94_n137;
  t94_n124: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t94_n130;
  t94_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t94_n127;
  t94_n126: return 0.05416359379887581f;
  t94_n127: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t94_n129;
  t94_n128: return 0.13045498728752136f;
  t94_n129: return 0.11935338377952576f;
  t94_n130: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t94_n132;
  t94_n131: return 0.04809173569083214f;
  t94_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t94_n134;
  t94_n133: return 0.11601338535547256f;
  t94_n134: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t94_n136;
  t94_n135: return 0.11044201254844666f;
  t94_n136: return -0.10078786313533783f;
  t94_n137: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t94_n139;
  t94_n138: return 0.09337002038955688f;
  t94_n139: return 0.10487189143896103f;
  t94_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t94_n142;
  t94_n141: return 0.0453207828104496f;
  t94_n142: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t94_n144;
  t94_n143: return 0.11713400483131409f;
  t94_n144: return 0.04731662943959236f;
  t94_n145: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t94_n207;
  t94_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t94_n198;
  t94_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t94_n195;
  t94_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t94_n160;
  t94_n149: if (E.getNumReferences() >= 3369273984 /*432212.0*/) goto t94_n155;
  t94_n150: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t94_n152;
  t94_n151: return -0.07029496878385544f;
  t94_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t94_n154;
  t94_n153: return 0.038747843354940414f;
  t94_n154: return 0.10758447647094727f;
  t94_n155: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t94_n157;
  t94_n156: return 0.020175550132989883f;
  t94_n157: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t94_n159;
  t94_n158: return -0.3716188669204712f;
  t94_n159: return 0.06937681883573532f;
  t94_n160: if (E.getNumReferences() >= 3334946304 /*25503.0*/) goto t94_n162;
  t94_n161: return -0.29144221544265747f;
  t94_n162: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t94_n180;
  t94_n163: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t94_n177;
  t94_n164: if (E.getNumReferences() >= 3341362816 /*43302.5*/) goto t94_n176;
  t94_n165: if (E.getNumReferences() >= 3336764160 /*29053.5*/) goto t94_n169;
  t94_n166: if (E.getNumReferences() >= 3335557632 /*26697.0*/) goto t94_n168;
  t94_n167: return 0.07782597839832306f;
  t94_n168: return -0.1102275550365448f;
  t94_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t94_n171;
  t94_n170: return 0.05460425093770027f;
  t94_n171: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t94_n173;
  t94_n172: return 0.023923341184854507f;
  t94_n173: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t94_n175;
  t94_n174: return 0.10758384317159653f;
  t94_n175: return 0.10870345681905746f;
  t94_n176: return -0.03814368695020676f;
  t94_n177: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t94_n179;
  t94_n178: return 0.07708410918712616f;
  t94_n179: return 0.03223476931452751f;
  t94_n180: if (E.getNumReferences() >= 3365914464 /*327227.0*/) goto t94_n192;
  t94_n181: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t94_n183;
  t94_n182: return -0.012612951919436455f;
  t94_n183: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t94_n191;
  t94_n184: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t94_n190;
  t94_n185: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t94_n187;
  t94_n186: return -0.21905367076396942f;
  t94_n187: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t94_n189;
  t94_n188: return -0.39470043778419495f;
  t94_n189: return -0.009662180207669735f;
  t94_n190: return 0.07373160868883133f;
  t94_n191: return 0.04871430993080139f;
  t94_n192: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t94_n194;
  t94_n193: return 0.10414925217628479f;
  t94_n194: return 0.04827053099870682f;
  t94_n195: if (E.getNumReferences() >= 3334582784 /*24793.0*/) goto t94_n197;
  t94_n196: return -0.2640700936317444f;
  t94_n197: return 0.0036174727138131857f;
  t94_n198: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t94_n206;
  t94_n199: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t94_n203;
  t94_n200: if (E.getNumReferences() >= 3350298560 /*90879.5*/) goto t94_n202;
  t94_n201: return 0.06224977970123291f;
  t94_n202: return -0.16030140221118927f;
  t94_n203: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t94_n205;
  t94_n204: return 0.11357630789279938f;
  t94_n205: return 0.09631999582052231f;
  t94_n206: return 0.013134988956153393f;
  t94_n207: return 0.07985271513462067f;
  t94_n208: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t94_n212;
  t94_n209: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t94_n211;
  t94_n210: return 0.042717549949884415f;
  t94_n211: return 0.002333856886252761f;
  t94_n212: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t94_n236;
  t94_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t94_n227;
  t94_n214: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t94_n216;
  t94_n215: return 0.004022443201392889f;
  t94_n216: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t94_n224;
  t94_n217: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t94_n219;
  t94_n218: return 0.024929264560341835f;
  t94_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t94_n223;
  t94_n220: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t94_n222;
  t94_n221: return 0.11010679602622986f;
  t94_n222: return 0.0728798359632492f;
  t94_n223: return 0.04722195491194725f;
  t94_n224: if (E.getNumReferences() >= 3335803904 /*27178.0*/) goto t94_n226;
  t94_n225: return 0.01729859597980976f;
  t94_n226: return -0.08759849518537521f;
  t94_n227: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t94_n229;
  t94_n228: return -0.28002557158470154f;
  t94_n229: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t94_n235;
  t94_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t94_n232;
  t94_n231: return 0.015656789764761925f;
  t94_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t94_n234;
  t94_n233: return 0.04030324146151543f;
  t94_n234: return 0.09721565991640091f;
  t94_n235: return 0.005002337973564863f;
  t94_n236: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t94_n248;
  t94_n237: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t94_n239;
  t94_n238: return -0.01006707176566124f;
  t94_n239: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t94_n241;
  t94_n240: return 0.015887858346104622f;
  t94_n241: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t94_n245;
  t94_n242: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t94_n244;
  t94_n243: return -0.12397295981645584f;
  t94_n244: return 0.10655312985181808f;
  t94_n245: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t94_n247;
  t94_n246: return -0.08677562326192856f;
  t94_n247: return 0.20670545101165771f;
  t94_n248: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t94_n250;
  t94_n249: return 0.010961592197418213f;
  t94_n250: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t94_n252;
  t94_n251: return 0.03787941858172417f;
  t94_n252: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t94_n254;
  t94_n253: return 0.10295313596725464f;
  t94_n254: return -0.26055750250816345f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree95(const Example& E) {
  t95_n0: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t95_n250;
  t95_n1: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t95_n171;
  t95_n2: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t95_n72;
  t95_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t95_n71;
  t95_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t95_n28;
  t95_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t95_n7;
  t95_n6: return -0.013831156305968761f;
  t95_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t95_n9;
  t95_n8: return -0.05929186940193176f;
  t95_n9: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t95_n21;
  t95_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t95_n20;
  t95_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t95_n19;
  t95_n12: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t95_n18;
  t95_n13: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t95_n17;
  t95_n14: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t95_n16;
  t95_n15: return 0.1217043474316597f;
  t95_n16: return 0.5627243518829346f;
  t95_n17: return 0.18070624768733978f;
  t95_n18: return -0.13386061787605286f;
  t95_n19: return 0.06994801014661789f;
  t95_n20: return 0.044278211891651154f;
  t95_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t95_n23;
  t95_n22: return 0.05303248390555382f;
  t95_n23: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t95_n27;
  t95_n24: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t95_n26;
  t95_n25: return 0.11188684403896332f;
  t95_n26: return -0.022099345922470093f;
  t95_n27: return 0.10482917726039886f;
  t95_n28: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t95_n70;
  t95_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t95_n47;
  t95_n30: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t95_n34;
  t95_n31: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t95_n33;
  t95_n32: return 0.09279827028512955f;
  t95_n33: return -0.008459771983325481f;
  t95_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t95_n46;
  t95_n35: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t95_n41;
  t95_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t95_n38;
  t95_n37: return 0.05428609624505043f;
  t95_n38: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t95_n40;
  t95_n39: return 0.09833281487226486f;
  t95_n40: return 0.09245607256889343f;
  t95_n41: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t95_n43;
  t95_n42: return -0.0890953540802002f;
  t95_n43: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t95_n45;
  t95_n44: return 0.12932367622852325f;
  t95_n45: return -0.34325462579727173f;
  t95_n46: return 0.008535853587090969f;
  t95_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t95_n65;
  t95_n48: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t95_n64;
  t95_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t95_n53;
  t95_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t95_n52;
  t95_n51: return -0.14471657574176788f;
  t95_n52: return -0.03503001853823662f;
  t95_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t95_n57;
  t95_n54: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t95_n56;
  t95_n55: return 0.0041875834576785564f;
  t95_n56: return -0.06927962601184845f;
  t95_n57: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t95_n63;
  t95_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t95_n62;
  t95_n59: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t95_n61;
  t95_n60: return 0.08208933472633362f;
  t95_n61: return 0.11114878952503204f;
  t95_n62: return 0.05661781504750252f;
  t95_n63: return -0.49670857191085815f;
  t95_n64: return 0.010245224460959435f;
  t95_n65: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t95_n69;
  t95_n66: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t95_n68;
  t95_n67: return 0.06536337733268738f;
  t95_n68: return -0.08631843328475952f;
  t95_n69: return 0.07712174206972122f;
  t95_n70: return -0.15727992355823517f;
  t95_n71: return 0.006015333347022533f;
  t95_n72: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t95_n82;
  t95_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t95_n75;
  t95_n74: return 0.008522223681211472f;
  t95_n75: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t95_n77;
  t95_n76: return 0.038420386612415314f;
  t95_n77: if (E.getNumReferences() >= 3276767232 /*207.5*/) goto t95_n79;
  t95_n78: return -0.06995117664337158f;
  t95_n79: if (E.getNumReferences() >= 3277684736 /*221.5*/) goto t95_n81;
  t95_n80: return 0.09281417727470398f;
  t95_n81: return 0.02748250402510166f;
  t95_n82: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t95_n86;
  t95_n83: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t95_n85;
  t95_n84: return -0.14001239836215973f;
  t95_n85: return 0.11598854511976242f;
  t95_n86: if (E.getNumReferences() >= 3316826112 /*5720.0*/) goto t95_n138;
  t95_n87: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t95_n113;
  t95_n88: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t95_n110;
  t95_n89: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t95_n93;
  t95_n90: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t95_n92;
  t95_n91: return -0.00433632405474782f;
  t95_n92: return 0.04320492595434189f;
  t95_n93: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t95_n109;
  t95_n94: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t95_n96;
  t95_n95: return 0.04016648605465889f;
  t95_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t95_n104;
  t95_n97: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t95_n99;
  t95_n98: return 0.08698327094316483f;
  t95_n99: if (E.getNumReferences() >= 3286155264 /*445.5*/) goto t95_n101;
  t95_n100: return 0.028163596987724304f;
  t95_n101: if (E.getNumReferences() >= 3292618752 /*773.5*/) goto t95_n103;
  t95_n102: return 0.12430143356323242f;
  t95_n103: return 0.17815786600112915f;
  t95_n104: if (E.getNumReferences() >= 3272736768 /*146.0*/) goto t95_n106;
  t95_n105: return -0.08129426836967468f;
  t95_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t95_n108;
  t95_n107: return 0.08975760638713837f;
  t95_n108: return 0.12624801695346832f;
  t95_n109: return 0.028782052919268608f;
  t95_n110: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t95_n112;
  t95_n111: return 0.04911132529377937f;
  t95_n112: return 0.030030490830540657f;
  t95_n113: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t95_n115;
  t95_n114: return 0.049926720559597015f;
  t95_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t95_n121;
  t95_n116: if (E.getNumReferences() >= 3266641920 /*90.5*/) goto t95_n118;
  t95_n117: return -0.00496789300814271f;
  t95_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t95_n120;
  t95_n119: return 0.06115007773041725f;
  t95_n120: return 0.1296716034412384f;
  t95_n121: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t95_n129;
  t95_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t95_n124;
  t95_n123: return 0.07205262780189514f;
  t95_n124: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t95_n128;
  t95_n125: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t95_n127;
  t95_n126: return 0.1062937006354332f;
  t95_n127: return 0.10807464271783829f;
  t95_n128: return 0.11970417201519012f;
  t95_n129: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t95_n137;
  t95_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t95_n132;
  t95_n131: return 0.09213744848966599f;
  t95_n132: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t95_n134;
  t95_n133: return 0.1594967395067215f;
  t95_n134: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t95_n136;
  t95_n135: return -0.02165360003709793f;
  t95_n136: return 0.10932871699333191f;
  t95_n137: return 0.004565135575830936f;
  t95_n138: if (E.getNumReferences() >= 3320489984 /*7509.0*/) goto t95_n166;
  t95_n139: if (E.getNumReferences() >= 3319805952 /*7175.0*/) goto t95_n161;
  t95_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t95_n142;
  t95_n141: return 0.009724318981170654f;
  t95_n142: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t95_n148;
  t95_n143: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t95_n145;
  t95_n144: return -0.10819146782159805f;
  t95_n145: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t95_n147;
  t95_n146: return 0.14307427406311035f;
  t95_n147: return 0.13859117031097412f;
  t95_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t95_n156;
  t95_n149: if (E.getNumReferences() >= 3319629824 /*7089.0*/) goto t95_n151;
  t95_n150: return -0.014172249473631382f;
  t95_n151: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t95_n153;
  t95_n152: return -0.3776301443576813f;
  t95_n153: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t95_n155;
  t95_n154: return 0.1087682694196701f;
  t95_n155: return 0.07028922438621521f;
  t95_n156: if (E.getNumReferences() >= 3317832704 /*6211.5*/) goto t95_n160;
  t95_n157: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t95_n159;
  t95_n158: return -0.21372193098068237f;
  t95_n159: return 0.11788588762283325f;
  t95_n160: return -0.27586793899536133f;
  t95_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t95_n163;
  t95_n162: return -0.016845911741256714f;
  t95_n163: if (E.getNumReferences() >= 3320267776 /*7400.5*/) goto t95_n165;
  t95_n164: return 0.11381061375141144f;
  t95_n165: return 0.1018018051981926f;
  t95_n166: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t95_n168;
  t95_n167: return 0.016363633796572685f;
  t95_n168: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t95_n170;
  t95_n169: return 0.1004263237118721f;
  t95_n170: return -0.08828537166118622f;
  t95_n171: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t95_n173;
  t95_n172: return -0.00015302262909244746f;
  t95_n173: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t95_n175;
  t95_n174: return -0.08699578046798706f;
  t95_n175: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t95_n225;
  t95_n176: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t95_n178;
  t95_n177: return 0.002956873271614313f;
  t95_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t95_n182;
  t95_n179: if (E.getNumReferences() >= 3326358528 /*12557.0*/) goto t95_n181;
  t95_n180: return 0.023394664749503136f;
  t95_n181: return 0.1517053097486496f;
  t95_n182: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t95_n196;
  t95_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t95_n185;
  t95_n184: return 0.0544055737555027f;
  t95_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t95_n187;
  t95_n186: return 0.07710598409175873f;
  t95_n187: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t95_n189;
  t95_n188: return 0.12484663724899292f;
  t95_n189: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t95_n195;
  t95_n190: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t95_n192;
  t95_n191: return -0.12603355944156647f;
  t95_n192: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t95_n194;
  t95_n193: return -0.3184296488761902f;
  t95_n194: return 0.10691507905721664f;
  t95_n195: return 0.12439411878585815f;
  t95_n196: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t95_n212;
  t95_n197: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t95_n201;
  t95_n198: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t95_n200;
  t95_n199: return -0.10416299104690552f;
  t95_n200: return 0.1216503456234932f;
  t95_n201: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t95_n211;
  t95_n202: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t95_n208;
  t95_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t95_n205;
  t95_n204: return 0.05336939916014671f;
  t95_n205: if (E.getNumReferences() >= 3274768384 /*177.0*/) goto t95_n207;
  t95_n206: return -0.12838785350322723f;
  t95_n207: return 0.12770839035511017f;
  t95_n208: if (E.getNumReferences() >= 3282927616 /*347.0*/) goto t95_n210;
  t95_n209: return 0.5322720408439636f;
  t95_n210: return 0.12513364851474762f;
  t95_n211: return -0.13621141016483307f;
  t95_n212: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t95_n222;
  t95_n213: if (E.getNumReferences() >= 3274637312 /*175.0*/) goto t95_n221;
  t95_n214: if (E.getNumReferences() >= 3273457664 /*157.0*/) goto t95_n218;
  t95_n215: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t95_n217;
  t95_n216: return 0.09234106540679932f;
  t95_n217: return 0.10857215523719788f;
  t95_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t95_n220;
  t95_n219: return 0.14452813565731049f;
  t95_n220: return 0.2710006833076477f;
  t95_n221: return 0.06067906320095062f;
  t95_n222: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t95_n224;
  t95_n223: return 0.05934165045619011f;
  t95_n224: return 0.125169575214386f;
  t95_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t95_n227;
  t95_n226: return -0.03517910838127136f;
  t95_n227: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t95_n229;
  t95_n228: return -0.02854122780263424f;
  t95_n229: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t95_n241;
  t95_n230: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t95_n232;
  t95_n231: return -0.02796221151947975f;
  t95_n232: if (E.getNumReferences() >= 3260809216 /*55.0*/) goto t95_n238;
  t95_n233: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t95_n237;
  t95_n234: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t95_n236;
  t95_n235: return 0.12765315175056458f;
  t95_n236: return -0.009770478121936321f;
  t95_n237: return 0.10427777469158173f;
  t95_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t95_n240;
  t95_n239: return -0.11298671364784241f;
  t95_n240: return 0.12413458526134491f;
  t95_n241: if (E.getNumReferences() >= 3317795840 /*6193.5*/) goto t95_n245;
  t95_n242: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t95_n244;
  t95_n243: return 0.04352886602282524f;
  t95_n244: return 0.055405404418706894f;
  t95_n245: if (E.getNumReferences() >= 3318784000 /*6676.0*/) goto t95_n249;
  t95_n246: if (E.getNumReferences() >= 3318737920 /*6653.5*/) goto t95_n248;
  t95_n247: return 0.07792850583791733f;
  t95_n248: return 0.13090892136096954f;
  t95_n249: return 0.05077635496854782f;
  t95_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t95_n254;
  t95_n251: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t95_n253;
  t95_n252: return 0.018980972468852997f;
  t95_n253: return -0.005057554226368666f;
  t95_n254: return 0.016959385946393013f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree96(const Example& E) {
  t96_n0: if (E.getNumReferences() >= 3304886272 /*2020.5*/) goto t96_n92;
  t96_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t96_n43;
  t96_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t96_n4;
  t96_n3: return -0.009348993189632893f;
  t96_n4: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t96_n24;
  t96_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t96_n19;
  t96_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t96_n8;
  t96_n7: return 0.013114457949995995f;
  t96_n8: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t96_n10;
  t96_n9: return 0.037008609622716904f;
  t96_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t96_n12;
  t96_n11: return -0.1042931079864502f;
  t96_n12: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t96_n16;
  t96_n13: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t96_n15;
  t96_n14: return -0.04246512055397034f;
  t96_n15: return 0.006388157140463591f;
  t96_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t96_n18;
  t96_n17: return -0.01506322342902422f;
  t96_n18: return 0.0432518795132637f;
  t96_n19: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t96_n23;
  t96_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t96_n22;
  t96_n21: return -0.004878230858594179f;
  t96_n22: return 0.019177524372935295f;
  t96_n23: return 0.02100509963929653f;
  t96_n24: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t96_n42;
  t96_n25: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t96_n29;
  t96_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t96_n28;
  t96_n27: return -0.13798484206199646f;
  t96_n28: return 0.10638165473937988f;
  t96_n29: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t96_n41;
  t96_n30: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t96_n38;
  t96_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t96_n33;
  t96_n32: return 0.030318081378936768f;
  t96_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t96_n35;
  t96_n34: return -0.06753135472536087f;
  t96_n35: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t96_n37;
  t96_n36: return 0.06571143865585327f;
  t96_n37: return 0.03353816643357277f;
  t96_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t96_n40;
  t96_n39: return -0.08801247924566269f;
  t96_n40: return 0.04145871847867966f;
  t96_n41: return 0.023379933089017868f;
  t96_n42: return 0.05398033931851387f;
  t96_n43: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t96_n45;
  t96_n44: return -0.01294593047350645f;
  t96_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t96_n49;
  t96_n46: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t96_n48;
  t96_n47: return -0.10630567371845245f;
  t96_n48: return -0.0009884960018098354f;
  t96_n49: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t96_n55;
  t96_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t96_n54;
  t96_n51: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t96_n53;
  t96_n52: return -0.07978007197380066f;
  t96_n53: return 0.0028004320338368416f;
  t96_n54: return 0.010023750364780426f;
  t96_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t96_n79;
  t96_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t96_n58;
  t96_n57: return 0.0043716453947126865f;
  t96_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t96_n68;
  t96_n59: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t96_n61;
  t96_n60: return 0.06591104716062546f;
  t96_n61: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t96_n63;
  t96_n62: return 0.01634824089705944f;
  t96_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t96_n67;
  t96_n64: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t96_n66;
  t96_n65: return -0.018574511632323265f;
  t96_n66: return -0.18057070672512054f;
  t96_n67: return -0.027338214218616486f;
  t96_n68: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t96_n78;
  t96_n69: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t96_n71;
  t96_n70: return 0.025426704436540604f;
  t96_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t96_n73;
  t96_n72: return 0.052589207887649536f;
  t96_n73: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t96_n75;
  t96_n74: return 0.05558105930685997f;
  t96_n75: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t96_n77;
  t96_n76: return 0.11321042478084564f;
  t96_n77: return 0.09546016156673431f;
  t96_n78: return 0.006165622733533382f;
  t96_n79: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t96_n91;
  t96_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t96_n90;
  t96_n81: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t96_n85;
  t96_n82: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t96_n84;
  t96_n83: return 0.11078125238418579f;
  t96_n84: return 0.0845177099108696f;
  t96_n85: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t96_n89;
  t96_n86: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t96_n88;
  t96_n87: return 0.11730778217315674f;
  t96_n88: return 0.10567427426576614f;
  t96_n89: return 0.0766647458076477f;
  t96_n90: return 0.08255369961261749f;
  t96_n91: return -0.05936150625348091f;
  t96_n92: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t96_n98;
  t96_n93: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t96_n97;
  t96_n94: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t96_n96;
  t96_n95: return 0.012983094900846481f;
  t96_n96: return 0.034184008836746216f;
  t96_n97: return -0.004477353300899267f;
  t96_n98: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t96_n252;
  t96_n99: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t96_n207;
  t96_n100: if (E.getNumReferences() >= 3318231040 /*6406.0*/) goto t96_n104;
  t96_n101: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t96_n103;
  t96_n102: return 0.014971796423196793f;
  t96_n103: return 0.08490604907274246f;
  t96_n104: if (E.getNumReferences() >= 3318784000 /*6676.0*/) goto t96_n116;
  t96_n105: if (E.getNumReferences() >= 3318759424 /*6664.0*/) goto t96_n107;
  t96_n106: return 0.08333209156990051f;
  t96_n107: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t96_n109;
  t96_n108: return 0.011243491433560848f;
  t96_n109: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t96_n111;
  t96_n110: return 0.11891432106494904f;
  t96_n111: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t96_n115;
  t96_n112: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t96_n114;
  t96_n113: return 0.14711754024028778f;
  t96_n114: return 0.12090428918600082f;
  t96_n115: return 0.13721801340579987f;
  t96_n116: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t96_n120;
  t96_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t96_n119;
  t96_n118: return -0.019225435331463814f;
  t96_n119: return 0.03922232240438461f;
  t96_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t96_n122;
  t96_n121: return 0.03421534597873688f;
  t96_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t96_n150;
  t96_n123: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t96_n127;
  t96_n124: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t96_n126;
  t96_n125: return 0.11317203938961029f;
  t96_n126: return -0.2755536139011383f;
  t96_n127: if (E.getNumReferences() >= 3330990592 /*17777.0*/) goto t96_n129;
  t96_n128: return 0.050295665860176086f;
  t96_n129: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t96_n149;
  t96_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t96_n136;
  t96_n131: if (E.getNumReferences() >= 3331176192 /*18139.5*/) goto t96_n135;
  t96_n132: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t96_n134;
  t96_n133: return -0.0058528282679617405f;
  t96_n134: return 0.12002094089984894f;
  t96_n135: return -0.3576519787311554f;
  t96_n136: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t96_n138;
  t96_n137: return 0.029911544173955917f;
  t96_n138: if (E.getNumReferences() >= 3332047872 /*19842.0*/) goto t96_n142;
  t96_n139: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t96_n141;
  t96_n140: return 0.1142316684126854f;
  t96_n141: return 0.10367000848054886f;
  t96_n142: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t96_n144;
  t96_n143: return 0.08324839174747467f;
  t96_n144: if (E.getNumReferences() >= 3333127936 /*21951.5*/) goto t96_n146;
  t96_n145: return 0.23297597467899323f;
  t96_n146: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t96_n148;
  t96_n147: return 0.11400819569826126f;
  t96_n148: return 0.07844395190477371f;
  t96_n149: return 0.002122376346960664f;
  t96_n150: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t96_n152;
  t96_n151: return 0.1139783039689064f;
  t96_n152: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t96_n186;
  t96_n153: if (E.getNumReferences() >= 3332440064 /*20608.0*/) goto t96_n185;
  t96_n154: if (E.getNumReferences() >= 3332338944 /*20410.5*/) goto t96_n182;
  t96_n155: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t96_n177;
  t96_n156: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t96_n158;
  t96_n157: return 0.048857733607292175f;
  t96_n158: if (E.getNumReferences() >= 3324409856 /*10654.0*/) goto t96_n176;
  t96_n159: if (E.getNumReferences() >= 3324087808 /*10339.5*/) goto t96_n175;
  t96_n160: if (E.getNumReferences() >= 3319414784 /*6984.0*/) goto t96_n162;
  t96_n161: return -0.006480421870946884f;
  t96_n162: if (E.getNumReferences() >= 3320403968 /*7467.0*/) goto t96_n170;
  t96_n163: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t96_n165;
  t96_n164: return 0.10594820976257324f;
  t96_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t96_n167;
  t96_n166: return 0.08868490904569626f;
  t96_n167: if (E.getNumReferences() >= 3319786496 /*7165.5*/) goto t96_n169;
  t96_n168: return 0.10039341449737549f;
  t96_n169: return 0.05307450145483017f;
  t96_n170: if (E.getNumReferences() >= 3321574400 /*8038.5*/) goto t96_n172;
  t96_n171: return -0.14285019040107727f;
  t96_n172: if (E.getNumReferences() >= 3321964032 /*8265.5*/) goto t96_n174;
  t96_n173: return 0.11261554062366486f;
  t96_n174: return 0.09208755940198898f;
  t96_n175: return 0.11061122268438339f;
  t96_n176: return 0.01783411018550396f;
  t96_n177: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t96_n181;
  t96_n178: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t96_n180;
  t96_n179: return 0.11960475891828537f;
  t96_n180: return 0.09780517965555191f;
  t96_n181: return 0.0440516360104084f;
  t96_n182: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t96_n184;
  t96_n183: return 0.11339151859283447f;
  t96_n184: return 0.08856186270713806f;
  t96_n185: return -0.34723520278930664f;
  t96_n186: if (E.getNumReferences() >= 3318970368 /*6767.0*/) goto t96_n188;
  t96_n187: return 0.10904903709888458f;
  t96_n188: if (E.getNumReferences() >= 3322122752 /*8420.5*/) goto t96_n190;
  t96_n189: return -0.08665937930345535f;
  t96_n190: if (E.getNumReferences() >= 3322210304 /*8506.0*/) goto t96_n192;
  t96_n191: return 0.11486365646123886f;
  t96_n192: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t96_n194;
  t96_n193: return 0.031551115214824677f;
  t96_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t96_n206;
  t96_n195: if (E.getNumReferences() >= 3322854400 /*9135.0*/) goto t96_n197;
  t96_n196: return 0.11217666417360306f;
  t96_n197: if (E.getNumReferences() >= 3329480192 /*15605.5*/) goto t96_n199;
  t96_n198: return 0.10136617720127106f;
  t96_n199: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t96_n205;
  t96_n200: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t96_n204;
  t96_n201: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t96_n203;
  t96_n202: return 0.08822064101696014f;
  t96_n203: return 0.103655144572258f;
  t96_n204: return 0.10398595035076141f;
  t96_n205: return -0.015971088781952858f;
  t96_n206: return 0.07387425750494003f;
  t96_n207: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t96_n251;
  t96_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t96_n250;
  t96_n209: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t96_n249;
  t96_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t96_n212;
  t96_n211: return 0.0004502807860262692f;
  t96_n212: if (E.getNumReferences() >= 3336764160 /*29053.5*/) goto t96_n214;
  t96_n213: return -0.09066782891750336f;
  t96_n214: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t96_n220;
  t96_n215: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t96_n217;
  t96_n216: return 0.00709532480686903f;
  t96_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t96_n219;
  t96_n218: return -0.0765317976474762f;
  t96_n219: return 0.10701580345630646f;
  t96_n220: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t96_n234;
  t96_n221: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t96_n233;
  t96_n222: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t96_n232;
  t96_n223: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t96_n227;
  t96_n224: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t96_n226;
  t96_n225: return -0.37269526720046997f;
  t96_n226: return 0.04755537584424019f;
  t96_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t96_n231;
  t96_n228: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t96_n230;
  t96_n229: return -0.11712319403886795f;
  t96_n230: return -0.5047888159751892f;
  t96_n231: return -0.24668928980827332f;
  t96_n232: return -0.06677182763814926f;
  t96_n233: return 0.011428928934037685f;
  t96_n234: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t96_n244;
  t96_n235: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t96_n243;
  t96_n236: if (E.getNumReferences() >= 3355504736 /*132033.5*/) goto t96_n242;
  t96_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t96_n239;
  t96_n238: return -0.006774561014026403f;
  t96_n239: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t96_n241;
  t96_n240: return 0.013853151351213455f;
  t96_n241: return 0.06747904419898987f;
  t96_n242: return -0.1272115856409073f;
  t96_n243: return 0.03241739794611931f;
  t96_n244: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t96_n248;
  t96_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t96_n247;
  t96_n246: return -0.13540565967559814f;
  t96_n247: return -0.018798407167196274f;
  t96_n248: return 0.003689679317176342f;
  t96_n249: return 0.019762221723794937f;
  t96_n250: return 0.04650440067052841f;
  t96_n251: return 0.0772392600774765f;
  t96_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t96_n254;
  t96_n253: return 0.037067752331495285f;
  t96_n254: return 0.05485525354743004f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree97(const Example& E) {
  t97_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t97_n154;
  t97_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t97_n3;
  t97_n2: return -0.0012955657439306378f;
  t97_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t97_n19;
  t97_n4: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t97_n6;
  t97_n5: return -0.006686662323772907f;
  t97_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t97_n14;
  t97_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t97_n9;
  t97_n8: return 0.08943556249141693f;
  t97_n9: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t97_n11;
  t97_n10: return 0.028681442141532898f;
  t97_n11: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t97_n13;
  t97_n12: return 0.07498548924922943f;
  t97_n13: return 0.10622687637805939f;
  t97_n14: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t97_n16;
  t97_n15: return 0.10819951444864273f;
  t97_n16: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t97_n18;
  t97_n17: return 0.06754162162542343f;
  t97_n18: return -0.4916348457336426f;
  t97_n19: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t97_n41;
  t97_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t97_n22;
  t97_n21: return 0.021074064075946808f;
  t97_n22: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t97_n26;
  t97_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t97_n25;
  t97_n24: return -0.01567552611231804f;
  t97_n25: return 0.07361116260290146f;
  t97_n26: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n38;
  t97_n27: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t97_n37;
  t97_n28: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t97_n34;
  t97_n29: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t97_n33;
  t97_n30: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t97_n32;
  t97_n31: return 0.09160799533128738f;
  t97_n32: return 0.11029797047376633f;
  t97_n33: return -0.11968391388654709f;
  t97_n34: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t97_n36;
  t97_n35: return 0.11452104151248932f;
  t97_n36: return 0.1004658192396164f;
  t97_n37: return 0.06394042819738388f;
  t97_n38: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t97_n40;
  t97_n39: return 0.07950667291879654f;
  t97_n40: return 0.0548374280333519f;
  t97_n41: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t97_n123;
  t97_n42: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t97_n118;
  t97_n43: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t97_n109;
  t97_n44: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t97_n108;
  t97_n45: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t97_n87;
  t97_n46: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t97_n86;
  t97_n47: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t97_n67;
  t97_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t97_n50;
  t97_n49: return 0.002060066442936659f;
  t97_n50: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t97_n52;
  t97_n51: return 0.12395332008600235f;
  t97_n52: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t97_n54;
  t97_n53: return 0.022845828905701637f;
  t97_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t97_n66;
  t97_n55: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t97_n59;
  t97_n56: if (E.getNumReferences() >= 3348338496 /*75566.5*/) goto t97_n58;
  t97_n57: return 0.05083879455924034f;
  t97_n58: return 0.12662507593631744f;
  t97_n59: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t97_n65;
  t97_n60: if (E.getNumReferences() >= 3350124096 /*89516.5*/) goto t97_n62;
  t97_n61: return -0.005357729736715555f;
  t97_n62: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t97_n64;
  t97_n63: return 0.11771401017904282f;
  t97_n64: return 0.10105127841234207f;
  t97_n65: return -0.05581415444612503f;
  t97_n66: return 0.1540730893611908f;
  t97_n67: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t97_n75;
  t97_n68: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t97_n70;
  t97_n69: return -0.08350095897912979f;
  t97_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t97_n72;
  t97_n71: return -0.24843968451023102f;
  t97_n72: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n74;
  t97_n73: return 0.1318340003490448f;
  t97_n74: return 0.09578090906143188f;
  t97_n75: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t97_n81;
  t97_n76: if (E.getNumReferences() >= 3352615936 /*108984.0*/) goto t97_n78;
  t97_n77: return 0.04153922200202942f;
  t97_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t97_n80;
  t97_n79: return 0.07976817339658737f;
  t97_n80: return 0.10976900160312653f;
  t97_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t97_n83;
  t97_n82: return -0.40390539169311523f;
  t97_n83: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t97_n85;
  t97_n84: return 0.09059277176856995f;
  t97_n85: return -0.04042375832796097f;
  t97_n86: return -0.04848996549844742f;
  t97_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t97_n95;
  t97_n88: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t97_n90;
  t97_n89: return 0.01580740511417389f;
  t97_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t97_n92;
  t97_n91: return -0.1108558252453804f;
  t97_n92: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t97_n94;
  t97_n93: return 0.12433090806007385f;
  t97_n94: return 0.030416235327720642f;
  t97_n95: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t97_n101;
  t97_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t97_n98;
  t97_n97: return -0.008401057682931423f;
  t97_n98: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t97_n100;
  t97_n99: return 0.10225042700767517f;
  t97_n100: return 0.07429160177707672f;
  t97_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t97_n103;
  t97_n102: return -0.12168710678815842f;
  t97_n103: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n105;
  t97_n104: return 0.08336204290390015f;
  t97_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t97_n107;
  t97_n106: return -0.08480236679315567f;
  t97_n107: return 0.05880757048726082f;
  t97_n108: return -0.05854702740907669f;
  t97_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t97_n111;
  t97_n110: return -0.05852372944355011f;
  t97_n111: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t97_n117;
  t97_n112: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t97_n116;
  t97_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t97_n115;
  t97_n114: return -0.03473115339875221f;
  t97_n115: return 0.09980129450559616f;
  t97_n116: return -0.03566311299800873f;
  t97_n117: return 0.014630191028118134f;
  t97_n118: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t97_n122;
  t97_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t97_n121;
  t97_n120: return -0.01973024010658264f;
  t97_n121: return 0.029583120718598366f;
  t97_n122: return -0.15654967725276947f;
  t97_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t97_n153;
  t97_n124: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t97_n146;
  t97_n125: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t97_n145;
  t97_n126: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t97_n144;
  t97_n127: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t97_n141;
  t97_n128: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t97_n134;
  t97_n129: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t97_n133;
  t97_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t97_n132;
  t97_n131: return 0.07284697145223618f;
  t97_n132: return 0.10881593823432922f;
  t97_n133: return 0.008876493200659752f;
  t97_n134: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n140;
  t97_n135: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t97_n139;
  t97_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t97_n138;
  t97_n137: return 0.06077319756150246f;
  t97_n138: return 0.1110326275229454f;
  t97_n139: return 0.09723310172557831f;
  t97_n140: return 0.04240293800830841f;
  t97_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t97_n143;
  t97_n142: return 0.060080982744693756f;
  t97_n143: return 0.10943829268217087f;
  t97_n144: return -0.15712396800518036f;
  t97_n145: return -0.11772087216377258f;
  t97_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t97_n148;
  t97_n147: return -0.011151168495416641f;
  t97_n148: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t97_n150;
  t97_n149: return -0.11926619708538055f;
  t97_n150: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t97_n152;
  t97_n151: return 0.11866813898086548f;
  t97_n152: return 0.03716165944933891f;
  t97_n153: return 0.15812315046787262f;
  t97_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t97_n158;
  t97_n155: if (E.getNumReferences() >= 3333877504 /*23415.5*/) goto t97_n157;
  t97_n156: return -0.007844231091439724f;
  t97_n157: return -0.22879558801651f;
  t97_n158: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t97_n234;
  t97_n159: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t97_n171;
  t97_n160: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t97_n168;
  t97_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n163;
  t97_n162: return 0.028998415917158127f;
  t97_n163: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t97_n165;
  t97_n164: return 0.009353924542665482f;
  t97_n165: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t97_n167;
  t97_n166: return -0.067509725689888f;
  t97_n167: return 0.02819921262562275f;
  t97_n168: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t97_n170;
  t97_n169: return -0.11658398061990738f;
  t97_n170: return 0.01122510526329279f;
  t97_n171: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t97_n207;
  t97_n172: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t97_n194;
  t97_n173: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t97_n193;
  t97_n174: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t97_n190;
  t97_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t97_n177;
  t97_n176: return 0.0968620777130127f;
  t97_n177: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t97_n181;
  t97_n178: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t97_n180;
  t97_n179: return 0.09543012827634811f;
  t97_n180: return 0.12066154927015305f;
  t97_n181: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t97_n183;
  t97_n182: return -0.1350410282611847f;
  t97_n183: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t97_n187;
  t97_n184: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t97_n186;
  t97_n185: return 0.23547491431236267f;
  t97_n186: return -0.11218053847551346f;
  t97_n187: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t97_n189;
  t97_n188: return 0.1165308877825737f;
  t97_n189: return 0.0f;
  t97_n190: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t97_n192;
  t97_n191: return 0.12485598772764206f;
  t97_n192: return -0.5664212107658386f;
  t97_n193: return -0.04198496788740158f;
  t97_n194: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t97_n206;
  t97_n195: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t97_n197;
  t97_n196: return 0.015895724296569824f;
  t97_n197: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t97_n205;
  t97_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t97_n204;
  t97_n199: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t97_n201;
  t97_n200: return 0.07101432234048843f;
  t97_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t97_n203;
  t97_n202: return 0.1330980360507965f;
  t97_n203: return -0.07823740690946579f;
  t97_n204: return -0.08844176679849625f;
  t97_n205: return 0.06015205383300781f;
  t97_n206: return -0.0396139919757843f;
  t97_n207: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t97_n213;
  t97_n208: if (E.getNumReferences() >= 3274014720 /*165.5*/) goto t97_n212;
  t97_n209: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t97_n211;
  t97_n210: return -0.08431185781955719f;
  t97_n211: return 0.04273049905896187f;
  t97_n212: return -0.00959805864840746f;
  t97_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t97_n231;
  t97_n214: if (E.getNumReferences() >= 3332089344 /*19923.0*/) goto t97_n226;
  t97_n215: if (E.getNumReferences() >= 3331505664 /*18783.0*/) goto t97_n219;
  t97_n216: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t97_n218;
  t97_n217: return 0.1161874458193779f;
  t97_n218: return 0.05432628467679024f;
  t97_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n225;
  t97_n220: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t97_n222;
  t97_n221: return 0.12299942970275879f;
  t97_n222: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t97_n224;
  t97_n223: return -0.14065155386924744f;
  t97_n224: return 0.12355731427669525f;
  t97_n225: return 0.08844872564077377f;
  t97_n226: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t97_n228;
  t97_n227: return -0.019143065437674522f;
  t97_n228: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t97_n230;
  t97_n229: return 0.08612046390771866f;
  t97_n230: return 0.032304901629686356f;
  t97_n231: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n233;
  t97_n232: return 0.10843551158905029f;
  t97_n233: return -0.05492519587278366f;
  t97_n234: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t97_n236;
  t97_n235: return 0.002839708235114813f;
  t97_n236: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t97_n254;
  t97_n237: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t97_n253;
  t97_n238: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t97_n240;
  t97_n239: return 0.012806297279894352f;
  t97_n240: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t97_n252;
  t97_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t97_n243;
  t97_n242: return 0.03627147525548935f;
  t97_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t97_n251;
  t97_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t97_n250;
  t97_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t97_n247;
  t97_n246: return 0.048722900450229645f;
  t97_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t97_n249;
  t97_n248: return 0.10171176493167877f;
  t97_n249: return 0.085167795419693f;
  t97_n250: return 0.10208897292613983f;
  t97_n251: return -0.024046888574957848f;
  t97_n252: return 0.04687828943133354f;
  t97_n253: return 0.01112605631351471f;
  t97_n254: return -0.10911855101585388f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree98(const Example& E) {
  t98_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t98_n254;
  t98_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t98_n163;
  t98_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t98_n20;
  t98_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t98_n5;
  t98_n4: return -0.025917746126651764f;
  t98_n5: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t98_n7;
  t98_n6: return -0.01079291757196188f;
  t98_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n9;
  t98_n8: return 0.001086836215108633f;
  t98_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t98_n11;
  t98_n10: return 0.007526696193963289f;
  t98_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t98_n13;
  t98_n12: return -0.07394518703222275f;
  t98_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t98_n15;
  t98_n14: return 0.024026377126574516f;
  t98_n15: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t98_n19;
  t98_n16: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t98_n18;
  t98_n17: return 0.10548684000968933f;
  t98_n18: return 0.06628863513469696f;
  t98_n19: return -0.05489664897322655f;
  t98_n20: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t98_n120;
  t98_n21: if (E.getFileProximityDistance() >= 3212836864 /*1.0*/) goto t98_n23;
  t98_n22: return 0.10188950598239899f;
  t98_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t98_n45;
  t98_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t98_n26;
  t98_n25: return -0.011332454159855843f;
  t98_n26: if (E.getNumReferences() >= 3363872672 /*263421.0*/) goto t98_n40;
  t98_n27: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t98_n29;
  t98_n28: return 0.0026240821462124586f;
  t98_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t98_n31;
  t98_n30: return 0.039505038410425186f;
  t98_n31: if (E.getNumReferences() >= 3318719488 /*6644.5*/) goto t98_n35;
  t98_n32: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t98_n34;
  t98_n33: return 0.022115956991910934f;
  t98_n34: return 0.07103898376226425f;
  t98_n35: if (E.getNumReferences() >= 3318872064 /*6719.0*/) goto t98_n39;
  t98_n36: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t98_n38;
  t98_n37: return 0.10624467581510544f;
  t98_n38: return 0.13437789678573608f;
  t98_n39: return 0.05179215222597122f;
  t98_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t98_n42;
  t98_n41: return 0.010144757106900215f;
  t98_n42: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n44;
  t98_n43: return 0.023026766255497932f;
  t98_n44: return 0.07597558945417404f;
  t98_n45: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t98_n119;
  t98_n46: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t98_n72;
  t98_n47: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t98_n71;
  t98_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t98_n50;
  t98_n49: return 0.006477975752204657f;
  t98_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t98_n70;
  t98_n51: if (E.getNumReferences() >= 3360148800 /*204597.0*/) goto t98_n53;
  t98_n52: return 0.010408995673060417f;
  t98_n53: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t98_n67;
  t98_n54: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n64;
  t98_n55: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t98_n57;
  t98_n56: return 0.07380001991987228f;
  t98_n57: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t98_n63;
  t98_n58: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t98_n60;
  t98_n59: return -0.11077883094549179f;
  t98_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t98_n62;
  t98_n61: return 0.10890991985797882f;
  t98_n62: return 0.12663143873214722f;
  t98_n63: return 0.22840331494808197f;
  t98_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n66;
  t98_n65: return 0.0883612260222435f;
  t98_n66: return 0.06053411588072777f;
  t98_n67: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t98_n69;
  t98_n68: return 0.12399494647979736f;
  t98_n69: return 0.013496384024620056f;
  t98_n70: return 0.05867446959018707f;
  t98_n71: return -0.024633320048451424f;
  t98_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t98_n114;
  t98_n73: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t98_n89;
  t98_n74: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t98_n82;
  t98_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t98_n79;
  t98_n76: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t98_n78;
  t98_n77: return -0.15405559539794922f;
  t98_n78: return -0.4305914640426636f;
  t98_n79: if (E.getNumReferences() >= 3301117952 /*1560.5*/) goto t98_n81;
  t98_n80: return -0.025418879464268684f;
  t98_n81: return 0.07792146503925323f;
  t98_n82: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t98_n84;
  t98_n83: return -0.026885859668254852f;
  t98_n84: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t98_n88;
  t98_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t98_n87;
  t98_n86: return -0.5091191530227661f;
  t98_n87: return 0.1224827840924263f;
  t98_n88: return -0.09435832500457764f;
  t98_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t98_n93;
  t98_n90: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t98_n92;
  t98_n91: return -0.3047519624233246f;
  t98_n92: return -0.05647498741745949f;
  t98_n93: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t98_n97;
  t98_n94: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t98_n96;
  t98_n95: return -0.049984999001026154f;
  t98_n96: return -0.04540818929672241f;
  t98_n97: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t98_n111;
  t98_n98: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n110;
  t98_n99: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t98_n109;
  t98_n100: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t98_n106;
  t98_n101: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t98_n105;
  t98_n102: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t98_n104;
  t98_n103: return 0.10310680419206619f;
  t98_n104: return 0.11385010927915573f;
  t98_n105: return -0.039733123034238815f;
  t98_n106: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t98_n108;
  t98_n107: return 0.10381212830543518f;
  t98_n108: return 0.10555332154035568f;
  t98_n109: return -0.1959865838289261f;
  t98_n110: return 0.014644855633378029f;
  t98_n111: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n113;
  t98_n112: return 0.0034323600120842457f;
  t98_n113: return -0.06147900968790054f;
  t98_n114: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t98_n118;
  t98_n115: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t98_n117;
  t98_n116: return -0.04275107756257057f;
  t98_n117: return 0.012362425215542316f;
  t98_n118: return 0.03856726735830307f;
  t98_n119: return -0.11621017754077911f;
  t98_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t98_n122;
  t98_n121: return -0.11495468765497208f;
  t98_n122: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t98_n126;
  t98_n123: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t98_n125;
  t98_n124: return 0.02098282426595688f;
  t98_n125: return -0.007571564055979252f;
  t98_n126: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t98_n162;
  t98_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t98_n139;
  t98_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n130;
  t98_n129: return 0.048850711435079575f;
  t98_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t98_n132;
  t98_n131: return -0.15491527318954468f;
  t98_n132: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t98_n138;
  t98_n133: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t98_n135;
  t98_n134: return 0.12212517857551575f;
  t98_n135: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t98_n137;
  t98_n136: return 0.12267785519361496f;
  t98_n137: return 0.20300018787384033f;
  t98_n138: return 0.03669493645429611f;
  t98_n139: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t98_n151;
  t98_n140: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t98_n148;
  t98_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t98_n143;
  t98_n142: return 0.04114600270986557f;
  t98_n143: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t98_n147;
  t98_n144: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t98_n146;
  t98_n145: return 0.10713643580675125f;
  t98_n146: return 0.053401779383420944f;
  t98_n147: return -0.13686306774616241f;
  t98_n148: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t98_n150;
  t98_n149: return 0.06871869415044785f;
  t98_n150: return 0.05125082656741142f;
  t98_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t98_n157;
  t98_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t98_n154;
  t98_n153: return 0.06836367398500443f;
  t98_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n156;
  t98_n155: return 0.1099194884300232f;
  t98_n156: return 0.08650656044483185f;
  t98_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n159;
  t98_n158: return 0.10291978716850281f;
  t98_n159: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n161;
  t98_n160: return -0.5920601487159729f;
  t98_n161: return 0.1010967269539833f;
  t98_n162: return -0.076923668384552f;
  t98_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t98_n165;
  t98_n164: return -0.007413034792989492f;
  t98_n165: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t98_n233;
  t98_n166: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t98_n168;
  t98_n167: return 0.009797945618629456f;
  t98_n168: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t98_n212;
  t98_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t98_n209;
  t98_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n186;
  t98_n171: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t98_n183;
  t98_n172: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t98_n176;
  t98_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t98_n175;
  t98_n174: return -0.10612310469150543f;
  t98_n175: return 0.11943849921226501f;
  t98_n176: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t98_n178;
  t98_n177: return -0.000205879463464953f;
  t98_n178: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t98_n180;
  t98_n179: return 0.15955989062786102f;
  t98_n180: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t98_n182;
  t98_n181: return 0.11516375094652176f;
  t98_n182: return 0.0f;
  t98_n183: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t98_n185;
  t98_n184: return 0.12509393692016602f;
  t98_n185: return -0.35683441162109375f;
  t98_n186: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t98_n188;
  t98_n187: return -0.007131151854991913f;
  t98_n188: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t98_n200;
  t98_n189: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t98_n193;
  t98_n190: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t98_n192;
  t98_n191: return 0.02247648872435093f;
  t98_n192: return 0.10635615140199661f;
  t98_n193: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t98_n199;
  t98_n194: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t98_n198;
  t98_n195: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n197;
  t98_n196: return 0.11125127226114273f;
  t98_n197: return 0.015340590849518776f;
  t98_n198: return 0.13294824957847595f;
  t98_n199: return -0.08084648847579956f;
  t98_n200: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t98_n202;
  t98_n201: return 0.007050762884318829f;
  t98_n202: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t98_n208;
  t98_n203: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t98_n205;
  t98_n204: return 0.023393461480736732f;
  t98_n205: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t98_n207;
  t98_n206: return 0.13868460059165955f;
  t98_n207: return 0.028283141553401947f;
  t98_n208: return -0.002604513196274638f;
  t98_n209: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t98_n211;
  t98_n210: return 0.028850411996245384f;
  t98_n211: return -0.08575962483882904f;
  t98_n212: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t98_n216;
  t98_n213: if (E.getNumReferences() >= 3274014720 /*165.5*/) goto t98_n215;
  t98_n214: return 0.0339847132563591f;
  t98_n215: return -0.008457883261144161f;
  t98_n216: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t98_n230;
  t98_n217: if (E.getNumReferences() >= 3332089344 /*19923.0*/) goto t98_n227;
  t98_n218: if (E.getNumReferences() >= 3331505664 /*18783.0*/) goto t98_n220;
  t98_n219: return 0.05406290292739868f;
  t98_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n226;
  t98_n221: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t98_n223;
  t98_n222: return 0.12170353531837463f;
  t98_n223: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t98_n225;
  t98_n224: return -0.12483987957239151f;
  t98_n225: return 0.11220915615558624f;
  t98_n226: return 0.08644632995128632f;
  t98_n227: if (E.getNumReferences() >= 3349646912 /*85788.5*/) goto t98_n229;
  t98_n228: return -0.014689773321151733f;
  t98_n229: return 0.05197470635175705f;
  t98_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n232;
  t98_n231: return 0.10736425966024399f;
  t98_n232: return -0.038208816200494766f;
  t98_n233: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t98_n235;
  t98_n234: return 0.0033093984238803387f;
  t98_n235: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t98_n253;
  t98_n236: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t98_n252;
  t98_n237: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t98_n239;
  t98_n238: return 0.013159465976059437f;
  t98_n239: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t98_n251;
  t98_n240: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t98_n250;
  t98_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t98_n249;
  t98_n242: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t98_n244;
  t98_n243: return 0.09914752095937729f;
  t98_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t98_n248;
  t98_n245: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t98_n247;
  t98_n246: return 0.09749525785446167f;
  t98_n247: return 0.09183991700410843f;
  t98_n248: return 0.0576641708612442f;
  t98_n249: return 0.04457258805632591f;
  t98_n250: return 0.041146740317344666f;
  t98_n251: return 0.0498821847140789f;
  t98_n252: return 0.00988976750522852f;
  t98_n253: return -0.14098307490348816f;
  t98_n254: return -0.06599750369787216f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree99(const Example& E) {
  t99_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t99_n186;
  t99_n1: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t99_n119;
  t99_n2: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t99_n72;
  t99_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t99_n7;
  t99_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t99_n6;
  t99_n5: return -0.02247381955385208f;
  t99_n6: return -0.0010186482686549425f;
  t99_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t99_n9;
  t99_n8: return 0.0040395865216851234f;
  t99_n9: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t99_n63;
  t99_n10: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t99_n60;
  t99_n11: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t99_n19;
  t99_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t99_n18;
  t99_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t99_n15;
  t99_n14: return -0.07185455411672592f;
  t99_n15: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t99_n17;
  t99_n16: return 0.07881180942058563f;
  t99_n17: return -0.08181405067443848f;
  t99_n18: return 0.017601244151592255f;
  t99_n19: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t99_n21;
  t99_n20: return 0.023444872349500656f;
  t99_n21: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t99_n35;
  t99_n22: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t99_n24;
  t99_n23: return -0.0007974344189278781f;
  t99_n24: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t99_n32;
  t99_n25: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t99_n27;
  t99_n26: return 0.0015288109425455332f;
  t99_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t99_n31;
  t99_n28: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t99_n30;
  t99_n29: return -0.7984578013420105f;
  t99_n30: return -0.14531725645065308f;
  t99_n31: return -0.09114042669534683f;
  t99_n32: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t99_n34;
  t99_n33: return -0.07422271370887756f;
  t99_n34: return 0.0656154453754425f;
  t99_n35: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t99_n43;
  t99_n36: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t99_n42;
  t99_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t99_n39;
  t99_n38: return -0.10530121624469757f;
  t99_n39: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t99_n41;
  t99_n40: return 0.07039990276098251f;
  t99_n41: return 0.130899116396904f;
  t99_n42: return 0.07713564485311508f;
  t99_n43: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t99_n59;
  t99_n44: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t99_n58;
  t99_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t99_n47;
  t99_n46: return 0.012599651701748371f;
  t99_n47: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t99_n49;
  t99_n48: return 0.11440284550189972f;
  t99_n49: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t99_n51;
  t99_n50: return 0.03276701271533966f;
  t99_n51: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t99_n55;
  t99_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t99_n54;
  t99_n53: return 0.07878798246383667f;
  t99_n54: return 0.12412294000387192f;
  t99_n55: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t99_n57;
  t99_n56: return -0.007857121527194977f;
  t99_n57: return 0.11605766415596008f;
  t99_n58: return 0.05927050858736038f;
  t99_n59: return -0.10728714615106583f;
  t99_n60: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t99_n62;
  t99_n61: return 0.022188924252986908f;
  t99_n62: return 0.0871528685092926f;
  t99_n63: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t99_n65;
  t99_n64: return -0.02852298691868782f;
  t99_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t99_n71;
  t99_n66: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t99_n70;
  t99_n67: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t99_n69;
  t99_n68: return -0.13913510739803314f;
  t99_n69: return 0.12048380076885223f;
  t99_n70: return -0.2039826661348343f;
  t99_n71: return 0.007591854780912399f;
  t99_n72: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t99_n92;
  t99_n73: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t99_n77;
  t99_n74: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t99_n76;
  t99_n75: return -0.06894463300704956f;
  t99_n76: return -0.1517312377691269f;
  t99_n77: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t99_n91;
  t99_n78: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t99_n80;
  t99_n79: return 0.0031485450454056263f;
  t99_n80: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t99_n82;
  t99_n81: return 0.02794468402862549f;
  t99_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t99_n84;
  t99_n83: return 0.04749739542603493f;
  t99_n84: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t99_n86;
  t99_n85: return -0.06049901619553566f;
  t99_n86: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t99_n90;
  t99_n87: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t99_n89;
  t99_n88: return 0.025920329615473747f;
  t99_n89: return 0.12797649204730988f;
  t99_n90: return 0.07939422130584717f;
  t99_n91: return -0.043427031487226486f;
  t99_n92: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t99_n100;
  t99_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t99_n95;
  t99_n94: return 0.001971433637663722f;
  t99_n95: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t99_n99;
  t99_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t99_n98;
  t99_n97: return -0.016107380390167236f;
  t99_n98: return 0.058954816311597824f;
  t99_n99: return -0.009606007486581802f;
  t99_n100: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t99_n104;
  t99_n101: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t99_n103;
  t99_n102: return 0.2797718942165375f;
  t99_n103: return 0.10791962593793869f;
  t99_n104: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t99_n106;
  t99_n105: return -0.0024723787792026997f;
  t99_n106: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t99_n118;
  t99_n107: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t99_n109;
  t99_n108: return -0.06927098333835602f;
  t99_n109: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t99_n113;
  t99_n110: if (E.getNumReferences() >= 3257008128 /*40.5*/) goto t99_n112;
  t99_n111: return 0.2051384299993515f;
  t99_n112: return 0.11563803255558014f;
  t99_n113: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t99_n117;
  t99_n114: if (E.getNumReferences() >= 3261071360 /*56.0*/) goto t99_n116;
  t99_n115: return 0.09422436356544495f;
  t99_n116: return 0.1168687492609024f;
  t99_n117: return -0.005000712815672159f;
  t99_n118: return -0.18732112646102905f;
  t99_n119: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t99_n181;
  t99_n120: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t99_n138;
  t99_n121: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t99_n123;
  t99_n122: return -0.00036497137625701725f;
  t99_n123: if (E.getNumReferences() >= 3308374016 /*2844.5*/) goto t99_n131;
  t99_n124: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t99_n130;
  t99_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t99_n127;
  t99_n126: return -0.04315929487347603f;
  t99_n127: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t99_n129;
  t99_n128: return 0.03585737943649292f;
  t99_n129: return 0.010206790640950203f;
  t99_n130: return 0.01155664399266243f;
  t99_n131: if (E.getNumReferences() >= 3308460032 /*2865.5*/) goto t99_n135;
  t99_n132: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t99_n134;
  t99_n133: return 0.11798751354217529f;
  t99_n134: return -0.016257615759968758f;
  t99_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t99_n137;
  t99_n136: return 0.0009885176550596952f;
  t99_n137: return 0.03373175114393234f;
  t99_n138: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t99_n180;
  t99_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t99_n159;
  t99_n140: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t99_n142;
  t99_n141: return 0.031184017658233643f;
  t99_n142: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t99_n144;
  t99_n143: return 0.025544099509716034f;
  t99_n144: if (E.getNumReferences() >= 3291381760 /*698.0*/) goto t99_n158;
  t99_n145: if (E.getNumReferences() >= 3289972736 /*612.0*/) goto t99_n157;
  t99_n146: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t99_n156;
  t99_n147: if (E.getNumReferences() >= 3281469440 /*302.5*/) goto t99_n153;
  t99_n148: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t99_n152;
  t99_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t99_n151;
  t99_n150: return -0.15325400233268738f;
  t99_n151: return 0.14473523199558258f;
  t99_n152: return 0.13363021612167358f;
  t99_n153: if (E.getNumReferences() >= 3288203264 /*508.0*/) goto t99_n155;
  t99_n154: return -0.1889498382806778f;
  t99_n155: return 0.124358169734478f;
  t99_n156: return 0.07142837345600128f;
  t99_n157: return 0.12412875145673752f;
  t99_n158: return 0.03355098143219948f;
  t99_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t99_n169;
  t99_n160: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t99_n162;
  t99_n161: return 0.032486509531736374f;
  t99_n162: if (E.getNumReferences() >= 3264741376 /*76.0*/) goto t99_n168;
  t99_n163: if (E.getNumReferences() >= 3264020480 /*70.5*/) goto t99_n167;
  t99_n164: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t99_n166;
  t99_n165: return 0.1160552054643631f;
  t99_n166: return 0.084187351167202f;
  t99_n167: return 0.1290033608675003f;
  t99_n168: return 0.09017060697078705f;
  t99_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t99_n173;
  t99_n170: if (E.getNumReferences() >= 3273195520 /*153.0*/) goto t99_n172;
  t99_n171: return 0.09974727779626846f;
  t99_n172: return 0.11199299991130829f;
  t99_n173: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t99_n175;
  t99_n174: return -0.006517359521239996f;
  t99_n175: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t99_n177;
  t99_n176: return 0.04292948916554451f;
  t99_n177: if (E.getNumReferences() >= 3279323136 /*246.5*/) goto t99_n179;
  t99_n178: return 0.11488592624664307f;
  t99_n179: return 0.09518758207559586f;
  t99_n180: return -0.0027210605330765247f;
  t99_n181: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t99_n183;
  t99_n182: return 0.04676608741283417f;
  t99_n183: if (E.getNumReferences() >= 3278307328 /*231.0*/) goto t99_n185;
  t99_n184: return 0.12747275829315186f;
  t99_n185: return -4.5000528189120814e-05f;
  t99_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t99_n188;
  t99_n187: return -0.007971166633069515f;
  t99_n188: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t99_n254;
  t99_n189: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t99_n191;
  t99_n190: return 0.00909496285021305f;
  t99_n191: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t99_n249;
  t99_n192: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t99_n242;
  t99_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t99_n209;
  t99_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t99_n196;
  t99_n195: return -0.0017628218047320843f;
  t99_n196: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t99_n204;
  t99_n197: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t99_n201;
  t99_n198: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t99_n200;
  t99_n199: return 0.07009056955575943f;
  t99_n200: return -0.010552742518484592f;
  t99_n201: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t99_n203;
  t99_n202: return 0.10489114373922348f;
  t99_n203: return -0.11152854561805725f;
  t99_n204: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t99_n206;
  t99_n205: return 0.04147110879421234f;
  t99_n206: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t99_n208;
  t99_n207: return 0.16673438251018524f;
  t99_n208: return -0.02379838563501835f;
  t99_n209: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t99_n211;
  t99_n210: return -0.000609453534707427f;
  t99_n211: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t99_n231;
  t99_n212: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t99_n214;
  t99_n213: return 0.012972507625818253f;
  t99_n214: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t99_n222;
  t99_n215: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t99_n217;
  t99_n216: return -0.10975341498851776f;
  t99_n217: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t99_n221;
  t99_n218: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t99_n220;
  t99_n219: return 0.11503834277391434f;
  t99_n220: return 0.12867103517055511f;
  t99_n221: return -0.1379668414592743f;
  t99_n222: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t99_n228;
  t99_n223: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t99_n227;
  t99_n224: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t99_n226;
  t99_n225: return 0.1247042715549469f;
  t99_n226: return 0.10964307188987732f;
  t99_n227: return -0.042227547615766525f;
  t99_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t99_n230;
  t99_n229: return 0.11286312341690063f;
  t99_n230: return -0.14302684366703033f;
  t99_n231: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t99_n241;
  t99_n232: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t99_n240;
  t99_n233: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t99_n237;
  t99_n234: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t99_n236;
  t99_n235: return 0.10694599896669388f;
  t99_n236: return -0.05581749603152275f;
  t99_n237: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t99_n239;
  t99_n238: return 0.15762417018413544f;
  t99_n239: return -0.1578037440776825f;
  t99_n240: return -0.09201379120349884f;
  t99_n241: return -0.5263067483901978f;
  t99_n242: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t99_n248;
  t99_n243: if (E.getNumReferences() >= 3283320832 /*359.0*/) goto t99_n245;
  t99_n244: return -0.24756969511508942f;
  t99_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t99_n247;
  t99_n246: return -0.07257755845785141f;
  t99_n247: return 0.09350777417421341f;
  t99_n248: return 0.02324744313955307f;
  t99_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t99_n253;
  t99_n250: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t99_n252;
  t99_n251: return 0.08859603852033615f;
  t99_n252: return -0.15283353626728058f;
  t99_n253: return -0.36519134044647217f;
  t99_n254: return 0.004929717630147934f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree100(const Example& E) {
  t100_n0: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t100_n72;
  t100_n1: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t100_n35;
  t100_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t100_n4;
  t100_n3: return -0.007117134053260088f;
  t100_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t100_n6;
  t100_n5: return -0.05293549224734306f;
  t100_n6: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t100_n34;
  t100_n7: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t100_n9;
  t100_n8: return 0.012345990166068077f;
  t100_n9: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t100_n11;
  t100_n10: return 0.015419003553688526f;
  t100_n11: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t100_n33;
  t100_n12: if (E.getSymbolScopeDistance() >= 3242196992 /*12.0*/) goto t100_n32;
  t100_n13: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t100_n29;
  t100_n14: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t100_n26;
  t100_n15: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t100_n21;
  t100_n16: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t100_n18;
  t100_n17: return 0.10217897593975067f;
  t100_n18: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t100_n20;
  t100_n19: return -0.01992705650627613f;
  t100_n20: return 0.07454870641231537f;
  t100_n21: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t100_n25;
  t100_n22: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n24;
  t100_n23: return 0.21275772154331207f;
  t100_n24: return 0.10546477138996124f;
  t100_n25: return -0.1588606834411621f;
  t100_n26: if (E.getNumReferences() >= 3258974208 /*48.0*/) goto t100_n28;
  t100_n27: return 0.11541157215833664f;
  t100_n28: return -0.14072667062282562f;
  t100_n29: if (E.getNumReferences() >= 3260809216 /*55.0*/) goto t100_n31;
  t100_n30: return -0.19598917663097382f;
  t100_n31: return 0.16945552825927734f;
  t100_n32: return -0.09042228758335114f;
  t100_n33: return 0.04871232062578201f;
  t100_n34: return -0.022444788366556168f;
  t100_n35: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t100_n39;
  t100_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t100_n38;
  t100_n37: return -0.013316378928720951f;
  t100_n38: return 0.0035592929925769567f;
  t100_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t100_n41;
  t100_n40: return -0.09663191437721252f;
  t100_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t100_n63;
  t100_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t100_n44;
  t100_n43: return 0.004157728049904108f;
  t100_n44: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t100_n60;
  t100_n45: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t100_n57;
  t100_n46: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t100_n50;
  t100_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t100_n49;
  t100_n48: return 0.03755262494087219f;
  t100_n49: return 0.03683480620384216f;
  t100_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n52;
  t100_n51: return 0.017990777269005775f;
  t100_n52: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t100_n56;
  t100_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t100_n55;
  t100_n54: return -0.030275627970695496f;
  t100_n55: return 0.0506172776222229f;
  t100_n56: return -0.0014397840714082122f;
  t100_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t100_n59;
  t100_n58: return -0.312025249004364f;
  t100_n59: return 0.13761456310749054f;
  t100_n60: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n62;
  t100_n61: return 0.0651453360915184f;
  t100_n62: return 0.018278302624821663f;
  t100_n63: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t100_n71;
  t100_n64: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n70;
  t100_n65: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t100_n69;
  t100_n66: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t100_n68;
  t100_n67: return 0.10979259759187698f;
  t100_n68: return 0.0746174305677414f;
  t100_n69: return 0.1086866557598114f;
  t100_n70: return 0.07953917980194092f;
  t100_n71: return -0.04691222310066223f;
  t100_n72: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t100_n254;
  t100_n73: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t100_n85;
  t100_n74: if (E.getNumReferences() >= 3308445696 /*2862.0*/) goto t100_n78;
  t100_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t100_n77;
  t100_n76: return 0.0018672461155802011f;
  t100_n77: return 0.01334365550428629f;
  t100_n78: if (E.getNumReferences() >= 3308460032 /*2865.5*/) goto t100_n80;
  t100_n79: return 0.11986399441957474f;
  t100_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t100_n82;
  t100_n81: return 0.009469736367464066f;
  t100_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t100_n84;
  t100_n83: return 0.002489333739504218f;
  t100_n84: return 0.033587757498025894f;
  t100_n85: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t100_n101;
  t100_n86: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t100_n88;
  t100_n87: return 0.008670412003993988f;
  t100_n88: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t100_n90;
  t100_n89: return -0.04582163318991661f;
  t100_n90: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t100_n92;
  t100_n91: return 0.04069442301988602f;
  t100_n92: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t100_n94;
  t100_n93: return 0.04068726301193237f;
  t100_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t100_n98;
  t100_n95: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t100_n97;
  t100_n96: return 0.03535458445549011f;
  t100_n97: return 0.09370940923690796f;
  t100_n98: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t100_n100;
  t100_n99: return 0.12149886786937714f;
  t100_n100: return 0.06086256727576256f;
  t100_n101: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t100_n131;
  t100_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t100_n120;
  t100_n103: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t100_n105;
  t100_n104: return 0.009929802268743515f;
  t100_n105: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t100_n113;
  t100_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t100_n108;
  t100_n107: return 0.029725583270192146f;
  t100_n108: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t100_n112;
  t100_n109: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t100_n111;
  t100_n110: return 0.031485386192798615f;
  t100_n111: return 0.06803857535123825f;
  t100_n112: return 0.09597394615411758f;
  t100_n113: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t100_n119;
  t100_n114: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t100_n116;
  t100_n115: return 0.14954912662506104f;
  t100_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t100_n118;
  t100_n117: return 0.09676600247621536f;
  t100_n118: return 0.11696851253509521f;
  t100_n119: return 0.06647340208292007f;
  t100_n120: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t100_n122;
  t100_n121: return 0.1290702372789383f;
  t100_n122: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t100_n128;
  t100_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t100_n125;
  t100_n124: return 0.07603978365659714f;
  t100_n125: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t100_n127;
  t100_n126: return 0.10179658234119415f;
  t100_n127: return 0.12063848227262497f;
  t100_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t100_n130;
  t100_n129: return 0.07793743908405304f;
  t100_n130: return 0.12909574806690216f;
  t100_n131: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t100_n133;
  t100_n132: return -0.005256231874227524f;
  t100_n133: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t100_n207;
  t100_n134: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t100_n206;
  t100_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t100_n163;
  t100_n136: if (E.getNumReferences() >= 3314422784 /*4546.5*/) goto t100_n138;
  t100_n137: return -0.0056073591113090515f;
  t100_n138: if (E.getNumReferences() >= 3324868096 /*11101.5*/) goto t100_n158;
  t100_n139: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t100_n141;
  t100_n140: return 0.0962492972612381f;
  t100_n141: if (E.getNumReferences() >= 3319766016 /*7155.5*/) goto t100_n143;
  t100_n142: return 0.03968605399131775f;
  t100_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t100_n145;
  t100_n144: return 0.05198945477604866f;
  t100_n145: if (E.getNumReferences() >= 3321975808 /*8277.0*/) goto t100_n157;
  t100_n146: if (E.getNumReferences() >= 3321886720 /*8191.0*/) goto t100_n156;
  t100_n147: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t100_n151;
  t100_n148: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t100_n150;
  t100_n149: return 0.10930727422237396f;
  t100_n150: return 0.09267087280750275f;
  t100_n151: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t100_n153;
  t100_n152: return 0.0594409815967083f;
  t100_n153: if (E.getNumReferences() >= 3320559616 /*7543.0*/) goto t100_n155;
  t100_n154: return -0.24785637855529785f;
  t100_n155: return 0.11027859151363373f;
  t100_n156: return 0.11724935472011566f;
  t100_n157: return 0.06381996721029282f;
  t100_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t100_n162;
  t100_n159: if (E.getNumReferences() >= 3359963264 /*201698.0*/) goto t100_n161;
  t100_n160: return -0.05548321455717087f;
  t100_n161: return 0.04357348382472992f;
  t100_n162: return 0.01653965562582016f;
  t100_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t100_n177;
  t100_n164: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t100_n176;
  t100_n165: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t100_n173;
  t100_n166: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t100_n172;
  t100_n167: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t100_n171;
  t100_n168: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t100_n170;
  t100_n169: return 0.11039439588785172f;
  t100_n170: return -0.43501412868499756f;
  t100_n171: return 0.16987191140651703f;
  t100_n172: return 0.020682387053966522f;
  t100_n173: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t100_n175;
  t100_n174: return 0.1153806820511818f;
  t100_n175: return 0.08998896926641464f;
  t100_n176: return -0.03576698899269104f;
  t100_n177: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t100_n205;
  t100_n178: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t100_n202;
  t100_n179: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t100_n201;
  t100_n180: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t100_n192;
  t100_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t100_n183;
  t100_n182: return 0.07896948605775833f;
  t100_n183: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t100_n185;
  t100_n184: return 0.02792362868785858f;
  t100_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n189;
  t100_n186: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t100_n188;
  t100_n187: return 0.09542229026556015f;
  t100_n188: return -0.12686435878276825f;
  t100_n189: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t100_n191;
  t100_n190: return 0.11833813041448593f;
  t100_n191: return 0.1436539590358734f;
  t100_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n200;
  t100_n193: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t100_n199;
  t100_n194: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t100_n198;
  t100_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t100_n197;
  t100_n196: return -0.10494139790534973f;
  t100_n197: return 0.12385237962007523f;
  t100_n198: return 0.05558205023407936f;
  t100_n199: return 0.0972064658999443f;
  t100_n200: return 0.029814274981617928f;
  t100_n201: return 0.016677264124155045f;
  t100_n202: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t100_n204;
  t100_n203: return 0.11342770606279373f;
  t100_n204: return 0.01779657043516636f;
  t100_n205: return 0.011396807618439198f;
  t100_n206: return -0.0930522084236145f;
  t100_n207: if (E.getNumReferences() >= 3283075072 /*351.5*/) goto t100_n249;
  t100_n208: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t100_n248;
  t100_n209: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t100_n247;
  t100_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t100_n216;
  t100_n211: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t100_n213;
  t100_n212: return 0.03233359754085541f;
  t100_n213: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t100_n215;
  t100_n214: return 0.058001138269901276f;
  t100_n215: return -0.0008437777869403362f;
  t100_n216: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t100_n224;
  t100_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t100_n219;
  t100_n218: return -0.05703316256403923f;
  t100_n219: if (E.getSymbolScopeDistance() >= 3249012736 /*21.0*/) goto t100_n221;
  t100_n220: return 0.13385875523090363f;
  t100_n221: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t100_n223;
  t100_n222: return 0.19728323817253113f;
  t100_n223: return 0.09294199198484421f;
  t100_n224: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t100_n226;
  t100_n225: return 0.047966182231903076f;
  t100_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t100_n234;
  t100_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t100_n229;
  t100_n228: return -0.0042120530270040035f;
  t100_n229: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t100_n233;
  t100_n230: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t100_n232;
  t100_n231: return 0.06354061514139175f;
  t100_n232: return 0.1053200289607048f;
  t100_n233: return 0.017986029386520386f;
  t100_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n246;
  t100_n235: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t100_n237;
  t100_n236: return -0.057146620005369186f;
  t100_n237: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t100_n245;
  t100_n238: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t100_n242;
  t100_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t100_n241;
  t100_n240: return 0.10424664616584778f;
  t100_n241: return 0.10138585418462753f;
  t100_n242: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t100_n244;
  t100_n243: return 0.12877249717712402f;
  t100_n244: return 0.0740169808268547f;
  t100_n245: return 0.012537374161183834f;
  t100_n246: return 0.046282269060611725f;
  t100_n247: return -0.1268102377653122f;
  t100_n248: return -0.0482647605240345f;
  t100_n249: if (E.getNumReferences() >= 3283107840 /*352.5*/) goto t100_n253;
  t100_n250: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t100_n252;
  t100_n251: return -0.1031135618686676f;
  t100_n252: return 0.12945617735385895f;
  t100_n253: return 0.050403159111738205f;
  t100_n254: return -0.07678487151861191f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree101(const Example& E) {
  t101_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t101_n206;
  t101_n1: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t101_n3;
  t101_n2: return -0.0012440572027117014f;
  t101_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t101_n7;
  t101_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t101_n6;
  t101_n5: return 0.01582495868206024f;
  t101_n6: return -0.04496360570192337f;
  t101_n7: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t101_n119;
  t101_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t101_n14;
  t101_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t101_n13;
  t101_n10: if (E.getNumReferences() >= 3375821112 /*749331.5*/) goto t101_n12;
  t101_n11: return -0.04958469048142433f;
  t101_n12: return -0.29980868101119995f;
  t101_n13: return 0.012938902713358402f;
  t101_n14: if (E.getNumReferences() >= 3359435680 /*193454.5*/) goto t101_n56;
  t101_n15: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t101_n55;
  t101_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t101_n28;
  t101_n17: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t101_n19;
  t101_n18: return 0.011307838372886181f;
  t101_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t101_n21;
  t101_n20: return -0.005015204194933176f;
  t101_n21: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t101_n27;
  t101_n22: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t101_n26;
  t101_n23: if (E.getNumReferences() >= 3351817408 /*102745.5*/) goto t101_n25;
  t101_n24: return 0.1008937805891037f;
  t101_n25: return -0.3384712338447571f;
  t101_n26: return 0.10382255166769028f;
  t101_n27: return -0.10280683636665344f;
  t101_n28: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t101_n30;
  t101_n29: return 0.02452937513589859f;
  t101_n30: if (E.getNumReferences() >= 3350198272 /*90096.0*/) goto t101_n44;
  t101_n31: if (E.getNumReferences() >= 3350105536 /*89371.5*/) goto t101_n41;
  t101_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t101_n40;
  t101_n33: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t101_n39;
  t101_n34: if (E.getNumReferences() >= 3348338496 /*75566.5*/) goto t101_n38;
  t101_n35: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n37;
  t101_n36: return 0.030117487534880638f;
  t101_n37: return 0.10336862504482269f;
  t101_n38: return 0.11976874619722366f;
  t101_n39: return -0.01484035886824131f;
  t101_n40: return 0.15699031949043274f;
  t101_n41: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t101_n43;
  t101_n42: return 0.11954190582036972f;
  t101_n43: return 0.0982334092259407f;
  t101_n44: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n46;
  t101_n45: return -0.07316607236862183f;
  t101_n46: if (E.getNumReferences() >= 3351190528 /*97848.0*/) goto t101_n50;
  t101_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t101_n49;
  t101_n48: return -0.14016307890415192f;
  t101_n49: return 0.08398330956697464f;
  t101_n50: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t101_n52;
  t101_n51: return -0.3914627730846405f;
  t101_n52: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n54;
  t101_n53: return 0.24901942908763885f;
  t101_n54: return 0.1127261072397232f;
  t101_n55: return -0.04680676385760307f;
  t101_n56: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t101_n62;
  t101_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t101_n59;
  t101_n58: return 0.07139728218317032f;
  t101_n59: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n61;
  t101_n60: return 0.0968475267291069f;
  t101_n61: return 0.06705089658498764f;
  t101_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t101_n66;
  t101_n63: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t101_n65;
  t101_n64: return -0.029753927141427994f;
  t101_n65: return -0.22092916071414948f;
  t101_n66: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t101_n88;
  t101_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t101_n77;
  t101_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t101_n70;
  t101_n69: return 0.007721350062638521f;
  t101_n70: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t101_n74;
  t101_n71: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n73;
  t101_n72: return 0.07054410874843597f;
  t101_n73: return 0.04599873721599579f;
  t101_n74: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n76;
  t101_n75: return -0.200369730591774f;
  t101_n76: return 0.11098639667034149f;
  t101_n77: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t101_n83;
  t101_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n82;
  t101_n79: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t101_n81;
  t101_n80: return -0.11556252837181091f;
  t101_n81: return 0.01692998595535755f;
  t101_n82: return 0.07134341448545456f;
  t101_n83: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n87;
  t101_n84: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n86;
  t101_n85: return 0.09148681908845901f;
  t101_n86: return 0.023003218695521355f;
  t101_n87: return -0.09473346918821335f;
  t101_n88: if (E.getNumReferences() >= 3364768256 /*291408.0*/) goto t101_n90;
  t101_n89: return -0.08059588074684143f;
  t101_n90: if (E.getNumReferences() >= 3368655888 /*412896.5*/) goto t101_n114;
  t101_n91: if (E.getNumReferences() >= 3366258096 /*337965.5*/) goto t101_n103;
  t101_n92: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n94;
  t101_n93: return 0.0416744202375412f;
  t101_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t101_n96;
  t101_n95: return -0.013951434753835201f;
  t101_n96: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n102;
  t101_n97: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t101_n99;
  t101_n98: return 0.15455769002437592f;
  t101_n99: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t101_n101;
  t101_n100: return 0.14147010445594788f;
  t101_n101: return 0.1443747580051422f;
  t101_n102: return -0.012758830562233925f;
  t101_n103: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t101_n113;
  t101_n104: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t101_n108;
  t101_n105: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t101_n107;
  t101_n106: return -0.15648968517780304f;
  t101_n107: return 0.10486802458763123f;
  t101_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t101_n110;
  t101_n109: return 0.09660053253173828f;
  t101_n110: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n112;
  t101_n111: return 0.10908293724060059f;
  t101_n112: return 0.1031324565410614f;
  t101_n113: return 0.0160165224224329f;
  t101_n114: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t101_n116;
  t101_n115: return 0.059442587196826935f;
  t101_n116: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t101_n118;
  t101_n117: return 0.045530617237091064f;
  t101_n118: return -0.039712049067020416f;
  t101_n119: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t101_n149;
  t101_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t101_n142;
  t101_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t101_n135;
  t101_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t101_n126;
  t101_n123: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t101_n125;
  t101_n124: return 0.09490129351615906f;
  t101_n125: return 0.024363258853554726f;
  t101_n126: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t101_n130;
  t101_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t101_n129;
  t101_n128: return 0.03094087913632393f;
  t101_n129: return 0.08568557351827621f;
  t101_n130: if (E.getNumReferences() >= 3338736000 /*33041.5*/) goto t101_n134;
  t101_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t101_n133;
  t101_n132: return -0.11738896369934082f;
  t101_n133: return 0.12589004635810852f;
  t101_n134: return 0.0675826147198677f;
  t101_n135: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t101_n141;
  t101_n136: if (E.getNumReferences() >= 3338840960 /*33451.5*/) goto t101_n138;
  t101_n137: return -0.11109226197004318f;
  t101_n138: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t101_n140;
  t101_n139: return 0.15244071185588837f;
  t101_n140: return 0.11942431330680847f;
  t101_n141: return 0.06459824740886688f;
  t101_n142: if (E.getNumReferences() >= 3338736000 /*33041.5*/) goto t101_n144;
  t101_n143: return 0.11677400022745132f;
  t101_n144: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t101_n148;
  t101_n145: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t101_n147;
  t101_n146: return 0.12053272873163223f;
  t101_n147: return -0.2594674229621887f;
  t101_n148: return 0.036869317293167114f;
  t101_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t101_n201;
  t101_n150: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t101_n184;
  t101_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t101_n181;
  t101_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t101_n176;
  t101_n153: if (E.getNumReferences() >= 3345968640 /*61294.0*/) goto t101_n155;
  t101_n154: return -0.040434423834085464f;
  t101_n155: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t101_n163;
  t101_n156: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t101_n160;
  t101_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n159;
  t101_n158: return -0.012133203446865082f;
  t101_n159: return 0.15419507026672363f;
  t101_n160: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t101_n162;
  t101_n161: return 0.0795866921544075f;
  t101_n162: return 0.11543381214141846f;
  t101_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t101_n165;
  t101_n164: return -0.001776328426785767f;
  t101_n165: if (E.getNumReferences() >= 3362358400 /*239122.0*/) goto t101_n175;
  t101_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t101_n174;
  t101_n167: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t101_n169;
  t101_n168: return 0.009695158340036869f;
  t101_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n173;
  t101_n170: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t101_n172;
  t101_n171: return 0.10395672172307968f;
  t101_n172: return 0.024867024272680283f;
  t101_n173: return 0.1071116104722023f;
  t101_n174: return 0.0065217167139053345f;
  t101_n175: return 0.013430611230432987f;
  t101_n176: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n178;
  t101_n177: return 0.07097947597503662f;
  t101_n178: if (E.getNumReferences() >= 3342340992 /*47123.5*/) goto t101_n180;
  t101_n179: return 0.13028131425380707f;
  t101_n180: return 0.00934992078691721f;
  t101_n181: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t101_n183;
  t101_n182: return 0.09085147827863693f;
  t101_n183: return -0.1690252721309662f;
  t101_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t101_n186;
  t101_n185: return -0.10428805649280548f;
  t101_n186: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t101_n200;
  t101_n187: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t101_n197;
  t101_n188: if (E.getNumReferences() >= 3350328576 /*91114.0*/) goto t101_n196;
  t101_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t101_n193;
  t101_n190: if (E.getNumReferences() >= 3342507520 /*47774.0*/) goto t101_n192;
  t101_n191: return -0.4239223599433899f;
  t101_n192: return 0.040283892303705215f;
  t101_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t101_n195;
  t101_n194: return 0.10929493606090546f;
  t101_n195: return 0.10240104794502258f;
  t101_n196: return -0.2216157615184784f;
  t101_n197: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t101_n199;
  t101_n198: return 0.08848845958709717f;
  t101_n199: return 0.01851079612970352f;
  t101_n200: return -0.06970164179801941f;
  t101_n201: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t101_n203;
  t101_n202: return -0.041990648955106735f;
  t101_n203: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n205;
  t101_n204: return 0.1643776297569275f;
  t101_n205: return 0.08238620311021805f;
  t101_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t101_n208;
  t101_n207: return -0.007114267908036709f;
  t101_n208: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t101_n248;
  t101_n209: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t101_n211;
  t101_n210: return 0.008827933110296726f;
  t101_n211: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t101_n247;
  t101_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t101_n218;
  t101_n213: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t101_n215;
  t101_n214: return 0.03754047304391861f;
  t101_n215: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t101_n217;
  t101_n216: return 0.10878918319940567f;
  t101_n217: return -0.11204543709754944f;
  t101_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t101_n220;
  t101_n219: return -0.002691802568733692f;
  t101_n220: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n240;
  t101_n221: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t101_n223;
  t101_n222: return 0.014913671649992466f;
  t101_n223: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t101_n231;
  t101_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t101_n226;
  t101_n225: return -0.10853876918554306f;
  t101_n226: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t101_n230;
  t101_n227: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n229;
  t101_n228: return 0.11506284028291702f;
  t101_n229: return 0.1250162273645401f;
  t101_n230: return -0.13102753460407257f;
  t101_n231: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t101_n237;
  t101_n232: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t101_n236;
  t101_n233: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t101_n235;
  t101_n234: return 0.12051969021558762f;
  t101_n235: return 0.10606411844491959f;
  t101_n236: return -0.038528237491846085f;
  t101_n237: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t101_n239;
  t101_n238: return 0.11090350151062012f;
  t101_n239: return -0.14015263319015503f;
  t101_n240: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t101_n242;
  t101_n241: return -0.03844604641199112f;
  t101_n242: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t101_n246;
  t101_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n245;
  t101_n244: return 0.14754508435726166f;
  t101_n245: return 0.20110984146595f;
  t101_n246: return -0.10944503545761108f;
  t101_n247: return 0.020355118438601494f;
  t101_n248: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t101_n250;
  t101_n249: return -0.00024374302302021533f;
  t101_n250: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t101_n252;
  t101_n251: return 0.03467272222042084f;
  t101_n252: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t101_n254;
  t101_n253: return 0.00905291922390461f;
  t101_n254: return -0.10799446702003479f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree102(const Example& E) {
  t102_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t102_n116;
  t102_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t102_n3;
  t102_n2: return -0.0011838588397949934f;
  t102_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t102_n7;
  t102_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t102_n6;
  t102_n5: return 0.014944098889827728f;
  t102_n6: return -0.04103991389274597f;
  t102_n7: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t102_n93;
  t102_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t102_n10;
  t102_n9: return 0.00979319866746664f;
  t102_n10: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t102_n92;
  t102_n11: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t102_n77;
  t102_n12: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t102_n76;
  t102_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t102_n41;
  t102_n14: if (E.getNumReferences() >= 3342384384 /*47293.0*/) goto t102_n30;
  t102_n15: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t102_n29;
  t102_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t102_n18;
  t102_n17: return 0.009811025112867355f;
  t102_n18: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t102_n20;
  t102_n19: return -0.03201291337609291f;
  t102_n20: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t102_n22;
  t102_n21: return -0.015070863999426365f;
  t102_n22: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t102_n24;
  t102_n23: return 0.14341099560260773f;
  t102_n24: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t102_n28;
  t102_n25: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t102_n27;
  t102_n26: return 0.12746873497962952f;
  t102_n27: return 0.10164807736873627f;
  t102_n28: return 0.1052374541759491f;
  t102_n29: return 0.13516804575920105f;
  t102_n30: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t102_n32;
  t102_n31: return 0.002317418809980154f;
  t102_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t102_n34;
  t102_n33: return -0.018146628513932228f;
  t102_n34: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t102_n40;
  t102_n35: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t102_n39;
  t102_n36: if (E.getNumReferences() >= 3351817408 /*102745.5*/) goto t102_n38;
  t102_n37: return 0.09609565883874893f;
  t102_n38: return -0.25040555000305176f;
  t102_n39: return 0.10064955800771713f;
  t102_n40: return -0.08909487724304199f;
  t102_n41: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t102_n43;
  t102_n42: return 0.12113964557647705f;
  t102_n43: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t102_n45;
  t102_n44: return 0.01451033167541027f;
  t102_n45: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t102_n57;
  t102_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t102_n50;
  t102_n47: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t102_n49;
  t102_n48: return 0.021332358941435814f;
  t102_n49: return 0.09927108138799667f;
  t102_n50: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t102_n54;
  t102_n51: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t102_n53;
  t102_n52: return 0.10315650701522827f;
  t102_n53: return 0.13931474089622498f;
  t102_n54: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t102_n56;
  t102_n55: return 0.10807869583368301f;
  t102_n56: return 0.01025224570184946f;
  t102_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t102_n75;
  t102_n58: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t102_n74;
  t102_n59: if (E.getNumReferences() >= 3351224064 /*98110.0*/) goto t102_n67;
  t102_n60: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t102_n66;
  t102_n61: if (E.getNumReferences() >= 3350124096 /*89516.5*/) goto t102_n63;
  t102_n62: return -0.020717384293675423f;
  t102_n63: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t102_n65;
  t102_n64: return 0.1129375696182251f;
  t102_n65: return 0.08724740147590637f;
  t102_n66: return -0.04298752546310425f;
  t102_n67: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t102_n69;
  t102_n68: return 0.2564763128757477f;
  t102_n69: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t102_n71;
  t102_n70: return -0.11615200340747833f;
  t102_n71: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t102_n73;
  t102_n72: return 0.1623276323080063f;
  t102_n73: return 0.10515744239091873f;
  t102_n74: return -0.33020707964897156f;
  t102_n75: return 0.15900665521621704f;
  t102_n76: return -0.03410477191209793f;
  t102_n77: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t102_n87;
  t102_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t102_n80;
  t102_n79: return 0.060492441058158875f;
  t102_n80: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t102_n84;
  t102_n81: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t102_n83;
  t102_n82: return 0.07951805740594864f;
  t102_n83: return 0.10748407989740372f;
  t102_n84: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t102_n86;
  t102_n85: return 0.08562947809696198f;
  t102_n86: return 0.03322446346282959f;
  t102_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t102_n91;
  t102_n88: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t102_n90;
  t102_n89: return -0.016260303556919098f;
  t102_n90: return -0.14236955344676971f;
  t102_n91: return 0.03231178596615791f;
  t102_n92: return -0.03934290632605553f;
  t102_n93: if (E.getNumReferences() >= 3349002688 /*80755.5*/) goto t102_n105;
  t102_n94: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t102_n104;
  t102_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t102_n103;
  t102_n96: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t102_n98;
  t102_n97: return -0.23184743523597717f;
  t102_n98: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t102_n102;
  t102_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t102_n101;
  t102_n100: return 0.2354399561882019f;
  t102_n101: return 0.1173439621925354f;
  t102_n102: return 0.14972051978111267f;
  t102_n103: return 0.009130963124334812f;
  t102_n104: return 0.07846727222204208f;
  t102_n105: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t102_n109;
  t102_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t102_n108;
  t102_n107: return 0.05656884238123894f;
  t102_n108: return -0.10886741429567337f;
  t102_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t102_n111;
  t102_n110: return -0.0003044422483071685f;
  t102_n111: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t102_n115;
  t102_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t102_n114;
  t102_n113: return 0.12505194544792175f;
  t102_n114: return 0.05659672990441322f;
  t102_n115: return 0.1502445787191391f;
  t102_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t102_n118;
  t102_n117: return -0.006826447322964668f;
  t102_n118: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t102_n158;
  t102_n119: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t102_n123;
  t102_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t102_n122;
  t102_n121: return -0.27010029554367065f;
  t102_n122: return 0.009607001207768917f;
  t102_n123: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t102_n157;
  t102_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t102_n134;
  t102_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t102_n127;
  t102_n126: return -0.005275926552712917f;
  t102_n127: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t102_n129;
  t102_n128: return 0.046259574592113495f;
  t102_n129: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t102_n131;
  t102_n130: return 0.03234317898750305f;
  t102_n131: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t102_n133;
  t102_n132: return 0.15027253329753876f;
  t102_n133: return -0.09206608682870865f;
  t102_n134: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t102_n156;
  t102_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t102_n137;
  t102_n136: return 0.035841308534145355f;
  t102_n137: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t102_n139;
  t102_n138: return 0.07467751950025558f;
  t102_n139: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t102_n147;
  t102_n140: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t102_n142;
  t102_n141: return -0.1075061485171318f;
  t102_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t102_n146;
  t102_n143: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t102_n145;
  t102_n144: return 0.11236882209777832f;
  t102_n145: return 0.12158970534801483f;
  t102_n146: return -0.1254243701696396f;
  t102_n147: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t102_n153;
  t102_n148: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t102_n152;
  t102_n149: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t102_n151;
  t102_n150: return 0.11664839833974838f;
  t102_n151: return 0.10254897177219391f;
  t102_n152: return -0.04517650976777077f;
  t102_n153: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t102_n155;
  t102_n154: return 0.1102452427148819f;
  t102_n155: return -0.13506537675857544f;
  t102_n156: return 3.3145453926408663e-05f;
  t102_n157: return 0.019790176302194595f;
  t102_n158: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t102_n228;
  t102_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t102_n161;
  t102_n160: return -0.055111877620220184f;
  t102_n161: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t102_n163;
  t102_n162: return -0.05306835472583771f;
  t102_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t102_n165;
  t102_n164: return 0.008050616830587387f;
  t102_n165: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t102_n187;
  t102_n166: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t102_n168;
  t102_n167: return 0.036207396537065506f;
  t102_n168: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t102_n184;
  t102_n169: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t102_n183;
  t102_n170: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t102_n172;
  t102_n171: return 0.04984699934720993f;
  t102_n172: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t102_n182;
  t102_n173: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t102_n175;
  t102_n174: return 0.0960436686873436f;
  t102_n175: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t102_n177;
  t102_n176: return 0.06218365952372551f;
  t102_n177: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t102_n181;
  t102_n178: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t102_n180;
  t102_n179: return 0.10081823915243149f;
  t102_n180: return 0.05935042351484299f;
  t102_n181: return 0.1301153600215912f;
  t102_n182: return -0.07184682041406631f;
  t102_n183: return -0.016873469576239586f;
  t102_n184: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t102_n186;
  t102_n185: return 0.024929087609052658f;
  t102_n186: return 0.11359627544879913f;
  t102_n187: if (E.getNumReferences() >= 3299749888 /*1393.5*/) goto t102_n189;
  t102_n188: return -0.04230913892388344f;
  t102_n189: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t102_n191;
  t102_n190: return -0.0027485068421810865f;
  t102_n191: if (E.getNumReferences() >= 3317245952 /*5925.0*/) goto t102_n205;
  t102_n192: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t102_n194;
  t102_n193: return 0.0020999261178076267f;
  t102_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t102_n202;
  t102_n195: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t102_n201;
  t102_n196: if (E.getNumReferences() >= 3302473728 /*1726.0*/) goto t102_n198;
  t102_n197: return 0.11918458342552185f;
  t102_n198: if (E.getNumReferences() >= 3306999808 /*2509.0*/) goto t102_n200;
  t102_n199: return -0.11695261299610138f;
  t102_n200: return 0.10421988368034363f;
  t102_n201: return -0.2851862907409668f;
  t102_n202: if (E.getNumReferences() >= 3300188160 /*1447.0*/) goto t102_n204;
  t102_n203: return 0.08237213641405106f;
  t102_n204: return -0.011129891499876976f;
  t102_n205: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t102_n213;
  t102_n206: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t102_n210;
  t102_n207: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t102_n209;
  t102_n208: return 0.0434594601392746f;
  t102_n209: return 0.11522144824266434f;
  t102_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t102_n212;
  t102_n211: return 0.11189568787813187f;
  t102_n212: return 0.11886132508516312f;
  t102_n213: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t102_n227;
  t102_n214: if (E.getNumReferences() >= 3321964544 /*8266.0*/) goto t102_n216;
  t102_n215: return 0.024418704211711884f;
  t102_n216: if (E.getNumReferences() >= 3322966016 /*9244.0*/) goto t102_n222;
  t102_n217: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t102_n219;
  t102_n218: return 0.11295975744724274f;
  t102_n219: if (E.getNumReferences() >= 3322208768 /*8504.5*/) goto t102_n221;
  t102_n220: return 0.1227223128080368f;
  t102_n221: return 0.10614801943302155f;
  t102_n222: if (E.getNumReferences() >= 3327465984 /*13638.5*/) goto t102_n224;
  t102_n223: return 0.07305021584033966f;
  t102_n224: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t102_n226;
  t102_n225: return 0.10248295962810516f;
  t102_n226: return 0.11337672919034958f;
  t102_n227: return 0.037182874977588654f;
  t102_n228: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t102_n252;
  t102_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t102_n243;
  t102_n230: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t102_n232;
  t102_n231: return 0.014113490469753742f;
  t102_n232: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t102_n240;
  t102_n233: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t102_n237;
  t102_n234: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t102_n236;
  t102_n235: return -0.03721721097826958f;
  t102_n236: return 0.11208359897136688f;
  t102_n237: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t102_n239;
  t102_n238: return 0.12178739905357361f;
  t102_n239: return -0.15298570692539215f;
  t102_n240: if (E.getNumReferences() >= 3346496384 /*63355.5*/) goto t102_n242;
  t102_n241: return 0.029831301420927048f;
  t102_n242: return 0.12540480494499207f;
  t102_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t102_n251;
  t102_n244: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t102_n246;
  t102_n245: return 0.04862911254167557f;
  t102_n246: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t102_n248;
  t102_n247: return 0.1315627247095108f;
  t102_n248: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t102_n250;
  t102_n249: return -0.24490463733673096f;
  t102_n250: return 0.12105496227741241f;
  t102_n251: return 0.026949459686875343f;
  t102_n252: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t102_n254;
  t102_n253: return 0.00836161244660616f;
  t102_n254: return -0.12085988372564316f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree103(const Example& E) {
  t103_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t103_n120;
  t103_n1: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t103_n63;
  t103_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t103_n4;
  t103_n3: return -0.042185228317976f;
  t103_n4: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t103_n22;
  t103_n5: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t103_n21;
  t103_n6: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t103_n20;
  t103_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t103_n9;
  t103_n8: return 0.010701197199523449f;
  t103_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t103_n17;
  t103_n10: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t103_n12;
  t103_n11: return -0.00481588626280427f;
  t103_n12: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t103_n14;
  t103_n13: return 0.0673171654343605f;
  t103_n14: if (E.getNumReferences() >= 3285254144 /*418.0*/) goto t103_n16;
  t103_n15: return 0.08710604161024094f;
  t103_n16: return 0.1355711966753006f;
  t103_n17: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t103_n19;
  t103_n18: return 0.07452519983053207f;
  t103_n19: return 0.040551476180553436f;
  t103_n20: return 0.0680081844329834f;
  t103_n21: return -0.0027918091509491205f;
  t103_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t103_n38;
  t103_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t103_n37;
  t103_n24: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t103_n26;
  t103_n25: return -0.10677899420261383f;
  t103_n26: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t103_n28;
  t103_n27: return -0.02804029919207096f;
  t103_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t103_n30;
  t103_n29: return -0.16148239374160767f;
  t103_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t103_n36;
  t103_n31: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t103_n33;
  t103_n32: return -0.2757401466369629f;
  t103_n33: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t103_n35;
  t103_n34: return 0.12371722608804703f;
  t103_n35: return -1.333760380744934f;
  t103_n36: return 0.10395526140928268f;
  t103_n37: return -0.016748741269111633f;
  t103_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n40;
  t103_n39: return -0.031110500916838646f;
  t103_n40: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t103_n62;
  t103_n41: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t103_n61;
  t103_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t103_n52;
  t103_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n47;
  t103_n44: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t103_n46;
  t103_n45: return -0.002564674010500312f;
  t103_n46: return -0.2024592161178589f;
  t103_n47: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t103_n49;
  t103_n48: return -0.011140267364680767f;
  t103_n49: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t103_n51;
  t103_n50: return -0.06289824098348618f;
  t103_n51: return 0.09447743743658066f;
  t103_n52: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t103_n54;
  t103_n53: return 0.04760001227259636f;
  t103_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t103_n56;
  t103_n55: return 0.00272904010489583f;
  t103_n56: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t103_n60;
  t103_n57: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t103_n59;
  t103_n58: return 0.06000305712223053f;
  t103_n59: return 0.11068055033683777f;
  t103_n60: return 0.012675615027546883f;
  t103_n61: return -0.08740631490945816f;
  t103_n62: return 0.0037470769602805376f;
  t103_n63: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t103_n103;
  t103_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t103_n94;
  t103_n65: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t103_n93;
  t103_n66: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t103_n88;
  t103_n67: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t103_n71;
  t103_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t103_n70;
  t103_n69: return -0.09629075974225998f;
  t103_n70: return 0.008982470259070396f;
  t103_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n87;
  t103_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t103_n74;
  t103_n73: return -0.06560280919075012f;
  t103_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t103_n76;
  t103_n75: return 0.019596168771386147f;
  t103_n76: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t103_n86;
  t103_n77: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t103_n81;
  t103_n78: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t103_n80;
  t103_n79: return 0.10727059096097946f;
  t103_n80: return 0.08093204349279404f;
  t103_n81: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t103_n85;
  t103_n82: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t103_n84;
  t103_n83: return 0.11154881119728088f;
  t103_n84: return 0.06840565800666809f;
  t103_n85: return 0.10132033377885818f;
  t103_n86: return 0.114262156188488f;
  t103_n87: return 0.022306784987449646f;
  t103_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t103_n92;
  t103_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t103_n91;
  t103_n90: return 0.03464723378419876f;
  t103_n91: return 0.06985417753458023f;
  t103_n92: return 0.09266972541809082f;
  t103_n93: return 0.0002477607049513608f;
  t103_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t103_n100;
  t103_n95: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t103_n97;
  t103_n96: return 0.0188297126442194f;
  t103_n97: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t103_n99;
  t103_n98: return 0.0561443492770195f;
  t103_n99: return 0.022976195439696312f;
  t103_n100: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t103_n102;
  t103_n101: return 0.12667100131511688f;
  t103_n102: return -0.14262613654136658f;
  t103_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t103_n105;
  t103_n104: return -0.04986315220594406f;
  t103_n105: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t103_n107;
  t103_n106: return 0.007489174138754606f;
  t103_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t103_n119;
  t103_n108: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t103_n110;
  t103_n109: return -0.04953548312187195f;
  t103_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t103_n114;
  t103_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t103_n113;
  t103_n112: return 0.028880136087536812f;
  t103_n113: return 0.046335503458976746f;
  t103_n114: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t103_n116;
  t103_n115: return 0.07466606050729752f;
  t103_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n118;
  t103_n117: return -0.05368359386920929f;
  t103_n118: return 0.024417974054813385f;
  t103_n119: return 0.0762549340724945f;
  t103_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t103_n168;
  t103_n121: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t103_n161;
  t103_n122: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t103_n144;
  t103_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t103_n125;
  t103_n124: return -0.01043697725981474f;
  t103_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t103_n127;
  t103_n126: return -0.04770897701382637f;
  t103_n127: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t103_n143;
  t103_n128: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t103_n142;
  t103_n129: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t103_n135;
  t103_n130: if (E.getNumReferences() >= 3273195520 /*153.0*/) goto t103_n134;
  t103_n131: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t103_n133;
  t103_n132: return -0.0061611514538526535f;
  t103_n133: return -0.11484456062316895f;
  t103_n134: return 0.0650709718465805f;
  t103_n135: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t103_n141;
  t103_n136: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t103_n138;
  t103_n137: return -0.06003289297223091f;
  t103_n138: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t103_n140;
  t103_n139: return -0.02554505132138729f;
  t103_n140: return 0.057200320065021515f;
  t103_n141: return 0.06494950503110886f;
  t103_n142: return 0.002371270675212145f;
  t103_n143: return 0.040629059076309204f;
  t103_n144: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t103_n150;
  t103_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t103_n149;
  t103_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t103_n148;
  t103_n147: return 0.020603276789188385f;
  t103_n148: return 0.08629173040390015f;
  t103_n149: return 0.030163820832967758f;
  t103_n150: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t103_n154;
  t103_n151: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t103_n153;
  t103_n152: return -0.10628781467676163f;
  t103_n153: return -0.22761854529380798f;
  t103_n154: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t103_n160;
  t103_n155: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t103_n159;
  t103_n156: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t103_n158;
  t103_n157: return 0.015504053793847561f;
  t103_n158: return -0.00015861920837778598f;
  t103_n159: return -0.09002165496349335f;
  t103_n160: return -0.027552206069231033f;
  t103_n161: if (E.getNumReferences() >= 3364952880 /*297177.5*/) goto t103_n167;
  t103_n162: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t103_n166;
  t103_n163: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t103_n165;
  t103_n164: return 0.039283908903598785f;
  t103_n165: return 0.1273079812526703f;
  t103_n166: return -0.014452102594077587f;
  t103_n167: return -0.03752823919057846f;
  t103_n168: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t103_n254;
  t103_n169: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t103_n219;
  t103_n170: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t103_n196;
  t103_n171: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t103_n189;
  t103_n172: if (E.getNumReferences() >= 3295674368 /*960.0*/) goto t103_n184;
  t103_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t103_n177;
  t103_n174: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t103_n176;
  t103_n175: return -0.05851195752620697f;
  t103_n176: return 0.005624039098620415f;
  t103_n177: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t103_n181;
  t103_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t103_n180;
  t103_n179: return 0.05159281566739082f;
  t103_n180: return 0.07941049337387085f;
  t103_n181: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t103_n183;
  t103_n182: return 0.07999060302972794f;
  t103_n183: return 0.10861729085445404f;
  t103_n184: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t103_n186;
  t103_n185: return 0.09879297018051147f;
  t103_n186: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t103_n188;
  t103_n187: return -1.071420431137085f;
  t103_n188: return 0.09658576548099518f;
  t103_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n195;
  t103_n190: if (E.getNumReferences() >= 3290103808 /*620.0*/) goto t103_n192;
  t103_n191: return -0.16850419342517853f;
  t103_n192: if (E.getNumReferences() >= 3291561984 /*709.0*/) goto t103_n194;
  t103_n193: return 0.11925102025270462f;
  t103_n194: return -0.08688531070947647f;
  t103_n195: return -0.049725670367479324f;
  t103_n196: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t103_n210;
  t103_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n201;
  t103_n198: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t103_n200;
  t103_n199: return -0.08268748223781586f;
  t103_n200: return 0.09396366029977798f;
  t103_n201: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t103_n209;
  t103_n202: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t103_n206;
  t103_n203: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t103_n205;
  t103_n204: return -0.11106916517019272f;
  t103_n205: return 0.11916961520910263f;
  t103_n206: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t103_n208;
  t103_n207: return -0.007320157717913389f;
  t103_n208: return 0.10553444921970367f;
  t103_n209: return 0.01106855645775795f;
  t103_n210: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t103_n218;
  t103_n211: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t103_n217;
  t103_n212: if (E.getNumReferences() >= 3337464320 /*30421.0*/) goto t103_n214;
  t103_n213: return 0.1255437582731247f;
  t103_n214: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t103_n216;
  t103_n215: return 0.08942023664712906f;
  t103_n216: return -0.16132022440433502f;
  t103_n217: return 0.03493569418787956f;
  t103_n218: return 0.048527900129556656f;
  t103_n219: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t103_n223;
  t103_n220: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t103_n222;
  t103_n221: return -0.026188138872385025f;
  t103_n222: return 0.0099426144734025f;
  t103_n223: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t103_n251;
  t103_n224: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t103_n250;
  t103_n225: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t103_n227;
  t103_n226: return -0.004237275570631027f;
  t103_n227: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t103_n239;
  t103_n228: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t103_n238;
  t103_n229: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t103_n237;
  t103_n230: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t103_n234;
  t103_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n233;
  t103_n232: return -0.09073421359062195f;
  t103_n233: return 0.12112225592136383f;
  t103_n234: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t103_n236;
  t103_n235: return 0.12451893091201782f;
  t103_n236: return 0.07112187147140503f;
  t103_n237: return 0.021150192245841026f;
  t103_n238: return 0.01050643716007471f;
  t103_n239: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t103_n241;
  t103_n240: return 0.06595055013895035f;
  t103_n241: if (E.getNumReferences() >= 3309293568 /*3069.0*/) goto t103_n243;
  t103_n242: return -0.09508325904607773f;
  t103_n243: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t103_n249;
  t103_n244: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t103_n246;
  t103_n245: return 0.04943186044692993f;
  t103_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t103_n248;
  t103_n247: return 0.11856953054666519f;
  t103_n248: return 0.11336357891559601f;
  t103_n249: return 0.017431406304240227f;
  t103_n250: return 0.08834793418645859f;
  t103_n251: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t103_n253;
  t103_n252: return 0.017910737544298172f;
  t103_n253: return -0.5304908156394958f;
  t103_n254: return 0.008678754791617393f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree104(const Example& E) {
  t104_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t104_n254;
  t104_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t104_n189;
  t104_n2: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t104_n4;
  t104_n3: return -0.0009289681329391897f;
  t104_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t104_n6;
  t104_n5: return 0.01856193318963051f;
  t104_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t104_n8;
  t104_n7: return -0.046534985303878784f;
  t104_n8: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t104_n114;
  t104_n9: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t104_n113;
  t104_n10: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t104_n76;
  t104_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t104_n13;
  t104_n12: return 0.006384469568729401f;
  t104_n13: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t104_n15;
  t104_n14: return -0.1710136979818344f;
  t104_n15: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t104_n17;
  t104_n16: return 0.11871505528688431f;
  t104_n17: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t104_n75;
  t104_n18: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t104_n26;
  t104_n19: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t104_n21;
  t104_n20: return 0.029803194105625153f;
  t104_n21: if (E.getNumReferences() >= 3334795520 /*25208.5*/) goto t104_n25;
  t104_n22: if (E.getNumReferences() >= 3333635072 /*22942.0*/) goto t104_n24;
  t104_n23: return -0.08958547562360764f;
  t104_n24: return 0.12849344313144684f;
  t104_n25: return 0.06613177061080933f;
  t104_n26: if (E.getNumReferences() >= 3349106816 /*81569.0*/) goto t104_n46;
  t104_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t104_n31;
  t104_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n30;
  t104_n29: return -0.00891927257180214f;
  t104_n30: return 0.1043766587972641f;
  t104_n31: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t104_n37;
  t104_n32: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t104_n34;
  t104_n33: return 0.13349884748458862f;
  t104_n34: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t104_n36;
  t104_n35: return 0.131144717335701f;
  t104_n36: return 0.0766022726893425f;
  t104_n37: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t104_n45;
  t104_n38: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t104_n42;
  t104_n39: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t104_n41;
  t104_n40: return 0.11334292590618134f;
  t104_n41: return -0.047848258167505264f;
  t104_n42: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t104_n44;
  t104_n43: return 0.11284042149782181f;
  t104_n44: return 0.10443861782550812f;
  t104_n45: return -0.09874249994754791f;
  t104_n46: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t104_n72;
  t104_n47: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t104_n55;
  t104_n48: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t104_n54;
  t104_n49: if (E.getNumReferences() >= 3350105536 /*89371.5*/) goto t104_n51;
  t104_n50: return -0.04584179446101189f;
  t104_n51: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t104_n53;
  t104_n52: return 0.1117437481880188f;
  t104_n53: return 0.07134941965341568f;
  t104_n54: return -0.015433013439178467f;
  t104_n55: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t104_n59;
  t104_n56: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t104_n58;
  t104_n57: return 0.07987043261528015f;
  t104_n58: return 0.10335318744182587f;
  t104_n59: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t104_n65;
  t104_n60: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t104_n62;
  t104_n61: return -0.21708424389362335f;
  t104_n62: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t104_n64;
  t104_n63: return -0.24922360479831696f;
  t104_n64: return 0.14832031726837158f;
  t104_n65: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t104_n67;
  t104_n66: return -0.1059417650103569f;
  t104_n67: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n71;
  t104_n68: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t104_n70;
  t104_n69: return 0.11103113740682602f;
  t104_n70: return 0.09023973345756531f;
  t104_n71: return -0.01757528819143772f;
  t104_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t104_n74;
  t104_n73: return -0.0071242074482142925f;
  t104_n74: return 0.07414118200540543f;
  t104_n75: return -0.19678598642349243f;
  t104_n76: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t104_n112;
  t104_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t104_n101;
  t104_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t104_n80;
  t104_n79: return 0.03592398017644882f;
  t104_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n94;
  t104_n81: if (E.getNumReferences() >= 3368655888 /*412896.5*/) goto t104_n93;
  t104_n82: if (E.getNumReferences() >= 3365914464 /*327227.0*/) goto t104_n88;
  t104_n83: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t104_n87;
  t104_n84: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t104_n86;
  t104_n85: return 0.00020157913968432695f;
  t104_n86: return 0.21681305766105652f;
  t104_n87: return -0.0816153809428215f;
  t104_n88: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t104_n92;
  t104_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t104_n91;
  t104_n90: return -0.21982485055923462f;
  t104_n91: return 0.10296829789876938f;
  t104_n92: return 0.10458703339099884f;
  t104_n93: return -0.018912298604846f;
  t104_n94: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t104_n100;
  t104_n95: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t104_n99;
  t104_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t104_n98;
  t104_n97: return 0.11529261618852615f;
  t104_n98: return 0.13200262188911438f;
  t104_n99: return -0.07426483184099197f;
  t104_n100: return -0.16460104286670685f;
  t104_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t104_n111;
  t104_n102: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t104_n110;
  t104_n103: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n109;
  t104_n104: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t104_n108;
  t104_n105: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t104_n107;
  t104_n106: return -0.16118626296520233f;
  t104_n107: return -0.07135550677776337f;
  t104_n108: return 0.05332639813423157f;
  t104_n109: return 0.0013481463538482785f;
  t104_n110: return 0.07649628818035126f;
  t104_n111: return 0.07082708179950714f;
  t104_n112: return -0.14798423647880554f;
  t104_n113: return -0.024766206741333008f;
  t104_n114: if (E.getNumReferences() >= 3349221056 /*82461.5*/) goto t104_n172;
  t104_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t104_n131;
  t104_n116: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t104_n118;
  t104_n117: return 0.006634552031755447f;
  t104_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t104_n126;
  t104_n119: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t104_n121;
  t104_n120: return 0.021277381107211113f;
  t104_n121: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t104_n123;
  t104_n122: return 0.00930460263043642f;
  t104_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t104_n125;
  t104_n124: return 0.09649540483951569f;
  t104_n125: return -0.14996181428432465f;
  t104_n126: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t104_n130;
  t104_n127: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t104_n129;
  t104_n128: return 0.08055882900953293f;
  t104_n129: return 0.1295280009508133f;
  t104_n130: return 0.08751511573791504f;
  t104_n131: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t104_n147;
  t104_n132: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t104_n142;
  t104_n133: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n139;
  t104_n134: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t104_n136;
  t104_n135: return -0.22697025537490845f;
  t104_n136: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t104_n138;
  t104_n137: return 0.10931986570358276f;
  t104_n138: return 0.09130210429430008f;
  t104_n139: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t104_n141;
  t104_n140: return 0.10918793827295303f;
  t104_n141: return 0.09898052364587784f;
  t104_n142: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t104_n144;
  t104_n143: return 0.10228690505027771f;
  t104_n144: if (E.getNumReferences() >= 3332281088 /*20297.5*/) goto t104_n146;
  t104_n145: return -0.028839172795414925f;
  t104_n146: return 0.12150644510984421f;
  t104_n147: if (E.getNumReferences() >= 3348846016 /*79531.5*/) goto t104_n171;
  t104_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t104_n150;
  t104_n149: return -0.3060219883918762f;
  t104_n150: if (E.getNumReferences() >= 3347827136 /*71571.5*/) goto t104_n168;
  t104_n151: if (E.getNumReferences() >= 3337423104 /*30340.5*/) goto t104_n159;
  t104_n152: if (E.getNumReferences() >= 3332189440 /*20118.5*/) goto t104_n154;
  t104_n153: return -0.11941805481910706f;
  t104_n154: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t104_n158;
  t104_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t104_n157;
  t104_n156: return 0.06600432097911835f;
  t104_n157: return 0.09872758388519287f;
  t104_n158: return 0.12577566504478455f;
  t104_n159: if (E.getNumReferences() >= 3338536704 /*32515.5*/) goto t104_n161;
  t104_n160: return -0.1938331574201584f;
  t104_n161: if (E.getNumReferences() >= 3339882752 /*37521.0*/) goto t104_n167;
  t104_n162: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t104_n164;
  t104_n163: return 0.1301296353340149f;
  t104_n164: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t104_n166;
  t104_n165: return 0.12367649376392365f;
  t104_n166: return -0.16735132038593292f;
  t104_n167: return 0.02398206666111946f;
  t104_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t104_n170;
  t104_n169: return 0.09813521057367325f;
  t104_n170: return 0.05117286369204521f;
  t104_n171: return 0.13992132246494293f;
  t104_n172: if (E.getNumReferences() >= 3351224064 /*98110.0*/) goto t104_n178;
  t104_n173: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t104_n175;
  t104_n174: return -0.2312234342098236f;
  t104_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t104_n177;
  t104_n176: return -0.11609581857919693f;
  t104_n177: return 0.07942131161689758f;
  t104_n178: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t104_n184;
  t104_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t104_n181;
  t104_n180: return -0.20245350897312164f;
  t104_n181: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t104_n183;
  t104_n182: return 0.08130864053964615f;
  t104_n183: return -0.003044578479602933f;
  t104_n184: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t104_n188;
  t104_n185: if (E.getNumReferences() >= 3362358400 /*239122.0*/) goto t104_n187;
  t104_n186: return 0.05001106485724449f;
  t104_n187: return 0.0077062975615262985f;
  t104_n188: return -0.052957482635974884f;
  t104_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t104_n191;
  t104_n190: return -0.006834574043750763f;
  t104_n191: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t104_n211;
  t104_n192: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t104_n194;
  t104_n193: return 0.008702443912625313f;
  t104_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t104_n208;
  t104_n195: if (E.getNumReferences() >= 3332089344 /*19923.0*/) goto t104_n203;
  t104_n196: if (E.getNumReferences() >= 3331505664 /*18783.0*/) goto t104_n198;
  t104_n197: return 0.04707762971520424f;
  t104_n198: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t104_n200;
  t104_n199: return 0.11351481825113297f;
  t104_n200: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t104_n202;
  t104_n201: return 0.07038013637065887f;
  t104_n202: return 0.1142609640955925f;
  t104_n203: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t104_n205;
  t104_n204: return -0.009146607480943203f;
  t104_n205: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t104_n207;
  t104_n206: return 0.08656540513038635f;
  t104_n207: return 0.02678319625556469f;
  t104_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t104_n210;
  t104_n209: return 0.10643021017313004f;
  t104_n210: return -0.04354948177933693f;
  t104_n211: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t104_n213;
  t104_n212: return 0.0031713033095002174f;
  t104_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t104_n215;
  t104_n214: return 0.0059476131573319435f;
  t104_n215: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t104_n233;
  t104_n216: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t104_n218;
  t104_n217: return 0.004738321993499994f;
  t104_n218: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t104_n220;
  t104_n219: return 0.029832351952791214f;
  t104_n220: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t104_n228;
  t104_n221: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t104_n227;
  t104_n222: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n224;
  t104_n223: return 0.09625398367643356f;
  t104_n224: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t104_n226;
  t104_n225: return 0.10142505168914795f;
  t104_n226: return -0.15410853922367096f;
  t104_n227: return 0.14134304225444794f;
  t104_n228: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t104_n232;
  t104_n229: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t104_n231;
  t104_n230: return 0.06931784749031067f;
  t104_n231: return 0.096028171479702f;
  t104_n232: return 0.028019191697239876f;
  t104_n233: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t104_n253;
  t104_n234: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t104_n244;
  t104_n235: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t104_n243;
  t104_n236: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t104_n238;
  t104_n237: return 0.10705088078975677f;
  t104_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n242;
  t104_n239: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t104_n241;
  t104_n240: return 0.09883067011833191f;
  t104_n241: return 0.08383184671401978f;
  t104_n242: return 0.06295142322778702f;
  t104_n243: return 0.0858079344034195f;
  t104_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n246;
  t104_n245: return 0.03337296098470688f;
  t104_n246: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t104_n252;
  t104_n247: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t104_n249;
  t104_n248: return 0.08767136931419373f;
  t104_n249: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t104_n251;
  t104_n250: return 0.12248013913631439f;
  t104_n251: return 0.0990072637796402f;
  t104_n252: return 0.04810183867812157f;
  t104_n253: return 0.013505439274013042f;
  t104_n254: return -0.06067192927002907f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree105(const Example& E) {
  t105_n0: if (E.getNumReferences() >= 3304886272 /*2020.5*/) goto t105_n106;
  t105_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t105_n31;
  t105_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t105_n4;
  t105_n3: return -0.007788688410073519f;
  t105_n4: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t105_n24;
  t105_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t105_n13;
  t105_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t105_n8;
  t105_n7: return 0.013405004516243935f;
  t105_n8: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t105_n10;
  t105_n9: return 0.034050676971673965f;
  t105_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t105_n12;
  t105_n11: return -0.07648354023694992f;
  t105_n12: return -0.008871299214661121f;
  t105_n13: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t105_n23;
  t105_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t105_n16;
  t105_n15: return -0.0060608950443565845f;
  t105_n16: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t105_n18;
  t105_n17: return -0.002165389247238636f;
  t105_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t105_n20;
  t105_n19: return 0.056305862963199615f;
  t105_n20: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t105_n22;
  t105_n21: return 0.07774948328733444f;
  t105_n22: return 0.11672227084636688f;
  t105_n23: return 0.015802696347236633f;
  t105_n24: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t105_n30;
  t105_n25: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t105_n29;
  t105_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t105_n28;
  t105_n27: return -0.13395079970359802f;
  t105_n28: return 0.10395882278680801f;
  t105_n29: return 0.02694077603518963f;
  t105_n30: return 0.052502017468214035f;
  t105_n31: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t105_n33;
  t105_n32: return -0.00014951032062526792f;
  t105_n33: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t105_n35;
  t105_n34: return -0.07939160615205765f;
  t105_n35: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t105_n87;
  t105_n36: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t105_n58;
  t105_n37: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t105_n39;
  t105_n38: return -0.002696667332202196f;
  t105_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t105_n55;
  t105_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t105_n42;
  t105_n41: return 0.014232191257178783f;
  t105_n42: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t105_n46;
  t105_n43: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t105_n45;
  t105_n44: return 0.12270987778902054f;
  t105_n45: return -0.1265888810157776f;
  t105_n46: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t105_n52;
  t105_n47: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t105_n51;
  t105_n48: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t105_n50;
  t105_n49: return -0.12304666638374329f;
  t105_n50: return 0.11885473877191544f;
  t105_n51: return -0.08941136300563812f;
  t105_n52: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t105_n54;
  t105_n53: return -0.04929902032017708f;
  t105_n54: return 0.12217466533184052f;
  t105_n55: if (E.getNumReferences() >= 3304820736 /*2012.5*/) goto t105_n57;
  t105_n56: return 0.03565646708011627f;
  t105_n57: return 0.12057453393936157f;
  t105_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t105_n68;
  t105_n59: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t105_n61;
  t105_n60: return -0.13271227478981018f;
  t105_n61: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t105_n67;
  t105_n62: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t105_n64;
  t105_n63: return -0.19046631455421448f;
  t105_n64: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t105_n66;
  t105_n65: return 0.106477752327919f;
  t105_n66: return -0.05341760814189911f;
  t105_n67: return -0.03848855197429657f;
  t105_n68: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t105_n70;
  t105_n69: return -0.012423812411725521f;
  t105_n70: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t105_n76;
  t105_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t105_n73;
  t105_n72: return -0.0470740869641304f;
  t105_n73: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t105_n75;
  t105_n74: return -0.0502253994345665f;
  t105_n75: return 0.11296150088310242f;
  t105_n76: if (E.getNumReferences() >= 3274539008 /*173.5*/) goto t105_n86;
  t105_n77: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t105_n85;
  t105_n78: if (E.getNumReferences() >= 3264348160 /*73.0*/) goto t105_n82;
  t105_n79: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t105_n81;
  t105_n80: return 0.12487678974866867f;
  t105_n81: return 0.05821298435330391f;
  t105_n82: if (E.getNumReferences() >= 3267231744 /*95.0*/) goto t105_n84;
  t105_n83: return 0.13251127302646637f;
  t105_n84: return 0.04829929396510124f;
  t105_n85: return 0.056051578372716904f;
  t105_n86: return -0.009598449803888798f;
  t105_n87: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t105_n93;
  t105_n88: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t105_n90;
  t105_n89: return 0.009926979430019855f;
  t105_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t105_n92;
  t105_n91: return -0.0700167864561081f;
  t105_n92: return -0.043501824140548706f;
  t105_n93: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t105_n97;
  t105_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t105_n96;
  t105_n95: return -0.0031936331652104855f;
  t105_n96: return 0.055333785712718964f;
  t105_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t105_n101;
  t105_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t105_n100;
  t105_n99: return 0.009865050204098225f;
  t105_n100: return 0.04063059762120247f;
  t105_n101: if (E.getNumReferences() >= 3291029504 /*676.5*/) goto t105_n103;
  t105_n102: return 0.05831661447882652f;
  t105_n103: if (E.getNumReferences() >= 3292938240 /*793.0*/) goto t105_n105;
  t105_n104: return 0.10580356419086456f;
  t105_n105: return 0.05903429538011551f;
  t105_n106: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t105_n110;
  t105_n107: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t105_n109;
  t105_n108: return 0.012441953644156456f;
  t105_n109: return 0.030501404777169228f;
  t105_n110: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t105_n112;
  t105_n111: return -0.004227975383400917f;
  t105_n112: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t105_n210;
  t105_n113: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t105_n195;
  t105_n114: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t105_n170;
  t105_n115: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t105_n149;
  t105_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t105_n118;
  t105_n117: return -0.1430446356534958f;
  t105_n118: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t105_n142;
  t105_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t105_n133;
  t105_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t105_n122;
  t105_n121: return -0.020358938723802567f;
  t105_n122: if (E.getNumReferences() >= 3326231552 /*12433.0*/) goto t105_n128;
  t105_n123: if (E.getNumReferences() >= 3305193472 /*2068.0*/) goto t105_n127;
  t105_n124: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t105_n126;
  t105_n125: return 0.11899462342262268f;
  t105_n126: return -0.11161234974861145f;
  t105_n127: return 0.05138365551829338f;
  t105_n128: if (E.getNumReferences() >= 3326755840 /*12945.0*/) goto t105_n132;
  t105_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t105_n131;
  t105_n130: return -0.10412328690290451f;
  t105_n131: return 0.11087366938591003f;
  t105_n132: return 0.09396158158779144f;
  t105_n133: if (E.getNumReferences() >= 3327097344 /*13278.5*/) goto t105_n137;
  t105_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t105_n136;
  t105_n135: return 0.07876740396022797f;
  t105_n136: return 0.09252890199422836f;
  t105_n137: if (E.getNumReferences() >= 3327775744 /*13941.0*/) goto t105_n141;
  t105_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t105_n140;
  t105_n139: return 0.1527901142835617f;
  t105_n140: return 0.10873042047023773f;
  t105_n141: return 0.01585688628256321f;
  t105_n142: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t105_n148;
  t105_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t105_n145;
  t105_n144: return 0.02688354067504406f;
  t105_n145: if (E.getNumReferences() >= 3329585664 /*15708.5*/) goto t105_n147;
  t105_n146: return 0.06906077265739441f;
  t105_n147: return 0.11140982806682587f;
  t105_n148: return -0.038522932678461075f;
  t105_n149: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t105_n169;
  t105_n150: if (E.getNumReferences() >= 3315700736 /*5170.5*/) goto t105_n152;
  t105_n151: return 0.0020612869411706924f;
  t105_n152: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t105_n160;
  t105_n153: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t105_n159;
  t105_n154: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t105_n156;
  t105_n155: return 0.1454029679298401f;
  t105_n156: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t105_n158;
  t105_n157: return 0.15530863404273987f;
  t105_n158: return 0.09645993262529373f;
  t105_n159: return -0.14520186185836792f;
  t105_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t105_n162;
  t105_n161: return 0.03372582793235779f;
  t105_n162: if (E.getNumReferences() >= 3324623872 /*10863.0*/) goto t105_n164;
  t105_n163: return 0.08944890648126602f;
  t105_n164: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t105_n168;
  t105_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t105_n167;
  t105_n166: return -0.22785353660583496f;
  t105_n167: return 0.11590453237295151f;
  t105_n168: return -0.12272772938013077f;
  t105_n169: return 0.0487816147506237f;
  t105_n170: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t105_n180;
  t105_n171: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t105_n179;
  t105_n172: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t105_n174;
  t105_n173: return 0.02706941030919552f;
  t105_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t105_n176;
  t105_n175: return 0.05000874027609825f;
  t105_n176: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t105_n178;
  t105_n177: return 0.13843663036823273f;
  t105_n178: return 0.0937054306268692f;
  t105_n179: return 0.12029501795768738f;
  t105_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t105_n182;
  t105_n181: return 0.029018374159932137f;
  t105_n182: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t105_n188;
  t105_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t105_n187;
  t105_n184: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t105_n186;
  t105_n185: return 0.108202263712883f;
  t105_n186: return 0.10220872610807419f;
  t105_n187: return -0.1023048609495163f;
  t105_n188: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t105_n190;
  t105_n189: return 0.032953280955553055f;
  t105_n190: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t105_n194;
  t105_n191: if (E.getNumReferences() >= 3332825344 /*21360.5*/) goto t105_n193;
  t105_n192: return 0.0951329916715622f;
  t105_n193: return 0.12123959511518478f;
  t105_n194: return 0.05651164799928665f;
  t105_n195: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t105_n197;
  t105_n196: return -0.013260744512081146f;
  t105_n197: if (E.getNumReferences() >= 3334782720 /*25183.5*/) goto t105_n199;
  t105_n198: return -0.22555093467235565f;
  t105_n199: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t105_n209;
  t105_n200: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t105_n202;
  t105_n201: return 0.01810896024107933f;
  t105_n202: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t105_n206;
  t105_n203: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t105_n205;
  t105_n204: return 0.08177301287651062f;
  t105_n205: return 0.10224281251430511f;
  t105_n206: if (E.getNumReferences() >= 3338840320 /*33449.0*/) goto t105_n208;
  t105_n207: return -0.016408536583185196f;
  t105_n208: return 0.06436483561992645f;
  t105_n209: return 0.011893359012901783f;
  t105_n210: if (E.getNumReferences() >= 3315990528 /*5312.0*/) goto t105_n222;
  t105_n211: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t105_n219;
  t105_n212: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t105_n214;
  t105_n213: return -0.0046730306930840015f;
  t105_n214: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t105_n216;
  t105_n215: return 0.06700523942708969f;
  t105_n216: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t105_n218;
  t105_n217: return 0.10438089072704315f;
  t105_n218: return 0.06518982350826263f;
  t105_n219: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t105_n221;
  t105_n220: return 0.10926511883735657f;
  t105_n221: return 0.05589936301112175f;
  t105_n222: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t105_n254;
  t105_n223: if (E.getNumReferences() >= 3329614848 /*15737.0*/) goto t105_n251;
  t105_n224: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t105_n236;
  t105_n225: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t105_n235;
  t105_n226: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t105_n228;
  t105_n227: return -0.27834317088127136f;
  t105_n228: if (E.getNumReferences() >= 3324040704 /*10293.5*/) goto t105_n234;
  t105_n229: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t105_n233;
  t105_n230: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t105_n232;
  t105_n231: return 0.07432638853788376f;
  t105_n232: return 0.11097238212823868f;
  t105_n233: return 0.10854888707399368f;
  t105_n234: return -0.1456984132528305f;
  t105_n235: return 0.004755386151373386f;
  t105_n236: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t105_n238;
  t105_n237: return 0.008960643783211708f;
  t105_n238: if (E.getNumReferences() >= 3321964544 /*8266.0*/) goto t105_n244;
  t105_n239: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t105_n243;
  t105_n240: if (E.getNumReferences() >= 3317903360 /*6246.0*/) goto t105_n242;
  t105_n241: return 0.05898597091436386f;
  t105_n242: return 0.1066913828253746f;
  t105_n243: return -0.002046253066509962f;
  t105_n244: if (E.getNumReferences() >= 3322966016 /*9244.0*/) goto t105_n250;
  t105_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t105_n247;
  t105_n246: return 0.11190854012966156f;
  t105_n247: if (E.getNumReferences() >= 3322208768 /*8504.5*/) goto t105_n249;
  t105_n248: return 0.11981604993343353f;
  t105_n249: return 0.08379321545362473f;
  t105_n250: return 0.0835183784365654f;
  t105_n251: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t105_n253;
  t105_n252: return 0.12048683315515518f;
  t105_n253: return 0.10880772024393082f;
  t105_n254: return 0.03534606844186783f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree106(const Example& E) {
  t106_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t106_n176;
  t106_n1: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t106_n171;
  t106_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t106_n4;
  t106_n3: return -0.04785056784749031f;
  t106_n4: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t106_n132;
  t106_n5: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t106_n53;
  t106_n6: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t106_n52;
  t106_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t106_n9;
  t106_n8: return 0.009708650410175323f;
  t106_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t106_n33;
  t106_n10: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t106_n12;
  t106_n11: return -0.004570034332573414f;
  t106_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n14;
  t106_n13: return 0.08249277621507645f;
  t106_n14: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t106_n32;
  t106_n15: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t106_n25;
  t106_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t106_n18;
  t106_n17: return 0.039481088519096375f;
  t106_n18: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t106_n20;
  t106_n19: return 0.14259478449821472f;
  t106_n20: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t106_n22;
  t106_n21: return 0.08145890384912491f;
  t106_n22: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t106_n24;
  t106_n23: return 0.114497110247612f;
  t106_n24: return 0.05085068568587303f;
  t106_n25: if (E.getNumReferences() >= 3241148416 /*11.0*/) goto t106_n27;
  t106_n26: return 0.13134460151195526f;
  t106_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t106_n29;
  t106_n28: return 0.08095571398735046f;
  t106_n29: if (E.getNumReferences() >= 3272736768 /*146.0*/) goto t106_n31;
  t106_n30: return 0.060030870139598846f;
  t106_n31: return 0.12802273035049438f;
  t106_n32: return 0.04130691662430763f;
  t106_n33: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t106_n51;
  t106_n34: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t106_n50;
  t106_n35: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t106_n45;
  t106_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n42;
  t106_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t106_n39;
  t106_n38: return -0.2318306267261505f;
  t106_n39: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t106_n41;
  t106_n40: return 0.11692235618829727f;
  t106_n41: return 0.2570885717868805f;
  t106_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t106_n44;
  t106_n43: return 0.056478265672922134f;
  t106_n44: return 0.0845155119895935f;
  t106_n45: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t106_n47;
  t106_n46: return -0.01956467516720295f;
  t106_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t106_n49;
  t106_n48: return 0.05905607342720032f;
  t106_n49: return 0.34317854046821594f;
  t106_n50: return 0.03932579606771469f;
  t106_n51: return 0.03152317553758621f;
  t106_n52: return 0.06625720113515854f;
  t106_n53: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t106_n55;
  t106_n54: return -0.0044729867950081825f;
  t106_n55: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n57;
  t106_n56: return -7.155397179303691e-05f;
  t106_n57: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t106_n121;
  t106_n58: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t106_n120;
  t106_n59: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t106_n91;
  t106_n60: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t106_n82;
  t106_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t106_n63;
  t106_n62: return 0.012542271986603737f;
  t106_n63: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t106_n79;
  t106_n64: if (E.getNumReferences() >= 3356105632 /*141422.5*/) goto t106_n78;
  t106_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t106_n67;
  t106_n66: return 0.040358226746320724f;
  t106_n67: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t106_n77;
  t106_n68: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t106_n74;
  t106_n69: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t106_n71;
  t106_n70: return -0.12222806364297867f;
  t106_n71: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t106_n73;
  t106_n72: return 0.07532041519880295f;
  t106_n73: return -0.05745209753513336f;
  t106_n74: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t106_n76;
  t106_n75: return 0.003855479648336768f;
  t106_n76: return 0.09996771812438965f;
  t106_n77: return 0.04191618412733078f;
  t106_n78: return -0.17104406654834747f;
  t106_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t106_n81;
  t106_n80: return 0.010229206643998623f;
  t106_n81: return 0.0968141034245491f;
  t106_n82: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t106_n90;
  t106_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t106_n85;
  t106_n84: return -0.0001448967377655208f;
  t106_n85: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t106_n89;
  t106_n86: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t106_n88;
  t106_n87: return 0.09906568378210068f;
  t106_n88: return 0.03595336526632309f;
  t106_n89: return 0.04814495891332626f;
  t106_n90: return -0.04443389177322388f;
  t106_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t106_n103;
  t106_n92: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t106_n94;
  t106_n93: return 0.005958489142358303f;
  t106_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t106_n96;
  t106_n95: return 0.018779592588543892f;
  t106_n96: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t106_n102;
  t106_n97: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t106_n99;
  t106_n98: return 0.03427806496620178f;
  t106_n99: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t106_n101;
  t106_n100: return 0.0838421955704689f;
  t106_n101: return 0.11868129670619965f;
  t106_n102: return 0.016380347311496735f;
  t106_n103: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t106_n115;
  t106_n104: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t106_n112;
  t106_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t106_n107;
  t106_n106: return 0.013757285661995411f;
  t106_n107: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t106_n111;
  t106_n108: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t106_n110;
  t106_n109: return 0.07703737914562225f;
  t106_n110: return 0.10693497210741043f;
  t106_n111: return 0.07498978078365326f;
  t106_n112: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t106_n114;
  t106_n113: return -0.1139008179306984f;
  t106_n114: return 0.04829062521457672f;
  t106_n115: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t106_n119;
  t106_n116: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t106_n118;
  t106_n117: return 0.10891387611627579f;
  t106_n118: return 0.015617492608726025f;
  t106_n119: return 0.13774359226226807f;
  t106_n120: return -0.0007430011173710227f;
  t106_n121: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t106_n127;
  t106_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t106_n124;
  t106_n123: return 0.10966711491346359f;
  t106_n124: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t106_n126;
  t106_n125: return 0.049170807003974915f;
  t106_n126: return 0.13933788239955902f;
  t106_n127: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t106_n129;
  t106_n128: return -0.06047673895955086f;
  t106_n129: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t106_n131;
  t106_n130: return 0.06309337913990021f;
  t106_n131: return 0.00720797386020422f;
  t106_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t106_n150;
  t106_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t106_n147;
  t106_n134: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t106_n136;
  t106_n135: return -0.13663624227046967f;
  t106_n136: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t106_n138;
  t106_n137: return -0.04353566840291023f;
  t106_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t106_n140;
  t106_n139: return -0.09547986090183258f;
  t106_n140: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t106_n144;
  t106_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n143;
  t106_n142: return -0.29213473200798035f;
  t106_n143: return 0.10142052173614502f;
  t106_n144: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t106_n146;
  t106_n145: return 0.11981692910194397f;
  t106_n146: return -0.13571247458457947f;
  t106_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t106_n149;
  t106_n148: return -0.026337696239352226f;
  t106_n149: return 0.04286905378103256f;
  t106_n150: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t106_n170;
  t106_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t106_n163;
  t106_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t106_n154;
  t106_n153: return -0.05294749513268471f;
  t106_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t106_n156;
  t106_n155: return -0.01409140508621931f;
  t106_n156: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t106_n162;
  t106_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n159;
  t106_n158: return 0.14442895352840424f;
  t106_n159: if (E.getNumReferences() >= 3309338624 /*3080.0*/) goto t106_n161;
  t106_n160: return 0.06063510850071907f;
  t106_n161: return -0.05853123590350151f;
  t106_n162: return -0.11845360696315765f;
  t106_n163: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t106_n169;
  t106_n164: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n166;
  t106_n165: return 0.10873198509216309f;
  t106_n166: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t106_n168;
  t106_n167: return 0.058722663670778275f;
  t106_n168: return 0.02208235114812851f;
  t106_n169: return -0.12534137070178986f;
  t106_n170: return 0.003916068933904171f;
  t106_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other))) goto t106_n175;
  t106_n172: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t106_n174;
  t106_n173: return 0.00613601366057992f;
  t106_n174: return -0.01579728163778782f;
  t106_n175: return 0.025972774252295494f;
  t106_n176: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t106_n226;
  t106_n177: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t106_n225;
  t106_n178: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t106_n222;
  t106_n179: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t106_n215;
  t106_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t106_n204;
  t106_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n185;
  t106_n182: if (E.getNumReferences() >= 3298205696 /*1205.0*/) goto t106_n184;
  t106_n183: return -0.05470952019095421f;
  t106_n184: return 0.09017197042703629f;
  t106_n185: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t106_n201;
  t106_n186: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t106_n198;
  t106_n187: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t106_n197;
  t106_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t106_n190;
  t106_n189: return -0.07259299606084824f;
  t106_n190: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t106_n192;
  t106_n191: return -0.04833535850048065f;
  t106_n192: if (E.getNumReferences() >= 3288637440 /*530.5*/) goto t106_n196;
  t106_n193: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t106_n195;
  t106_n194: return 0.014673135243356228f;
  t106_n195: return 0.07529710233211517f;
  t106_n196: return 0.09669049829244614f;
  t106_n197: return -0.14001460373401642f;
  t106_n198: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t106_n200;
  t106_n199: return 0.12141679227352142f;
  t106_n200: return -0.19695548713207245f;
  t106_n201: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t106_n203;
  t106_n202: return -0.04244104400277138f;
  t106_n203: return 0.10963378846645355f;
  t106_n204: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t106_n214;
  t106_n205: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t106_n213;
  t106_n206: if (E.getNumReferences() >= 3295674368 /*960.0*/) goto t106_n210;
  t106_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t106_n209;
  t106_n208: return -0.06050409376621246f;
  t106_n209: return 0.02801145613193512f;
  t106_n210: if (E.getNumReferences() >= 3299438592 /*1355.5*/) goto t106_n212;
  t106_n211: return 0.10331157594919205f;
  t106_n212: return 0.06952841579914093f;
  t106_n213: return -0.07759001106023788f;
  t106_n214: return -0.004621441010385752f;
  t106_n215: if (E.getNumReferences() >= 3367232976 /*368430.5*/) goto t106_n221;
  t106_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t106_n218;
  t106_n217: return 0.04943685606122017f;
  t106_n218: if (E.getNumReferences() >= 3334339584 /*24318.0*/) goto t106_n220;
  t106_n219: return 0.12108432501554489f;
  t106_n220: return 0.0898384377360344f;
  t106_n221: return -0.0010953607270494103f;
  t106_n222: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t106_n224;
  t106_n223: return -0.07752253115177155f;
  t106_n224: return -0.1498555690050125f;
  t106_n225: return 0.005041930824518204f;
  t106_n226: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t106_n230;
  t106_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t106_n229;
  t106_n228: return -0.02833806723356247f;
  t106_n229: return 0.009162032045423985f;
  t106_n230: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t106_n250;
  t106_n231: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t106_n243;
  t106_n232: if (E.getNumReferences() >= 3290226688 /*627.5*/) goto t106_n240;
  t106_n233: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t106_n239;
  t106_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t106_n238;
  t106_n235: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t106_n237;
  t106_n236: return -0.13133689761161804f;
  t106_n237: return -0.27364352345466614f;
  t106_n238: return -0.01906738430261612f;
  t106_n239: return 0.0020744232460856438f;
  t106_n240: if (E.getNumReferences() >= 3291791360 /*723.0*/) goto t106_n242;
  t106_n241: return 0.12791068851947784f;
  t106_n242: return 0.032701525837183f;
  t106_n243: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t106_n249;
  t106_n244: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t106_n246;
  t106_n245: return -0.013597841374576092f;
  t106_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t106_n248;
  t106_n247: return -0.00495989341288805f;
  t106_n248: return 0.023651864379644394f;
  t106_n249: return 0.011781160719692707f;
  t106_n250: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t106_n254;
  t106_n251: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t106_n253;
  t106_n252: return 0.02233525738120079f;
  t106_n253: return 0.007045858073979616f;
  t106_n254: return -0.4977693557739258f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree107(const Example& E) {
  t107_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t107_n254;
  t107_n1: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t107_n3;
  t107_n2: return -0.0011864107800647616f;
  t107_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t107_n49;
  t107_n4: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t107_n44;
  t107_n5: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t107_n29;
  t107_n6: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t107_n8;
  t107_n7: return 0.021495457738637924f;
  t107_n8: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t107_n16;
  t107_n9: if (E.getFileProximityDistance() >= 3250061312 /*23.0*/) goto t107_n15;
  t107_n10: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t107_n12;
  t107_n11: return -0.06634462624788284f;
  t107_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t107_n14;
  t107_n13: return 0.028809456154704094f;
  t107_n14: return -0.06773534417152405f;
  t107_n15: return 0.1062864437699318f;
  t107_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t107_n22;
  t107_n17: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t107_n19;
  t107_n18: return 0.018690209835767746f;
  t107_n19: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t107_n21;
  t107_n20: return 0.11605633050203323f;
  t107_n21: return 0.07785113155841827f;
  t107_n22: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t107_n26;
  t107_n23: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t107_n25;
  t107_n24: return 0.06501712650060654f;
  t107_n25: return 0.04209334775805473f;
  t107_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t107_n28;
  t107_n27: return 0.1011669784784317f;
  t107_n28: return 0.02818835899233818f;
  t107_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t107_n43;
  t107_n30: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t107_n34;
  t107_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t107_n33;
  t107_n32: return -0.2496727555990219f;
  t107_n33: return 0.0036502915900200605f;
  t107_n34: if (E.getNumReferences() >= 3365683120 /*319997.5*/) goto t107_n42;
  t107_n35: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t107_n37;
  t107_n36: return -0.15738345682621002f;
  t107_n37: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t107_n39;
  t107_n38: return -0.018823981285095215f;
  t107_n39: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t107_n41;
  t107_n40: return 0.11374856531620026f;
  t107_n41: return -0.2082132250070572f;
  t107_n42: return -0.35492002964019775f;
  t107_n43: return 0.11869043111801147f;
  t107_n44: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t107_n46;
  t107_n45: return 0.024709295481443405f;
  t107_n46: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t107_n48;
  t107_n47: return 0.09035299718379974f;
  t107_n48: return 0.08440802246332169f;
  t107_n49: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t107_n51;
  t107_n50: return -0.04593776911497116f;
  t107_n51: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t107_n187;
  t107_n52: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t107_n130;
  t107_n53: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t107_n129;
  t107_n54: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t107_n104;
  t107_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t107_n57;
  t107_n56: return 0.010842700488865376f;
  t107_n57: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t107_n59;
  t107_n58: return -0.14066019654273987f;
  t107_n59: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t107_n61;
  t107_n60: return 0.018799014389514923f;
  t107_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t107_n99;
  t107_n62: if (E.getNumReferences() >= 3332023808 /*19795.0*/) goto t107_n68;
  t107_n63: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t107_n65;
  t107_n64: return -0.2310979813337326f;
  t107_n65: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t107_n67;
  t107_n66: return 0.2359764575958252f;
  t107_n67: return 0.1225743442773819f;
  t107_n68: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t107_n70;
  t107_n69: return 0.005425779614597559f;
  t107_n70: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t107_n80;
  t107_n71: if (E.getNumReferences() >= 3347948160 /*72517.0*/) goto t107_n73;
  t107_n72: return 0.07143858820199966f;
  t107_n73: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t107_n77;
  t107_n74: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t107_n76;
  t107_n75: return 0.11575417965650558f;
  t107_n76: return 0.07873411476612091f;
  t107_n77: if (E.getNumReferences() >= 3349616960 /*85554.5*/) goto t107_n79;
  t107_n78: return 0.08009658753871918f;
  t107_n79: return -0.27135276794433594f;
  t107_n80: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t107_n94;
  t107_n81: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t107_n83;
  t107_n82: return 0.0031867406796664f;
  t107_n83: if (E.getNumReferences() >= 3338840320 /*33449.0*/) goto t107_n85;
  t107_n84: return -0.20625366270542145f;
  t107_n85: if (E.getNumReferences() >= 3355904736 /*138283.5*/) goto t107_n93;
  t107_n86: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t107_n90;
  t107_n87: if (E.getNumReferences() >= 3351190528 /*97848.0*/) goto t107_n89;
  t107_n88: return -0.14722071588039398f;
  t107_n89: return 0.16456453502178192f;
  t107_n90: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t107_n92;
  t107_n91: return 0.123024582862854f;
  t107_n92: return 0.1724221110343933f;
  t107_n93: return -0.2910914421081543f;
  t107_n94: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t107_n98;
  t107_n95: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t107_n97;
  t107_n96: return 0.08884187042713165f;
  t107_n97: return 0.10001213103532791f;
  t107_n98: return -0.14643965661525726f;
  t107_n99: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t107_n101;
  t107_n100: return -0.34476831555366516f;
  t107_n101: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t107_n103;
  t107_n102: return 0.1482323706150055f;
  t107_n103: return -0.10469603538513184f;
  t107_n104: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t107_n120;
  t107_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t107_n107;
  t107_n106: return -0.0638386681675911f;
  t107_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t107_n119;
  t107_n108: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t107_n110;
  t107_n109: return 0.10144755244255066f;
  t107_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t107_n112;
  t107_n111: return 0.07199988514184952f;
  t107_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t107_n118;
  t107_n113: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t107_n115;
  t107_n114: return 0.11527804285287857f;
  t107_n115: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t107_n117;
  t107_n116: return 0.13333705067634583f;
  t107_n117: return 0.12869073450565338f;
  t107_n118: return -0.1619233936071396f;
  t107_n119: return 0.05924098566174507f;
  t107_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t107_n122;
  t107_n121: return -0.05902828276157379f;
  t107_n122: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t107_n124;
  t107_n123: return 0.02349097654223442f;
  t107_n124: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t107_n128;
  t107_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t107_n127;
  t107_n126: return -0.015393403358757496f;
  t107_n127: return 0.09602778404951096f;
  t107_n128: return 0.039311494678258896f;
  t107_n129: return -0.021023863926529884f;
  t107_n130: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t107_n146;
  t107_n131: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t107_n143;
  t107_n132: if (E.getNumReferences() >= 3334023936 /*23701.5*/) goto t107_n138;
  t107_n133: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t107_n135;
  t107_n134: return 0.00504118949174881f;
  t107_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t107_n137;
  t107_n136: return 0.058641474694013596f;
  t107_n137: return 0.10427017509937286f;
  t107_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t107_n142;
  t107_n139: if (E.getNumReferences() >= 3334111488 /*23872.5*/) goto t107_n141;
  t107_n140: return 0.09535340964794159f;
  t107_n141: return 0.02815033495426178f;
  t107_n142: return 0.11268886923789978f;
  t107_n143: if (E.getNumReferences() >= 3331729664 /*19220.5*/) goto t107_n145;
  t107_n144: return 0.1087355986237526f;
  t107_n145: return 0.07090120017528534f;
  t107_n146: if (E.getNumReferences() >= 3336764160 /*29053.5*/) goto t107_n158;
  t107_n147: if (E.getNumReferences() >= 3336654336 /*28839.0*/) goto t107_n157;
  t107_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t107_n150;
  t107_n149: return -0.1450883001089096f;
  t107_n150: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t107_n156;
  t107_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t107_n153;
  t107_n152: return 0.04356779530644417f;
  t107_n153: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t107_n155;
  t107_n154: return 0.10755644738674164f;
  t107_n155: return 0.07835857570171356f;
  t107_n156: return -0.030450092628598213f;
  t107_n157: return -0.40433546900749207f;
  t107_n158: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t107_n186;
  t107_n159: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t107_n181;
  t107_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t107_n162;
  t107_n161: return -0.080263152718544f;
  t107_n162: if (E.getNumReferences() >= 3340289792 /*39111.0*/) goto t107_n166;
  t107_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t107_n165;
  t107_n164: return -0.14431680738925934f;
  t107_n165: return 0.01892254874110222f;
  t107_n166: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t107_n180;
  t107_n167: if (E.getNumReferences() >= 3341381632 /*43376.0*/) goto t107_n173;
  t107_n168: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t107_n170;
  t107_n169: return 0.026556771248579025f;
  t107_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t107_n172;
  t107_n171: return 0.2498188465833664f;
  t107_n172: return 0.10678518563508987f;
  t107_n173: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t107_n177;
  t107_n174: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t107_n176;
  t107_n175: return 0.09647145122289658f;
  t107_n176: return 0.11529389768838882f;
  t107_n177: if (E.getNumReferences() >= 3341699072 /*44616.0*/) goto t107_n179;
  t107_n178: return 0.014966145157814026f;
  t107_n179: return 0.10689843446016312f;
  t107_n180: return 0.021364666521549225f;
  t107_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t107_n183;
  t107_n182: return -0.07742533832788467f;
  t107_n183: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t107_n185;
  t107_n184: return 0.11009593307971954f;
  t107_n185: return 0.10385629534721375f;
  t107_n186: return -0.028690198436379433f;
  t107_n187: if (E.getNumReferences() >= 3349221056 /*82461.5*/) goto t107_n243;
  t107_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t107_n204;
  t107_n189: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t107_n191;
  t107_n190: return 0.007161872927099466f;
  t107_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t107_n199;
  t107_n192: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t107_n194;
  t107_n193: return 0.013468941673636436f;
  t107_n194: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t107_n196;
  t107_n195: return 0.007944093085825443f;
  t107_n196: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t107_n198;
  t107_n197: return 0.09349934011697769f;
  t107_n198: return -0.12217191606760025f;
  t107_n199: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t107_n203;
  t107_n200: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t107_n202;
  t107_n201: return 0.07794244587421417f;
  t107_n202: return 0.12814059853553772f;
  t107_n203: return 0.08466757088899612f;
  t107_n204: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t107_n220;
  t107_n205: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t107_n215;
  t107_n206: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t107_n212;
  t107_n207: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t107_n209;
  t107_n208: return -0.208570659160614f;
  t107_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t107_n211;
  t107_n210: return 0.10807225108146667f;
  t107_n211: return 0.08861587941646576f;
  t107_n212: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t107_n214;
  t107_n213: return 0.10802551358938217f;
  t107_n214: return 0.0921211689710617f;
  t107_n215: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t107_n217;
  t107_n216: return 0.09253481775522232f;
  t107_n217: if (E.getNumReferences() >= 3332281088 /*20297.5*/) goto t107_n219;
  t107_n218: return -0.031965140253305435f;
  t107_n219: return 0.11936970055103302f;
  t107_n220: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t107_n242;
  t107_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t107_n223;
  t107_n222: return -0.2286827117204666f;
  t107_n223: if (E.getNumReferences() >= 3347827136 /*71571.5*/) goto t107_n239;
  t107_n224: if (E.getNumReferences() >= 3337423104 /*30340.5*/) goto t107_n232;
  t107_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t107_n231;
  t107_n226: if (E.getNumReferences() >= 3332189440 /*20118.5*/) goto t107_n228;
  t107_n227: return -0.07205896824598312f;
  t107_n228: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t107_n230;
  t107_n229: return 0.057704564183950424f;
  t107_n230: return 0.12920553982257843f;
  t107_n231: return 0.09820074588060379f;
  t107_n232: if (E.getNumReferences() >= 3338536704 /*32515.5*/) goto t107_n234;
  t107_n233: return -0.17930996417999268f;
  t107_n234: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t107_n238;
  t107_n235: if (E.getNumReferences() >= 3339772928 /*37092.0*/) goto t107_n237;
  t107_n236: return 0.12344493716955185f;
  t107_n237: return 0.07734917849302292f;
  t107_n238: return 0.01562989316880703f;
  t107_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t107_n241;
  t107_n240: return 0.09180352836847305f;
  t107_n241: return 0.04594188928604126f;
  t107_n242: return 0.13584855198860168f;
  t107_n243: if (E.getNumReferences() >= 3351224064 /*98110.0*/) goto t107_n245;
  t107_n244: return -0.0778931975364685f;
  t107_n245: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t107_n249;
  t107_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t107_n248;
  t107_n247: return -0.20342952013015747f;
  t107_n248: return 0.06714117527008057f;
  t107_n249: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t107_n253;
  t107_n250: if (E.getNumReferences() >= 3362358400 /*239122.0*/) goto t107_n252;
  t107_n251: return 0.04644278064370155f;
  t107_n252: return 0.007845095358788967f;
  t107_n253: return -0.05083240941166878f;
  t107_n254: return 0.005349564831703901f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree108(const Example& E) {
  t108_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t108_n254;
  t108_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t108_n9;
  t108_n2: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t108_n6;
  t108_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t108_n5;
  t108_n4: return -0.11286461353302002f;
  t108_n5: return -0.0004231093334965408f;
  t108_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t108_n8;
  t108_n7: return 0.004917247220873833f;
  t108_n8: return 0.015857910737395287f;
  t108_n9: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t108_n251;
  t108_n10: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t108_n134;
  t108_n11: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t108_n85;
  t108_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t108_n20;
  t108_n13: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t108_n15;
  t108_n14: return 0.02001996710896492f;
  t108_n15: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t108_n19;
  t108_n16: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n18;
  t108_n17: return -0.010568060912191868f;
  t108_n18: return -0.03835008665919304f;
  t108_n19: return 0.0021702470257878304f;
  t108_n20: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t108_n84;
  t108_n21: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t108_n83;
  t108_n22: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t108_n72;
  t108_n23: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t108_n71;
  t108_n24: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n28;
  t108_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t108_n27;
  t108_n26: return -0.06894336640834808f;
  t108_n27: return -0.005926181096583605f;
  t108_n28: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t108_n66;
  t108_n29: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t108_n35;
  t108_n30: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t108_n34;
  t108_n31: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t108_n33;
  t108_n32: return 0.08131766319274902f;
  t108_n33: return 0.10653312504291534f;
  t108_n34: return 0.004689754452556372f;
  t108_n35: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t108_n37;
  t108_n36: return -0.00722834188491106f;
  t108_n37: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t108_n49;
  t108_n38: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t108_n46;
  t108_n39: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t108_n41;
  t108_n40: return -0.13848648965358734f;
  t108_n41: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t108_n43;
  t108_n42: return 0.1486824005842209f;
  t108_n43: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t108_n45;
  t108_n44: return 0.2039068043231964f;
  t108_n45: return -0.2122068852186203f;
  t108_n46: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t108_n48;
  t108_n47: return 0.1412477046251297f;
  t108_n48: return 1.436333179473877f;
  t108_n49: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t108_n55;
  t108_n50: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t108_n54;
  t108_n51: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t108_n53;
  t108_n52: return 0.13134203851222992f;
  t108_n53: return -0.012662292458117008f;
  t108_n54: return -0.03216436132788658f;
  t108_n55: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t108_n65;
  t108_n56: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t108_n60;
  t108_n57: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t108_n59;
  t108_n58: return 0.09296421706676483f;
  t108_n59: return 0.10961701720952988f;
  t108_n60: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t108_n62;
  t108_n61: return -0.026104167103767395f;
  t108_n62: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t108_n64;
  t108_n63: return 0.09895900636911392f;
  t108_n64: return -0.47973594069480896f;
  t108_n65: return 0.11285216361284256f;
  t108_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t108_n70;
  t108_n67: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t108_n69;
  t108_n68: return -0.06850721687078476f;
  t108_n69: return -0.3885495960712433f;
  t108_n70: return 0.022898536175489426f;
  t108_n71: return -0.1283421367406845f;
  t108_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n74;
  t108_n73: return -0.02876734547317028f;
  t108_n74: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t108_n76;
  t108_n75: return 0.027097651734948158f;
  t108_n76: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t108_n82;
  t108_n77: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t108_n79;
  t108_n78: return -0.008023513481020927f;
  t108_n79: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t108_n81;
  t108_n80: return -0.024795671924948692f;
  t108_n81: return 0.10434582829475403f;
  t108_n82: return -0.12785930931568146f;
  t108_n83: return 0.002751260297372937f;
  t108_n84: return 0.017354683950543404f;
  t108_n85: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t108_n119;
  t108_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t108_n88;
  t108_n87: return 0.07925828546285629f;
  t108_n88: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t108_n118;
  t108_n89: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t108_n91;
  t108_n90: return -0.12387900799512863f;
  t108_n91: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t108_n95;
  t108_n92: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t108_n94;
  t108_n93: return -0.12524938583374023f;
  t108_n94: return 0.15380461513996124f;
  t108_n95: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t108_n117;
  t108_n96: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t108_n116;
  t108_n97: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t108_n105;
  t108_n98: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t108_n100;
  t108_n99: return 0.0019125292310491204f;
  t108_n100: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n104;
  t108_n101: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t108_n103;
  t108_n102: return 0.109049953520298f;
  t108_n103: return -0.10451656579971313f;
  t108_n104: return 0.050562236458063126f;
  t108_n105: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t108_n109;
  t108_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t108_n108;
  t108_n107: return -0.11698174476623535f;
  t108_n108: return 0.12051878869533539f;
  t108_n109: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t108_n111;
  t108_n110: return -0.24358947575092316f;
  t108_n111: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n113;
  t108_n112: return 0.09129749983549118f;
  t108_n113: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t108_n115;
  t108_n114: return 0.1294027715921402f;
  t108_n115: return 0.08857088536024094f;
  t108_n116: return 0.02349686250090599f;
  t108_n117: return -0.04005490615963936f;
  t108_n118: return 0.10881628841161728f;
  t108_n119: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t108_n127;
  t108_n120: if (E.getNumReferences() >= 3290554368 /*647.5*/) goto t108_n124;
  t108_n121: if (E.getNumReferences() >= 3290251264 /*629.0*/) goto t108_n123;
  t108_n122: return 0.02390304021537304f;
  t108_n123: return 0.10446184873580933f;
  t108_n124: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t108_n126;
  t108_n125: return 0.1151149794459343f;
  t108_n126: return -0.01782059296965599f;
  t108_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t108_n131;
  t108_n128: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t108_n130;
  t108_n129: return 0.11329609900712967f;
  t108_n130: return 0.027472611516714096f;
  t108_n131: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t108_n133;
  t108_n132: return 0.10556893050670624f;
  t108_n133: return -0.035918813198804855f;
  t108_n134: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t108_n210;
  t108_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t108_n137;
  t108_n136: return -0.04231291636824608f;
  t108_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t108_n139;
  t108_n138: return -0.006549580488353968f;
  t108_n139: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t108_n171;
  t108_n140: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t108_n170;
  t108_n141: if (E.getNumReferences() >= 3322049024 /*8348.5*/) goto t108_n165;
  t108_n142: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t108_n144;
  t108_n143: return 0.02096213959157467f;
  t108_n144: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t108_n146;
  t108_n145: return -0.031219016760587692f;
  t108_n146: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t108_n164;
  t108_n147: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t108_n157;
  t108_n148: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t108_n156;
  t108_n149: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t108_n155;
  t108_n150: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n152;
  t108_n151: return 0.07417061924934387f;
  t108_n152: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t108_n154;
  t108_n153: return 0.13540907204151154f;
  t108_n154: return -0.3198298513889313f;
  t108_n155: return 0.07219202071428299f;
  t108_n156: return -0.01198350265622139f;
  t108_n157: if (E.getNumReferences() >= 3265986560 /*85.5*/) goto t108_n159;
  t108_n158: return 0.119319848716259f;
  t108_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n161;
  t108_n160: return 0.01752832904458046f;
  t108_n161: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t108_n163;
  t108_n162: return -0.09485418349504471f;
  t108_n163: return 0.133169025182724f;
  t108_n164: return 0.06414017826318741f;
  t108_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t108_n167;
  t108_n166: return 0.05112353339791298f;
  t108_n167: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t108_n169;
  t108_n168: return 0.11191870272159576f;
  t108_n169: return 0.031302209943532944f;
  t108_n170: return -0.03888939321041107f;
  t108_n171: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t108_n187;
  t108_n172: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t108_n174;
  t108_n173: return 0.02802443690598011f;
  t108_n174: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t108_n186;
  t108_n175: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n183;
  t108_n176: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t108_n178;
  t108_n177: return 0.03216920793056488f;
  t108_n178: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t108_n182;
  t108_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t108_n181;
  t108_n180: return -0.030569706112146378f;
  t108_n181: return 0.07147342711687088f;
  t108_n182: return -0.0674576461315155f;
  t108_n183: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t108_n185;
  t108_n184: return -0.012197661213576794f;
  t108_n185: return 0.06482543796300888f;
  t108_n186: return -0.013482295908033848f;
  t108_n187: if (E.getNumReferences() >= 3299196928 /*1326.0*/) goto t108_n189;
  t108_n188: return -0.0418480783700943f;
  t108_n189: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t108_n191;
  t108_n190: return -0.007612803019583225f;
  t108_n191: if (E.getNumReferences() >= 3316736000 /*5676.0*/) goto t108_n203;
  t108_n192: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t108_n194;
  t108_n193: return 0.004056120291352272f;
  t108_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t108_n202;
  t108_n195: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t108_n201;
  t108_n196: if (E.getNumReferences() >= 3301761024 /*1639.0*/) goto t108_n198;
  t108_n197: return -0.10528569668531418f;
  t108_n198: if (E.getNumReferences() >= 3304402944 /*1961.5*/) goto t108_n200;
  t108_n199: return 0.11899376660585403f;
  t108_n200: return 0.10090307891368866f;
  t108_n201: return -0.25037792325019836f;
  t108_n202: return 0.030549556016921997f;
  t108_n203: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t108_n209;
  t108_n204: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t108_n208;
  t108_n205: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t108_n207;
  t108_n206: return 0.07166364043951035f;
  t108_n207: return 0.11133620142936707f;
  t108_n208: return 0.07071349024772644f;
  t108_n209: return 0.034006621688604355f;
  t108_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t108_n212;
  t108_n211: return 0.007082744967192411f;
  t108_n212: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t108_n232;
  t108_n213: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t108_n215;
  t108_n214: return 0.003062926232814789f;
  t108_n215: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t108_n217;
  t108_n216: return 0.027561094611883163f;
  t108_n217: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t108_n227;
  t108_n218: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t108_n226;
  t108_n219: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n223;
  t108_n220: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t108_n222;
  t108_n221: return 0.07324222475290298f;
  t108_n222: return 0.10848125070333481f;
  t108_n223: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t108_n225;
  t108_n224: return 0.10166443139314651f;
  t108_n225: return -0.14526525139808655f;
  t108_n226: return 0.13681469857692719f;
  t108_n227: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t108_n231;
  t108_n228: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t108_n230;
  t108_n229: return 0.0703771561384201f;
  t108_n230: return 0.0943087711930275f;
  t108_n231: return 0.02510892041027546f;
  t108_n232: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t108_n244;
  t108_n233: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t108_n243;
  t108_n234: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t108_n242;
  t108_n235: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t108_n237;
  t108_n236: return 0.09268385916948318f;
  t108_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n241;
  t108_n238: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t108_n240;
  t108_n239: return 0.09668228775262833f;
  t108_n240: return 0.09301890432834625f;
  t108_n241: return 0.024385154247283936f;
  t108_n242: return 0.04367486760020256f;
  t108_n243: return 0.03794324770569801f;
  t108_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n246;
  t108_n245: return 0.025433795526623726f;
  t108_n246: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t108_n248;
  t108_n247: return 0.0943824052810669f;
  t108_n248: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t108_n250;
  t108_n249: return 0.0603717565536499f;
  t108_n250: return -0.07878647744655609f;
  t108_n251: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t108_n253;
  t108_n252: return -0.019522352144122124f;
  t108_n253: return 0.03792057931423187f;
  t108_n254: return -0.058125562965869904f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree109(const Example& E) {
  t109_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t109_n2;
  t109_n1: return -0.0021486016921699047f;
  t109_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t109_n200;
  t109_n3: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t109_n185;
  t109_n4: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t109_n184;
  t109_n5: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t109_n47;
  t109_n6: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t109_n18;
  t109_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t109_n9;
  t109_n8: return -0.00914754904806614f;
  t109_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t109_n11;
  t109_n10: return -0.0027786889113485813f;
  t109_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t109_n15;
  t109_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t109_n14;
  t109_n13: return -0.04379050061106682f;
  t109_n14: return 0.01061689481139183f;
  t109_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t109_n17;
  t109_n16: return 0.0411078967154026f;
  t109_n17: return 0.04908469691872597f;
  t109_n18: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t109_n38;
  t109_n19: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t109_n23;
  t109_n20: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t109_n22;
  t109_n21: return -0.17292429506778717f;
  t109_n22: return -0.02869286946952343f;
  t109_n23: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t109_n37;
  t109_n24: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t109_n26;
  t109_n25: return 0.02904873713850975f;
  t109_n26: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t109_n28;
  t109_n27: return 0.04533325880765915f;
  t109_n28: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t109_n34;
  t109_n29: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t109_n31;
  t109_n30: return 0.1063987985253334f;
  t109_n31: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t109_n33;
  t109_n32: return -0.06161653995513916f;
  t109_n33: return 0.08574696630239487f;
  t109_n34: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t109_n36;
  t109_n35: return 0.16330155730247498f;
  t109_n36: return 0.11397112905979156f;
  t109_n37: return 0.0022759686689823866f;
  t109_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t109_n40;
  t109_n39: return -0.025402335450053215f;
  t109_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t109_n46;
  t109_n41: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t109_n43;
  t109_n42: return -0.11161887645721436f;
  t109_n43: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t109_n45;
  t109_n44: return 0.14575417339801788f;
  t109_n45: return -0.6579122543334961f;
  t109_n46: return 0.07166557013988495f;
  t109_n47: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t109_n123;
  t109_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t109_n72;
  t109_n49: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t109_n65;
  t109_n50: if (E.getNumReferences() >= 3355694624 /*135000.5*/) goto t109_n64;
  t109_n51: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t109_n59;
  t109_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t109_n58;
  t109_n53: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t109_n55;
  t109_n54: return -0.18354587256908417f;
  t109_n55: if (E.getNumReferences() >= 3292332032 /*756.0*/) goto t109_n57;
  t109_n56: return -0.031764689832925797f;
  t109_n57: return -0.24469487369060516f;
  t109_n58: return -0.0030498960986733437f;
  t109_n59: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t109_n61;
  t109_n60: return 0.023000987246632576f;
  t109_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t109_n63;
  t109_n62: return 0.009211068041622639f;
  t109_n63: return 0.07607362419366837f;
  t109_n64: return -0.16039152443408966f;
  t109_n65: if (E.getNumReferences() >= 3364952880 /*297177.5*/) goto t109_n71;
  t109_n66: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t109_n70;
  t109_n67: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t109_n69;
  t109_n68: return 0.0219977218657732f;
  t109_n69: return 0.11656370759010315f;
  t109_n70: return -0.008634855039417744f;
  t109_n71: return -0.01036047749221325f;
  t109_n72: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t109_n88;
  t109_n73: if (E.getNumReferences() >= 3278012416 /*226.5*/) goto t109_n79;
  t109_n74: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t109_n78;
  t109_n75: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t109_n77;
  t109_n76: return 0.10310908406972885f;
  t109_n77: return 0.021762220188975334f;
  t109_n78: return 0.018263839185237885f;
  t109_n79: if (E.getNumReferences() >= 3279994880 /*257.5*/) goto t109_n83;
  t109_n80: if (E.getNumReferences() >= 3278536704 /*234.5*/) goto t109_n82;
  t109_n81: return 0.1128055527806282f;
  t109_n82: return 0.13696610927581787f;
  t109_n83: if (E.getNumReferences() >= 3290841088 /*665.0*/) goto t109_n85;
  t109_n84: return -0.034045834094285965f;
  t109_n85: if (E.getNumReferences() >= 3294789632 /*906.0*/) goto t109_n87;
  t109_n86: return 0.11583797633647919f;
  t109_n87: return 0.053477950394153595f;
  t109_n88: if (E.getNumReferences() >= 3314442240 /*4556.0*/) goto t109_n108;
  t109_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t109_n91;
  t109_n90: return 0.008678211830556393f;
  t109_n91: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t109_n101;
  t109_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t109_n100;
  t109_n93: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t109_n95;
  t109_n94: return 0.00562353665009141f;
  t109_n95: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t109_n97;
  t109_n96: return 0.04967578500509262f;
  t109_n97: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t109_n99;
  t109_n98: return 0.12216942757368088f;
  t109_n99: return -0.10023592412471771f;
  t109_n100: return 0.056046903133392334f;
  t109_n101: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t109_n107;
  t109_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t109_n104;
  t109_n103: return 0.1235121637582779f;
  t109_n104: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t109_n106;
  t109_n105: return -0.11600305885076523f;
  t109_n106: return 0.11414606124162674f;
  t109_n107: return 0.05135686695575714f;
  t109_n108: if (E.getNumReferences() >= 3315382272 /*5015.0*/) goto t109_n122;
  t109_n109: if (E.getNumReferences() >= 3314929664 /*4794.0*/) goto t109_n113;
  t109_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t109_n112;
  t109_n111: return 0.04129163175821304f;
  t109_n112: return 0.1101246178150177f;
  t109_n113: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t109_n121;
  t109_n114: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t109_n116;
  t109_n115: return 0.12729109823703766f;
  t109_n116: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t109_n120;
  t109_n117: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t109_n119;
  t109_n118: return 0.12789525091648102f;
  t109_n119: return 0.12602843344211578f;
  t109_n120: return 0.108506940305233f;
  t109_n121: return -0.06353357434272766f;
  t109_n122: return 0.02155785821378231f;
  t109_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t109_n179;
  t109_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t109_n144;
  t109_n125: if (E.getNumReferences() >= 3281764352 /*311.5*/) goto t109_n127;
  t109_n126: return -0.12375829368829727f;
  t109_n127: if (E.getNumReferences() >= 3293585408 /*832.5*/) goto t109_n137;
  t109_n128: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t109_n130;
  t109_n129: return -0.024436306208372116f;
  t109_n130: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t109_n136;
  t109_n131: if (E.getNumReferences() >= 3283877888 /*376.0*/) goto t109_n133;
  t109_n132: return 0.1231277585029602f;
  t109_n133: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t109_n135;
  t109_n134: return 0.10412620007991791f;
  t109_n135: return -0.3206042945384979f;
  t109_n136: return -0.007147527765482664f;
  t109_n137: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t109_n139;
  t109_n138: return -0.046179525554180145f;
  t109_n139: if (E.getNumReferences() >= 3347921344 /*72307.5*/) goto t109_n143;
  t109_n140: if (E.getNumReferences() >= 3332248320 /*20233.5*/) goto t109_n142;
  t109_n141: return 0.06290004402399063f;
  t109_n142: return 0.0966353714466095f;
  t109_n143: return 0.021205324679613113f;
  t109_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t109_n146;
  t109_n145: return -0.14170636236667633f;
  t109_n146: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t109_n160;
  t109_n147: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t109_n157;
  t109_n148: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t109_n150;
  t109_n149: return -0.0782509595155716f;
  t109_n150: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t109_n152;
  t109_n151: return 0.08922497928142548f;
  t109_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t109_n154;
  t109_n153: return -0.011631588451564312f;
  t109_n154: if (E.getNumReferences() >= 3277422592 /*217.5*/) goto t109_n156;
  t109_n155: return 0.06881436705589294f;
  t109_n156: return 0.1092655137181282f;
  t109_n157: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t109_n159;
  t109_n158: return -0.1667409986257553f;
  t109_n159: return 0.10809878259897232f;
  t109_n160: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t109_n162;
  t109_n161: return -0.10926590114831924f;
  t109_n162: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t109_n164;
  t109_n163: return -0.004843577276915312f;
  t109_n164: if (E.getNumReferences() >= 3318893568 /*6729.5*/) goto t109_n178;
  t109_n165: if (E.getNumReferences() >= 3292364800 /*758.0*/) goto t109_n171;
  t109_n166: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t109_n168;
  t109_n167: return -0.012438679113984108f;
  t109_n168: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t109_n170;
  t109_n169: return 0.11655660718679428f;
  t109_n170: return -0.022940317168831825f;
  t109_n171: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t109_n173;
  t109_n172: return 0.10687104612588882f;
  t109_n173: if (E.getNumReferences() >= 3309690880 /*3166.0*/) goto t109_n175;
  t109_n174: return -0.10342381149530411f;
  t109_n175: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t109_n177;
  t109_n176: return 0.09019176661968231f;
  t109_n177: return 0.12167365849018097f;
  t109_n178: return -0.022723637521266937f;
  t109_n179: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t109_n181;
  t109_n180: return 0.12215733528137207f;
  t109_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t109_n183;
  t109_n182: return 0.06778787076473236f;
  t109_n183: return 0.04998055100440979f;
  t109_n184: return -0.03715747967362404f;
  t109_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t109_n187;
  t109_n186: return -0.04412158206105232f;
  t109_n187: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t109_n189;
  t109_n188: return -0.11603259295225143f;
  t109_n189: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t109_n197;
  t109_n190: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t109_n192;
  t109_n191: return 0.028491264209151268f;
  t109_n192: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t109_n196;
  t109_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t109_n195;
  t109_n194: return 0.050153303891420364f;
  t109_n195: return 0.10589256137609482f;
  t109_n196: return 0.041616689413785934f;
  t109_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t109_n199;
  t109_n198: return -0.2590908408164978f;
  t109_n199: return -0.008438258431851864f;
  t109_n200: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t109_n216;
  t109_n201: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t109_n205;
  t109_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t109_n204;
  t109_n203: return -0.012624423950910568f;
  t109_n204: return 0.005651253275573254f;
  t109_n205: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t109_n215;
  t109_n206: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t109_n210;
  t109_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t109_n209;
  t109_n208: return 0.018332235515117645f;
  t109_n209: return 0.03206348791718483f;
  t109_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag))) goto t109_n212;
  t109_n211: return 0.015267196111381054f;
  t109_n212: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t109_n214;
  t109_n213: return -0.10699521750211716f;
  t109_n214: return 0.09125234931707382f;
  t109_n215: return -0.07831739634275436f;
  t109_n216: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t109_n222;
  t109_n217: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t109_n221;
  t109_n218: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t109_n220;
  t109_n219: return -0.04804547503590584f;
  t109_n220: return -0.1946006864309311f;
  t109_n221: return 0.0013157717185094953f;
  t109_n222: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t109_n252;
  t109_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t109_n225;
  t109_n224: return -0.19159355759620667f;
  t109_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t109_n247;
  t109_n226: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t109_n236;
  t109_n227: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t109_n229;
  t109_n228: return 0.011982613243162632f;
  t109_n229: if (E.getNumReferences() >= 3255566336 /*35.0*/) goto t109_n233;
  t109_n230: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t109_n232;
  t109_n231: return 0.07709824293851852f;
  t109_n232: return 0.14488309621810913f;
  t109_n233: if (E.getNumReferences() >= 3263692800 /*68.0*/) goto t109_n235;
  t109_n234: return 0.11579592525959015f;
  t109_n235: return 0.08614420145750046f;
  t109_n236: if (E.getNumReferences() >= 3324914176 /*11146.5*/) goto t109_n246;
  t109_n237: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t109_n245;
  t109_n238: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t109_n240;
  t109_n239: return 0.08186691254377365f;
  t109_n240: if (E.getNumReferences() >= 3257925632 /*44.0*/) goto t109_n244;
  t109_n241: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t109_n243;
  t109_n242: return 0.32141992449760437f;
  t109_n243: return 0.1328524947166443f;
  t109_n244: return 0.11991830915212631f;
  t109_n245: return -0.0370052307844162f;
  t109_n246: return 0.08417563140392303f;
  t109_n247: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t109_n251;
  t109_n248: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t109_n250;
  t109_n249: return 0.2096516638994217f;
  t109_n250: return 0.19620658457279205f;
  t109_n251: return -0.060512106865644455f;
  t109_n252: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t109_n254;
  t109_n253: return 0.07599984854459763f;
  t109_n254: return -0.059132590889930725f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree110(const Example& E) {
  t110_n0: if (E.getNumReferences() >= 3305437184 /*2127.5*/) goto t110_n18;
  t110_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t110_n3;
  t110_n2: return 0.005317645613104105f;
  t110_n3: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t110_n5;
  t110_n4: return -0.00020123773720115423f;
  t110_n5: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t110_n7;
  t110_n6: return -0.08294682204723358f;
  t110_n7: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t110_n11;
  t110_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t110_n10;
  t110_n9: return -0.006481718737632036f;
  t110_n10: return 0.02434486895799637f;
  t110_n11: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t110_n13;
  t110_n12: return -0.028117772191762924f;
  t110_n13: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t110_n17;
  t110_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t110_n16;
  t110_n15: return -0.0021343333646655083f;
  t110_n16: return 0.04880533367395401f;
  t110_n17: return 0.04057788848876953f;
  t110_n18: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t110_n22;
  t110_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t110_n21;
  t110_n20: return 0.012561727315187454f;
  t110_n21: return 0.029484158381819725f;
  t110_n22: if (E.getNumReferences() >= 3305449472 /*2130.5*/) goto t110_n28;
  t110_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t110_n27;
  t110_n24: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t110_n26;
  t110_n25: return -0.10578509420156479f;
  t110_n26: return 0.10798432677984238f;
  t110_n27: return 0.3837612569332123f;
  t110_n28: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t110_n30;
  t110_n29: return -0.004263578914105892f;
  t110_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t110_n254;
  t110_n31: if (E.getNumReferences() >= 3345503360 /*59476.5*/) goto t110_n237;
  t110_n32: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t110_n94;
  t110_n33: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t110_n37;
  t110_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t110_n36;
  t110_n35: return -0.11677894741296768f;
  t110_n36: return -0.012557084672152996f;
  t110_n37: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t110_n71;
  t110_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t110_n40;
  t110_n39: return -0.2117966264486313f;
  t110_n40: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t110_n70;
  t110_n41: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t110_n49;
  t110_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t110_n44;
  t110_n43: return 0.06509707123041153f;
  t110_n44: if (E.getNumReferences() >= 3322947584 /*9226.0*/) goto t110_n46;
  t110_n45: return 0.10077022761106491f;
  t110_n46: if (E.getNumReferences() >= 3325011456 /*11241.5*/) goto t110_n48;
  t110_n47: return 0.12778158485889435f;
  t110_n48: return 0.1015375480055809f;
  t110_n49: if (E.getNumReferences() >= 3309021184 /*3002.5*/) goto t110_n51;
  t110_n50: return 0.03176850453019142f;
  t110_n51: if (E.getNumReferences() >= 3309780992 /*3188.0*/) goto t110_n53;
  t110_n52: return 0.1080024391412735f;
  t110_n53: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t110_n65;
  t110_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t110_n62;
  t110_n55: if (E.getNumReferences() >= 3316458496 /*5540.5*/) goto t110_n57;
  t110_n56: return 0.15401476621627808f;
  t110_n57: if (E.getNumReferences() >= 3317757952 /*6175.0*/) goto t110_n59;
  t110_n58: return 0.13474881649017334f;
  t110_n59: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t110_n61;
  t110_n60: return 0.08033127337694168f;
  t110_n61: return 0.10190572589635849f;
  t110_n62: if (E.getNumReferences() >= 3317139456 /*5873.0*/) goto t110_n64;
  t110_n63: return 0.11761501431465149f;
  t110_n64: return -0.14179201424121857f;
  t110_n65: if (E.getNumReferences() >= 3313203200 /*4023.5*/) goto t110_n69;
  t110_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t110_n68;
  t110_n67: return -0.014653726480901241f;
  t110_n68: return 0.11140505969524384f;
  t110_n69: return 0.04833702743053436f;
  t110_n70: return -0.02306232787668705f;
  t110_n71: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t110_n93;
  t110_n72: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t110_n74;
  t110_n73: return -0.14871132373809814f;
  t110_n74: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t110_n78;
  t110_n75: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t110_n77;
  t110_n76: return 0.02349746786057949f;
  t110_n77: return 0.09320134669542313f;
  t110_n78: if (E.getNumReferences() >= 3324282368 /*10529.5*/) goto t110_n84;
  t110_n79: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t110_n81;
  t110_n80: return 0.1316251903772354f;
  t110_n81: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t110_n83;
  t110_n82: return -0.10939975827932358f;
  t110_n83: return 0.13278700411319733f;
  t110_n84: if (E.getNumReferences() >= 3333771776 /*23209.0*/) goto t110_n88;
  t110_n85: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t110_n87;
  t110_n86: return 0.10099005699157715f;
  t110_n87: return 0.10597929358482361f;
  t110_n88: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t110_n90;
  t110_n89: return 0.04541635885834694f;
  t110_n90: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t110_n92;
  t110_n91: return 0.06703097373247147f;
  t110_n92: return 0.09012176096439362f;
  t110_n93: return -0.0062019401229918f;
  t110_n94: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t110_n150;
  t110_n95: if (E.getNumReferences() >= 3315700736 /*5170.5*/) goto t110_n97;
  t110_n96: return 0.0012076976709067822f;
  t110_n97: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t110_n105;
  t110_n98: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t110_n104;
  t110_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t110_n103;
  t110_n100: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t110_n102;
  t110_n101: return 0.14447811245918274f;
  t110_n102: return 0.09312889724969864f;
  t110_n103: return 0.13257001340389252f;
  t110_n104: return -0.13818100094795227f;
  t110_n105: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t110_n125;
  t110_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t110_n108;
  t110_n107: return -0.03425498679280281f;
  t110_n108: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t110_n122;
  t110_n109: if (E.getNumReferences() >= 3334660864 /*24945.5*/) goto t110_n121;
  t110_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t110_n112;
  t110_n111: return 0.03265966847538948f;
  t110_n112: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t110_n120;
  t110_n113: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t110_n115;
  t110_n114: return 0.2236657440662384f;
  t110_n115: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t110_n119;
  t110_n116: if (E.getNumReferences() >= 3316636672 /*5627.5*/) goto t110_n118;
  t110_n117: return 0.11472438275814056f;
  t110_n118: return 0.10362329334020615f;
  t110_n119: return 0.11049258708953857f;
  t110_n120: return -0.12358719855546951f;
  t110_n121: return -0.056997403502464294f;
  t110_n122: if (E.getNumReferences() >= 3342583296 /*48070.0*/) goto t110_n124;
  t110_n123: return 0.07422259449958801f;
  t110_n124: return -0.03426699340343475f;
  t110_n125: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t110_n129;
  t110_n126: if (E.getSymbolScopeDistance() >= 3240099840 /*10.0*/) goto t110_n128;
  t110_n127: return 0.10822981595993042f;
  t110_n128: return 0.028454042971134186f;
  t110_n129: if (E.getNumReferences() >= 3327446528 /*13619.5*/) goto t110_n137;
  t110_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t110_n132;
  t110_n131: return 0.03616912290453911f;
  t110_n132: if (E.getNumReferences() >= 3324087808 /*10339.5*/) goto t110_n134;
  t110_n133: return 0.07340879738330841f;
  t110_n134: if (E.getNumReferences() >= 3324406784 /*10651.0*/) goto t110_n136;
  t110_n135: return 0.1265668272972107f;
  t110_n136: return 0.23877140879631042f;
  t110_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t110_n143;
  t110_n138: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t110_n142;
  t110_n139: if (E.getNumReferences() >= 3340394880 /*39521.5*/) goto t110_n141;
  t110_n140: return 0.06306152045726776f;
  t110_n141: return 0.11021175980567932f;
  t110_n142: return -0.05491824075579643f;
  t110_n143: if (E.getNumReferences() >= 3331176192 /*18139.5*/) goto t110_n149;
  t110_n144: if (E.getNumReferences() >= 3330760192 /*17327.0*/) goto t110_n148;
  t110_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t110_n147;
  t110_n146: return -0.2186264842748642f;
  t110_n147: return 0.10904200375080109f;
  t110_n148: return 0.11915002018213272f;
  t110_n149: return 0.06163695827126503f;
  t110_n150: if (E.getNumReferences() >= 3305697280 /*2191.0*/) goto t110_n166;
  t110_n151: if (E.getNumReferences() >= 3305539584 /*2152.5*/) goto t110_n153;
  t110_n152: return -0.08360258489847183f;
  t110_n153: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t110_n163;
  t110_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t110_n160;
  t110_n155: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t110_n157;
  t110_n156: return 0.004528628196567297f;
  t110_n157: if (E.getNumReferences() >= 3305564160 /*2158.5*/) goto t110_n159;
  t110_n158: return -0.10050200670957565f;
  t110_n159: return 0.11461639404296875f;
  t110_n160: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t110_n162;
  t110_n161: return 0.11815992742776871f;
  t110_n162: return -0.101721853017807f;
  t110_n163: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t110_n165;
  t110_n164: return 0.12280648946762085f;
  t110_n165: return 0.13700160384178162f;
  t110_n166: if (E.getNumReferences() >= 3318252544 /*6416.5*/) goto t110_n188;
  t110_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t110_n169;
  t110_n168: return 0.021815961226820946f;
  t110_n169: if (E.getNumReferences() >= 3315159040 /*4906.0*/) goto t110_n187;
  t110_n170: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t110_n186;
  t110_n171: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t110_n181;
  t110_n172: if (E.getNumReferences() >= 3306842112 /*2470.5*/) goto t110_n176;
  t110_n173: if (E.getNumReferences() >= 3306567680 /*2403.5*/) goto t110_n175;
  t110_n174: return -0.024765130132436752f;
  t110_n175: return 0.11812925338745117f;
  t110_n176: if (E.getNumReferences() >= 3313252352 /*4035.5*/) goto t110_n178;
  t110_n177: return 0.005925746634602547f;
  t110_n178: if (E.getNumReferences() >= 3313448960 /*4083.5*/) goto t110_n180;
  t110_n179: return 0.11895076930522919f;
  t110_n180: return 0.07719963788986206f;
  t110_n181: if (E.getNumReferences() >= 3308484608 /*2871.5*/) goto t110_n183;
  t110_n182: return 0.12250781059265137f;
  t110_n183: if (E.getNumReferences() >= 3314669568 /*4667.0*/) goto t110_n185;
  t110_n184: return 0.046414852142333984f;
  t110_n185: return 0.14402572810649872f;
  t110_n186: return -0.11015762388706207f;
  t110_n187: return -0.13976331055164337f;
  t110_n188: if (E.getNumReferences() >= 3318256640 /*6418.5*/) goto t110_n192;
  t110_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t110_n191;
  t110_n190: return -0.07657530903816223f;
  t110_n191: return 0.126930370926857f;
  t110_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t110_n204;
  t110_n193: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t110_n195;
  t110_n194: return 0.03308549523353577f;
  t110_n195: if (E.getNumReferences() >= 3344355328 /*54992.0*/) goto t110_n197;
  t110_n196: return 0.1251550167798996f;
  t110_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t110_n201;
  t110_n198: if (E.getNumReferences() >= 3344974336 /*57410.0*/) goto t110_n200;
  t110_n199: return -0.0806415006518364f;
  t110_n200: return 0.09630706906318665f;
  t110_n201: if (E.getNumReferences() >= 3344562560 /*55801.5*/) goto t110_n203;
  t110_n202: return 0.102473683655262f;
  t110_n203: return -0.08492956310510635f;
  t110_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t110_n206;
  t110_n205: return 0.04810589179396629f;
  t110_n206: if (E.getNumReferences() >= 3319788544 /*7166.5*/) goto t110_n212;
  t110_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t110_n211;
  t110_n208: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t110_n210;
  t110_n209: return 0.1012040376663208f;
  t110_n210: return -0.1655595898628235f;
  t110_n211: return 0.11846832931041718f;
  t110_n212: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t110_n230;
  t110_n213: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t110_n229;
  t110_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t110_n226;
  t110_n215: if (E.getNumReferences() >= 3323776512 /*10035.5*/) goto t110_n225;
  t110_n216: if (E.getNumReferences() >= 3322122752 /*8420.5*/) goto t110_n218;
  t110_n217: return -0.0013777143321931362f;
  t110_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t110_n220;
  t110_n219: return 0.0960787683725357f;
  t110_n220: if (E.getNumReferences() >= 3322854400 /*9135.0*/) goto t110_n222;
  t110_n221: return 0.11316104233264923f;
  t110_n222: if (E.getNumReferences() >= 3323401216 /*9669.0*/) goto t110_n224;
  t110_n223: return 0.21430489420890808f;
  t110_n224: return 0.19095195829868317f;
  t110_n225: return 0.06095360964536667f;
  t110_n226: if (E.getNumReferences() >= 3325309440 /*11532.5*/) goto t110_n228;
  t110_n227: return -0.26250696182250977f;
  t110_n228: return 0.10755648463964462f;
  t110_n229: return 0.1023545116186142f;
  t110_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t110_n232;
  t110_n231: return -0.02139846608042717f;
  t110_n232: if (E.getNumReferences() >= 3336401664 /*28345.5*/) goto t110_n234;
  t110_n233: return -0.0861520916223526f;
  t110_n234: if (E.getNumReferences() >= 3340569472 /*40203.5*/) goto t110_n236;
  t110_n235: return 0.10691935569047928f;
  t110_n236: return 0.0831514298915863f;
  t110_n237: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t110_n249;
  t110_n238: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t110_n244;
  t110_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t110_n243;
  t110_n240: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t110_n242;
  t110_n241: return -0.0144036915153265f;
  t110_n242: return -0.27576884627342224f;
  t110_n243: return -0.08865491300821304f;
  t110_n244: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t110_n246;
  t110_n245: return 0.11837565153837204f;
  t110_n246: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t110_n248;
  t110_n247: return -0.09891572594642639f;
  t110_n248: return 0.05489999055862427f;
  t110_n249: if (E.getNumReferences() >= 3345974912 /*61318.5*/) goto t110_n251;
  t110_n250: return 0.108639195561409f;
  t110_n251: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t110_n253;
  t110_n252: return -0.016935251653194427f;
  t110_n253: return 0.016510747373104095f;
  t110_n254: return 0.046243034303188324f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree111(const Example& E) {
  t111_n0: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t111_n254;
  t111_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t111_n3;
  t111_n2: return -0.08620188385248184f;
  t111_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t111_n9;
  t111_n4: if (E.getNumReferences() >= 3310407680 /*3341.0*/) goto t111_n6;
  t111_n5: return 0.003410970326513052f;
  t111_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t111_n8;
  t111_n7: return 0.012890883721411228f;
  t111_n8: return 0.029902594164013863f;
  t111_n9: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t111_n109;
  t111_n10: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t111_n60;
  t111_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t111_n17;
  t111_n12: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t111_n16;
  t111_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t111_n15;
  t111_n14: return -0.16420885920524597f;
  t111_n15: return -0.06669827550649643f;
  t111_n16: return -0.003591548651456833f;
  t111_n17: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t111_n19;
  t111_n18: return 0.005133422091603279f;
  t111_n19: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t111_n23;
  t111_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t111_n22;
  t111_n21: return -0.01763959601521492f;
  t111_n22: return 0.010446936823427677f;
  t111_n23: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t111_n33;
  t111_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t111_n26;
  t111_n25: return 0.02308523841202259f;
  t111_n26: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t111_n30;
  t111_n27: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t111_n29;
  t111_n28: return 0.04917636513710022f;
  t111_n29: return -0.012932147830724716f;
  t111_n30: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t111_n32;
  t111_n31: return 0.11087167263031006f;
  t111_n32: return -0.01868957281112671f;
  t111_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t111_n59;
  t111_n34: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t111_n36;
  t111_n35: return 0.08883478492498398f;
  t111_n36: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t111_n52;
  t111_n37: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t111_n43;
  t111_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t111_n42;
  t111_n39: if (E.getNumReferences() >= 3240099840 /*10.0*/) goto t111_n41;
  t111_n40: return -0.0451643243432045f;
  t111_n41: return 0.10201218724250793f;
  t111_n42: return 0.14656488597393036f;
  t111_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t111_n51;
  t111_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t111_n48;
  t111_n45: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t111_n47;
  t111_n46: return -0.15709197521209717f;
  t111_n47: return 0.07912632077932358f;
  t111_n48: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t111_n50;
  t111_n49: return 0.11461324244737625f;
  t111_n50: return 0.042461100965738297f;
  t111_n51: return 0.3237234950065613f;
  t111_n52: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t111_n54;
  t111_n53: return 0.020142626017332077f;
  t111_n54: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t111_n58;
  t111_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n57;
  t111_n56: return 0.1295635998249054f;
  t111_n57: return 0.07518229633569717f;
  t111_n58: return 0.034956205636262894f;
  t111_n59: return 0.005187667906284332f;
  t111_n60: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t111_n70;
  t111_n61: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t111_n63;
  t111_n62: return -0.023294156417250633f;
  t111_n63: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t111_n69;
  t111_n64: if (E.getNumReferences() >= 3322163200 /*8460.0*/) goto t111_n68;
  t111_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t111_n67;
  t111_n66: return -0.15322239696979523f;
  t111_n67: return -0.0456671379506588f;
  t111_n68: return 0.041583046317100525f;
  t111_n69: return -0.05385706573724747f;
  t111_n70: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t111_n74;
  t111_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t111_n73;
  t111_n72: return -0.33518022298812866f;
  t111_n73: return 0.04852826148271561f;
  t111_n74: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t111_n84;
  t111_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t111_n81;
  t111_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t111_n78;
  t111_n77: return -0.003388351295143366f;
  t111_n78: if (E.getNumReferences() >= 3281731584 /*310.5*/) goto t111_n80;
  t111_n79: return 0.10409659892320633f;
  t111_n80: return -0.47908294200897217f;
  t111_n81: if (E.getNumReferences() >= 3287973888 /*501.0*/) goto t111_n83;
  t111_n82: return -0.05049615353345871f;
  t111_n83: return 0.10929498076438904f;
  t111_n84: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t111_n104;
  t111_n85: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t111_n93;
  t111_n86: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t111_n92;
  t111_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t111_n89;
  t111_n88: return 0.05257877707481384f;
  t111_n89: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t111_n91;
  t111_n90: return 0.12676474452018738f;
  t111_n91: return 0.08171453326940536f;
  t111_n92: return -0.00863591581583023f;
  t111_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n101;
  t111_n94: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t111_n96;
  t111_n95: return -0.008191796019673347f;
  t111_n96: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t111_n100;
  t111_n97: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t111_n99;
  t111_n98: return 0.15910173952579498f;
  t111_n99: return 0.09332653880119324f;
  t111_n100: return 0.10142143815755844f;
  t111_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t111_n103;
  t111_n102: return 0.013872805051505566f;
  t111_n103: return 0.11392500251531601f;
  t111_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t111_n106;
  t111_n105: return 0.0011513129575178027f;
  t111_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t111_n108;
  t111_n107: return 0.11531469970941544f;
  t111_n108: return 0.030993463471531868f;
  t111_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t111_n201;
  t111_n110: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t111_n112;
  t111_n111: return -0.007182210683822632f;
  t111_n112: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t111_n114;
  t111_n113: return -0.0006674834876321256f;
  t111_n114: if (E.getNumReferences() >= 3297136640 /*1074.5*/) goto t111_n184;
  t111_n115: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t111_n183;
  t111_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t111_n150;
  t111_n117: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t111_n149;
  t111_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t111_n138;
  t111_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t111_n131;
  t111_n120: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t111_n124;
  t111_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t111_n123;
  t111_n122: return 0.03686348721385002f;
  t111_n123: return -0.022123750299215317f;
  t111_n124: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t111_n126;
  t111_n125: return -0.051720030605793f;
  t111_n126: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t111_n128;
  t111_n127: return 0.12636888027191162f;
  t111_n128: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t111_n130;
  t111_n129: return -0.06252571940422058f;
  t111_n130: return 0.1122167780995369f;
  t111_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t111_n133;
  t111_n132: return 0.009810473769903183f;
  t111_n133: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t111_n135;
  t111_n134: return 0.09114436060190201f;
  t111_n135: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n137;
  t111_n136: return 0.1433493047952652f;
  t111_n137: return 0.1154501885175705f;
  t111_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t111_n140;
  t111_n139: return -0.09438508003950119f;
  t111_n140: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t111_n142;
  t111_n141: return 0.05667519569396973f;
  t111_n142: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n148;
  t111_n143: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t111_n145;
  t111_n144: return 0.08388188481330872f;
  t111_n145: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t111_n147;
  t111_n146: return 0.12357982993125916f;
  t111_n147: return 0.024879496544599533f;
  t111_n148: return 0.06289323419332504f;
  t111_n149: return -0.020869020372629166f;
  t111_n150: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t111_n152;
  t111_n151: return -0.0799277275800705f;
  t111_n152: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t111_n182;
  t111_n153: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t111_n155;
  t111_n154: return 0.059885166585445404f;
  t111_n155: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n181;
  t111_n156: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t111_n164;
  t111_n157: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t111_n163;
  t111_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t111_n162;
  t111_n159: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t111_n161;
  t111_n160: return 0.10863477736711502f;
  t111_n161: return 0.06224352493882179f;
  t111_n162: return 0.09158165007829666f;
  t111_n163: return 0.010302817448973656f;
  t111_n164: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t111_n180;
  t111_n165: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t111_n169;
  t111_n166: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t111_n168;
  t111_n167: return 0.12738406658172607f;
  t111_n168: return 0.015530858188867569f;
  t111_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t111_n171;
  t111_n170: return 0.10218239575624466f;
  t111_n171: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t111_n179;
  t111_n172: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t111_n176;
  t111_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t111_n175;
  t111_n174: return 0.11110081523656845f;
  t111_n175: return 0.15051768720149994f;
  t111_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t111_n178;
  t111_n177: return 0.15140852332115173f;
  t111_n178: return 0.13161130249500275f;
  t111_n179: return 0.18770064413547516f;
  t111_n180: return 0.07041681557893753f;
  t111_n181: return 0.041398659348487854f;
  t111_n182: return -0.013327161781489849f;
  t111_n183: return -0.001569500076584518f;
  t111_n184: if (E.getNumReferences() >= 3297198080 /*1082.0*/) goto t111_n188;
  t111_n185: if (E.getNumReferences() >= 3297153024 /*1076.5*/) goto t111_n187;
  t111_n186: return 0.10303439944982529f;
  t111_n187: return 0.12197224050760269f;
  t111_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t111_n190;
  t111_n189: return 0.04123164713382721f;
  t111_n190: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t111_n198;
  t111_n191: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t111_n197;
  t111_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n196;
  t111_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t111_n195;
  t111_n194: return 0.0801309198141098f;
  t111_n195: return 0.1076282486319542f;
  t111_n196: return 0.1174749881029129f;
  t111_n197: return 0.1109902486205101f;
  t111_n198: if (E.getNumReferences() >= 3301470208 /*1603.5*/) goto t111_n200;
  t111_n199: return 0.11309792101383209f;
  t111_n200: return 0.020040906965732574f;
  t111_n201: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t111_n215;
  t111_n202: if (E.getNumReferences() >= 3325698048 /*11912.0*/) goto t111_n212;
  t111_n203: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t111_n211;
  t111_n204: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t111_n210;
  t111_n205: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t111_n207;
  t111_n206: return 0.04404567554593086f;
  t111_n207: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t111_n209;
  t111_n208: return -0.10222906619310379f;
  t111_n209: return 0.11454859375953674f;
  t111_n210: return 0.010678659193217754f;
  t111_n211: return -0.27696582674980164f;
  t111_n212: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t111_n214;
  t111_n213: return 0.04443143680691719f;
  t111_n214: return -0.15075655281543732f;
  t111_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t111_n243;
  t111_n216: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t111_n240;
  t111_n217: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t111_n229;
  t111_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n224;
  t111_n219: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t111_n221;
  t111_n220: return 0.03609981760382652f;
  t111_n221: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t111_n223;
  t111_n222: return 0.08250903338193893f;
  t111_n223: return 0.14168347418308258f;
  t111_n224: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t111_n226;
  t111_n225: return 0.05914967507123947f;
  t111_n226: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t111_n228;
  t111_n227: return 0.08855459839105606f;
  t111_n228: return 0.1558709740638733f;
  t111_n229: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t111_n235;
  t111_n230: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t111_n232;
  t111_n231: return 0.07122772932052612f;
  t111_n232: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n234;
  t111_n233: return 0.07952980697154999f;
  t111_n234: return 0.1303512156009674f;
  t111_n235: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t111_n237;
  t111_n236: return -0.00648451829329133f;
  t111_n237: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t111_n239;
  t111_n238: return 0.01730351895093918f;
  t111_n239: return 0.04129362851381302f;
  t111_n240: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t111_n242;
  t111_n241: return 0.011659188196063042f;
  t111_n242: return 0.061720408499240875f;
  t111_n243: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t111_n247;
  t111_n244: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t111_n246;
  t111_n245: return 0.05701494961977005f;
  t111_n246: return 0.09789404273033142f;
  t111_n247: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t111_n253;
  t111_n248: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t111_n250;
  t111_n249: return 0.1325892210006714f;
  t111_n250: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t111_n252;
  t111_n251: return 0.0849018469452858f;
  t111_n252: return 0.12424824386835098f;
  t111_n253: return 0.08074268698692322f;
  t111_n254: return -0.09555252641439438f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree112(const Example& E) {
  t112_n0: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t112_n112;
  t112_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t112_n5;
  t112_n2: if (E.getNumReferences() >= 3358365376 /*176731.0*/) goto t112_n4;
  t112_n3: return -0.0008065446163527668f;
  t112_n4: return -0.13900481164455414f;
  t112_n5: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t112_n111;
  t112_n6: if (E.getNumReferences() >= 3354462528 /*123410.5*/) goto t112_n104;
  t112_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t112_n9;
  t112_n8: return -0.006996885873377323f;
  t112_n9: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t112_n89;
  t112_n10: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t112_n24;
  t112_n11: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t112_n13;
  t112_n12: return 0.008728818036615849f;
  t112_n13: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t112_n17;
  t112_n14: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t112_n16;
  t112_n15: return -0.01304757222533226f;
  t112_n16: return -0.1143481507897377f;
  t112_n17: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t112_n23;
  t112_n18: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t112_n20;
  t112_n19: return -0.1993517428636551f;
  t112_n20: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t112_n22;
  t112_n21: return -0.15541763603687286f;
  t112_n22: return 0.13538798689842224f;
  t112_n23: return 0.021079471334815025f;
  t112_n24: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t112_n84;
  t112_n25: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t112_n35;
  t112_n26: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t112_n28;
  t112_n27: return 0.05628621205687523f;
  t112_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t112_n30;
  t112_n29: return -0.04073021188378334f;
  t112_n30: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t112_n32;
  t112_n31: return 0.11027254164218903f;
  t112_n32: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t112_n34;
  t112_n33: return -0.07132728397846222f;
  t112_n34: return 0.10432092100381851f;
  t112_n35: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t112_n43;
  t112_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t112_n42;
  t112_n37: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t112_n39;
  t112_n38: return 0.01704433746635914f;
  t112_n39: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t112_n41;
  t112_n40: return -0.09796152263879776f;
  t112_n41: return 0.1274372637271881f;
  t112_n42: return -0.13342837989330292f;
  t112_n43: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t112_n79;
  t112_n44: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t112_n72;
  t112_n45: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t112_n53;
  t112_n46: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t112_n48;
  t112_n47: return -0.02250647358596325f;
  t112_n48: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t112_n52;
  t112_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t112_n51;
  t112_n50: return 0.08428172767162323f;
  t112_n51: return 0.13165420293807983f;
  t112_n52: return -0.12727296352386475f;
  t112_n53: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t112_n65;
  t112_n54: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t112_n64;
  t112_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t112_n57;
  t112_n56: return 0.05720401927828789f;
  t112_n57: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t112_n59;
  t112_n58: return -0.10260824859142303f;
  t112_n59: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t112_n63;
  t112_n60: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t112_n62;
  t112_n61: return 0.10811829566955566f;
  t112_n62: return -0.13913118839263916f;
  t112_n63: return 0.08031418174505234f;
  t112_n64: return 0.03547518700361252f;
  t112_n65: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t112_n67;
  t112_n66: return 0.06160707771778107f;
  t112_n67: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t112_n71;
  t112_n68: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t112_n70;
  t112_n69: return 0.05377751588821411f;
  t112_n70: return 0.14869418740272522f;
  t112_n71: return -0.16388049721717834f;
  t112_n72: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t112_n78;
  t112_n73: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t112_n77;
  t112_n74: if (E.getNumReferences() >= 3243245568 /*13.0*/) goto t112_n76;
  t112_n75: return -0.16454166173934937f;
  t112_n76: return 0.1335010528564453f;
  t112_n77: return -0.04134251922369003f;
  t112_n78: return 0.08837078511714935f;
  t112_n79: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t112_n81;
  t112_n80: return -0.07967275381088257f;
  t112_n81: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t112_n83;
  t112_n82: return 0.10763800889253616f;
  t112_n83: return -0.10952768474817276f;
  t112_n84: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t112_n86;
  t112_n85: return -0.096590057015419f;
  t112_n86: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t112_n88;
  t112_n87: return 0.018568027764558792f;
  t112_n88: return -0.3833959400653839f;
  t112_n89: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t112_n91;
  t112_n90: return -0.0005437724175862968f;
  t112_n91: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t112_n95;
  t112_n92: if (E.getNumReferences() >= 3350564160 /*92954.5*/) goto t112_n94;
  t112_n93: return 0.001686161500401795f;
  t112_n94: return 0.16425560414791107f;
  t112_n95: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n103;
  t112_n96: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t112_n102;
  t112_n97: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t112_n99;
  t112_n98: return 0.053870271891355515f;
  t112_n99: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t112_n101;
  t112_n100: return 0.1250665932893753f;
  t112_n101: return 0.10089994221925735f;
  t112_n102: return 0.03598732128739357f;
  t112_n103: return 0.010322781279683113f;
  t112_n104: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n108;
  t112_n105: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t112_n107;
  t112_n106: return 0.12284120917320251f;
  t112_n107: return 0.07134249061346054f;
  t112_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t112_n110;
  t112_n109: return 0.10076242685317993f;
  t112_n110: return 0.11095788329839706f;
  t112_n111: return -0.22941994667053223f;
  t112_n112: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t112_n166;
  t112_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t112_n139;
  t112_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t112_n116;
  t112_n115: return -0.14019393920898438f;
  t112_n116: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n118;
  t112_n117: return 0.05402511730790138f;
  t112_n118: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t112_n122;
  t112_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t112_n121;
  t112_n120: return 0.0008328949916176498f;
  t112_n121: return 0.06893834471702576f;
  t112_n122: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t112_n138;
  t112_n123: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t112_n125;
  t112_n124: return 0.018171342089772224f;
  t112_n125: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t112_n129;
  t112_n126: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t112_n128;
  t112_n127: return 0.12089342623949051f;
  t112_n128: return 0.13694706559181213f;
  t112_n129: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t112_n131;
  t112_n130: return 0.08143304288387299f;
  t112_n131: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t112_n133;
  t112_n132: return 0.14756588637828827f;
  t112_n133: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t112_n137;
  t112_n134: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t112_n136;
  t112_n135: return 0.11300187557935715f;
  t112_n136: return 0.10897821187973022f;
  t112_n137: return 0.05106695368885994f;
  t112_n138: return -0.009715267457067966f;
  t112_n139: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t112_n141;
  t112_n140: return -0.1642022281885147f;
  t112_n141: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t112_n157;
  t112_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t112_n150;
  t112_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t112_n145;
  t112_n144: return 0.028491321951150894f;
  t112_n145: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t112_n149;
  t112_n146: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t112_n148;
  t112_n147: return 0.06302149593830109f;
  t112_n148: return -0.003003341844305396f;
  t112_n149: return 0.04213697090744972f;
  t112_n150: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t112_n156;
  t112_n151: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t112_n155;
  t112_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n154;
  t112_n153: return 0.12486748397350311f;
  t112_n154: return 0.08539526164531708f;
  t112_n155: return 0.0647084191441536f;
  t112_n156: return -0.11117464303970337f;
  t112_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n161;
  t112_n158: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t112_n160;
  t112_n159: return 0.08102285861968994f;
  t112_n160: return 0.09832008928060532f;
  t112_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t112_n163;
  t112_n162: return 0.03549456596374512f;
  t112_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t112_n165;
  t112_n164: return 0.09519558399915695f;
  t112_n165: return 0.05702663213014603f;
  t112_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t112_n168;
  t112_n167: return -0.0034813794773072004f;
  t112_n168: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t112_n208;
  t112_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t112_n171;
  t112_n170: return -0.11219514161348343f;
  t112_n171: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n181;
  t112_n172: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t112_n174;
  t112_n173: return 0.07879224419593811f;
  t112_n174: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t112_n180;
  t112_n175: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t112_n177;
  t112_n176: return -0.1100250706076622f;
  t112_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t112_n179;
  t112_n178: return 0.10824315994977951f;
  t112_n179: return 0.12235153466463089f;
  t112_n180: return 0.2070373296737671f;
  t112_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t112_n207;
  t112_n182: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t112_n206;
  t112_n183: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t112_n193;
  t112_n184: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t112_n186;
  t112_n185: return 0.0605517253279686f;
  t112_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t112_n188;
  t112_n187: return -0.31475841999053955f;
  t112_n188: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t112_n190;
  t112_n189: return -0.1188344657421112f;
  t112_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t112_n192;
  t112_n191: return 0.12576936185359955f;
  t112_n192: return 0.12239545583724976f;
  t112_n193: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t112_n203;
  t112_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t112_n198;
  t112_n195: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t112_n197;
  t112_n196: return 0.08511008322238922f;
  t112_n197: return 0.005017453338950872f;
  t112_n198: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t112_n200;
  t112_n199: return 0.1079002171754837f;
  t112_n200: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t112_n202;
  t112_n201: return 0.06177927553653717f;
  t112_n202: return 0.11697910726070404f;
  t112_n203: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t112_n205;
  t112_n204: return 0.025920357555150986f;
  t112_n205: return -0.39547955989837646f;
  t112_n206: return 0.13680638372898102f;
  t112_n207: return 0.04789825528860092f;
  t112_n208: if (E.getNumReferences() >= 3364277024 /*276057.0*/) goto t112_n210;
  t112_n209: return -0.1405039280653f;
  t112_n210: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t112_n216;
  t112_n211: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t112_n213;
  t112_n212: return 0.1258837729692459f;
  t112_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t112_n215;
  t112_n214: return -0.8602725267410278f;
  t112_n215: return 0.09653224796056747f;
  t112_n216: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t112_n252;
  t112_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t112_n229;
  t112_n218: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t112_n220;
  t112_n219: return 0.012423806823790073f;
  t112_n220: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n228;
  t112_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t112_n225;
  t112_n222: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t112_n224;
  t112_n223: return 0.01851225085556507f;
  t112_n224: return 0.11032824218273163f;
  t112_n225: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t112_n227;
  t112_n226: return 0.0985206812620163f;
  t112_n227: return -0.2322947382926941f;
  t112_n228: return 0.010065220296382904f;
  t112_n229: if (E.getNumReferences() >= 3365247648 /*306389.0*/) goto t112_n249;
  t112_n230: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t112_n242;
  t112_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t112_n235;
  t112_n232: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t112_n234;
  t112_n233: return -0.42937013506889343f;
  t112_n234: return 0.11495418846607208f;
  t112_n235: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t112_n237;
  t112_n236: return 0.02179361693561077f;
  t112_n237: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t112_n239;
  t112_n238: return -0.10391581803560257f;
  t112_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t112_n241;
  t112_n240: return 0.1116829663515091f;
  t112_n241: return 0.12063923478126526f;
  t112_n242: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t112_n246;
  t112_n243: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t112_n245;
  t112_n244: return 0.06295417249202728f;
  t112_n245: return -0.09457431733608246f;
  t112_n246: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t112_n248;
  t112_n247: return -0.5742807388305664f;
  t112_n248: return 0.08474238961935043f;
  t112_n249: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t112_n251;
  t112_n250: return 0.03159073740243912f;
  t112_n251: return -0.10252464562654495f;
  t112_n252: if (E.getNumReferences() >= 3364286400 /*276350.0*/) goto t112_n254;
  t112_n253: return 0.252142071723938f;
  t112_n254: return -0.10188305377960205f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree113(const Example& E) {
  t113_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t113_n128;
  t113_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t113_n3;
  t113_n2: return -0.0010125640546903014f;
  t113_n3: if (E.getNumReferences() >= 3338172416 /*31804.0*/) goto t113_n127;
  t113_n4: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t113_n118;
  t113_n5: if (E.getNumReferences() >= 3327652864 /*13821.0*/) goto t113_n91;
  t113_n6: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t113_n82;
  t113_n7: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t113_n25;
  t113_n8: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t113_n16;
  t113_n9: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t113_n11;
  t113_n10: return 0.006387209054082632f;
  t113_n11: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t113_n13;
  t113_n12: return -0.014286782592535019f;
  t113_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t113_n15;
  t113_n14: return -0.27079764008522034f;
  t113_n15: return -0.12903989851474762f;
  t113_n16: if (E.getNumReferences() >= 3323708928 /*9969.5*/) goto t113_n18;
  t113_n17: return 0.016281381249427795f;
  t113_n18: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t113_n22;
  t113_n19: if (E.getNumReferences() >= 3327475712 /*13648.0*/) goto t113_n21;
  t113_n20: return 0.06901571154594421f;
  t113_n21: return -0.482233464717865f;
  t113_n22: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t113_n24;
  t113_n23: return 0.10714308172464371f;
  t113_n24: return -0.26747438311576843f;
  t113_n25: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t113_n47;
  t113_n26: if (E.getNumReferences() >= 3324139520 /*10390.0*/) goto t113_n46;
  t113_n27: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t113_n29;
  t113_n28: return -0.001508801244199276f;
  t113_n29: if (E.getNumReferences() >= 3320516608 /*7522.0*/) goto t113_n33;
  t113_n30: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t113_n32;
  t113_n31: return 0.11240744590759277f;
  t113_n32: return 0.1301344782114029f;
  t113_n33: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t113_n39;
  t113_n34: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t113_n36;
  t113_n35: return -0.33932971954345703f;
  t113_n36: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t113_n38;
  t113_n37: return 0.09756802022457123f;
  t113_n38: return 0.06855101883411407f;
  t113_n39: if (E.getNumReferences() >= 3322603520 /*8890.0*/) goto t113_n41;
  t113_n40: return -0.03824267163872719f;
  t113_n41: if (E.getNumReferences() >= 3322734080 /*9017.5*/) goto t113_n43;
  t113_n42: return 0.11597266048192978f;
  t113_n43: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t113_n45;
  t113_n44: return -0.023975253105163574f;
  t113_n45: return 0.0907072052359581f;
  t113_n46: return -0.07160011678934097f;
  t113_n47: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t113_n81;
  t113_n48: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t113_n52;
  t113_n49: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t113_n51;
  t113_n50: return 0.058742549270391464f;
  t113_n51: return -0.09067855030298233f;
  t113_n52: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t113_n54;
  t113_n53: return 0.000416527152992785f;
  t113_n54: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t113_n68;
  t113_n55: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t113_n57;
  t113_n56: return -0.04691549018025398f;
  t113_n57: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t113_n61;
  t113_n58: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t113_n60;
  t113_n59: return 0.002574129495769739f;
  t113_n60: return 0.09928228706121445f;
  t113_n61: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t113_n67;
  t113_n62: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t113_n64;
  t113_n63: return 0.12263872474431992f;
  t113_n64: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t113_n66;
  t113_n65: return 0.11794767528772354f;
  t113_n66: return 0.1211668998003006f;
  t113_n67: return 0.05154416710138321f;
  t113_n68: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t113_n70;
  t113_n69: return -0.12504494190216064f;
  t113_n70: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t113_n80;
  t113_n71: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t113_n73;
  t113_n72: return -0.09526936709880829f;
  t113_n73: if (E.getNumReferences() >= 3277455360 /*218.0*/) goto t113_n79;
  t113_n74: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t113_n78;
  t113_n75: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t113_n77;
  t113_n76: return 0.10859335958957672f;
  t113_n77: return 0.003606262383982539f;
  t113_n78: return 0.12852397561073303f;
  t113_n79: return -0.2207106351852417f;
  t113_n80: return 0.05059683695435524f;
  t113_n81: return 0.00623049633577466f;
  t113_n82: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t113_n84;
  t113_n83: return -0.02655532956123352f;
  t113_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t113_n86;
  t113_n85: return 0.009329966269433498f;
  t113_n86: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t113_n90;
  t113_n87: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t113_n89;
  t113_n88: return 0.0804581344127655f;
  t113_n89: return 0.05343931168317795f;
  t113_n90: return 0.024355309084057808f;
  t113_n91: if (E.getNumReferences() >= 3331936768 /*19625.0*/) goto t113_n117;
  t113_n92: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t113_n114;
  t113_n93: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t113_n113;
  t113_n94: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t113_n108;
  t113_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t113_n105;
  t113_n96: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t113_n100;
  t113_n97: if (E.getNumReferences() >= 3329347072 /*15475.5*/) goto t113_n99;
  t113_n98: return 0.11205584555864334f;
  t113_n99: return -0.40139591693878174f;
  t113_n100: if (E.getNumReferences() >= 3328519680 /*14667.5*/) goto t113_n102;
  t113_n101: return 0.07295110076665878f;
  t113_n102: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t113_n104;
  t113_n103: return 0.13506537675857544f;
  t113_n104: return 0.10988235473632812f;
  t113_n105: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t113_n107;
  t113_n106: return 0.10595739632844925f;
  t113_n107: return 0.0653110221028328f;
  t113_n108: if (E.getNumReferences() >= 3327952896 /*14114.0*/) goto t113_n110;
  t113_n109: return 0.11752846837043762f;
  t113_n110: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t113_n112;
  t113_n111: return -0.34471866488456726f;
  t113_n112: return 0.10445758700370789f;
  t113_n113: return 0.009184540249407291f;
  t113_n114: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t113_n116;
  t113_n115: return 0.12422611564397812f;
  t113_n116: return -0.013448969461023808f;
  t113_n117: return -0.005782031454145908f;
  t113_n118: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t113_n120;
  t113_n119: return 0.048628486692905426f;
  t113_n120: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t113_n124;
  t113_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t113_n123;
  t113_n122: return 0.09917844831943512f;
  t113_n123: return 0.10494117438793182f;
  t113_n124: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t113_n126;
  t113_n125: return 0.06387092173099518f;
  t113_n126: return 0.09917286038398743f;
  t113_n127: return -0.05729765444993973f;
  t113_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t113_n162;
  t113_n129: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t113_n141;
  t113_n130: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t113_n138;
  t113_n131: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t113_n137;
  t113_n132: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t113_n134;
  t113_n133: return -0.1557353436946869f;
  t113_n134: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t113_n136;
  t113_n135: return -0.6296876668930054f;
  t113_n136: return 0.05655486509203911f;
  t113_n137: return 0.014629537239670753f;
  t113_n138: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t113_n140;
  t113_n139: return -0.044955186545848846f;
  t113_n140: return -0.09794137626886368f;
  t113_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t113_n157;
  t113_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t113_n144;
  t113_n143: return 0.10855557769536972f;
  t113_n144: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t113_n146;
  t113_n145: return 0.08255819976329803f;
  t113_n146: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t113_n148;
  t113_n147: return -0.16658300161361694f;
  t113_n148: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t113_n152;
  t113_n149: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t113_n151;
  t113_n150: return 0.009928634390234947f;
  t113_n151: return 0.08218076080083847f;
  t113_n152: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t113_n154;
  t113_n153: return 0.1141527071595192f;
  t113_n154: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t113_n156;
  t113_n155: return 0.09291860461235046f;
  t113_n156: return -0.20640332996845245f;
  t113_n157: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t113_n161;
  t113_n158: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t113_n160;
  t113_n159: return 0.10036206245422363f;
  t113_n160: return 0.0782063752412796f;
  t113_n161: return -0.23426400125026703f;
  t113_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t113_n204;
  t113_n163: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t113_n179;
  t113_n164: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t113_n178;
  t113_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t113_n169;
  t113_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t113_n168;
  t113_n167: return -0.09612645208835602f;
  t113_n168: return 0.24563412368297577f;
  t113_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t113_n177;
  t113_n170: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t113_n176;
  t113_n171: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t113_n175;
  t113_n172: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t113_n174;
  t113_n173: return 0.10848600417375565f;
  t113_n174: return 0.11031470447778702f;
  t113_n175: return 0.0952845886349678f;
  t113_n176: return -0.006218523718416691f;
  t113_n177: return -0.15308377146720886f;
  t113_n178: return 0.008147881366312504f;
  t113_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t113_n203;
  t113_n180: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t113_n202;
  t113_n181: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t113_n191;
  t113_n182: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t113_n190;
  t113_n183: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t113_n189;
  t113_n184: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t113_n186;
  t113_n185: return -0.11020471155643463f;
  t113_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t113_n188;
  t113_n187: return 0.24473735690116882f;
  t113_n188: return 0.11070398986339569f;
  t113_n189: return -0.1384427398443222f;
  t113_n190: return -0.029445869848132133f;
  t113_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t113_n197;
  t113_n192: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t113_n196;
  t113_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t113_n195;
  t113_n194: return 0.044512104243040085f;
  t113_n195: return 0.09421112388372421f;
  t113_n196: return 0.00914801936596632f;
  t113_n197: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t113_n199;
  t113_n198: return 0.07628295570611954f;
  t113_n199: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t113_n201;
  t113_n200: return 0.12132339924573898f;
  t113_n201: return -0.04599607735872269f;
  t113_n202: return -0.11876823753118515f;
  t113_n203: return 0.1331397294998169f;
  t113_n204: if (E.getNumReferences() >= 3342384384 /*47293.0*/) goto t113_n224;
  t113_n205: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t113_n223;
  t113_n206: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t113_n208;
  t113_n207: return -0.017426103353500366f;
  t113_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t113_n210;
  t113_n209: return -0.0006043873145245016f;
  t113_n210: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t113_n212;
  t113_n211: return -0.07946711778640747f;
  t113_n212: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t113_n214;
  t113_n213: return -0.15265709161758423f;
  t113_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t113_n222;
  t113_n215: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t113_n217;
  t113_n216: return 0.2837183177471161f;
  t113_n217: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t113_n221;
  t113_n218: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t113_n220;
  t113_n219: return 0.12435115873813629f;
  t113_n220: return 0.11202605068683624f;
  t113_n221: return 0.18021486699581146f;
  t113_n222: return 0.06458580493927002f;
  t113_n223: return 0.12451539188623428f;
  t113_n224: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t113_n234;
  t113_n225: if (E.getNumReferences() >= 3346697088 /*64139.5*/) goto t113_n227;
  t113_n226: return -0.0012357158120721579f;
  t113_n227: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t113_n229;
  t113_n228: return -0.04871062934398651f;
  t113_n229: if (E.getNumReferences() >= 3347118592 /*66036.0*/) goto t113_n233;
  t113_n230: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t113_n232;
  t113_n231: return -0.8626901507377625f;
  t113_n232: return 0.11538844555616379f;
  t113_n233: return -0.007814529351890087f;
  t113_n234: if (E.getNumReferences() >= 3348896192 /*79923.5*/) goto t113_n254;
  t113_n235: if (E.getNumReferences() >= 3348846016 /*79531.5*/) goto t113_n253;
  t113_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t113_n238;
  t113_n237: return 0.022406887263059616f;
  t113_n238: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t113_n244;
  t113_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t113_n241;
  t113_n240: return -0.19007530808448792f;
  t113_n241: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t113_n243;
  t113_n242: return 0.08444316685199738f;
  t113_n243: return -0.19789764285087585f;
  t113_n244: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t113_n250;
  t113_n245: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t113_n247;
  t113_n246: return 0.10549017786979675f;
  t113_n247: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t113_n249;
  t113_n248: return 0.09716090559959412f;
  t113_n249: return 0.0031175604090094566f;
  t113_n250: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t113_n252;
  t113_n251: return 0.07852393388748169f;
  t113_n252: return -1.251798391342163f;
  t113_n253: return 0.14666397869586945f;
  t113_n254: return 0.01769060268998146f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree114(const Example& E) {
  t114_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t114_n254;
  t114_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t114_n243;
  t114_n2: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t114_n240;
  t114_n3: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t114_n5;
  t114_n4: return -0.003150621661916375f;
  t114_n5: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t114_n227;
  t114_n6: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t114_n50;
  t114_n7: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t114_n39;
  t114_n8: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t114_n24;
  t114_n9: if (E.getNumReferences() >= 3295674368 /*960.0*/) goto t114_n21;
  t114_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t114_n12;
  t114_n11: return -0.017162611708045006f;
  t114_n12: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t114_n16;
  t114_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t114_n15;
  t114_n14: return 0.03853083401918411f;
  t114_n15: return 0.07846973091363907f;
  t114_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t114_n18;
  t114_n17: return 0.11184865236282349f;
  t114_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t114_n20;
  t114_n19: return -0.19601069390773773f;
  t114_n20: return 0.15201710164546967f;
  t114_n21: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t114_n23;
  t114_n22: return 0.10509020835161209f;
  t114_n23: return 0.0002386351698078215f;
  t114_n24: if (E.getNumReferences() >= 3334339584 /*24318.0*/) goto t114_n36;
  t114_n25: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t114_n31;
  t114_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n30;
  t114_n27: if (E.getNumReferences() >= 3328268288 /*14422.0*/) goto t114_n29;
  t114_n28: return -0.11523876339197159f;
  t114_n29: return 0.08320096135139465f;
  t114_n30: return -0.0612543523311615f;
  t114_n31: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t114_n35;
  t114_n32: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t114_n34;
  t114_n33: return -0.15366512537002563f;
  t114_n34: return 0.09287429600954056f;
  t114_n35: return 0.12245729565620422f;
  t114_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t114_n38;
  t114_n37: return -0.18620739877223969f;
  t114_n38: return 0.10191267728805542f;
  t114_n39: if (E.getNumReferences() >= 3332248320 /*20233.5*/) goto t114_n47;
  t114_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n42;
  t114_n41: return -0.031018264591693878f;
  t114_n42: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t114_n46;
  t114_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function))) goto t114_n45;
  t114_n44: return -0.023875288665294647f;
  t114_n45: return 0.03039623610675335f;
  t114_n46: return -0.015151089057326317f;
  t114_n47: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t114_n49;
  t114_n48: return 0.12631113827228546f;
  t114_n49: return -0.017374740913510323f;
  t114_n50: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t114_n210;
  t114_n51: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t114_n159;
  t114_n52: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t114_n132;
  t114_n53: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t114_n97;
  t114_n54: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t114_n56;
  t114_n55: return 0.003760918276384473f;
  t114_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t114_n94;
  t114_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t114_n89;
  t114_n58: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t114_n88;
  t114_n59: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t114_n71;
  t114_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t114_n62;
  t114_n61: return 0.01788526400923729f;
  t114_n62: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t114_n70;
  t114_n63: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t114_n65;
  t114_n64: return 0.05401628464460373f;
  t114_n65: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t114_n69;
  t114_n66: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t114_n68;
  t114_n67: return 0.08827493339776993f;
  t114_n68: return 0.12328046560287476f;
  t114_n69: return 0.044398821890354156f;
  t114_n70: return -0.14483153820037842f;
  t114_n71: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t114_n73;
  t114_n72: return 0.09516153484582901f;
  t114_n73: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t114_n85;
  t114_n74: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t114_n84;
  t114_n75: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t114_n77;
  t114_n76: return 0.11024614423513412f;
  t114_n77: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t114_n81;
  t114_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t114_n80;
  t114_n79: return 0.20131881535053253f;
  t114_n80: return 0.14974242448806763f;
  t114_n81: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t114_n83;
  t114_n82: return -0.12215574085712433f;
  t114_n83: return 0.11920485645532608f;
  t114_n84: return 0.04098328948020935f;
  t114_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n87;
  t114_n86: return -0.12049750983715057f;
  t114_n87: return 0.18518200516700745f;
  t114_n88: return -0.004625359084457159f;
  t114_n89: if (E.getNumReferences() >= 3251634176 /*26.0*/) goto t114_n93;
  t114_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t114_n92;
  t114_n91: return 0.0632224753499031f;
  t114_n92: return 0.12544265389442444f;
  t114_n93: return 0.1349276602268219f;
  t114_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t114_n96;
  t114_n95: return -0.03740733861923218f;
  t114_n96: return 0.07623527944087982f;
  t114_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n105;
  t114_n98: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t114_n100;
  t114_n99: return -0.1681453287601471f;
  t114_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t114_n104;
  t114_n101: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t114_n103;
  t114_n102: return -0.0372917503118515f;
  t114_n103: return -0.20203034579753876f;
  t114_n104: return 0.047615960240364075f;
  t114_n105: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t114_n111;
  t114_n106: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t114_n108;
  t114_n107: return -0.015973152592778206f;
  t114_n108: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t114_n110;
  t114_n109: return -0.1013803705573082f;
  t114_n110: return -0.018689323216676712f;
  t114_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t114_n113;
  t114_n112: return -0.14697137475013733f;
  t114_n113: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t114_n115;
  t114_n114: return 0.008571074344217777f;
  t114_n115: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t114_n117;
  t114_n116: return 0.03429441526532173f;
  t114_n117: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t114_n131;
  t114_n118: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t114_n130;
  t114_n119: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t114_n129;
  t114_n120: if (E.getNumReferences() >= 3238002688 /*8.0*/) goto t114_n128;
  t114_n121: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t114_n127;
  t114_n122: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t114_n126;
  t114_n123: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t114_n125;
  t114_n124: return -0.13640296459197998f;
  t114_n125: return 0.12711597979068756f;
  t114_n126: return -0.007454232778400183f;
  t114_n127: return -0.12286550551652908f;
  t114_n128: return 0.12470043450593948f;
  t114_n129: return -0.2114323228597641f;
  t114_n130: return 0.10057158768177032f;
  t114_n131: return 0.02732250839471817f;
  t114_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t114_n156;
  t114_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t114_n135;
  t114_n134: return -0.11398661136627197f;
  t114_n135: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t114_n147;
  t114_n136: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t114_n144;
  t114_n137: if (E.getNumReferences() >= 3275816960 /*193.0*/) goto t114_n139;
  t114_n138: return 0.16377362608909607f;
  t114_n139: if (E.getNumReferences() >= 3281485824 /*303.0*/) goto t114_n141;
  t114_n140: return -0.09577084332704544f;
  t114_n141: if (E.getNumReferences() >= 3289022464 /*554.0*/) goto t114_n143;
  t114_n142: return 0.1317494660615921f;
  t114_n143: return 0.023664403706789017f;
  t114_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t114_n146;
  t114_n145: return -0.02085653692483902f;
  t114_n146: return 0.07650510966777802f;
  t114_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t114_n155;
  t114_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t114_n154;
  t114_n149: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t114_n151;
  t114_n150: return -0.26414334774017334f;
  t114_n151: if (E.getNumReferences() >= 3280207872 /*264.0*/) goto t114_n153;
  t114_n152: return -0.21028836071491241f;
  t114_n153: return 0.1153070405125618f;
  t114_n154: return 0.10848581790924072f;
  t114_n155: return 0.11938705295324326f;
  t114_n156: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t114_n158;
  t114_n157: return 0.03214200586080551f;
  t114_n158: return 0.11588671058416367f;
  t114_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n167;
  t114_n160: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t114_n164;
  t114_n161: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t114_n163;
  t114_n162: return -0.22044311463832855f;
  t114_n163: return -0.06514474004507065f;
  t114_n164: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t114_n166;
  t114_n165: return 0.0385587215423584f;
  t114_n166: return -0.03707956150174141f;
  t114_n167: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t114_n205;
  t114_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t114_n176;
  t114_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n175;
  t114_n170: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t114_n174;
  t114_n171: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t114_n173;
  t114_n172: return -0.14222098886966705f;
  t114_n173: return 0.035740867257118225f;
  t114_n174: return -0.2493657022714615f;
  t114_n175: return -0.039664167910814285f;
  t114_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t114_n200;
  t114_n177: if (E.getNumReferences() >= 3290136576 /*622.0*/) goto t114_n197;
  t114_n178: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t114_n184;
  t114_n179: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t114_n181;
  t114_n180: return -0.019519802182912827f;
  t114_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t114_n183;
  t114_n182: return -0.46303850412368774f;
  t114_n183: return -0.03427404910326004f;
  t114_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other))) goto t114_n186;
  t114_n185: return -0.01851538009941578f;
  t114_n186: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t114_n196;
  t114_n187: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t114_n193;
  t114_n188: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t114_n192;
  t114_n189: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t114_n191;
  t114_n190: return 0.08622743934392929f;
  t114_n191: return -0.04486977681517601f;
  t114_n192: return -0.04147372767329216f;
  t114_n193: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t114_n195;
  t114_n194: return 0.01115089375525713f;
  t114_n195: return 0.14565102756023407f;
  t114_n196: return 0.10625141113996506f;
  t114_n197: if (E.getNumReferences() >= 3291693056 /*717.0*/) goto t114_n199;
  t114_n198: return 0.15308640897274017f;
  t114_n199: return -0.013808679766952991f;
  t114_n200: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t114_n202;
  t114_n201: return 0.006992613431066275f;
  t114_n202: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t114_n204;
  t114_n203: return 0.07568813860416412f;
  t114_n204: return -0.014681723900139332f;
  t114_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n207;
  t114_n206: return -0.1355845332145691f;
  t114_n207: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t114_n209;
  t114_n208: return -0.03529350087046623f;
  t114_n209: return 0.012154833413660526f;
  t114_n210: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t114_n212;
  t114_n211: return 0.014329912140965462f;
  t114_n212: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t114_n216;
  t114_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t114_n215;
  t114_n214: return -0.03336598351597786f;
  t114_n215: return 0.0076484279707074165f;
  t114_n216: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t114_n220;
  t114_n217: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t114_n219;
  t114_n218: return 0.0034265476278960705f;
  t114_n219: return 0.006132943090051413f;
  t114_n220: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t114_n224;
  t114_n221: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t114_n223;
  t114_n222: return 0.10771755874156952f;
  t114_n223: return 0.09699947386980057f;
  t114_n224: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t114_n226;
  t114_n225: return -0.2380194365978241f;
  t114_n226: return 0.07308954000473022f;
  t114_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t114_n239;
  t114_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t114_n234;
  t114_n229: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t114_n233;
  t114_n230: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t114_n232;
  t114_n231: return -0.04567265510559082f;
  t114_n232: return -0.11566118896007538f;
  t114_n233: return -0.023499606177210808f;
  t114_n234: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t114_n236;
  t114_n235: return -0.010456474497914314f;
  t114_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t114_n238;
  t114_n237: return 0.03379111364483833f;
  t114_n238: return 0.10181237757205963f;
  t114_n239: return 0.08772274106740952f;
  t114_n240: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t114_n242;
  t114_n241: return -0.00528799369931221f;
  t114_n242: return 0.014611350372433662f;
  t114_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t114_n245;
  t114_n244: return -0.0063942852430045605f;
  t114_n245: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t114_n249;
  t114_n246: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t114_n248;
  t114_n247: return 0.0077834222465753555f;
  t114_n248: return 0.02095988392829895f;
  t114_n249: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t114_n251;
  t114_n250: return 0.0015454816166311502f;
  t114_n251: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t114_n253;
  t114_n252: return 0.015036865137517452f;
  t114_n253: return -0.12344242632389069f;
  t114_n254: return -0.05403263121843338f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree115(const Example& E) {
  t115_n0: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t115_n128;
  t115_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t115_n67;
  t115_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t115_n4;
  t115_n3: return -0.006456674076616764f;
  t115_n4: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t115_n6;
  t115_n5: return -0.07311305403709412f;
  t115_n6: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t115_n66;
  t115_n7: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t115_n65;
  t115_n8: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t115_n42;
  t115_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t115_n41;
  t115_n10: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t115_n40;
  t115_n11: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t115_n39;
  t115_n12: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t115_n30;
  t115_n13: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t115_n15;
  t115_n14: return 0.00035164266591891646f;
  t115_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t115_n17;
  t115_n16: return 0.01534357201308012f;
  t115_n17: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t115_n19;
  t115_n18: return 0.0070784566923975945f;
  t115_n19: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t115_n21;
  t115_n20: return 0.030532974749803543f;
  t115_n21: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t115_n29;
  t115_n22: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t115_n28;
  t115_n23: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t115_n25;
  t115_n24: return 0.047558125108480453f;
  t115_n25: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t115_n27;
  t115_n26: return 0.07455472648143768f;
  t115_n27: return -0.03035913035273552f;
  t115_n28: return -0.01678524911403656f;
  t115_n29: return 0.0188948642462492f;
  t115_n30: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t115_n32;
  t115_n31: return -0.0013855349970981479f;
  t115_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t115_n34;
  t115_n33: return -0.01999022625386715f;
  t115_n34: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t115_n38;
  t115_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t115_n37;
  t115_n36: return 0.061730463057756424f;
  t115_n37: return 0.037862733006477356f;
  t115_n38: return -0.007171624340116978f;
  t115_n39: return 0.02437194623053074f;
  t115_n40: return -0.03504323214292526f;
  t115_n41: return 0.007943084463477135f;
  t115_n42: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t115_n50;
  t115_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t115_n45;
  t115_n44: return -0.02915671095252037f;
  t115_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t115_n49;
  t115_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t115_n48;
  t115_n47: return 0.006036481354385614f;
  t115_n48: return 0.04336726665496826f;
  t115_n49: return 0.08187226206064224f;
  t115_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t115_n52;
  t115_n51: return 0.00020567956380546093f;
  t115_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t115_n64;
  t115_n53: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t115_n55;
  t115_n54: return -0.20699025690555573f;
  t115_n55: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t115_n57;
  t115_n56: return 0.059680432081222534f;
  t115_n57: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t115_n63;
  t115_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t115_n62;
  t115_n59: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t115_n61;
  t115_n60: return 0.10109574347734451f;
  t115_n61: return 0.07421503961086273f;
  t115_n62: return -0.18166087567806244f;
  t115_n63: return -0.2719360888004303f;
  t115_n64: return 0.006292193196713924f;
  t115_n65: return -0.10496051609516144f;
  t115_n66: return -0.07067995518445969f;
  t115_n67: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t115_n71;
  t115_n68: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t115_n70;
  t115_n69: return -0.05811729282140732f;
  t115_n70: return -0.13179101049900055f;
  t115_n71: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t115_n117;
  t115_n72: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t115_n74;
  t115_n73: return 0.002048746682703495f;
  t115_n74: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t115_n78;
  t115_n75: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t115_n77;
  t115_n76: return 0.021725911647081375f;
  t115_n77: return 0.013924548402428627f;
  t115_n78: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t115_n112;
  t115_n79: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t115_n81;
  t115_n80: return 0.030475087463855743f;
  t115_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t115_n83;
  t115_n82: return -0.024879157543182373f;
  t115_n83: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t115_n85;
  t115_n84: return 0.08393609523773193f;
  t115_n85: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t115_n103;
  t115_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t115_n88;
  t115_n87: return 0.07716289162635803f;
  t115_n88: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t115_n98;
  t115_n89: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t115_n91;
  t115_n90: return 0.06821141391992569f;
  t115_n91: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t115_n95;
  t115_n92: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t115_n94;
  t115_n93: return 0.10393726825714111f;
  t115_n94: return -0.10805223137140274f;
  t115_n95: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t115_n97;
  t115_n96: return 0.09368650615215302f;
  t115_n97: return 0.13888642191886902f;
  t115_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t115_n100;
  t115_n99: return 0.03768331930041313f;
  t115_n100: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t115_n102;
  t115_n101: return 0.10805825144052505f;
  t115_n102: return 0.07787485420703888f;
  t115_n103: if (E.getNumReferences() >= 3255828480 /*36.0*/) goto t115_n111;
  t115_n104: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t115_n110;
  t115_n105: if (E.getNumReferences() >= 3249012736 /*21.0*/) goto t115_n109;
  t115_n106: if (E.getFilterLength() >= 3246391296 /*16.0*/) goto t115_n108;
  t115_n107: return 0.08691719174385071f;
  t115_n108: return 0.13870282471179962f;
  t115_n109: return 0.12872569262981415f;
  t115_n110: return 0.043844521045684814f;
  t115_n111: return 0.11952745914459229f;
  t115_n112: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t115_n116;
  t115_n113: if (E.getFileProximityDistance() >= 3238002688 /*8.0*/) goto t115_n115;
  t115_n114: return -0.14129507541656494f;
  t115_n115: return 0.10988131910562515f;
  t115_n116: return 0.06512820720672607f;
  t115_n117: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t115_n119;
  t115_n118: return 0.006834635976701975f;
  t115_n119: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t115_n121;
  t115_n120: return -0.07833348214626312f;
  t115_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t115_n123;
  t115_n122: return 0.033059488981962204f;
  t115_n123: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t115_n127;
  t115_n124: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t115_n126;
  t115_n125: return 0.07007820159196854f;
  t115_n126: return 0.10905271023511887f;
  t115_n127: return 0.0719507709145546f;
  t115_n128: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t115_n192;
  t115_n129: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t115_n191;
  t115_n130: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t115_n132;
  t115_n131: return 0.004455015063285828f;
  t115_n132: if (E.getNumReferences() >= 3314682880 /*4673.5*/) goto t115_n184;
  t115_n133: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t115_n183;
  t115_n134: if (E.getNumReferences() >= 3285057536 /*412.0*/) goto t115_n156;
  t115_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t115_n137;
  t115_n136: return 0.0025757020339369774f;
  t115_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t115_n151;
  t115_n138: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t115_n140;
  t115_n139: return 0.021717682480812073f;
  t115_n140: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t115_n144;
  t115_n141: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t115_n143;
  t115_n142: return 0.11317528784275055f;
  t115_n143: return -0.016980228945612907f;
  t115_n144: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t115_n146;
  t115_n145: return 0.10018628090620041f;
  t115_n146: if (E.getNumReferences() >= 3277193216 /*214.0*/) goto t115_n148;
  t115_n147: return -0.0069372509606182575f;
  t115_n148: if (E.getNumReferences() >= 3277520896 /*219.0*/) goto t115_n150;
  t115_n149: return 0.14864863455295563f;
  t115_n150: return 0.06920699030160904f;
  t115_n151: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t115_n153;
  t115_n152: return -0.030843539163470268f;
  t115_n153: if (E.getNumReferences() >= 3268542464 /*105.0*/) goto t115_n155;
  t115_n154: return 0.12858526408672333f;
  t115_n155: return 0.09504850953817368f;
  t115_n156: if (E.getNumReferences() >= 3288522752 /*523.5*/) goto t115_n172;
  t115_n157: if (E.getNumReferences() >= 3288489984 /*521.5*/) goto t115_n171;
  t115_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t115_n170;
  t115_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t115_n167;
  t115_n160: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t115_n166;
  t115_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t115_n165;
  t115_n162: if (E.getNumReferences() >= 3287220224 /*478.0*/) goto t115_n164;
  t115_n163: return 0.06090166047215462f;
  t115_n164: return 0.11550191044807434f;
  t115_n165: return 0.014572307467460632f;
  t115_n166: return 0.05603950098156929f;
  t115_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t115_n169;
  t115_n168: return 0.11461571604013443f;
  t115_n169: return -0.11478004604578018f;
  t115_n170: return 0.10128585994243622f;
  t115_n171: return 0.13415813446044922f;
  t115_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t115_n174;
  t115_n173: return 0.01927989348769188f;
  t115_n174: if (E.getNumReferences() >= 3297521664 /*1121.5*/) goto t115_n182;
  t115_n175: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t115_n177;
  t115_n176: return -0.25848814845085144f;
  t115_n177: if (E.getNumReferences() >= 3292217344 /*749.0*/) goto t115_n179;
  t115_n178: return 0.04927382245659828f;
  t115_n179: if (E.getNumReferences() >= 3293175808 /*807.5*/) goto t115_n181;
  t115_n180: return 0.11611510068178177f;
  t115_n181: return 0.13657540082931519f;
  t115_n182: return 0.020958280190825462f;
  t115_n183: return 0.012774044647812843f;
  t115_n184: if (E.getNumReferences() >= 3315159040 /*4906.0*/) goto t115_n190;
  t115_n185: if (E.getNumReferences() >= 3315124224 /*4889.0*/) goto t115_n187;
  t115_n186: return 0.07971300184726715f;
  t115_n187: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t115_n189;
  t115_n188: return 0.11044172197580338f;
  t115_n189: return 0.12576310336589813f;
  t115_n190: return 0.029450125992298126f;
  t115_n191: return -0.0006151639390736818f;
  t115_n192: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t115_n194;
  t115_n193: return 0.027731457725167274f;
  t115_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t115_n196;
  t115_n195: return 0.024797143414616585f;
  t115_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t115_n232;
  t115_n197: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t115_n231;
  t115_n198: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t115_n200;
  t115_n199: return 0.01220737025141716f;
  t115_n200: if (E.getNumReferences() >= 3271589888 /*128.5*/) goto t115_n220;
  t115_n201: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t115_n219;
  t115_n202: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t115_n208;
  t115_n203: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t115_n207;
  t115_n204: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t115_n206;
  t115_n205: return 0.09749031811952591f;
  t115_n206: return 0.10870536416769028f;
  t115_n207: return 0.11189619451761246f;
  t115_n208: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t115_n210;
  t115_n209: return 0.09114079177379608f;
  t115_n210: if (E.getNumReferences() >= 3267952640 /*100.5*/) goto t115_n212;
  t115_n211: return 0.118137426674366f;
  t115_n212: if (E.getNumReferences() >= 3271294976 /*126.0*/) goto t115_n218;
  t115_n213: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t115_n215;
  t115_n214: return 0.045995794236660004f;
  t115_n215: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t115_n217;
  t115_n216: return 0.1180589348077774f;
  t115_n217: return 0.08795364201068878f;
  t115_n218: return 0.11126367002725601f;
  t115_n219: return 0.09317993372678757f;
  t115_n220: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t115_n226;
  t115_n221: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t115_n223;
  t115_n222: return 0.08323357254266739f;
  t115_n223: if (E.getNumReferences() >= 3283353600 /*360.0*/) goto t115_n225;
  t115_n224: return -0.06789899617433548f;
  t115_n225: return 0.12319473177194595f;
  t115_n226: if (E.getNumReferences() >= 3309076480 /*3016.0*/) goto t115_n228;
  t115_n227: return -0.06452896445989609f;
  t115_n228: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t115_n230;
  t115_n229: return 0.06855525076389313f;
  t115_n230: return 0.10843657702207565f;
  t115_n231: return 0.09731343388557434f;
  t115_n232: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t115_n242;
  t115_n233: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t115_n239;
  t115_n234: if (E.getNumReferences() >= 3318737920 /*6653.5*/) goto t115_n236;
  t115_n235: return -0.009049820713698864f;
  t115_n236: if (E.getNumReferences() >= 3319312384 /*6934.0*/) goto t115_n238;
  t115_n237: return 0.1264542192220688f;
  t115_n238: return 0.047953490167856216f;
  t115_n239: if (E.getNumReferences() >= 3267100672 /*94.0*/) goto t115_n241;
  t115_n240: return 0.11310163140296936f;
  t115_n241: return -0.041396696120500565f;
  t115_n242: if (E.getSymbolScopeDistance() >= 3245342720 /*15.0*/) goto t115_n254;
  t115_n243: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t115_n253;
  t115_n244: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t115_n252;
  t115_n245: if (E.getNumReferences() >= 3265265664 /*80.0*/) goto t115_n251;
  t115_n246: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t115_n250;
  t115_n247: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t115_n249;
  t115_n248: return -0.13457639515399933f;
  t115_n249: return 0.13173462450504303f;
  t115_n250: return -0.23131859302520752f;
  t115_n251: return 0.12128722667694092f;
  t115_n252: return 0.04333626106381416f;
  t115_n253: return 0.11538258194923401f;
  t115_n254: return 0.05902184545993805f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree116(const Example& E) {
  t116_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t116_n178;
  t116_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t116_n3;
  t116_n2: return -0.0009391837520524859f;
  t116_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t116_n5;
  t116_n4: return 0.004171603824943304f;
  t116_n5: if (E.getNumReferences() >= 3342384384 /*47293.0*/) goto t116_n27;
  t116_n6: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t116_n8;
  t116_n7: return 0.021995363757014275f;
  t116_n8: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t116_n16;
  t116_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n15;
  t116_n10: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t116_n14;
  t116_n11: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n13;
  t116_n12: return 0.30967360734939575f;
  t116_n13: return 0.19098018109798431f;
  t116_n14: return 0.09920673072338104f;
  t116_n15: return -0.5464823246002197f;
  t116_n16: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n26;
  t116_n17: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t116_n23;
  t116_n18: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t116_n20;
  t116_n19: return 0.19555127620697021f;
  t116_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n22;
  t116_n21: return 0.13427451252937317f;
  t116_n22: return 0.0640413910150528f;
  t116_n23: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t116_n25;
  t116_n24: return 0.15103015303611755f;
  t116_n25: return 0.1875970959663391f;
  t116_n26: return 0.11586011946201324f;
  t116_n27: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t116_n51;
  t116_n28: if (E.getNumReferences() >= 3358365376 /*176731.0*/) goto t116_n50;
  t116_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n31;
  t116_n30: return 0.005708937533199787f;
  t116_n31: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t116_n45;
  t116_n32: if (E.getNumReferences() >= 3346253184 /*62405.5*/) goto t116_n40;
  t116_n33: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t116_n35;
  t116_n34: return 0.025847727432847023f;
  t116_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t116_n37;
  t116_n36: return 0.05325540900230408f;
  t116_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n39;
  t116_n38: return 0.10347405076026917f;
  t116_n39: return 0.13496030867099762f;
  t116_n40: if (E.getNumReferences() >= 3347118592 /*66036.0*/) goto t116_n42;
  t116_n41: return -0.2528097927570343f;
  t116_n42: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n44;
  t116_n43: return -0.041449300944805145f;
  t116_n44: return 0.03703747317194939f;
  t116_n45: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t116_n47;
  t116_n46: return 0.06104596331715584f;
  t116_n47: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t116_n49;
  t116_n48: return 0.0974324569106102f;
  t116_n49: return 0.13552266359329224f;
  t116_n50: return -0.14977924525737762f;
  t116_n51: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t116_n69;
  t116_n52: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t116_n60;
  t116_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t116_n55;
  t116_n54: return 0.022186893969774246f;
  t116_n55: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t116_n59;
  t116_n56: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n58;
  t116_n57: return 0.0967201516032219f;
  t116_n58: return 0.05556899681687355f;
  t116_n59: return -0.2648533284664154f;
  t116_n60: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t116_n62;
  t116_n61: return -0.01705847680568695f;
  t116_n62: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t116_n66;
  t116_n63: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t116_n65;
  t116_n64: return 0.06402237713336945f;
  t116_n65: return 0.04296813905239105f;
  t116_n66: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n68;
  t116_n67: return 0.0932050570845604f;
  t116_n68: return 0.032075949013233185f;
  t116_n69: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t116_n177;
  t116_n70: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t116_n132;
  t116_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t116_n73;
  t116_n72: return -0.07501518726348877f;
  t116_n73: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n121;
  t116_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t116_n100;
  t116_n75: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t116_n77;
  t116_n76: return -0.01087980903685093f;
  t116_n77: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t116_n83;
  t116_n78: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n80;
  t116_n79: return 0.0546102300286293f;
  t116_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t116_n82;
  t116_n81: return -0.2953689992427826f;
  t116_n82: return 0.014308429323136806f;
  t116_n83: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t116_n91;
  t116_n84: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t116_n90;
  t116_n85: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t116_n89;
  t116_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n88;
  t116_n87: return -1.3626515865325928f;
  t116_n88: return -0.08388447016477585f;
  t116_n89: return -0.1631462424993515f;
  t116_n90: return 0.027509959414601326f;
  t116_n91: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n99;
  t116_n92: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t116_n98;
  t116_n93: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t116_n95;
  t116_n94: return -0.23234741389751434f;
  t116_n95: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t116_n97;
  t116_n96: return 0.10499978065490723f;
  t116_n97: return 0.08016661554574966f;
  t116_n98: return 0.12221740186214447f;
  t116_n99: return -0.025420568883419037f;
  t116_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n106;
  t116_n101: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t116_n103;
  t116_n102: return 0.15128906071186066f;
  t116_n103: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t116_n105;
  t116_n104: return 0.11962801963090897f;
  t116_n105: return -0.017092343419790268f;
  t116_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t116_n120;
  t116_n107: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t116_n111;
  t116_n108: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t116_n110;
  t116_n109: return 0.07589557021856308f;
  t116_n110: return -0.6387305855751038f;
  t116_n111: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t116_n119;
  t116_n112: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t116_n118;
  t116_n113: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n117;
  t116_n114: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t116_n116;
  t116_n115: return -0.11680411547422409f;
  t116_n116: return 0.12291338294744492f;
  t116_n117: return 0.07854059338569641f;
  t116_n118: return 0.0750964805483818f;
  t116_n119: return 0.1334635466337204f;
  t116_n120: return 0.01271007303148508f;
  t116_n121: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t116_n125;
  t116_n122: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n124;
  t116_n123: return -0.6476038694381714f;
  t116_n124: return -0.07126330584287643f;
  t116_n125: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t116_n131;
  t116_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n130;
  t116_n127: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t116_n129;
  t116_n128: return 0.029594380408525467f;
  t116_n129: return 0.1043812483549118f;
  t116_n130: return 0.07019782811403275f;
  t116_n131: return -0.1664157211780548f;
  t116_n132: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t116_n134;
  t116_n133: return -0.12225186079740524f;
  t116_n134: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t116_n174;
  t116_n135: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t116_n143;
  t116_n136: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n140;
  t116_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n139;
  t116_n138: return -0.07830388844013214f;
  t116_n139: return 0.038949307054281235f;
  t116_n140: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t116_n142;
  t116_n141: return 0.008233723230659962f;
  t116_n142: return 0.08869510143995285f;
  t116_n143: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t116_n173;
  t116_n144: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t116_n166;
  t116_n145: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n155;
  t116_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n154;
  t116_n147: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t116_n153;
  t116_n148: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t116_n150;
  t116_n149: return 0.10684318095445633f;
  t116_n150: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t116_n152;
  t116_n151: return 0.06349701434373856f;
  t116_n152: return 0.03706282749772072f;
  t116_n153: return -0.11418171972036362f;
  t116_n154: return 0.032101623713970184f;
  t116_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t116_n161;
  t116_n156: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t116_n160;
  t116_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n159;
  t116_n158: return 0.09912935644388199f;
  t116_n159: return 0.06933202594518661f;
  t116_n160: return -0.749660849571228f;
  t116_n161: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t116_n163;
  t116_n162: return 0.02147522196173668f;
  t116_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n165;
  t116_n164: return 0.1099315732717514f;
  t116_n165: return 0.1028478592634201f;
  t116_n166: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t116_n172;
  t116_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n169;
  t116_n168: return 0.09760476648807526f;
  t116_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t116_n171;
  t116_n170: return 0.08528729528188705f;
  t116_n171: return 0.2818364202976227f;
  t116_n172: return 0.030236467719078064f;
  t116_n173: return -0.024779390543699265f;
  t116_n174: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t116_n176;
  t116_n175: return 0.027164394035935402f;
  t116_n176: return -0.01689852774143219f;
  t116_n177: return -0.059355732053518295f;
  t116_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t116_n180;
  t116_n179: return -0.005826101638376713f;
  t116_n180: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t116_n254;
  t116_n181: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t116_n183;
  t116_n182: return 0.006944065447896719f;
  t116_n183: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t116_n189;
  t116_n184: if (E.getNumReferences() >= 3283320832 /*359.0*/) goto t116_n186;
  t116_n185: return -0.1264275461435318f;
  t116_n186: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t116_n188;
  t116_n187: return -1.9493842124938965f;
  t116_n188: return 0.08172906190156937f;
  t116_n189: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t116_n215;
  t116_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t116_n192;
  t116_n191: return 0.03631755709648132f;
  t116_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t116_n194;
  t116_n193: return -0.00605006655678153f;
  t116_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t116_n210;
  t116_n195: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t116_n201;
  t116_n196: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t116_n198;
  t116_n197: return 0.04270866513252258f;
  t116_n198: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t116_n200;
  t116_n199: return 0.10954464226961136f;
  t116_n200: return 0.059360578656196594f;
  t116_n201: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t116_n207;
  t116_n202: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t116_n204;
  t116_n203: return -0.1765878051519394f;
  t116_n204: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n206;
  t116_n205: return 0.10782850533723831f;
  t116_n206: return 0.11239052563905716f;
  t116_n207: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n209;
  t116_n208: return 0.0962611734867096f;
  t116_n209: return -0.06763017177581787f;
  t116_n210: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t116_n214;
  t116_n211: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t116_n213;
  t116_n212: return -0.23107755184173584f;
  t116_n213: return 0.09154658764600754f;
  t116_n214: return -0.05417567864060402f;
  t116_n215: if (E.getNumReferences() >= 3323686912 /*9948.0*/) goto t116_n235;
  t116_n216: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t116_n218;
  t116_n217: return 0.010602716356515884f;
  t116_n218: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t116_n230;
  t116_n219: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t116_n229;
  t116_n220: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t116_n222;
  t116_n221: return 0.05538333207368851f;
  t116_n222: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t116_n224;
  t116_n223: return 0.0885487049818039f;
  t116_n224: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t116_n228;
  t116_n225: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t116_n227;
  t116_n226: return -0.010000121779739857f;
  t116_n227: return 0.1304931491613388f;
  t116_n228: return 0.13460467755794525f;
  t116_n229: return 0.02741134725511074f;
  t116_n230: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n234;
  t116_n231: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t116_n233;
  t116_n232: return 0.13379478454589844f;
  t116_n233: return -0.009069147519767284f;
  t116_n234: return 0.044629599899053574f;
  t116_n235: if (E.getNumReferences() >= 3331945984 /*19643.0*/) goto t116_n247;
  t116_n236: if (E.getNumReferences() >= 3331505664 /*18783.0*/) goto t116_n242;
  t116_n237: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t116_n239;
  t116_n238: return 0.05351872742176056f;
  t116_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n241;
  t116_n240: return 0.10168880224227905f;
  t116_n241: return 0.06761809438467026f;
  t116_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n244;
  t116_n243: return 0.10833635181188583f;
  t116_n244: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t116_n246;
  t116_n245: return 0.06300561130046844f;
  t116_n246: return 0.10511960834264755f;
  t116_n247: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t116_n249;
  t116_n248: return -0.01232527568936348f;
  t116_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t116_n251;
  t116_n250: return -0.452093243598938f;
  t116_n251: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t116_n253;
  t116_n252: return 0.08088917285203934f;
  t116_n253: return 0.024667711928486824f;
  t116_n254: return 0.004104897379875183f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree117(const Example& E) {
  t117_n0: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t117_n146;
  t117_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t117_n29;
  t117_n2: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t117_n4;
  t117_n3: return -0.004875313024967909f;
  t117_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t117_n14;
  t117_n5: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t117_n13;
  t117_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t117_n8;
  t117_n7: return 0.00629357760772109f;
  t117_n8: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t117_n12;
  t117_n9: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t117_n11;
  t117_n10: return -0.14502909779548645f;
  t117_n11: return 0.0352114662528038f;
  t117_n12: return -0.0013329193461686373f;
  t117_n13: return -0.023563191294670105f;
  t117_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t117_n16;
  t117_n15: return 0.018107272684574127f;
  t117_n16: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t117_n22;
  t117_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t117_n19;
  t117_n18: return 0.0042839874513447285f;
  t117_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t117_n21;
  t117_n20: return 0.02655239962041378f;
  t117_n21: return 0.07478447258472443f;
  t117_n22: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t117_n24;
  t117_n23: return 0.04927981272339821f;
  t117_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t117_n28;
  t117_n25: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t117_n27;
  t117_n26: return 0.053067468106746674f;
  t117_n27: return -0.07643654197454453f;
  t117_n28: return 0.06167517602443695f;
  t117_n29: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t117_n145;
  t117_n30: if (E.getNumReferences() >= 3352895680 /*111169.5*/) goto t117_n142;
  t117_n31: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t117_n139;
  t117_n32: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t117_n80;
  t117_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t117_n79;
  t117_n34: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t117_n72;
  t117_n35: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t117_n67;
  t117_n36: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t117_n60;
  t117_n37: if (E.getNumReferences() >= 3294724096 /*902.0*/) goto t117_n59;
  t117_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t117_n58;
  t117_n39: if (E.getNumReferences() >= 3268280320 /*103.0*/) goto t117_n57;
  t117_n40: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t117_n56;
  t117_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t117_n47;
  t117_n42: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t117_n44;
  t117_n43: return -0.013708589598536491f;
  t117_n44: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t117_n46;
  t117_n45: return -0.14925259351730347f;
  t117_n46: return 0.20089603960514069f;
  t117_n47: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t117_n55;
  t117_n48: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t117_n50;
  t117_n49: return 0.006674222648143768f;
  t117_n50: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t117_n54;
  t117_n51: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t117_n53;
  t117_n52: return 0.1350673884153366f;
  t117_n53: return 0.09321553260087967f;
  t117_n54: return 0.006629837676882744f;
  t117_n55: return -0.20074060559272766f;
  t117_n56: return 0.11149752140045166f;
  t117_n57: return -0.24772772192955017f;
  t117_n58: return 0.07559092342853546f;
  t117_n59: return 0.0962860956788063f;
  t117_n60: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t117_n62;
  t117_n61: return -0.05647876113653183f;
  t117_n62: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t117_n66;
  t117_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t117_n65;
  t117_n64: return -0.0013512055156752467f;
  t117_n65: return 0.08431249111890793f;
  t117_n66: return 0.0974838063120842f;
  t117_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t117_n71;
  t117_n68: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t117_n70;
  t117_n69: return -0.0745190978050232f;
  t117_n70: return 0.08423719555139542f;
  t117_n71: return -0.005177449434995651f;
  t117_n72: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t117_n78;
  t117_n73: if (E.getNumReferences() >= 3337464320 /*30421.0*/) goto t117_n75;
  t117_n74: return 0.12306182831525803f;
  t117_n75: if (E.getNumReferences() >= 3343861504 /*53063.0*/) goto t117_n77;
  t117_n76: return -0.08574552834033966f;
  t117_n77: return 0.10130751132965088f;
  t117_n78: return 0.050735291093587875f;
  t117_n79: return 0.005108850542455912f;
  t117_n80: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t117_n82;
  t117_n81: return 0.007298256736248732f;
  t117_n82: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t117_n136;
  t117_n83: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t117_n125;
  t117_n84: if (E.getNumReferences() >= 3290226688 /*627.5*/) goto t117_n122;
  t117_n85: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t117_n95;
  t117_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t117_n88;
  t117_n87: return -0.05127602815628052f;
  t117_n88: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t117_n90;
  t117_n89: return -0.013796835206449032f;
  t117_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t117_n94;
  t117_n91: if (E.getNumReferences() >= 3270574080 /*120.5*/) goto t117_n93;
  t117_n92: return -0.07319074869155884f;
  t117_n93: return -0.17400586605072021f;
  t117_n94: return -0.016905928030610085f;
  t117_n95: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t117_n97;
  t117_n96: return -0.01413580309599638f;
  t117_n97: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t117_n99;
  t117_n98: return 0.012268472462892532f;
  t117_n99: if (E.getSymbolScopeDistance() >= 3245342720 /*15.0*/) goto t117_n121;
  t117_n100: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t117_n120;
  t117_n101: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t117_n119;
  t117_n102: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t117_n104;
  t117_n103: return 0.06491345912218094f;
  t117_n104: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t117_n114;
  t117_n105: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t117_n113;
  t117_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t117_n108;
  t117_n107: return 0.30617135763168335f;
  t117_n108: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t117_n112;
  t117_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t117_n111;
  t117_n110: return 0.09939441084861755f;
  t117_n111: return 0.10560627281665802f;
  t117_n112: return 0.07141008228063583f;
  t117_n113: return -0.03378999978303909f;
  t117_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t117_n116;
  t117_n115: return -0.16470052301883698f;
  t117_n116: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t117_n118;
  t117_n117: return 0.14450904726982117f;
  t117_n118: return 0.025639265775680542f;
  t117_n119: return -0.012141813524067402f;
  t117_n120: return -0.08485142886638641f;
  t117_n121: return -0.0062081776559352875f;
  t117_n122: if (E.getNumReferences() >= 3291791360 /*723.0*/) goto t117_n124;
  t117_n123: return 0.1423717439174652f;
  t117_n124: return 0.03384258598089218f;
  t117_n125: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t117_n133;
  t117_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t117_n132;
  t117_n127: if (E.getNumReferences() >= 3346232448 /*62324.5*/) goto t117_n131;
  t117_n128: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t117_n130;
  t117_n129: return -0.08926289528608322f;
  t117_n130: return -0.015647156164050102f;
  t117_n131: return 0.07102817296981812f;
  t117_n132: return 0.010965506546199322f;
  t117_n133: if (E.getNumReferences() >= 3336505344 /*28548.0*/) goto t117_n135;
  t117_n134: return -0.01312785129994154f;
  t117_n135: return -0.07199972122907639f;
  t117_n136: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t117_n138;
  t117_n137: return 0.018686166033148766f;
  t117_n138: return -0.4901137053966522f;
  t117_n139: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t117_n141;
  t117_n140: return 0.060563825070858f;
  t117_n141: return 0.13395613431930542f;
  t117_n142: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t117_n144;
  t117_n143: return 0.11169620603322983f;
  t117_n144: return 0.06816107779741287f;
  t117_n145: return -0.08650375157594681f;
  t117_n146: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t117_n200;
  t117_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t117_n163;
  t117_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t117_n150;
  t117_n149: return -0.1313246339559555f;
  t117_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t117_n152;
  t117_n151: return 0.049539219588041306f;
  t117_n152: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t117_n156;
  t117_n153: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t117_n155;
  t117_n154: return -0.008281872607767582f;
  t117_n155: return 0.06587288528680801f;
  t117_n156: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t117_n158;
  t117_n157: return 0.0884166732430458f;
  t117_n158: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t117_n160;
  t117_n159: return 0.07131265103816986f;
  t117_n160: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t117_n162;
  t117_n161: return 0.1253790408372879f;
  t117_n162: return 0.06563864648342133f;
  t117_n163: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t117_n165;
  t117_n164: return -0.14514237642288208f;
  t117_n165: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t117_n181;
  t117_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t117_n176;
  t117_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t117_n169;
  t117_n168: return 0.01678081788122654f;
  t117_n169: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t117_n175;
  t117_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t117_n172;
  t117_n171: return 0.11766556650400162f;
  t117_n172: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t117_n174;
  t117_n173: return 0.06828994303941727f;
  t117_n174: return 0.017045272514224052f;
  t117_n175: return -0.1068769097328186f;
  t117_n176: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t117_n180;
  t117_n177: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t117_n179;
  t117_n178: return 0.05874117836356163f;
  t117_n179: return 0.0038949844893068075f;
  t117_n180: return 0.04530695825815201f;
  t117_n181: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t117_n197;
  t117_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t117_n192;
  t117_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t117_n189;
  t117_n184: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t117_n188;
  t117_n185: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t117_n187;
  t117_n186: return 0.05272065848112106f;
  t117_n187: return 0.08760230988264084f;
  t117_n188: return 0.015415901318192482f;
  t117_n189: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t117_n191;
  t117_n190: return 0.08654134720563889f;
  t117_n191: return 0.10204149782657623f;
  t117_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t117_n194;
  t117_n193: return 0.05464540421962738f;
  t117_n194: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t117_n196;
  t117_n195: return 0.09228751063346863f;
  t117_n196: return 0.05856413021683693f;
  t117_n197: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t117_n199;
  t117_n198: return -0.48829278349876404f;
  t117_n199: return 0.0791824534535408f;
  t117_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t117_n202;
  t117_n201: return -0.0033793780021369457f;
  t117_n202: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t117_n236;
  t117_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t117_n205;
  t117_n204: return -0.10493304580450058f;
  t117_n205: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t117_n215;
  t117_n206: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t117_n208;
  t117_n207: return 0.043948907405138016f;
  t117_n208: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t117_n214;
  t117_n209: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t117_n211;
  t117_n210: return -0.1082763597369194f;
  t117_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t117_n213;
  t117_n212: return 0.10775347799062729f;
  t117_n213: return 0.11732577532529831f;
  t117_n214: return 0.17318879067897797f;
  t117_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t117_n235;
  t117_n216: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t117_n224;
  t117_n217: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t117_n219;
  t117_n218: return 0.05666393041610718f;
  t117_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t117_n221;
  t117_n220: return -0.2925950884819031f;
  t117_n221: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t117_n223;
  t117_n222: return -0.11537104099988937f;
  t117_n223: return 0.11785241216421127f;
  t117_n224: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t117_n232;
  t117_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t117_n227;
  t117_n226: return 0.07410643994808197f;
  t117_n227: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t117_n231;
  t117_n228: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t117_n230;
  t117_n229: return 0.05707468464970589f;
  t117_n230: return 0.11625943332910538f;
  t117_n231: return 0.10651259869337082f;
  t117_n232: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t117_n234;
  t117_n233: return 0.011081867851316929f;
  t117_n234: return 0.10344342887401581f;
  t117_n235: return 0.041815903037786484f;
  t117_n236: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t117_n238;
  t117_n237: return 0.0011512425262480974f;
  t117_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t117_n252;
  t117_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t117_n247;
  t117_n240: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t117_n244;
  t117_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t117_n243;
  t117_n242: return -0.19879376888275146f;
  t117_n243: return 0.07299237698316574f;
  t117_n244: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t117_n246;
  t117_n245: return -0.20096111297607422f;
  t117_n246: return 0.12253524363040924f;
  t117_n247: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t117_n249;
  t117_n248: return 0.10540606826543808f;
  t117_n249: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t117_n251;
  t117_n250: return 0.06916607916355133f;
  t117_n251: return -0.20177848637104034f;
  t117_n252: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t117_n254;
  t117_n253: return 0.01062485110014677f;
  t117_n254: return -0.29301878809928894f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree118(const Example& E) {
  t118_n0: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t118_n228;
  t118_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t118_n73;
  t118_n2: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t118_n6;
  t118_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t118_n5;
  t118_n4: return 0.008813892491161823f;
  t118_n5: return -0.004455797374248505f;
  t118_n6: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t118_n20;
  t118_n7: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t118_n11;
  t118_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t118_n10;
  t118_n9: return 0.00981551967561245f;
  t118_n10: return 0.025349218398332596f;
  t118_n11: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t118_n15;
  t118_n12: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t118_n14;
  t118_n13: return -0.1372603476047516f;
  t118_n14: return 0.10658054798841476f;
  t118_n15: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t118_n17;
  t118_n16: return 0.048506226390600204f;
  t118_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t118_n19;
  t118_n18: return 0.25934943556785583f;
  t118_n19: return 0.00705204252153635f;
  t118_n20: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t118_n22;
  t118_n21: return 0.11044688522815704f;
  t118_n22: if (E.getNumReferences() >= 3319647232 /*7097.5*/) goto t118_n60;
  t118_n23: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t118_n57;
  t118_n24: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t118_n30;
  t118_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t118_n29;
  t118_n26: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t118_n28;
  t118_n27: return -0.04948277026414871f;
  t118_n28: return 0.004917928017675877f;
  t118_n29: return 0.03702174127101898f;
  t118_n30: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t118_n50;
  t118_n31: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t118_n33;
  t118_n32: return 0.07715199887752533f;
  t118_n33: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t118_n49;
  t118_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t118_n36;
  t118_n35: return 0.0891265794634819f;
  t118_n36: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t118_n48;
  t118_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t118_n45;
  t118_n38: if (E.getNumReferences() >= 3280551936 /*274.5*/) goto t118_n44;
  t118_n39: if (E.getNumReferences() >= 3278929920 /*240.5*/) goto t118_n43;
  t118_n40: if (E.getNumReferences() >= 3273424896 /*156.5*/) goto t118_n42;
  t118_n41: return 0.15378323197364807f;
  t118_n42: return 0.050687164068222046f;
  t118_n43: return 0.12276605516672134f;
  t118_n44: return 0.09754334390163422f;
  t118_n45: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t118_n47;
  t118_n46: return 0.08803266286849976f;
  t118_n47: return 0.12451596558094025f;
  t118_n48: return 0.05658352002501488f;
  t118_n49: return 0.06104641780257225f;
  t118_n50: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t118_n52;
  t118_n51: return 0.024967852979898453f;
  t118_n52: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t118_n56;
  t118_n53: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t118_n55;
  t118_n54: return 0.10946809500455856f;
  t118_n55: return -0.204900860786438f;
  t118_n56: return -0.1653704047203064f;
  t118_n57: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t118_n59;
  t118_n58: return 0.027295725420117378f;
  t118_n59: return 0.04367908835411072f;
  t118_n60: if (E.getNumReferences() >= 3320122368 /*7329.5*/) goto t118_n72;
  t118_n61: if (E.getNumReferences() >= 3319813120 /*7178.5*/) goto t118_n67;
  t118_n62: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t118_n66;
  t118_n63: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t118_n65;
  t118_n64: return 0.11092821508646011f;
  t118_n65: return 0.0487385131418705f;
  t118_n66: return 0.003724399022758007f;
  t118_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t118_n69;
  t118_n68: return -0.2130768597126007f;
  t118_n69: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t118_n71;
  t118_n70: return 0.11107797920703888f;
  t118_n71: return 0.09241697192192078f;
  t118_n72: return 0.0538821667432785f;
  t118_n73: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t118_n75;
  t118_n74: return -0.00029140725382603705f;
  t118_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t118_n77;
  t118_n76: return -0.03409666195511818f;
  t118_n77: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t118_n147;
  t118_n78: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t118_n106;
  t118_n79: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t118_n81;
  t118_n80: return -0.06014958769083023f;
  t118_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t118_n83;
  t118_n82: return 0.005980978719890118f;
  t118_n83: if (E.getNumReferences() >= 3326358528 /*12557.0*/) goto t118_n103;
  t118_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t118_n100;
  t118_n85: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t118_n87;
  t118_n86: return 0.020877448841929436f;
  t118_n87: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t118_n89;
  t118_n88: return 0.03225495666265488f;
  t118_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t118_n91;
  t118_n90: return 0.07340915501117706f;
  t118_n91: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t118_n99;
  t118_n92: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t118_n94;
  t118_n93: return 0.6714432239532471f;
  t118_n94: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t118_n96;
  t118_n95: return 0.10469558835029602f;
  t118_n96: if (E.getNumReferences() >= 3281387520 /*300.0*/) goto t118_n98;
  t118_n97: return 0.40318959951400757f;
  t118_n98: return 0.16106769442558289f;
  t118_n99: return 0.1534224897623062f;
  t118_n100: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t118_n102;
  t118_n101: return 0.025558246299624443f;
  t118_n102: return 0.07364863157272339f;
  t118_n103: if (E.getNumReferences() >= 3326422016 /*12619.0*/) goto t118_n105;
  t118_n104: return 0.11768218874931335f;
  t118_n105: return 0.35770490765571594f;
  t118_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t118_n122;
  t118_n107: if (E.getNumReferences() >= 3281829888 /*313.5*/) goto t118_n119;
  t118_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t118_n110;
  t118_n109: return -0.0908157154917717f;
  t118_n110: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t118_n118;
  t118_n111: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t118_n113;
  t118_n112: return 0.006041351705789566f;
  t118_n113: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t118_n117;
  t118_n114: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t118_n116;
  t118_n115: return 0.13916151225566864f;
  t118_n116: return 0.0702851414680481f;
  t118_n117: return -0.6602993011474609f;
  t118_n118: return -0.14572398364543915f;
  t118_n119: if (E.getNumReferences() >= 3282157568 /*323.5*/) goto t118_n121;
  t118_n120: return 0.1195901483297348f;
  t118_n121: return -0.022094568237662315f;
  t118_n122: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t118_n146;
  t118_n123: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t118_n129;
  t118_n124: if (E.getNumReferences() >= 3276144640 /*198.0*/) goto t118_n128;
  t118_n125: if (E.getNumReferences() >= 3274375168 /*171.0*/) goto t118_n127;
  t118_n126: return 0.030894450843334198f;
  t118_n127: return 0.09772448241710663f;
  t118_n128: return -0.23181003332138062f;
  t118_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t118_n131;
  t118_n130: return -0.01166196446865797f;
  t118_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t118_n137;
  t118_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t118_n134;
  t118_n133: return 0.01815449260175228f;
  t118_n134: if (E.getNumReferences() >= 3293626368 /*835.0*/) goto t118_n136;
  t118_n135: return 0.11426651477813721f;
  t118_n136: return -0.020585540682077408f;
  t118_n137: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t118_n139;
  t118_n138: return 0.09065687656402588f;
  t118_n139: if (E.getNumReferences() >= 3256614912 /*39.0*/) goto t118_n141;
  t118_n140: return -0.018791818991303444f;
  t118_n141: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t118_n145;
  t118_n142: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t118_n144;
  t118_n143: return 0.10511317849159241f;
  t118_n144: return 0.10873588174581528f;
  t118_n145: return 0.15018628537654877f;
  t118_n146: return -0.11852744966745377f;
  t118_n147: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t118_n149;
  t118_n148: return -0.06501361727714539f;
  t118_n149: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t118_n151;
  t118_n150: return -0.03629907965660095f;
  t118_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t118_n209;
  t118_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t118_n154;
  t118_n153: return -0.36782392859458923f;
  t118_n154: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t118_n156;
  t118_n155: return -0.0004780296585522592f;
  t118_n156: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t118_n158;
  t118_n157: return -0.0526997409760952f;
  t118_n158: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t118_n192;
  t118_n159: if (E.getNumReferences() >= 3326102016 /*12306.5*/) goto t118_n189;
  t118_n160: if (E.getNumReferences() >= 3289284608 /*570.0*/) goto t118_n172;
  t118_n161: if (E.getNumReferences() >= 3280551936 /*274.5*/) goto t118_n171;
  t118_n162: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t118_n170;
  t118_n163: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t118_n165;
  t118_n164: return 0.02775774896144867f;
  t118_n165: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t118_n167;
  t118_n166: return 0.11161285638809204f;
  t118_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t118_n169;
  t118_n168: return -0.24901629984378815f;
  t118_n169: return 0.07662933319807053f;
  t118_n170: return -0.09548220783472061f;
  t118_n171: return -0.12383008003234863f;
  t118_n172: if (E.getNumReferences() >= 3293069312 /*801.0*/) goto t118_n182;
  t118_n173: if (E.getNumReferences() >= 3292192768 /*747.5*/) goto t118_n181;
  t118_n174: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t118_n176;
  t118_n175: return -0.036423586308956146f;
  t118_n176: if (E.getNumReferences() >= 3290480640 /*643.0*/) goto t118_n180;
  t118_n177: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t118_n179;
  t118_n178: return 0.1162264421582222f;
  t118_n179: return 0.09013713151216507f;
  t118_n180: return 0.06116314232349396f;
  t118_n181: return 0.10376159101724625f;
  t118_n182: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t118_n184;
  t118_n183: return 0.003754277480766177f;
  t118_n184: if (E.getNumReferences() >= 3316855808 /*5734.5*/) goto t118_n188;
  t118_n185: if (E.getNumReferences() >= 3314754560 /*4708.5*/) goto t118_n187;
  t118_n186: return 0.07590613514184952f;
  t118_n187: return 0.13562436401844025f;
  t118_n188: return 0.037133049219846725f;
  t118_n189: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t118_n191;
  t118_n190: return 0.11279448121786118f;
  t118_n191: return -0.011394676752388477f;
  t118_n192: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t118_n206;
  t118_n193: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t118_n199;
  t118_n194: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t118_n198;
  t118_n195: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t118_n197;
  t118_n196: return 0.021849697455763817f;
  t118_n197: return 0.22660233080387115f;
  t118_n198: return -0.07446306198835373f;
  t118_n199: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t118_n205;
  t118_n200: if (E.getNumReferences() >= 3249012736 /*21.0*/) goto t118_n204;
  t118_n201: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t118_n203;
  t118_n202: return 0.1169624775648117f;
  t118_n203: return 0.11849658191204071f;
  t118_n204: return 0.09597093611955643f;
  t118_n205: return 0.10122110694646835f;
  t118_n206: if (E.getNumReferences() >= 3325940736 /*12149.0*/) goto t118_n208;
  t118_n207: return 0.021371984854340553f;
  t118_n208: return -0.3908306658267975f;
  t118_n209: if (E.getNumReferences() >= 3307579392 /*2650.5*/) goto t118_n217;
  t118_n210: if (E.getNumReferences() >= 3283140608 /*353.5*/) goto t118_n212;
  t118_n211: return 0.06842711567878723f;
  t118_n212: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t118_n214;
  t118_n213: return -0.10689559578895569f;
  t118_n214: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t118_n216;
  t118_n215: return 0.11973344534635544f;
  t118_n216: return 0.03538462147116661f;
  t118_n217: if (E.getNumReferences() >= 3310143488 /*3276.5*/) goto t118_n221;
  t118_n218: if (E.getNumReferences() >= 3309223936 /*3052.0*/) goto t118_n220;
  t118_n219: return 0.08247756212949753f;
  t118_n220: return 0.11286861449480057f;
  t118_n221: if (E.getNumReferences() >= 3325050880 /*11280.0*/) goto t118_n227;
  t118_n222: if (E.getNumReferences() >= 3322876928 /*9157.0*/) goto t118_n226;
  t118_n223: if (E.getNumReferences() >= 3322330112 /*8623.0*/) goto t118_n225;
  t118_n224: return 0.09703976660966873f;
  t118_n225: return 0.1365666538476944f;
  t118_n226: return 0.01763412170112133f;
  t118_n227: return 0.11357587575912476f;
  t118_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t118_n230;
  t118_n229: return 0.0029706789646297693f;
  t118_n230: if (E.getNumReferences() >= 3327319040 /*13495.0*/) goto t118_n252;
  t118_n231: if (E.getNumReferences() >= 3327291904 /*13468.5*/) goto t118_n251;
  t118_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t118_n240;
  t118_n233: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t118_n239;
  t118_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t118_n236;
  t118_n235: return 0.06015996262431145f;
  t118_n236: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t118_n238;
  t118_n237: return 0.10588925331830978f;
  t118_n238: return -0.01354050263762474f;
  t118_n239: return -0.4640491306781769f;
  t118_n240: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t118_n250;
  t118_n241: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t118_n249;
  t118_n242: if (E.getNumReferences() >= 3326945792 /*13130.5*/) goto t118_n248;
  t118_n243: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t118_n247;
  t118_n244: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t118_n246;
  t118_n245: return 0.05963708087801933f;
  t118_n246: return 0.10309398919343948f;
  t118_n247: return -0.09578441083431244f;
  t118_n248: return 0.004259220324456692f;
  t118_n249: return 0.09853137284517288f;
  t118_n250: return 0.12132924050092697f;
  t118_n251: return 0.2794002592563629f;
  t118_n252: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t118_n254;
  t118_n253: return 0.014615865424275398f;
  t118_n254: return -0.3203522562980652f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree119(const Example& E) {
  t119_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t119_n232;
  t119_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t119_n3;
  t119_n2: return -0.08368232101202011f;
  t119_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t119_n151;
  t119_n4: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t119_n54;
  t119_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t119_n7;
  t119_n6: return 0.0059097143821418285f;
  t119_n7: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t119_n13;
  t119_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t119_n10;
  t119_n9: return 0.0006743604899384081f;
  t119_n10: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t119_n12;
  t119_n11: return 0.07651519775390625f;
  t119_n12: return -0.015455747954547405f;
  t119_n13: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t119_n31;
  t119_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n18;
  t119_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t119_n17;
  t119_n16: return 0.08815103769302368f;
  t119_n17: return 0.1245064064860344f;
  t119_n18: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t119_n20;
  t119_n19: return 0.11373381316661835f;
  t119_n20: if (E.getNumReferences() >= 3288834048 /*542.5*/) goto t119_n28;
  t119_n21: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t119_n23;
  t119_n22: return 0.04673929512500763f;
  t119_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t119_n25;
  t119_n24: return 0.09726834297180176f;
  t119_n25: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t119_n27;
  t119_n26: return 0.11278121918439865f;
  t119_n27: return 0.12714868783950806f;
  t119_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t119_n30;
  t119_n29: return 0.07269325852394104f;
  t119_n30: return 0.12096067517995834f;
  t119_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t119_n33;
  t119_n32: return 0.050599001348018646f;
  t119_n33: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t119_n43;
  t119_n34: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t119_n36;
  t119_n35: return 0.04713740199804306f;
  t119_n36: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t119_n42;
  t119_n37: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t119_n39;
  t119_n38: return 0.07611840963363647f;
  t119_n39: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t119_n41;
  t119_n40: return -0.22943854331970215f;
  t119_n41: return 0.1515735238790512f;
  t119_n42: return 0.13534995913505554f;
  t119_n43: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t119_n45;
  t119_n44: return -0.0642678439617157f;
  t119_n45: if (E.getNumReferences() >= 3262119936 /*60.0*/) goto t119_n49;
  t119_n46: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t119_n48;
  t119_n47: return 0.08786381036043167f;
  t119_n48: return 0.12260088324546814f;
  t119_n49: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t119_n53;
  t119_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n52;
  t119_n51: return 0.10123966634273529f;
  t119_n52: return 0.0702512338757515f;
  t119_n53: return -0.008419912308454514f;
  t119_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t119_n56;
  t119_n55: return -0.0289535541087389f;
  t119_n56: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t119_n72;
  t119_n57: if (E.getNumReferences() >= 3310407680 /*3341.0*/) goto t119_n71;
  t119_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n60;
  t119_n59: return -0.01432056725025177f;
  t119_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t119_n64;
  t119_n61: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t119_n63;
  t119_n62: return -0.023590756580233574f;
  t119_n63: return 0.0171373151242733f;
  t119_n64: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t119_n70;
  t119_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t119_n67;
  t119_n66: return -0.131847083568573f;
  t119_n67: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t119_n69;
  t119_n68: return 0.02586863376200199f;
  t119_n69: return -0.11445274204015732f;
  t119_n70: return -0.02822856418788433f;
  t119_n71: return 0.023558620363473892f;
  t119_n72: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t119_n76;
  t119_n73: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t119_n75;
  t119_n74: return 0.013722056522965431f;
  t119_n75: return -0.058147333562374115f;
  t119_n76: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t119_n78;
  t119_n77: return -0.007446447387337685f;
  t119_n78: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t119_n80;
  t119_n79: return 0.002117577474564314f;
  t119_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t119_n96;
  t119_n81: if (E.getNumReferences() >= 3283075072 /*351.5*/) goto t119_n91;
  t119_n82: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t119_n90;
  t119_n83: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t119_n89;
  t119_n84: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t119_n88;
  t119_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t119_n87;
  t119_n86: return 0.042672932147979736f;
  t119_n87: return 0.04898682236671448f;
  t119_n88: return -0.12040358781814575f;
  t119_n89: return 0.04461628198623657f;
  t119_n90: return -0.049301356077194214f;
  t119_n91: if (E.getNumReferences() >= 3283107840 /*352.5*/) goto t119_n95;
  t119_n92: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t119_n94;
  t119_n93: return 0.12389284372329712f;
  t119_n94: return -0.10222271829843521f;
  t119_n95: return 0.04521864652633667f;
  t119_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t119_n98;
  t119_n97: return -0.10866522043943405f;
  t119_n98: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t119_n150;
  t119_n99: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t119_n111;
  t119_n100: if (E.getNumReferences() >= 3286712320 /*462.5*/) goto t119_n102;
  t119_n101: return 0.06224014610052109f;
  t119_n102: if (E.getNumReferences() >= 3287318528 /*481.0*/) goto t119_n104;
  t119_n103: return 0.12236981093883514f;
  t119_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t119_n106;
  t119_n105: return 0.025570763275027275f;
  t119_n106: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t119_n110;
  t119_n107: if (E.getNumReferences() >= 3299962880 /*1419.5*/) goto t119_n109;
  t119_n108: return 0.11836866289377213f;
  t119_n109: return 0.07487404346466064f;
  t119_n110: return 0.034864820539951324f;
  t119_n111: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t119_n149;
  t119_n112: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t119_n144;
  t119_n113: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t119_n143;
  t119_n114: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t119_n122;
  t119_n115: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t119_n117;
  t119_n116: return 0.0975308045744896f;
  t119_n117: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t119_n119;
  t119_n118: return 0.009906069375574589f;
  t119_n119: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t119_n121;
  t119_n120: return 0.09420853108167648f;
  t119_n121: return 0.009428651072084904f;
  t119_n122: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t119_n142;
  t119_n123: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t119_n131;
  t119_n124: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t119_n130;
  t119_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t119_n129;
  t119_n126: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t119_n128;
  t119_n127: return 0.1385149508714676f;
  t119_n128: return 0.08573047816753387f;
  t119_n129: return 0.12233884632587433f;
  t119_n130: return 0.007401027716696262f;
  t119_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t119_n139;
  t119_n132: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t119_n134;
  t119_n133: return 0.062471531331539154f;
  t119_n134: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t119_n138;
  t119_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t119_n137;
  t119_n136: return 0.1140805333852768f;
  t119_n137: return 0.12391635030508041f;
  t119_n138: return 0.17225034534931183f;
  t119_n139: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t119_n141;
  t119_n140: return 0.14514626562595367f;
  t119_n141: return 0.1645526885986328f;
  t119_n142: return -0.05554990842938423f;
  t119_n143: return 0.052207838743925095f;
  t119_n144: if (E.getNumReferences() >= 3312433152 /*3835.5*/) goto t119_n146;
  t119_n145: return -0.009851234033703804f;
  t119_n146: if (E.getNumReferences() >= 3312824320 /*3931.0*/) goto t119_n148;
  t119_n147: return 0.10180730372667313f;
  t119_n148: return 0.0781218409538269f;
  t119_n149: return -0.10411331802606583f;
  t119_n150: return 0.0055674174800515175f;
  t119_n151: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t119_n177;
  t119_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Other))) goto t119_n164;
  t119_n153: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t119_n163;
  t119_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t119_n158;
  t119_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t119_n157;
  t119_n156: return -0.0874096006155014f;
  t119_n157: return -0.014483263716101646f;
  t119_n158: if (E.getNumReferences() >= 3291414528 /*700.0*/) goto t119_n160;
  t119_n159: return -0.02694448083639145f;
  t119_n160: if (E.getNumReferences() >= 3292438528 /*762.5*/) goto t119_n162;
  t119_n161: return 0.13632509112358093f;
  t119_n162: return -0.006801556330174208f;
  t119_n163: return 0.00796998105943203f;
  t119_n164: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t119_n176;
  t119_n165: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n171;
  t119_n166: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t119_n168;
  t119_n167: return 0.08451105654239655f;
  t119_n168: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t119_n170;
  t119_n169: return 0.0807809829711914f;
  t119_n170: return -0.1588355004787445f;
  t119_n171: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t119_n173;
  t119_n172: return 0.03031376376748085f;
  t119_n173: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t119_n175;
  t119_n174: return 0.07636731117963791f;
  t119_n175: return -0.13260450959205627f;
  t119_n176: return -0.02397395856678486f;
  t119_n177: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t119_n201;
  t119_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t119_n186;
  t119_n179: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t119_n185;
  t119_n180: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t119_n184;
  t119_n181: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t119_n183;
  t119_n182: return -0.032753318548202515f;
  t119_n183: return 0.1063629612326622f;
  t119_n184: return -0.023107165470719337f;
  t119_n185: return -0.04030613973736763f;
  t119_n186: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t119_n188;
  t119_n187: return -0.06691868603229523f;
  t119_n188: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t119_n190;
  t119_n189: return 0.0019041515188291669f;
  t119_n190: if (E.getNumReferences() >= 3333190144 /*22073.0*/) goto t119_n192;
  t119_n191: return 0.07211173325777054f;
  t119_n192: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n194;
  t119_n193: return 0.008774415589869022f;
  t119_n194: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t119_n200;
  t119_n195: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t119_n197;
  t119_n196: return 0.028570514172315598f;
  t119_n197: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t119_n199;
  t119_n198: return 0.08369462937116623f;
  t119_n199: return 0.01860407181084156f;
  t119_n200: return 0.0064019509591162205f;
  t119_n201: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t119_n205;
  t119_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t119_n204;
  t119_n203: return -0.066767618060112f;
  t119_n204: return 0.006491901818662882f;
  t119_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t119_n219;
  t119_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t119_n208;
  t119_n207: return 0.004431404173374176f;
  t119_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t119_n212;
  t119_n209: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t119_n211;
  t119_n210: return 0.03360496461391449f;
  t119_n211: return 0.03437560796737671f;
  t119_n212: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t119_n216;
  t119_n213: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t119_n215;
  t119_n214: return 0.017077088356018066f;
  t119_n215: return 0.08726978302001953f;
  t119_n216: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n218;
  t119_n217: return -0.02178242988884449f;
  t119_n218: return 0.003296775044873357f;
  t119_n219: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t119_n231;
  t119_n220: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t119_n230;
  t119_n221: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t119_n225;
  t119_n222: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t119_n224;
  t119_n223: return 0.10537099093198776f;
  t119_n224: return 0.07580988854169846f;
  t119_n225: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t119_n229;
  t119_n226: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t119_n228;
  t119_n227: return 0.11023791879415512f;
  t119_n228: return 0.05206086114048958f;
  t119_n229: return 0.08104458451271057f;
  t119_n230: return 0.07408168166875839f;
  t119_n231: return -0.048481062054634094f;
  t119_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t119_n236;
  t119_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t119_n235;
  t119_n234: return -0.29013216495513916f;
  t119_n235: return 0.0054184976033866405f;
  t119_n236: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t119_n242;
  t119_n237: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t119_n241;
  t119_n238: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t119_n240;
  t119_n239: return -0.11665145307779312f;
  t119_n240: return 0.0914924219250679f;
  t119_n241: return -0.7106292843818665f;
  t119_n242: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t119_n244;
  t119_n243: return -0.12035848200321198f;
  t119_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n254;
  t119_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t119_n251;
  t119_n246: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t119_n248;
  t119_n247: return 0.014660126529633999f;
  t119_n248: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t119_n250;
  t119_n249: return 0.06525640934705734f;
  t119_n250: return 0.10126413404941559f;
  t119_n251: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t119_n253;
  t119_n252: return 0.10471587628126144f;
  t119_n253: return 0.0928502306342125f;
  t119_n254: return 0.033176589757204056f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree120(const Example& E) {
  t120_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t120_n230;
  t120_n1: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t120_n167;
  t120_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t120_n4;
  t120_n3: return -0.0018479072023183107f;
  t120_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t120_n154;
  t120_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t120_n121;
  t120_n6: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t120_n112;
  t120_n7: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t120_n25;
  t120_n8: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t120_n12;
  t120_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t120_n11;
  t120_n10: return -0.07208352535963058f;
  t120_n11: return -0.004859523382037878f;
  t120_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t120_n14;
  t120_n13: return -0.017543643712997437f;
  t120_n14: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t120_n24;
  t120_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t120_n21;
  t120_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t120_n20;
  t120_n17: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t120_n19;
  t120_n18: return -0.15574558079242706f;
  t120_n19: return -0.3764133155345917f;
  t120_n20: return 0.07249245792627335f;
  t120_n21: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t120_n23;
  t120_n22: return 0.09605144709348679f;
  t120_n23: return 0.12000320851802826f;
  t120_n24: return -0.018199052661657333f;
  t120_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t120_n91;
  t120_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t120_n28;
  t120_n27: return -0.025444669649004936f;
  t120_n28: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t120_n30;
  t120_n29: return -0.001676475745625794f;
  t120_n30: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t120_n76;
  t120_n31: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t120_n75;
  t120_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t120_n50;
  t120_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n47;
  t120_n34: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t120_n46;
  t120_n35: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t120_n41;
  t120_n36: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t120_n38;
  t120_n37: return 0.027955397963523865f;
  t120_n38: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n40;
  t120_n39: return 0.08588802069425583f;
  t120_n40: return -0.027408583089709282f;
  t120_n41: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n45;
  t120_n42: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t120_n44;
  t120_n43: return 0.12428901344537735f;
  t120_n44: return 0.10975395888090134f;
  t120_n45: return 0.00036917137913405895f;
  t120_n46: return 0.0219903364777565f;
  t120_n47: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t120_n49;
  t120_n48: return 0.09341812878847122f;
  t120_n49: return 0.021439313888549805f;
  t120_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n52;
  t120_n51: return -0.059933654963970184f;
  t120_n52: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t120_n74;
  t120_n53: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t120_n71;
  t120_n54: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t120_n56;
  t120_n55: return -0.37892812490463257f;
  t120_n56: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t120_n58;
  t120_n57: return 0.10259576886892319f;
  t120_n58: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t120_n60;
  t120_n59: return -0.03999272361397743f;
  t120_n60: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t120_n62;
  t120_n61: return 0.09768949449062347f;
  t120_n62: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t120_n64;
  t120_n63: return -0.13378335535526276f;
  t120_n64: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n70;
  t120_n65: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t120_n67;
  t120_n66: return 0.08537545055150986f;
  t120_n67: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t120_n69;
  t120_n68: return -0.0053179142996668816f;
  t120_n69: return 0.11812304705381393f;
  t120_n70: return 0.07574526220560074f;
  t120_n71: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t120_n73;
  t120_n72: return 0.05839142948389053f;
  t120_n73: return 0.10823224484920502f;
  t120_n74: return -0.03699526935815811f;
  t120_n75: return -0.01602153666317463f;
  t120_n76: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t120_n86;
  t120_n77: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t120_n83;
  t120_n78: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t120_n80;
  t120_n79: return -0.03382200747728348f;
  t120_n80: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n82;
  t120_n81: return -0.13605482876300812f;
  t120_n82: return 0.11663958430290222f;
  t120_n83: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t120_n85;
  t120_n84: return 0.11296091973781586f;
  t120_n85: return 0.08183750510215759f;
  t120_n86: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t120_n88;
  t120_n87: return -0.030233316123485565f;
  t120_n88: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t120_n90;
  t120_n89: return -0.2189343273639679f;
  t120_n90: return -0.0017865264089778066f;
  t120_n91: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t120_n111;
  t120_n92: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t120_n110;
  t120_n93: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t120_n109;
  t120_n94: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t120_n96;
  t120_n95: return 0.05839492753148079f;
  t120_n96: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t120_n98;
  t120_n97: return 0.006333892233669758f;
  t120_n98: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t120_n108;
  t120_n99: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n105;
  t120_n100: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t120_n104;
  t120_n101: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n103;
  t120_n102: return 0.10722570866346359f;
  t120_n103: return 0.10348476469516754f;
  t120_n104: return 0.08462608605623245f;
  t120_n105: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t120_n107;
  t120_n106: return 0.002971793757751584f;
  t120_n107: return 0.0967206135392189f;
  t120_n108: return -0.13129979372024536f;
  t120_n109: return 0.03278029337525368f;
  t120_n110: return -0.07339786738157272f;
  t120_n111: return -0.027242233976721764f;
  t120_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t120_n120;
  t120_n113: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t120_n119;
  t120_n114: if (E.getNumReferences() >= 3259236352 /*49.0*/) goto t120_n116;
  t120_n115: return 0.028971469029784203f;
  t120_n116: if (E.getNumReferences() >= 3275325440 /*185.5*/) goto t120_n118;
  t120_n117: return 0.17112332582473755f;
  t120_n118: return -0.5840075612068176f;
  t120_n119: return 0.0262122955173254f;
  t120_n120: return -0.04572742432355881f;
  t120_n121: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t120_n123;
  t120_n122: return -0.004067303147166967f;
  t120_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t120_n153;
  t120_n124: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t120_n146;
  t120_n125: if (E.getNumReferences() >= 3292086272 /*741.0*/) goto t120_n145;
  t120_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t120_n130;
  t120_n127: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t120_n129;
  t120_n128: return 0.09434956312179565f;
  t120_n129: return -0.15151894092559814f;
  t120_n130: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t120_n136;
  t120_n131: if (E.getNumReferences() >= 3267756032 /*99.0*/) goto t120_n133;
  t120_n132: return -0.003968546167016029f;
  t120_n133: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t120_n135;
  t120_n134: return 0.1129620149731636f;
  t120_n135: return 0.0457441583275795f;
  t120_n136: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t120_n144;
  t120_n137: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t120_n139;
  t120_n138: return 0.034896619617938995f;
  t120_n139: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n141;
  t120_n140: return 0.055127136409282684f;
  t120_n141: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t120_n143;
  t120_n142: return 0.10213568061590195f;
  t120_n143: return 0.12004516273736954f;
  t120_n144: return 0.011731973849236965f;
  t120_n145: return 0.08691812306642532f;
  t120_n146: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t120_n150;
  t120_n147: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t120_n149;
  t120_n148: return -0.0060467179864645f;
  t120_n149: return 0.09290796518325806f;
  t120_n150: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t120_n152;
  t120_n151: return 0.02969115413725376f;
  t120_n152: return 0.04323728382587433f;
  t120_n153: return 0.02039957605302334f;
  t120_n154: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t120_n156;
  t120_n155: return 0.06029253453016281f;
  t120_n156: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t120_n160;
  t120_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t120_n159;
  t120_n158: return 0.0944695770740509f;
  t120_n159: return -0.09528782218694687f;
  t120_n160: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t120_n166;
  t120_n161: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t120_n163;
  t120_n162: return 0.12947039306163788f;
  t120_n163: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t120_n165;
  t120_n164: return 0.08186306059360504f;
  t120_n165: return 0.12464483082294464f;
  t120_n166: return 0.08722574263811111f;
  t120_n167: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t120_n227;
  t120_n168: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t120_n224;
  t120_n169: if (E.getNumReferences() >= 3355264064 /*129672.5*/) goto t120_n173;
  t120_n170: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t120_n172;
  t120_n171: return 0.008673684671521187f;
  t120_n172: return -0.438306599855423f;
  t120_n173: if (E.getNumReferences() >= 3356582432 /*148872.5*/) goto t120_n177;
  t120_n174: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t120_n176;
  t120_n175: return 0.10905773937702179f;
  t120_n176: return 0.038543619215488434f;
  t120_n177: if (E.getNumReferences() >= 3361098688 /*219439.0*/) goto t120_n191;
  t120_n178: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t120_n180;
  t120_n179: return 0.0013266172027215362f;
  t120_n180: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t120_n184;
  t120_n181: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n183;
  t120_n182: return 0.03497501462697983f;
  t120_n183: return -0.2998804450035095f;
  t120_n184: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t120_n188;
  t120_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n187;
  t120_n186: return 0.05076202005147934f;
  t120_n187: return -0.27877554297447205f;
  t120_n188: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n190;
  t120_n189: return 0.07733647525310516f;
  t120_n190: return 0.0865892767906189f;
  t120_n191: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n211;
  t120_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t120_n194;
  t120_n193: return -0.09183484315872192f;
  t120_n194: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t120_n208;
  t120_n195: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t120_n197;
  t120_n196: return -0.7563222050666809f;
  t120_n197: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t120_n203;
  t120_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n202;
  t120_n199: if (E.getNumReferences() >= 3362887008 /*247381.5*/) goto t120_n201;
  t120_n200: return 0.05256318673491478f;
  t120_n201: return -0.2505616247653961f;
  t120_n202: return -0.8039416074752808f;
  t120_n203: if (E.getNumReferences() >= 3365641360 /*318692.5*/) goto t120_n207;
  t120_n204: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t120_n206;
  t120_n205: return 0.10732876509428024f;
  t120_n206: return 0.06386164575815201f;
  t120_n207: return -0.1285344958305359f;
  t120_n208: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t120_n210;
  t120_n209: return -0.11319008469581604f;
  t120_n210: return 0.014427142217755318f;
  t120_n211: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t120_n215;
  t120_n212: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t120_n214;
  t120_n213: return -0.14910481870174408f;
  t120_n214: return -0.38791555166244507f;
  t120_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t120_n221;
  t120_n216: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t120_n218;
  t120_n217: return -0.25990962982177734f;
  t120_n218: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t120_n220;
  t120_n219: return 0.07601949572563171f;
  t120_n220: return -0.028281722217798233f;
  t120_n221: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t120_n223;
  t120_n222: return -0.20468683540821075f;
  t120_n223: return 0.11132701486349106f;
  t120_n224: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t120_n226;
  t120_n225: return 0.026827316731214523f;
  t120_n226: return -0.36314263939857483f;
  t120_n227: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t120_n229;
  t120_n228: return -0.010091566480696201f;
  t120_n229: return 0.009399627335369587f;
  t120_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t120_n234;
  t120_n231: if (E.getNumReferences() >= 3333877504 /*23415.5*/) goto t120_n233;
  t120_n232: return -0.004786872770637274f;
  t120_n233: return -0.21210457384586334f;
  t120_n234: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t120_n250;
  t120_n235: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t120_n237;
  t120_n236: return 0.006775474641472101f;
  t120_n237: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t120_n243;
  t120_n238: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t120_n240;
  t120_n239: return 0.03821006044745445f;
  t120_n240: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t120_n242;
  t120_n241: return 0.10676880925893784f;
  t120_n242: return -0.12504830956459045f;
  t120_n243: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t120_n249;
  t120_n244: if (E.getNumReferences() >= 3283320832 /*359.0*/) goto t120_n246;
  t120_n245: return -0.1903197318315506f;
  t120_n246: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t120_n248;
  t120_n247: return -0.2535499334335327f;
  t120_n248: return 0.07757803052663803f;
  t120_n249: return 0.01717926561832428f;
  t120_n250: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t120_n252;
  t120_n251: return -9.784966096049175e-05f;
  t120_n252: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t120_n254;
  t120_n253: return 0.028064146637916565f;
  t120_n254: return 0.0058842371217906475f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree121(const Example& E) {
  t121_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t121_n10;
  t121_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t121_n3;
  t121_n2: return -0.0008136239484883845f;
  t121_n3: if (E.getNumReferences() >= 3343006592 /*49723.5*/) goto t121_n9;
  t121_n4: if (E.getNumReferences() >= 3341699072 /*44616.0*/) goto t121_n6;
  t121_n5: return 0.004330262541770935f;
  t121_n6: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t121_n8;
  t121_n7: return 0.06120527535676956f;
  t121_n8: return 0.11150621622800827f;
  t121_n9: return -0.0923863872885704f;
  t121_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t121_n22;
  t121_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t121_n21;
  t121_n12: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t121_n18;
  t121_n13: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n17;
  t121_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t121_n16;
  t121_n15: return 0.06472869217395782f;
  t121_n16: return 0.07488028705120087f;
  t121_n17: return -0.6716023683547974f;
  t121_n18: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n20;
  t121_n19: return -0.22609955072402954f;
  t121_n20: return 0.009677066467702389f;
  t121_n21: return 0.016843924298882484f;
  t121_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t121_n24;
  t121_n23: return -0.02322203479707241f;
  t121_n24: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t121_n184;
  t121_n25: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t121_n135;
  t121_n26: if (E.getNumReferences() >= 3354631552 /*124731.0*/) goto t121_n134;
  t121_n27: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t121_n115;
  t121_n28: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t121_n48;
  t121_n29: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t121_n47;
  t121_n30: if (E.getNumReferences() >= 3350448512 /*92051.0*/) goto t121_n46;
  t121_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t121_n37;
  t121_n32: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t121_n34;
  t121_n33: return 0.027038993313908577f;
  t121_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n36;
  t121_n35: return -0.24666623771190643f;
  t121_n36: return 0.21157829463481903f;
  t121_n37: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t121_n41;
  t121_n38: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t121_n40;
  t121_n39: return 0.10980738699436188f;
  t121_n40: return -0.1068832129240036f;
  t121_n41: if (E.getNumReferences() >= 3350267136 /*90634.0*/) goto t121_n45;
  t121_n42: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t121_n44;
  t121_n43: return 0.025846485048532486f;
  t121_n44: return 0.07789076119661331f;
  t121_n45: return -0.9663264155387878f;
  t121_n46: return -0.03287314996123314f;
  t121_n47: return -0.1342821717262268f;
  t121_n48: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t121_n56;
  t121_n49: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t121_n51;
  t121_n50: return -0.06185571849346161f;
  t121_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t121_n53;
  t121_n52: return -0.2520313262939453f;
  t121_n53: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n55;
  t121_n54: return 0.1324869692325592f;
  t121_n55: return 0.09376392513513565f;
  t121_n56: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n114;
  t121_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t121_n75;
  t121_n58: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t121_n70;
  t121_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t121_n61;
  t121_n60: return -0.05740068852901459f;
  t121_n61: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t121_n69;
  t121_n62: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t121_n64;
  t121_n63: return 0.08846881240606308f;
  t121_n64: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t121_n68;
  t121_n65: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n67;
  t121_n66: return 0.1077990010380745f;
  t121_n67: return 0.10843516141176224f;
  t121_n68: return 0.0561409629881382f;
  t121_n69: return 0.04634026437997818f;
  t121_n70: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t121_n72;
  t121_n71: return -0.0009094633278436959f;
  t121_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t121_n74;
  t121_n73: return -0.1857205480337143f;
  t121_n74: return 0.06546047329902649f;
  t121_n75: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t121_n83;
  t121_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t121_n78;
  t121_n77: return 0.015834052115678787f;
  t121_n78: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t121_n82;
  t121_n79: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t121_n81;
  t121_n80: return 0.10408013314008713f;
  t121_n81: return 0.05321686714887619f;
  t121_n82: return -0.1417713612318039f;
  t121_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t121_n85;
  t121_n84: return -0.1791583150625229f;
  t121_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n111;
  t121_n86: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n106;
  t121_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t121_n95;
  t121_n88: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t121_n90;
  t121_n89: return 0.04253807291388512f;
  t121_n90: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t121_n92;
  t121_n91: return 0.11148002743721008f;
  t121_n92: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t121_n94;
  t121_n93: return -0.29272690415382385f;
  t121_n94: return 0.11758869141340256f;
  t121_n95: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t121_n103;
  t121_n96: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t121_n102;
  t121_n97: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t121_n99;
  t121_n98: return 0.04537766054272652f;
  t121_n99: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t121_n101;
  t121_n100: return -0.10286005586385727f;
  t121_n101: return 0.1183018833398819f;
  t121_n102: return 0.04269244149327278f;
  t121_n103: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t121_n105;
  t121_n104: return 0.1604272425174713f;
  t121_n105: return 0.1307855248451233f;
  t121_n106: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t121_n110;
  t121_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t121_n109;
  t121_n108: return 0.0761164128780365f;
  t121_n109: return 0.11299784481525421f;
  t121_n110: return -0.1063123345375061f;
  t121_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t121_n113;
  t121_n112: return 0.09216956794261932f;
  t121_n113: return 0.09162356704473495f;
  t121_n114: return -0.09706656634807587f;
  t121_n115: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t121_n131;
  t121_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n124;
  t121_n117: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t121_n119;
  t121_n118: return 0.11880061775445938f;
  t121_n119: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t121_n121;
  t121_n120: return 0.07099207490682602f;
  t121_n121: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t121_n123;
  t121_n122: return 0.14416183531284332f;
  t121_n123: return -0.050913408398628235f;
  t121_n124: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t121_n128;
  t121_n125: if (E.getNumReferences() >= 3350572224 /*93017.5*/) goto t121_n127;
  t121_n126: return -0.11439347267150879f;
  t121_n127: return 0.10489355772733688f;
  t121_n128: if (E.getNumReferences() >= 3350564160 /*92954.5*/) goto t121_n130;
  t121_n129: return 0.13999700546264648f;
  t121_n130: return 0.061929695308208466f;
  t121_n131: if (E.getNumReferences() >= 3354462528 /*123410.5*/) goto t121_n133;
  t121_n132: return -0.1958032101392746f;
  t121_n133: return 0.11129455268383026f;
  t121_n134: return -0.02224287949502468f;
  t121_n135: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t121_n151;
  t121_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t121_n138;
  t121_n137: return -0.11286065727472305f;
  t121_n138: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t121_n150;
  t121_n139: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t121_n141;
  t121_n140: return 0.02464512176811695f;
  t121_n141: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n147;
  t121_n142: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t121_n146;
  t121_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n145;
  t121_n144: return 0.11873649805784225f;
  t121_n145: return 0.0834541916847229f;
  t121_n146: return 0.10146079957485199f;
  t121_n147: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t121_n149;
  t121_n148: return 0.06413096934556961f;
  t121_n149: return 0.12104043364524841f;
  t121_n150: return -0.018144046887755394f;
  t121_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t121_n153;
  t121_n152: return -0.0016389169031754136f;
  t121_n153: if (E.getNumReferences() >= 3360662464 /*212623.0*/) goto t121_n157;
  t121_n154: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t121_n156;
  t121_n155: return -0.34024569392204285f;
  t121_n156: return 0.06982045620679855f;
  t121_n157: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t121_n171;
  t121_n158: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t121_n170;
  t121_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n165;
  t121_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t121_n164;
  t121_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t121_n163;
  t121_n162: return -0.5412164330482483f;
  t121_n163: return -0.2057962715625763f;
  t121_n164: return -0.11200535297393799f;
  t121_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t121_n167;
  t121_n166: return -0.23994584381580353f;
  t121_n167: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t121_n169;
  t121_n168: return 0.08757229149341583f;
  t121_n169: return 0.014109600335359573f;
  t121_n170: return 0.09727024286985397f;
  t121_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t121_n173;
  t121_n172: return 0.028992824256420135f;
  t121_n173: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t121_n183;
  t121_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n182;
  t121_n175: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t121_n181;
  t121_n176: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n180;
  t121_n177: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t121_n179;
  t121_n178: return -0.11376678198575974f;
  t121_n179: return 0.11779148131608963f;
  t121_n180: return 0.0597439780831337f;
  t121_n181: return 0.06451418250799179f;
  t121_n182: return -0.24703523516654968f;
  t121_n183: return 0.12592624127864838f;
  t121_n184: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t121_n188;
  t121_n185: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t121_n187;
  t121_n186: return -0.1496889889240265f;
  t121_n187: return -0.37038150429725647f;
  t121_n188: if (E.getNumReferences() >= 3364158064 /*272339.5*/) goto t121_n202;
  t121_n189: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n191;
  t121_n190: return -0.0651002749800682f;
  t121_n191: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t121_n201;
  t121_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n200;
  t121_n193: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t121_n197;
  t121_n194: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t121_n196;
  t121_n195: return -0.1417653113603592f;
  t121_n196: return 0.14596281945705414f;
  t121_n197: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t121_n199;
  t121_n198: return 0.09223441034555435f;
  t121_n199: return 0.12854520976543427f;
  t121_n200: return 0.094652459025383f;
  t121_n201: return 0.04612626135349274f;
  t121_n202: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t121_n204;
  t121_n203: return -0.12916016578674316f;
  t121_n204: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t121_n232;
  t121_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t121_n207;
  t121_n206: return -0.07494128495454788f;
  t121_n207: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t121_n215;
  t121_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n214;
  t121_n209: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t121_n211;
  t121_n210: return 0.0645519569516182f;
  t121_n211: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t121_n213;
  t121_n212: return 0.09753041714429855f;
  t121_n213: return -0.058912813663482666f;
  t121_n214: return 0.05158914625644684f;
  t121_n215: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t121_n221;
  t121_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t121_n218;
  t121_n217: return -0.1017947718501091f;
  t121_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n220;
  t121_n219: return 0.12631365656852722f;
  t121_n220: return 0.057765062898397446f;
  t121_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t121_n231;
  t121_n222: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t121_n230;
  t121_n223: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t121_n225;
  t121_n224: return -0.02531570754945278f;
  t121_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t121_n227;
  t121_n226: return -0.5223464965820312f;
  t121_n227: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n229;
  t121_n228: return -0.17357368767261505f;
  t121_n229: return 0.05359027162194252f;
  t121_n230: return 0.0968577116727829f;
  t121_n231: return 0.17067889869213104f;
  t121_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n248;
  t121_n233: if (E.getNumReferences() >= 3366258096 /*337965.5*/) goto t121_n235;
  t121_n234: return -0.03846646100282669f;
  t121_n235: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t121_n239;
  t121_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t121_n238;
  t121_n237: return -0.08720789849758148f;
  t121_n238: return 0.009532937780022621f;
  t121_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t121_n241;
  t121_n240: return 0.07080162316560745f;
  t121_n241: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t121_n245;
  t121_n242: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n244;
  t121_n243: return 0.07263907045125961f;
  t121_n244: return 0.11601392179727554f;
  t121_n245: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t121_n247;
  t121_n246: return 0.09541334211826324f;
  t121_n247: return -0.4360460042953491f;
  t121_n248: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t121_n254;
  t121_n249: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t121_n253;
  t121_n250: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t121_n252;
  t121_n251: return -0.005449157208204269f;
  t121_n252: return -0.21968968212604523f;
  t121_n253: return 0.06720120459794998f;
  t121_n254: return -0.08902497589588165f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree122(const Example& E) {
  t122_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t122_n224;
  t122_n1: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t122_n223;
  t122_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t122_n220;
  t122_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t122_n5;
  t122_n4: return -0.00337641267105937f;
  t122_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t122_n27;
  t122_n6: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t122_n8;
  t122_n7: return -0.00714267510920763f;
  t122_n8: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t122_n10;
  t122_n9: return -0.002955490490421653f;
  t122_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t122_n24;
  t122_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t122_n23;
  t122_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t122_n14;
  t122_n13: return -0.09943527728319168f;
  t122_n14: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t122_n22;
  t122_n15: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t122_n17;
  t122_n16: return -0.6717197299003601f;
  t122_n17: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t122_n19;
  t122_n18: return 0.04343970865011215f;
  t122_n19: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t122_n21;
  t122_n20: return 0.11318942904472351f;
  t122_n21: return 0.027382833883166313f;
  t122_n22: return -0.10678087174892426f;
  t122_n23: return -0.11919289082288742f;
  t122_n24: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t122_n26;
  t122_n25: return -0.007768396288156509f;
  t122_n26: return 0.1125953271985054f;
  t122_n27: if (E.getNumReferences() >= 3305189376 /*2067.0*/) goto t122_n183;
  t122_n28: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t122_n56;
  t122_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t122_n35;
  t122_n30: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t122_n34;
  t122_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t122_n33;
  t122_n32: return -0.05049632489681244f;
  t122_n33: return 0.02280276268720627f;
  t122_n34: return -0.1050126850605011f;
  t122_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t122_n37;
  t122_n36: return -0.01992836780846119f;
  t122_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t122_n55;
  t122_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t122_n54;
  t122_n39: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t122_n41;
  t122_n40: return 0.03742225840687752f;
  t122_n41: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t122_n43;
  t122_n42: return 0.032055992633104324f;
  t122_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t122_n53;
  t122_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t122_n46;
  t122_n45: return -0.14418353140354156f;
  t122_n46: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t122_n48;
  t122_n47: return 0.08994279056787491f;
  t122_n48: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t122_n50;
  t122_n49: return -0.007478195242583752f;
  t122_n50: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t122_n52;
  t122_n51: return 0.1088041365146637f;
  t122_n52: return 0.019433530047535896f;
  t122_n53: return 0.020367048680782318f;
  t122_n54: return 0.0031054047867655754f;
  t122_n55: return -0.0005766264512203634f;
  t122_n56: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t122_n58;
  t122_n57: return 0.0016097330953925848f;
  t122_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t122_n132;
  t122_n59: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t122_n113;
  t122_n60: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t122_n64;
  t122_n61: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t122_n63;
  t122_n62: return -0.03559311479330063f;
  t122_n63: return 0.033557191491127014f;
  t122_n64: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t122_n100;
  t122_n65: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t122_n67;
  t122_n66: return 0.006152387708425522f;
  t122_n67: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t122_n69;
  t122_n68: return 0.07722695171833038f;
  t122_n69: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t122_n95;
  t122_n70: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t122_n90;
  t122_n71: if (E.getNumReferences() >= 3292233728 /*750.0*/) goto t122_n87;
  t122_n72: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t122_n80;
  t122_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t122_n75;
  t122_n74: return 0.031015891581773758f;
  t122_n75: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t122_n77;
  t122_n76: return 0.7931569814682007f;
  t122_n77: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t122_n79;
  t122_n78: return 0.1165679544210434f;
  t122_n79: return 0.10827359557151794f;
  t122_n80: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t122_n82;
  t122_n81: return 0.05242413282394409f;
  t122_n82: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t122_n84;
  t122_n83: return 0.032918531447649f;
  t122_n84: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t122_n86;
  t122_n85: return 0.10960261523723602f;
  t122_n86: return 0.05541666969656944f;
  t122_n87: if (E.getNumReferences() >= 3294003200 /*858.0*/) goto t122_n89;
  t122_n88: return 0.10163227468729019f;
  t122_n89: return 0.07892747968435287f;
  t122_n90: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t122_n92;
  t122_n91: return 0.14040090143680573f;
  t122_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t122_n94;
  t122_n93: return -1.0735070705413818f;
  t122_n94: return 0.11057841777801514f;
  t122_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t122_n99;
  t122_n96: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t122_n98;
  t122_n97: return -0.06271082907915115f;
  t122_n98: return 0.11679618060588837f;
  t122_n99: return 0.1127442717552185f;
  t122_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t122_n102;
  t122_n101: return 0.005813293159008026f;
  t122_n102: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t122_n112;
  t122_n103: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t122_n105;
  t122_n104: return 0.0008484457503072917f;
  t122_n105: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t122_n109;
  t122_n106: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t122_n108;
  t122_n107: return 0.06664413213729858f;
  t122_n108: return -0.06389165669679642f;
  t122_n109: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t122_n111;
  t122_n110: return 0.1130666509270668f;
  t122_n111: return -0.1170116513967514f;
  t122_n112: return 0.11095526069402695f;
  t122_n113: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n115;
  t122_n114: return -0.10202369093894958f;
  t122_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t122_n117;
  t122_n116: return -0.04994477704167366f;
  t122_n117: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t122_n131;
  t122_n118: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t122_n130;
  t122_n119: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t122_n123;
  t122_n120: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t122_n122;
  t122_n121: return 0.12147916853427887f;
  t122_n122: return 0.06767110526561737f;
  t122_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t122_n125;
  t122_n124: return -2.4678449630737305f;
  t122_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t122_n127;
  t122_n126: return -0.4913688600063324f;
  t122_n127: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t122_n129;
  t122_n128: return 0.1068556010723114f;
  t122_n129: return 0.06659799069166183f;
  t122_n130: return 0.11450798809528351f;
  t122_n131: return 0.02210543118417263f;
  t122_n132: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t122_n176;
  t122_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t122_n135;
  t122_n134: return -0.017749695107340813f;
  t122_n135: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t122_n171;
  t122_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t122_n166;
  t122_n137: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t122_n141;
  t122_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t122_n140;
  t122_n139: return -0.014384492300450802f;
  t122_n140: return 0.02366306632757187f;
  t122_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t122_n157;
  t122_n142: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t122_n144;
  t122_n143: return 0.05689803883433342f;
  t122_n144: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t122_n154;
  t122_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n147;
  t122_n146: return 0.08411693572998047f;
  t122_n147: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t122_n149;
  t122_n148: return -0.9293398261070251f;
  t122_n149: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t122_n151;
  t122_n150: return 0.11945788562297821f;
  t122_n151: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t122_n153;
  t122_n152: return 0.10121826082468033f;
  t122_n153: return 0.10770061612129211f;
  t122_n154: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t122_n156;
  t122_n155: return -0.16368988156318665f;
  t122_n156: return 0.09389559924602509f;
  t122_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t122_n159;
  t122_n158: return -0.04501825198531151f;
  t122_n159: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t122_n163;
  t122_n160: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t122_n162;
  t122_n161: return -0.06695260852575302f;
  t122_n162: return 0.07605402916669846f;
  t122_n163: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t122_n165;
  t122_n164: return 0.15924040973186493f;
  t122_n165: return 0.12300436943769455f;
  t122_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n168;
  t122_n167: return 0.13843730092048645f;
  t122_n168: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t122_n170;
  t122_n169: return 0.01110445149242878f;
  t122_n170: return 0.027091018855571747f;
  t122_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t122_n173;
  t122_n172: return -0.06890305876731873f;
  t122_n173: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t122_n175;
  t122_n174: return 0.04273722320795059f;
  t122_n175: return -0.041676148772239685f;
  t122_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n182;
  t122_n177: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t122_n181;
  t122_n178: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t122_n180;
  t122_n179: return -0.26468273997306824f;
  t122_n180: return 0.09720201790332794f;
  t122_n181: return -0.021195635199546814f;
  t122_n182: return 0.025617223232984543f;
  t122_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t122_n187;
  t122_n184: if (E.getNumReferences() >= 3305881600 /*2236.0*/) goto t122_n186;
  t122_n185: return 0.09719738364219666f;
  t122_n186: return -0.0016825146740302444f;
  t122_n187: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t122_n215;
  t122_n188: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t122_n198;
  t122_n189: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t122_n191;
  t122_n190: return 0.0795573741197586f;
  t122_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n197;
  t122_n192: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t122_n194;
  t122_n193: return 0.11495033651590347f;
  t122_n194: if (E.getNumReferences() >= 3359900416 /*200716.0*/) goto t122_n196;
  t122_n195: return 0.190157949924469f;
  t122_n196: return 0.10336281359195709f;
  t122_n197: return 0.08167044073343277f;
  t122_n198: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t122_n214;
  t122_n199: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t122_n201;
  t122_n200: return 0.049247000366449356f;
  t122_n201: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t122_n213;
  t122_n202: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t122_n204;
  t122_n203: return -0.18549659848213196f;
  t122_n204: if (E.getNumReferences() >= 3324282368 /*10529.5*/) goto t122_n208;
  t122_n205: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t122_n207;
  t122_n206: return 0.11528391391038895f;
  t122_n207: return 0.10224338620901108f;
  t122_n208: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n210;
  t122_n209: return -0.10058716684579849f;
  t122_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t122_n212;
  t122_n211: return 0.10524145513772964f;
  t122_n212: return 0.08453644067049026f;
  t122_n213: return 0.013556082732975483f;
  t122_n214: return 0.013235291466116905f;
  t122_n215: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t122_n217;
  t122_n216: return 0.0162896066904068f;
  t122_n217: if (E.getNumReferences() >= 3342575744 /*48040.5*/) goto t122_n219;
  t122_n218: return 0.0681162178516388f;
  t122_n219: return 0.11754170805215836f;
  t122_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t122_n222;
  t122_n221: return -0.00567244179546833f;
  t122_n222: return 0.006785525009036064f;
  t122_n223: return -0.04794328287243843f;
  t122_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t122_n236;
  t122_n225: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t122_n231;
  t122_n226: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t122_n230;
  t122_n227: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t122_n229;
  t122_n228: return -0.030524635687470436f;
  t122_n229: return 0.07403313368558884f;
  t122_n230: return -0.01143946684896946f;
  t122_n231: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t122_n235;
  t122_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t122_n234;
  t122_n233: return -0.005234685726463795f;
  t122_n234: return 0.036914221942424774f;
  t122_n235: return -0.025341080501675606f;
  t122_n236: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t122_n242;
  t122_n237: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t122_n239;
  t122_n238: return 0.0871398001909256f;
  t122_n239: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t122_n241;
  t122_n240: return -0.20487385988235474f;
  t122_n241: return 0.09269776940345764f;
  t122_n242: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t122_n244;
  t122_n243: return -0.09408969432115555f;
  t122_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n254;
  t122_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t122_n251;
  t122_n246: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t122_n250;
  t122_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t122_n249;
  t122_n248: return 0.0028658187948167324f;
  t122_n249: return 0.06656645238399506f;
  t122_n250: return 0.07479199022054672f;
  t122_n251: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t122_n253;
  t122_n252: return 0.10331472754478455f;
  t122_n253: return 0.09081719815731049f;
  t122_n254: return 0.030133714899420738f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree123(const Example& E) {
  t123_n0: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t123_n128;
  t123_n1: if (E.getNumReferences() >= 3358365376 /*176731.0*/) goto t123_n127;
  t123_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t123_n44;
  t123_n3: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t123_n5;
  t123_n4: return -0.00433315709233284f;
  t123_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t123_n9;
  t123_n6: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t123_n8;
  t123_n7: return 0.0060534849762916565f;
  t123_n8: return -0.019019780680537224f;
  t123_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t123_n11;
  t123_n10: return 0.020910656079649925f;
  t123_n11: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t123_n43;
  t123_n12: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t123_n16;
  t123_n13: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t123_n15;
  t123_n14: return 0.21037757396697998f;
  t123_n15: return 0.11434727907180786f;
  t123_n16: if (E.getFileProximityDistance() >= 3254255616 /*31.0*/) goto t123_n34;
  t123_n17: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t123_n33;
  t123_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t123_n20;
  t123_n19: return -0.01605822704732418f;
  t123_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t123_n26;
  t123_n21: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t123_n25;
  t123_n22: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t123_n24;
  t123_n23: return -0.1514359712600708f;
  t123_n24: return -1.7857098579406738f;
  t123_n25: return 0.12753848731517792f;
  t123_n26: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t123_n32;
  t123_n27: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t123_n29;
  t123_n28: return 0.1105390191078186f;
  t123_n29: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t123_n31;
  t123_n30: return 0.07874608784914017f;
  t123_n31: return -0.2027072161436081f;
  t123_n32: return 0.037151310592889786f;
  t123_n33: return 0.051518380641937256f;
  t123_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t123_n38;
  t123_n35: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t123_n37;
  t123_n36: return -0.059207573533058167f;
  t123_n37: return 0.04294084385037422f;
  t123_n38: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t123_n42;
  t123_n39: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t123_n41;
  t123_n40: return 0.08230346441268921f;
  t123_n41: return 0.1068190187215805f;
  t123_n42: return 0.018338076770305634f;
  t123_n43: return -0.00967724621295929f;
  t123_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t123_n116;
  t123_n45: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t123_n85;
  t123_n46: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t123_n48;
  t123_n47: return -0.023467110469937325f;
  t123_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t123_n54;
  t123_n49: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t123_n53;
  t123_n50: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t123_n52;
  t123_n51: return -0.09306753426790237f;
  t123_n52: return -0.17064695060253143f;
  t123_n53: return -0.0008029698510654271f;
  t123_n54: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t123_n84;
  t123_n55: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t123_n79;
  t123_n56: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t123_n58;
  t123_n57: return 0.02530818246304989f;
  t123_n58: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t123_n60;
  t123_n59: return -0.16064460575580597f;
  t123_n60: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t123_n78;
  t123_n61: if (E.getNumReferences() >= 3273162752 /*152.5*/) goto t123_n77;
  t123_n62: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t123_n72;
  t123_n63: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t123_n67;
  t123_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t123_n66;
  t123_n65: return -0.0659472644329071f;
  t123_n66: return -0.6103721857070923f;
  t123_n67: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t123_n71;
  t123_n68: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t123_n70;
  t123_n69: return 0.08934111148118973f;
  t123_n70: return 0.17515027523040771f;
  t123_n71: return -0.07875999808311462f;
  t123_n72: if (E.getNumReferences() >= 3260153856 /*52.5*/) goto t123_n74;
  t123_n73: return 0.13051164150238037f;
  t123_n74: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t123_n76;
  t123_n75: return 0.07344110310077667f;
  t123_n76: return -0.03118104487657547f;
  t123_n77: return -0.19536727666854858f;
  t123_n78: return 0.09703115373849869f;
  t123_n79: if (E.getNumReferences() >= 3292962816 /*794.5*/) goto t123_n81;
  t123_n80: return 0.11384545266628265f;
  t123_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t123_n83;
  t123_n82: return -0.3516378402709961f;
  t123_n83: return 0.09441978484392166f;
  t123_n84: return 0.0022419202141463757f;
  t123_n85: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t123_n113;
  t123_n86: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t123_n90;
  t123_n87: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n89;
  t123_n88: return -0.041483502835035324f;
  t123_n89: return -0.010422604158520699f;
  t123_n90: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t123_n92;
  t123_n91: return -0.094046451151371f;
  t123_n92: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t123_n96;
  t123_n93: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t123_n95;
  t123_n94: return 0.12640592455863953f;
  t123_n95: return 0.03581729531288147f;
  t123_n96: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t123_n100;
  t123_n97: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t123_n99;
  t123_n98: return -0.418911337852478f;
  t123_n99: return 0.09272754192352295f;
  t123_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n102;
  t123_n101: return -0.757485568523407f;
  t123_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t123_n112;
  t123_n103: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t123_n109;
  t123_n104: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t123_n106;
  t123_n105: return 0.008663039654493332f;
  t123_n106: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t123_n108;
  t123_n107: return 0.1215401366353035f;
  t123_n108: return -2.746586799621582f;
  t123_n109: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t123_n111;
  t123_n110: return 0.11229239404201508f;
  t123_n111: return 0.07403956353664398f;
  t123_n112: return 0.08508092910051346f;
  t123_n113: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t123_n115;
  t123_n114: return -0.4396460950374603f;
  t123_n115: return -0.0713634192943573f;
  t123_n116: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t123_n126;
  t123_n117: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t123_n119;
  t123_n118: return -0.0037201433442533016f;
  t123_n119: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t123_n121;
  t123_n120: return 0.004021233879029751f;
  t123_n121: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t123_n123;
  t123_n122: return 0.017264163121581078f;
  t123_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t123_n125;
  t123_n124: return 0.08247751742601395f;
  t123_n125: return -0.0005136454710736871f;
  t123_n126: return 0.00654307845979929f;
  t123_n127: return -0.14226825535297394f;
  t123_n128: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t123_n164;
  t123_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t123_n131;
  t123_n130: return -0.07721345871686935f;
  t123_n131: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t123_n133;
  t123_n132: return -0.05203079804778099f;
  t123_n133: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t123_n139;
  t123_n134: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t123_n136;
  t123_n135: return 0.03911077231168747f;
  t123_n136: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t123_n138;
  t123_n137: return 0.10357656329870224f;
  t123_n138: return 0.08463110774755478f;
  t123_n139: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t123_n161;
  t123_n140: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t123_n152;
  t123_n141: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t123_n151;
  t123_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t123_n150;
  t123_n143: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t123_n145;
  t123_n144: return 0.06611701101064682f;
  t123_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n147;
  t123_n146: return 0.08438672870397568f;
  t123_n147: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t123_n149;
  t123_n148: return 0.10443763434886932f;
  t123_n149: return -0.026957539841532707f;
  t123_n150: return 0.03477137163281441f;
  t123_n151: return 0.04489578679203987f;
  t123_n152: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t123_n154;
  t123_n153: return -0.3026442229747772f;
  t123_n154: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t123_n160;
  t123_n155: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t123_n157;
  t123_n156: return 0.08983970433473587f;
  t123_n157: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t123_n159;
  t123_n158: return 0.10500462353229523f;
  t123_n159: return 0.10696935653686523f;
  t123_n160: return 0.048522576689720154f;
  t123_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t123_n163;
  t123_n162: return -0.062332961708307266f;
  t123_n163: return 0.06915168464183807f;
  t123_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t123_n166;
  t123_n165: return -0.0064353072084486485f;
  t123_n166: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t123_n210;
  t123_n167: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t123_n209;
  t123_n168: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t123_n202;
  t123_n169: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t123_n171;
  t123_n170: return -0.011273867450654507f;
  t123_n171: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t123_n173;
  t123_n172: return -0.13726706802845f;
  t123_n173: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t123_n185;
  t123_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t123_n182;
  t123_n175: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n177;
  t123_n176: return 0.045721907168626785f;
  t123_n177: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t123_n179;
  t123_n178: return 0.013118487782776356f;
  t123_n179: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t123_n181;
  t123_n180: return 0.08190584182739258f;
  t123_n181: return -0.02778971567749977f;
  t123_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t123_n184;
  t123_n183: return -0.12755027413368225f;
  t123_n184: return 0.10317441821098328f;
  t123_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t123_n199;
  t123_n186: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t123_n198;
  t123_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n189;
  t123_n188: return 0.015019144862890244f;
  t123_n189: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t123_n197;
  t123_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t123_n194;
  t123_n191: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t123_n193;
  t123_n192: return 0.08207014203071594f;
  t123_n193: return -0.2383783459663391f;
  t123_n194: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t123_n196;
  t123_n195: return 0.11371021717786789f;
  t123_n196: return -0.25231125950813293f;
  t123_n197: return 0.001285133883357048f;
  t123_n198: return -0.3856939971446991f;
  t123_n199: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n201;
  t123_n200: return 0.09294728934764862f;
  t123_n201: return 0.06019655615091324f;
  t123_n202: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t123_n208;
  t123_n203: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n207;
  t123_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t123_n206;
  t123_n205: return 0.09138273447751999f;
  t123_n206: return 0.11163540929555893f;
  t123_n207: return -0.002461845986545086f;
  t123_n208: return 0.09895333647727966f;
  t123_n209: return -0.07402161508798599f;
  t123_n210: if (E.getNumReferences() >= 3364768256 /*291408.0*/) goto t123_n212;
  t123_n211: return -0.009782373905181885f;
  t123_n212: if (E.getNumReferences() >= 3368655888 /*412896.5*/) goto t123_n240;
  t123_n213: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t123_n237;
  t123_n214: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t123_n226;
  t123_n215: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t123_n225;
  t123_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t123_n224;
  t123_n217: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t123_n219;
  t123_n218: return 0.06270851939916611f;
  t123_n219: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t123_n221;
  t123_n220: return -0.0383063405752182f;
  t123_n221: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t123_n223;
  t123_n222: return 0.007637991104274988f;
  t123_n223: return 0.08539023995399475f;
  t123_n224: return -0.06285233795642853f;
  t123_n225: return 0.027267057448625565f;
  t123_n226: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t123_n230;
  t123_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t123_n229;
  t123_n228: return -0.6029350161552429f;
  t123_n229: return -0.025518380105495453f;
  t123_n230: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t123_n232;
  t123_n231: return 0.011735408566892147f;
  t123_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t123_n234;
  t123_n233: return -0.2548428177833557f;
  t123_n234: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t123_n236;
  t123_n235: return 0.1071246862411499f;
  t123_n236: return 0.08277123421430588f;
  t123_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t123_n239;
  t123_n238: return 0.1004863977432251f;
  t123_n239: return 0.10207395255565643f;
  t123_n240: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t123_n244;
  t123_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t123_n243;
  t123_n242: return -0.014967148192226887f;
  t123_n243: return -0.2570604383945465f;
  t123_n244: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t123_n252;
  t123_n245: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t123_n247;
  t123_n246: return 0.08351768553256989f;
  t123_n247: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t123_n249;
  t123_n248: return 0.017161648720502853f;
  t123_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t123_n251;
  t123_n250: return 0.06853078305721283f;
  t123_n251: return 0.09682799875736237f;
  t123_n252: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t123_n254;
  t123_n253: return -0.001434783567674458f;
  t123_n254: return 0.02996240369975567f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree124(const Example& E) {
  t124_n0: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t124_n130;
  t124_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t124_n3;
  t124_n2: return -0.020896567031741142f;
  t124_n3: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t124_n109;
  t124_n4: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t124_n6;
  t124_n5: return -0.0050608813762664795f;
  t124_n6: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t124_n12;
  t124_n7: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t124_n11;
  t124_n8: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t124_n10;
  t124_n9: return -0.0995188057422638f;
  t124_n10: return 0.09981288015842438f;
  t124_n11: return 0.036035697907209396f;
  t124_n12: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t124_n52;
  t124_n13: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t124_n15;
  t124_n14: return 0.010122710838913918f;
  t124_n15: if (E.getNumReferences() >= 3347692736 /*70521.5*/) goto t124_n51;
  t124_n16: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t124_n18;
  t124_n17: return 0.0069194938987493515f;
  t124_n18: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t124_n42;
  t124_n19: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t124_n35;
  t124_n20: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t124_n22;
  t124_n21: return 0.030142972245812416f;
  t124_n22: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t124_n26;
  t124_n23: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t124_n25;
  t124_n24: return 0.10956933349370956f;
  t124_n25: return -0.060833752155303955f;
  t124_n26: if (E.getNumReferences() >= 3252158464 /*27.0*/) goto t124_n28;
  t124_n27: return 0.14408306777477264f;
  t124_n28: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t124_n34;
  t124_n29: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t124_n31;
  t124_n30: return 0.03991539403796196f;
  t124_n31: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t124_n33;
  t124_n32: return 0.11306992918252945f;
  t124_n33: return 0.09016381204128265f;
  t124_n34: return 0.04929221048951149f;
  t124_n35: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t124_n39;
  t124_n36: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t124_n38;
  t124_n37: return 0.09571623057126999f;
  t124_n38: return 0.14735710620880127f;
  t124_n39: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t124_n41;
  t124_n40: return -0.010509354993700981f;
  t124_n41: return 0.11881177127361298f;
  t124_n42: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t124_n50;
  t124_n43: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t124_n45;
  t124_n44: return -0.034161560237407684f;
  t124_n45: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t124_n49;
  t124_n46: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t124_n48;
  t124_n47: return 0.11967784911394119f;
  t124_n48: return -0.15275612473487854f;
  t124_n49: return 0.034412916749715805f;
  t124_n50: return -0.10339276492595673f;
  t124_n51: return 0.11865227669477463f;
  t124_n52: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t124_n100;
  t124_n53: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t124_n85;
  t124_n54: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n56;
  t124_n55: return -0.037345144897699356f;
  t124_n56: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t124_n80;
  t124_n57: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t124_n73;
  t124_n58: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t124_n70;
  t124_n59: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t124_n61;
  t124_n60: return 0.07193496823310852f;
  t124_n61: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t124_n63;
  t124_n62: return 0.02121904492378235f;
  t124_n63: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t124_n69;
  t124_n64: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t124_n68;
  t124_n65: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t124_n67;
  t124_n66: return 0.1085951179265976f;
  t124_n67: return 0.13527730107307434f;
  t124_n68: return 0.04856189340353012f;
  t124_n69: return 0.10202700644731522f;
  t124_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t124_n72;
  t124_n71: return -2.5147597789764404f;
  t124_n72: return 0.014663285575807095f;
  t124_n73: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t124_n75;
  t124_n74: return 0.10377860814332962f;
  t124_n75: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t124_n79;
  t124_n76: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t124_n78;
  t124_n77: return 0.627682626247406f;
  t124_n78: return 0.09140121191740036f;
  t124_n79: return 0.11427227407693863f;
  t124_n80: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t124_n84;
  t124_n81: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t124_n83;
  t124_n82: return 0.12068520486354828f;
  t124_n83: return -0.25836411118507385f;
  t124_n84: return -0.014673622325062752f;
  t124_n85: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t124_n99;
  t124_n86: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t124_n88;
  t124_n87: return 0.06720764189958572f;
  t124_n88: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t124_n96;
  t124_n89: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t124_n95;
  t124_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t124_n92;
  t124_n91: return -0.10185080766677856f;
  t124_n92: if (E.getNumReferences() >= 3279060992 /*242.5*/) goto t124_n94;
  t124_n93: return 1.642093539237976f;
  t124_n94: return 0.11695287376642227f;
  t124_n95: return -0.11335495859384537f;
  t124_n96: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t124_n98;
  t124_n97: return 0.13075275719165802f;
  t124_n98: return 0.06508241593837738f;
  t124_n99: return -0.11348243057727814f;
  t124_n100: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t124_n102;
  t124_n101: return -0.042523618787527084f;
  t124_n102: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n108;
  t124_n103: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t124_n107;
  t124_n104: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t124_n106;
  t124_n105: return 0.18056900799274445f;
  t124_n106: return 0.1251317411661148f;
  t124_n107: return 0.07032786309719086f;
  t124_n108: return 0.02277163229882717f;
  t124_n109: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t124_n111;
  t124_n110: return 0.0032555803190916777f;
  t124_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t124_n113;
  t124_n112: return -0.07034942507743835f;
  t124_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t124_n121;
  t124_n114: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t124_n116;
  t124_n115: return 0.014294841326773167f;
  t124_n116: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t124_n120;
  t124_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t124_n119;
  t124_n118: return 0.014823627658188343f;
  t124_n119: return 0.042839791625738144f;
  t124_n120: return 0.006180221680551767f;
  t124_n121: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t124_n129;
  t124_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n128;
  t124_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t124_n127;
  t124_n124: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t124_n126;
  t124_n125: return 0.10382474958896637f;
  t124_n126: return 0.07655324786901474f;
  t124_n127: return 0.10333442687988281f;
  t124_n128: return 0.07403696328401566f;
  t124_n129: return -0.042834147810935974f;
  t124_n130: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t124_n132;
  t124_n131: return -0.05767954885959625f;
  t124_n132: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t124_n254;
  t124_n133: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t124_n253;
  t124_n134: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t124_n196;
  t124_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t124_n137;
  t124_n136: return 0.0021232357248663902f;
  t124_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t124_n139;
  t124_n138: return 0.0004246726748533547f;
  t124_n139: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t124_n141;
  t124_n140: return 0.010111787356436253f;
  t124_n141: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t124_n149;
  t124_n142: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t124_n148;
  t124_n143: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t124_n145;
  t124_n144: return -0.011212768033146858f;
  t124_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t124_n147;
  t124_n146: return -0.08199531584978104f;
  t124_n147: return -0.01922149956226349f;
  t124_n148: return 0.014394101686775684f;
  t124_n149: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t124_n153;
  t124_n150: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t124_n152;
  t124_n151: return -0.02703022211790085f;
  t124_n152: return 0.08627358824014664f;
  t124_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t124_n187;
  t124_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t124_n158;
  t124_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t124_n157;
  t124_n156: return -0.026787525042891502f;
  t124_n157: return 0.047638073563575745f;
  t124_n158: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t124_n160;
  t124_n159: return 0.07336004078388214f;
  t124_n160: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t124_n186;
  t124_n161: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t124_n167;
  t124_n162: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t124_n166;
  t124_n163: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t124_n165;
  t124_n164: return 0.08559101819992065f;
  t124_n165: return 0.12411387264728546f;
  t124_n166: return -0.0674724131822586f;
  t124_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n185;
  t124_n168: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t124_n184;
  t124_n169: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t124_n179;
  t124_n170: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t124_n172;
  t124_n171: return -0.13514874875545502f;
  t124_n172: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t124_n174;
  t124_n173: return 0.12346110492944717f;
  t124_n174: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t124_n176;
  t124_n175: return 0.03196222335100174f;
  t124_n176: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t124_n178;
  t124_n177: return 0.12407013028860092f;
  t124_n178: return -0.13480322062969208f;
  t124_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t124_n181;
  t124_n180: return 0.14051911234855652f;
  t124_n181: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t124_n183;
  t124_n182: return 0.1343545764684677f;
  t124_n183: return 0.15086470544338226f;
  t124_n184: return -0.05078578740358353f;
  t124_n185: return 0.0901794359087944f;
  t124_n186: return 0.010290198028087616f;
  t124_n187: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n195;
  t124_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t124_n190;
  t124_n189: return -0.03247556462883949f;
  t124_n190: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t124_n192;
  t124_n191: return 0.09683816134929657f;
  t124_n192: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t124_n194;
  t124_n193: return -0.011684909462928772f;
  t124_n194: return 0.11404728889465332f;
  t124_n195: return 0.013109708204865456f;
  t124_n196: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t124_n198;
  t124_n197: return -0.017045004293322563f;
  t124_n198: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t124_n214;
  t124_n199: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t124_n213;
  t124_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t124_n202;
  t124_n201: return -0.060662347823381424f;
  t124_n202: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t124_n204;
  t124_n203: return 0.0045723142102360725f;
  t124_n204: if (E.getNumReferences() >= 3314682880 /*4673.5*/) goto t124_n206;
  t124_n205: return 0.013563672080636024f;
  t124_n206: if (E.getNumReferences() >= 3315159040 /*4906.0*/) goto t124_n212;
  t124_n207: if (E.getNumReferences() >= 3315124224 /*4889.0*/) goto t124_n209;
  t124_n208: return 0.07269328832626343f;
  t124_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n211;
  t124_n210: return 0.10784521698951721f;
  t124_n211: return 0.12461785227060318f;
  t124_n212: return 0.02735866978764534f;
  t124_n213: return -0.0028372874949127436f;
  t124_n214: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t124_n250;
  t124_n215: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t124_n249;
  t124_n216: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t124_n230;
  t124_n217: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t124_n219;
  t124_n218: return -0.022033998742699623f;
  t124_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t124_n225;
  t124_n220: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t124_n224;
  t124_n221: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t124_n223;
  t124_n222: return 0.029283858835697174f;
  t124_n223: return 0.09068386256694794f;
  t124_n224: return 0.0527169331908226f;
  t124_n225: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t124_n229;
  t124_n226: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t124_n228;
  t124_n227: return -0.35043972730636597f;
  t124_n228: return 0.13569721579551697f;
  t124_n229: return 0.06926409155130386f;
  t124_n230: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n236;
  t124_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t124_n233;
  t124_n232: return 0.05748164281249046f;
  t124_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t124_n235;
  t124_n234: return 0.0911215990781784f;
  t124_n235: return 0.11589568853378296f;
  t124_n236: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t124_n238;
  t124_n237: return 0.05178854614496231f;
  t124_n238: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t124_n240;
  t124_n239: return -0.07367116957902908f;
  t124_n240: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t124_n246;
  t124_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t124_n245;
  t124_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t124_n244;
  t124_n243: return -0.6372920870780945f;
  t124_n244: return 0.10688463598489761f;
  t124_n245: return 0.11981471627950668f;
  t124_n246: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t124_n248;
  t124_n247: return 0.08757530152797699f;
  t124_n248: return 0.12087096273899078f;
  t124_n249: return -0.022800562903285027f;
  t124_n250: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t124_n252;
  t124_n251: return 0.05286682769656181f;
  t124_n252: return 0.0337362177670002f;
  t124_n253: return -0.09848681092262268f;
  t124_n254: return -0.06376885622739792f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree125(const Example& E) {
  t125_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t125_n2;
  t125_n1: return -0.0005637154681608081f;
  t125_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t125_n12;
  t125_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t125_n5;
  t125_n4: return 0.009199585765600204f;
  t125_n5: if (E.getNumReferences() >= 3300909056 /*1535.0*/) goto t125_n7;
  t125_n6: return -0.010147254914045334f;
  t125_n7: if (E.getNumReferences() >= 3300937728 /*1538.5*/) goto t125_n11;
  t125_n8: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t125_n10;
  t125_n9: return -0.11384525150060654f;
  t125_n10: return 0.1334943026304245f;
  t125_n11: return 0.027145465835928917f;
  t125_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t125_n14;
  t125_n13: return -0.00973731279373169f;
  t125_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t125_n62;
  t125_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t125_n61;
  t125_n16: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t125_n54;
  t125_n17: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n25;
  t125_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t125_n24;
  t125_n19: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t125_n21;
  t125_n20: return 0.10878061503171921f;
  t125_n21: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t125_n23;
  t125_n22: return -0.07899052649736404f;
  t125_n23: return -0.40743541717529297f;
  t125_n24: return 0.00523192435503006f;
  t125_n25: if (E.getNumReferences() >= 3349697792 /*86186.0*/) goto t125_n49;
  t125_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t125_n28;
  t125_n27: return 0.011177174746990204f;
  t125_n28: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t125_n48;
  t125_n29: if (E.getNumReferences() >= 3300868096 /*1530.0*/) goto t125_n35;
  t125_n30: if (E.getNumReferences() >= 3299028992 /*1305.5*/) goto t125_n32;
  t125_n31: return -0.1261858344078064f;
  t125_n32: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t125_n34;
  t125_n33: return 0.10915057361125946f;
  t125_n34: return 0.1331447958946228f;
  t125_n35: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t125_n39;
  t125_n36: if (E.getNumReferences() >= 3344932992 /*57248.5*/) goto t125_n38;
  t125_n37: return -0.008332254365086555f;
  t125_n38: return 0.14137254655361176f;
  t125_n39: if (E.getNumReferences() >= 3322808320 /*9090.0*/) goto t125_n43;
  t125_n40: if (E.getNumReferences() >= 3307612160 /*2658.5*/) goto t125_n42;
  t125_n41: return -0.5645287036895752f;
  t125_n42: return 0.11575573682785034f;
  t125_n43: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t125_n47;
  t125_n44: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t125_n46;
  t125_n45: return -0.052750058472156525f;
  t125_n46: return 0.09290187805891037f;
  t125_n47: return -0.27792230248451233f;
  t125_n48: return 0.0011099730618298054f;
  t125_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t125_n53;
  t125_n50: if (E.getNumReferences() >= 3350811072 /*94883.5*/) goto t125_n52;
  t125_n51: return 0.09590713679790497f;
  t125_n52: return 0.02781890332698822f;
  t125_n53: return 0.11022662371397018f;
  t125_n54: if (E.getNumReferences() >= 3375821112 /*749331.5*/) goto t125_n60;
  t125_n55: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t125_n57;
  t125_n56: return -0.04730561003088951f;
  t125_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t125_n59;
  t125_n58: return -0.10182526707649231f;
  t125_n59: return 0.02003094181418419f;
  t125_n60: return 0.016195302829146385f;
  t125_n61: return 0.0562780387699604f;
  t125_n62: if (E.getNumReferences() >= 3360630592 /*212125.0*/) goto t125_n252;
  t125_n63: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t125_n251;
  t125_n64: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t125_n74;
  t125_n65: if (E.getNumReferences() >= 3332134144 /*20010.5*/) goto t125_n67;
  t125_n66: return -0.012733710929751396f;
  t125_n67: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t125_n71;
  t125_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t125_n70;
  t125_n69: return -0.28092533349990845f;
  t125_n70: return 0.11567599326372147f;
  t125_n71: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t125_n73;
  t125_n72: return 0.03243936598300934f;
  t125_n73: return 0.004524259362369776f;
  t125_n74: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t125_n244;
  t125_n75: if (E.getNumReferences() >= 3346171648 /*62087.0*/) goto t125_n241;
  t125_n76: if (E.getNumReferences() >= 3315681280 /*5161.0*/) goto t125_n78;
  t125_n77: return 0.009753653779625893f;
  t125_n78: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t125_n88;
  t125_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t125_n85;
  t125_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t125_n82;
  t125_n81: return -0.1499626636505127f;
  t125_n82: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t125_n84;
  t125_n83: return 0.11693571507930756f;
  t125_n84: return -0.13528883457183838f;
  t125_n85: if (E.getNumReferences() >= 3315727360 /*5183.5*/) goto t125_n87;
  t125_n86: return 0.10011856257915497f;
  t125_n87: return 0.13095353543758392f;
  t125_n88: if (E.getNumReferences() >= 3333845504 /*23353.0*/) goto t125_n170;
  t125_n89: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t125_n125;
  t125_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t125_n92;
  t125_n91: return 0.024829713627696037f;
  t125_n92: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t125_n96;
  t125_n93: if (E.getNumReferences() >= 3321171968 /*7842.0*/) goto t125_n95;
  t125_n94: return 0.13847936689853668f;
  t125_n95: return -0.4016248881816864f;
  t125_n96: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t125_n116;
  t125_n97: if (E.getNumReferences() >= 3318849536 /*6708.0*/) goto t125_n105;
  t125_n98: if (E.getNumReferences() >= 3318293504 /*6436.5*/) goto t125_n104;
  t125_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t125_n101;
  t125_n100: return 0.08662443608045578f;
  t125_n101: if (E.getNumReferences() >= 3317264384 /*5934.0*/) goto t125_n103;
  t125_n102: return 0.12218739837408066f;
  t125_n103: return 0.051246099174022675f;
  t125_n104: return 0.10669324547052383f;
  t125_n105: if (E.getNumReferences() >= 3327376384 /*13551.0*/) goto t125_n107;
  t125_n106: return -0.020247332751750946f;
  t125_n107: if (E.getNumReferences() >= 3327536128 /*13707.0*/) goto t125_n109;
  t125_n108: return 0.1267378330230713f;
  t125_n109: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t125_n111;
  t125_n110: return -0.3748004734516144f;
  t125_n111: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t125_n113;
  t125_n112: return 0.11210978031158447f;
  t125_n113: if (E.getNumReferences() >= 3329434624 /*15561.0*/) goto t125_n115;
  t125_n114: return -0.4744958281517029f;
  t125_n115: return 0.1408231556415558f;
  t125_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t125_n118;
  t125_n117: return 0.019836166873574257f;
  t125_n118: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t125_n124;
  t125_n119: if (E.getNumReferences() >= 3324154880 /*10405.0*/) goto t125_n121;
  t125_n120: return 0.11084577441215515f;
  t125_n121: if (E.getNumReferences() >= 3326979584 /*13163.5*/) goto t125_n123;
  t125_n122: return 0.13542814552783966f;
  t125_n123: return 0.27585968375205994f;
  t125_n124: return 0.049238838255405426f;
  t125_n125: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t125_n133;
  t125_n126: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t125_n132;
  t125_n127: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t125_n131;
  t125_n128: if (E.getNumReferences() >= 3331533568 /*18837.5*/) goto t125_n130;
  t125_n129: return 0.12329771369695663f;
  t125_n130: return -0.009945327416062355f;
  t125_n131: return 0.0789128765463829f;
  t125_n132: return 0.12166270613670349f;
  t125_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t125_n161;
  t125_n134: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t125_n150;
  t125_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t125_n137;
  t125_n136: return -0.013954248279333115f;
  t125_n137: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t125_n139;
  t125_n138: return 0.037484701722860336f;
  t125_n139: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t125_n141;
  t125_n140: return 0.04978246986865997f;
  t125_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t125_n149;
  t125_n142: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t125_n148;
  t125_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t125_n145;
  t125_n144: return 0.073585644364357f;
  t125_n145: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t125_n147;
  t125_n146: return 0.10740593820810318f;
  t125_n147: return 0.1326887309551239f;
  t125_n148: return 0.055981989949941635f;
  t125_n149: return 0.11343348771333694f;
  t125_n150: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t125_n160;
  t125_n151: if (E.getNumReferences() >= 3333150720 /*21996.0*/) goto t125_n159;
  t125_n152: if (E.getNumReferences() >= 3332141568 /*20025.0*/) goto t125_n154;
  t125_n153: return -0.022221030667424202f;
  t125_n154: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t125_n156;
  t125_n155: return 0.051976364105939865f;
  t125_n156: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n158;
  t125_n157: return 0.18335220217704773f;
  t125_n158: return 0.1581178456544876f;
  t125_n159: return 0.11904427409172058f;
  t125_n160: return 0.03777940198779106f;
  t125_n161: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t125_n163;
  t125_n162: return 0.07177601009607315f;
  t125_n163: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t125_n165;
  t125_n164: return 0.10323023796081543f;
  t125_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t125_n167;
  t125_n166: return -0.5143533945083618f;
  t125_n167: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t125_n169;
  t125_n168: return 0.11588083207607269f;
  t125_n169: return 0.02650080807507038f;
  t125_n170: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t125_n172;
  t125_n171: return -0.035940416157245636f;
  t125_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t125_n196;
  t125_n173: if (E.getNumReferences() >= 3339403904 /*35650.5*/) goto t125_n193;
  t125_n174: if (E.getNumReferences() >= 3339274880 /*35146.5*/) goto t125_n188;
  t125_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t125_n177;
  t125_n176: return 0.0008422802784480155f;
  t125_n177: if (E.getNumReferences() >= 3338881664 /*33610.5*/) goto t125_n187;
  t125_n178: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t125_n186;
  t125_n179: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t125_n185;
  t125_n180: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t125_n182;
  t125_n181: return -0.34606438875198364f;
  t125_n182: if (E.getNumReferences() >= 3338840320 /*33449.0*/) goto t125_n184;
  t125_n183: return 0.046466197818517685f;
  t125_n184: return 0.11699489504098892f;
  t125_n185: return 0.11950990557670593f;
  t125_n186: return 0.11798810213804245f;
  t125_n187: return 0.028896372765302658f;
  t125_n188: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n192;
  t125_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t125_n191;
  t125_n190: return 0.08272868394851685f;
  t125_n191: return 0.12919901311397552f;
  t125_n192: return -0.04765400290489197f;
  t125_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t125_n195;
  t125_n194: return -0.13993413746356964f;
  t125_n195: return -0.017008209601044655f;
  t125_n196: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t125_n198;
  t125_n197: return -0.05489268898963928f;
  t125_n198: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t125_n236;
  t125_n199: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t125_n225;
  t125_n200: if (E.getNumReferences() >= 3341306880 /*43084.0*/) goto t125_n204;
  t125_n201: if (E.getNumReferences() >= 3339235072 /*34991.0*/) goto t125_n203;
  t125_n202: return 0.06792664527893066f;
  t125_n203: return -0.15654367208480835f;
  t125_n204: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t125_n216;
  t125_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t125_n215;
  t125_n206: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t125_n214;
  t125_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t125_n209;
  t125_n208: return 0.10032469779253006f;
  t125_n209: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t125_n211;
  t125_n210: return 0.11447910964488983f;
  t125_n211: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n213;
  t125_n212: return 0.10599382221698761f;
  t125_n213: return 0.09464733302593231f;
  t125_n214: return 0.08089105039834976f;
  t125_n215: return -0.1366194784641266f;
  t125_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t125_n220;
  t125_n217: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t125_n219;
  t125_n218: return -0.0724717453122139f;
  t125_n219: return 0.08580578863620758f;
  t125_n220: if (E.getNumReferences() >= 3343171712 /*50368.5*/) goto t125_n222;
  t125_n221: return -0.11405692249536514f;
  t125_n222: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n224;
  t125_n223: return 0.1087941974401474f;
  t125_n224: return 0.09851793199777603f;
  t125_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t125_n227;
  t125_n226: return -0.010892890393733978f;
  t125_n227: if (E.getNumReferences() >= 3345871872 /*60916.0*/) goto t125_n229;
  t125_n228: return -0.024018313735723495f;
  t125_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t125_n235;
  t125_n230: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n234;
  t125_n231: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t125_n233;
  t125_n232: return 0.16506510972976685f;
  t125_n233: return 0.09420420974493027f;
  t125_n234: return 0.10135547071695328f;
  t125_n235: return 0.10685014724731445f;
  t125_n236: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t125_n238;
  t125_n237: return 0.019714215770363808f;
  t125_n238: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n240;
  t125_n239: return 0.12278103828430176f;
  t125_n240: return 0.08661378920078278f;
  t125_n241: if (E.getNumReferences() >= 3348207616 /*74544.0*/) goto t125_n243;
  t125_n242: return -0.07601060718297958f;
  t125_n243: return -0.010367942973971367f;
  t125_n244: if (E.getNumReferences() >= 3306448896 /*2374.5*/) goto t125_n246;
  t125_n245: return 0.005952934268862009f;
  t125_n246: if (E.getNumReferences() >= 3306622976 /*2417.0*/) goto t125_n250;
  t125_n247: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n249;
  t125_n248: return 0.1136278435587883f;
  t125_n249: return 0.03851057589054108f;
  t125_n250: return 0.04403729736804962f;
  t125_n251: return 0.03749065101146698f;
  t125_n252: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t125_n254;
  t125_n253: return 0.0006489047082141042f;
  t125_n254: return -0.042307689785957336f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree126(const Example& E) {
  t126_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t126_n216;
  t126_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t126_n61;
  t126_n2: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t126_n48;
  t126_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t126_n47;
  t126_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n6;
  t126_n5: return -0.008822734467685223f;
  t126_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t126_n8;
  t126_n7: return 0.008846553973853588f;
  t126_n8: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t126_n42;
  t126_n9: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t126_n41;
  t126_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t126_n14;
  t126_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t126_n13;
  t126_n12: return 0.009785561822354794f;
  t126_n13: return 0.0405304953455925f;
  t126_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t126_n16;
  t126_n15: return -0.15780645608901978f;
  t126_n16: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t126_n40;
  t126_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t126_n31;
  t126_n18: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t126_n30;
  t126_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t126_n23;
  t126_n20: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t126_n22;
  t126_n21: return 0.07260951399803162f;
  t126_n22: return 0.097422756254673f;
  t126_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n29;
  t126_n24: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t126_n28;
  t126_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t126_n27;
  t126_n26: return 0.07412230223417282f;
  t126_n27: return 0.09212172776460648f;
  t126_n28: return -0.0080293333157897f;
  t126_n29: return -0.04144708812236786f;
  t126_n30: return 0.12174052745103836f;
  t126_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t126_n33;
  t126_n32: return 0.05874788761138916f;
  t126_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n39;
  t126_n34: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t126_n36;
  t126_n35: return -0.06616085022687912f;
  t126_n36: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t126_n38;
  t126_n37: return 0.13623753190040588f;
  t126_n38: return -0.3684638440608978f;
  t126_n39: return 0.058814018964767456f;
  t126_n40: return 0.049112532287836075f;
  t126_n41: return 0.03658365458250046f;
  t126_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t126_n44;
  t126_n43: return -0.049485862255096436f;
  t126_n44: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t126_n46;
  t126_n45: return -0.00630435673519969f;
  t126_n46: return 0.03133440762758255f;
  t126_n47: return -0.005568749736994505f;
  t126_n48: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t126_n54;
  t126_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t126_n51;
  t126_n50: return 0.005894300527870655f;
  t126_n51: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t126_n53;
  t126_n52: return -0.1420665681362152f;
  t126_n53: return 0.025000395253300667f;
  t126_n54: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t126_n56;
  t126_n55: return 0.10747992992401123f;
  t126_n56: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t126_n60;
  t126_n57: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t126_n59;
  t126_n58: return 0.02434244565665722f;
  t126_n59: return 0.03864603117108345f;
  t126_n60: return 0.043412238359451294f;
  t126_n61: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t126_n63;
  t126_n62: return -0.008928303606808186f;
  t126_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t126_n103;
  t126_n64: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t126_n102;
  t126_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t126_n71;
  t126_n66: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t126_n68;
  t126_n67: return -0.04737340286374092f;
  t126_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t126_n70;
  t126_n69: return -0.2939850091934204f;
  t126_n70: return -0.001827917993068695f;
  t126_n71: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t126_n91;
  t126_n72: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t126_n90;
  t126_n73: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t126_n89;
  t126_n74: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t126_n78;
  t126_n75: if (E.getNumReferences() >= 3287728128 /*493.5*/) goto t126_n77;
  t126_n76: return 0.037169985473155975f;
  t126_n77: return -0.5693904161453247f;
  t126_n78: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t126_n88;
  t126_n79: if (E.getNumReferences() >= 3292397568 /*760.0*/) goto t126_n87;
  t126_n80: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n86;
  t126_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t126_n83;
  t126_n82: return -0.04541948810219765f;
  t126_n83: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t126_n85;
  t126_n84: return 0.1534135937690735f;
  t126_n85: return 0.05904470384120941f;
  t126_n86: return 0.0964607298374176f;
  t126_n87: return 0.10287586599588394f;
  t126_n88: return 0.06046068295836449f;
  t126_n89: return -0.11164644360542297f;
  t126_n90: return -0.013682711869478226f;
  t126_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n93;
  t126_n92: return 0.027389662340283394f;
  t126_n93: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t126_n101;
  t126_n94: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t126_n100;
  t126_n95: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t126_n97;
  t126_n96: return 0.07272951304912567f;
  t126_n97: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t126_n99;
  t126_n98: return 0.11706756055355072f;
  t126_n99: return -0.04786892980337143f;
  t126_n100: return 0.11768224090337753f;
  t126_n101: return 0.04524023458361626f;
  t126_n102: return -0.01273490022867918f;
  t126_n103: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t126_n205;
  t126_n104: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t126_n106;
  t126_n105: return 0.0013430019607767463f;
  t126_n106: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t126_n134;
  t126_n107: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t126_n115;
  t126_n108: if (E.getNumReferences() >= 3331557888 /*18885.0*/) goto t126_n110;
  t126_n109: return -0.023148639127612114f;
  t126_n110: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t126_n114;
  t126_n111: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n113;
  t126_n112: return 0.12388382107019424f;
  t126_n113: return -0.02188846468925476f;
  t126_n114: return 0.03868130221962929f;
  t126_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t126_n117;
  t126_n116: return 0.02076449990272522f;
  t126_n117: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n123;
  t126_n118: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t126_n120;
  t126_n119: return 0.04106396436691284f;
  t126_n120: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t126_n122;
  t126_n121: return 0.05658723786473274f;
  t126_n122: return 0.16305339336395264f;
  t126_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t126_n125;
  t126_n124: return 0.00611960981041193f;
  t126_n125: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n127;
  t126_n126: return 0.07506255805492401f;
  t126_n127: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t126_n133;
  t126_n128: if (E.getNumReferences() >= 3283468288 /*363.5*/) goto t126_n132;
  t126_n129: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t126_n131;
  t126_n130: return 0.19970528781414032f;
  t126_n131: return 0.0738551914691925f;
  t126_n132: return 0.008960568346083164f;
  t126_n133: return 0.10164233297109604f;
  t126_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t126_n136;
  t126_n135: return -0.0015841034473851323f;
  t126_n136: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n146;
  t126_n137: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t126_n145;
  t126_n138: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t126_n140;
  t126_n139: return -0.02359459176659584f;
  t126_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t126_n142;
  t126_n141: return 0.020251663401722908f;
  t126_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t126_n144;
  t126_n143: return 0.0756794661283493f;
  t126_n144: return -0.06176726520061493f;
  t126_n145: return 0.03235805407166481f;
  t126_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t126_n160;
  t126_n147: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t126_n149;
  t126_n148: return -0.022706588730216026f;
  t126_n149: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t126_n159;
  t126_n150: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t126_n158;
  t126_n151: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t126_n153;
  t126_n152: return 0.16093343496322632f;
  t126_n153: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t126_n157;
  t126_n154: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t126_n156;
  t126_n155: return -0.23073598742485046f;
  t126_n156: return 0.1353970319032669f;
  t126_n157: return 0.05437649041414261f;
  t126_n158: return 0.03750879317522049f;
  t126_n159: return 0.020173873752355576f;
  t126_n160: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t126_n196;
  t126_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t126_n171;
  t126_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t126_n164;
  t126_n163: return 0.05262317508459091f;
  t126_n164: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t126_n170;
  t126_n165: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t126_n167;
  t126_n166: return 0.048346493393182755f;
  t126_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n169;
  t126_n168: return 0.11784671992063522f;
  t126_n169: return -0.008896072395145893f;
  t126_n170: return 0.07161793112754822f;
  t126_n171: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t126_n185;
  t126_n172: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t126_n174;
  t126_n173: return 0.017685966566205025f;
  t126_n174: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t126_n182;
  t126_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t126_n177;
  t126_n176: return 0.06472183018922806f;
  t126_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t126_n181;
  t126_n178: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t126_n180;
  t126_n179: return 0.10013968497514725f;
  t126_n180: return 0.022990647703409195f;
  t126_n181: return 0.0682075172662735f;
  t126_n182: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t126_n184;
  t126_n183: return 0.057042196393013f;
  t126_n184: return 0.10493331402540207f;
  t126_n185: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t126_n187;
  t126_n186: return 0.04050278291106224f;
  t126_n187: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t126_n195;
  t126_n188: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t126_n194;
  t126_n189: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t126_n193;
  t126_n190: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t126_n192;
  t126_n191: return 0.09187858551740646f;
  t126_n192: return 0.111749567091465f;
  t126_n193: return 0.08488841354846954f;
  t126_n194: return 0.11326152086257935f;
  t126_n195: return -0.14818908274173737f;
  t126_n196: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t126_n198;
  t126_n197: return -0.012756812386214733f;
  t126_n198: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t126_n200;
  t126_n199: return 0.12274686992168427f;
  t126_n200: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t126_n202;
  t126_n201: return 0.05110799893736839f;
  t126_n202: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t126_n204;
  t126_n203: return 0.11167322844266891f;
  t126_n204: return -0.062261443585157394f;
  t126_n205: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t126_n213;
  t126_n206: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n208;
  t126_n207: return -0.10066234320402145f;
  t126_n208: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t126_n210;
  t126_n209: return 0.10792338848114014f;
  t126_n210: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n212;
  t126_n211: return 0.10199138522148132f;
  t126_n212: return 0.01883263885974884f;
  t126_n213: if (E.getNumReferences() >= 3338536704 /*32515.5*/) goto t126_n215;
  t126_n214: return -0.1252259463071823f;
  t126_n215: return 0.07133835554122925f;
  t126_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t126_n218;
  t126_n217: return 0.00367922754958272f;
  t126_n218: if (E.getNumReferences() >= 3342384384 /*47293.0*/) goto t126_n242;
  t126_n219: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n221;
  t126_n220: return 0.018727563321590424f;
  t126_n221: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t126_n231;
  t126_n222: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n224;
  t126_n223: return 0.04908359795808792f;
  t126_n224: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t126_n230;
  t126_n225: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t126_n227;
  t126_n226: return 0.10542458295822144f;
  t126_n227: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t126_n229;
  t126_n228: return 0.17628929018974304f;
  t126_n229: return 0.11563727259635925f;
  t126_n230: return 0.08340660482645035f;
  t126_n231: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t126_n241;
  t126_n232: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t126_n238;
  t126_n233: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t126_n235;
  t126_n234: return 0.18736298382282257f;
  t126_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n237;
  t126_n236: return 0.12762442231178284f;
  t126_n237: return 0.05347271263599396f;
  t126_n238: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t126_n240;
  t126_n239: return 0.1298864483833313f;
  t126_n240: return 0.177943155169487f;
  t126_n241: return 0.11456988751888275f;
  t126_n242: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t126_n244;
  t126_n243: return 0.00509154237806797f;
  t126_n244: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t126_n254;
  t126_n245: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t126_n247;
  t126_n246: return 0.02673785388469696f;
  t126_n247: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t126_n251;
  t126_n248: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n250;
  t126_n249: return 0.11059890687465668f;
  t126_n250: return 0.07374662160873413f;
  t126_n251: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t126_n253;
  t126_n252: return -0.03276846185326576f;
  t126_n253: return 0.1078302413225174f;
  t126_n254: return 0.007208246737718582f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree127(const Example& E) {
  t127_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t127_n242;
  t127_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t127_n181;
  t127_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t127_n102;
  t127_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t127_n5;
  t127_n4: return -0.05422738939523697f;
  t127_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t127_n7;
  t127_n6: return -0.07048683613538742f;
  t127_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t127_n9;
  t127_n8: return -0.016828810796141624f;
  t127_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t127_n71;
  t127_n10: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t127_n14;
  t127_n11: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t127_n13;
  t127_n12: return 0.0027640073094516993f;
  t127_n13: return -0.08297746628522873f;
  t127_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t127_n22;
  t127_n15: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n17;
  t127_n16: return 0.09661374241113663f;
  t127_n17: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t127_n21;
  t127_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t127_n20;
  t127_n19: return 0.022709861397743225f;
  t127_n20: return 0.10967832803726196f;
  t127_n21: return 0.05946961045265198f;
  t127_n22: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t127_n66;
  t127_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t127_n55;
  t127_n24: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n48;
  t127_n25: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t127_n43;
  t127_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t127_n28;
  t127_n27: return -0.30071479082107544f;
  t127_n28: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t127_n30;
  t127_n29: return 0.055070456117391586f;
  t127_n30: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t127_n42;
  t127_n31: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t127_n33;
  t127_n32: return 0.07263805717229843f;
  t127_n33: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t127_n35;
  t127_n34: return 0.11922219395637512f;
  t127_n35: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t127_n37;
  t127_n36: return 0.1306476593017578f;
  t127_n37: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t127_n39;
  t127_n38: return -0.1288345605134964f;
  t127_n39: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t127_n41;
  t127_n40: return 0.0483977384865284f;
  t127_n41: return 0.1072768047451973f;
  t127_n42: return 0.03366093337535858f;
  t127_n43: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t127_n47;
  t127_n44: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t127_n46;
  t127_n45: return 0.037131838500499725f;
  t127_n46: return -0.13605868816375732f;
  t127_n47: return 0.07532640546560287f;
  t127_n48: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t127_n50;
  t127_n49: return -0.0032845884561538696f;
  t127_n50: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t127_n54;
  t127_n51: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t127_n53;
  t127_n52: return 0.11161372065544128f;
  t127_n53: return 0.1183457300066948f;
  t127_n54: return 0.0431731753051281f;
  t127_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t127_n59;
  t127_n56: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t127_n58;
  t127_n57: return 0.05898178368806839f;
  t127_n58: return -0.5843892693519592f;
  t127_n59: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t127_n61;
  t127_n60: return 0.0010973496828228235f;
  t127_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n65;
  t127_n62: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t127_n64;
  t127_n63: return 0.15549711883068085f;
  t127_n64: return -0.012947706505656242f;
  t127_n65: return -0.11956842988729477f;
  t127_n66: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t127_n70;
  t127_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t127_n69;
  t127_n68: return -0.013398624956607819f;
  t127_n69: return 0.019384577870368958f;
  t127_n70: return -0.039001934230327606f;
  t127_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t127_n91;
  t127_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n86;
  t127_n73: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t127_n85;
  t127_n74: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t127_n84;
  t127_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t127_n77;
  t127_n76: return 0.031251393258571625f;
  t127_n77: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t127_n79;
  t127_n78: return 0.046755533665418625f;
  t127_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t127_n83;
  t127_n80: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t127_n82;
  t127_n81: return 0.058441318571567535f;
  t127_n82: return -0.05314752459526062f;
  t127_n83: return 0.06480571627616882f;
  t127_n84: return 0.07780595123767853f;
  t127_n85: return 0.05466768145561218f;
  t127_n86: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t127_n88;
  t127_n87: return 0.013061321340501308f;
  t127_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t127_n90;
  t127_n89: return -0.029706981033086777f;
  t127_n90: return 0.0008772704168222845f;
  t127_n91: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t127_n101;
  t127_n92: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n100;
  t127_n93: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t127_n99;
  t127_n94: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t127_n96;
  t127_n95: return 0.10119357705116272f;
  t127_n96: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t127_n98;
  t127_n97: return 0.10621928423643112f;
  t127_n98: return 0.10030637681484222f;
  t127_n99: return 0.06524621695280075f;
  t127_n100: return 0.07354927808046341f;
  t127_n101: return -0.04423133283853531f;
  t127_n102: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t127_n180;
  t127_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t127_n105;
  t127_n104: return 0.0014856281923130155f;
  t127_n105: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t127_n107;
  t127_n106: return -0.0011221299646422267f;
  t127_n107: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t127_n109;
  t127_n108: return 0.008709805086255074f;
  t127_n109: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t127_n113;
  t127_n110: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t127_n112;
  t127_n111: return -0.016332441940903664f;
  t127_n112: return 0.01289936900138855f;
  t127_n113: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t127_n117;
  t127_n114: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t127_n116;
  t127_n115: return -0.02270347811281681f;
  t127_n116: return 0.08250240981578827f;
  t127_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t127_n139;
  t127_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t127_n122;
  t127_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t127_n121;
  t127_n120: return -0.028481846675276756f;
  t127_n121: return 0.040446601808071136f;
  t127_n122: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t127_n124;
  t127_n123: return 0.06189781054854393f;
  t127_n124: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t127_n138;
  t127_n125: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t127_n137;
  t127_n126: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n136;
  t127_n127: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t127_n131;
  t127_n128: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t127_n130;
  t127_n129: return 0.07174193114042282f;
  t127_n130: return 0.0993870422244072f;
  t127_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t127_n133;
  t127_n132: return 0.029433585703372955f;
  t127_n133: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t127_n135;
  t127_n134: return 0.10577358305454254f;
  t127_n135: return 0.11528288573026657f;
  t127_n136: return 0.07377087324857712f;
  t127_n137: return -0.10452565550804138f;
  t127_n138: return 0.003777815494686365f;
  t127_n139: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t127_n179;
  t127_n140: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n176;
  t127_n141: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t127_n149;
  t127_n142: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t127_n148;
  t127_n143: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t127_n145;
  t127_n144: return -0.13743169605731964f;
  t127_n145: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t127_n147;
  t127_n146: return 0.10013304650783539f;
  t127_n147: return -0.03956957161426544f;
  t127_n148: return 0.011656754650175571f;
  t127_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t127_n151;
  t127_n150: return -0.031949084252119064f;
  t127_n151: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t127_n155;
  t127_n152: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t127_n154;
  t127_n153: return 0.1280033141374588f;
  t127_n154: return 0.06160049885511398f;
  t127_n155: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t127_n161;
  t127_n156: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t127_n160;
  t127_n157: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t127_n159;
  t127_n158: return 0.08969153463840485f;
  t127_n159: return 0.047046806663274765f;
  t127_n160: return 0.01157862413674593f;
  t127_n161: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t127_n175;
  t127_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t127_n166;
  t127_n163: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t127_n165;
  t127_n164: return 0.10557664930820465f;
  t127_n165: return 0.08195451647043228f;
  t127_n166: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t127_n172;
  t127_n167: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t127_n169;
  t127_n168: return 0.1287168264389038f;
  t127_n169: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t127_n171;
  t127_n170: return 0.12299631536006927f;
  t127_n171: return 0.08464450389146805f;
  t127_n172: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t127_n174;
  t127_n173: return 0.13471311330795288f;
  t127_n174: return 0.13825483620166779f;
  t127_n175: return 0.019043762236833572f;
  t127_n176: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t127_n178;
  t127_n177: return 0.032184481620788574f;
  t127_n178: return -0.1731066107749939f;
  t127_n179: return -0.10475355386734009f;
  t127_n180: return -0.06754317879676819f;
  t127_n181: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t127_n239;
  t127_n182: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t127_n186;
  t127_n183: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t127_n185;
  t127_n184: return -0.03854561224579811f;
  t127_n185: return -0.12401048094034195f;
  t127_n186: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t127_n196;
  t127_n187: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t127_n195;
  t127_n188: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t127_n190;
  t127_n189: return 0.0035606706514954567f;
  t127_n190: if (E.getNumReferences() >= 3289227264 /*566.5*/) goto t127_n192;
  t127_n191: return 0.028551191091537476f;
  t127_n192: if (E.getNumReferences() >= 3290800128 /*662.5*/) goto t127_n194;
  t127_n193: return 0.11445698887109756f;
  t127_n194: return -0.15344519913196564f;
  t127_n195: return 0.015302308835089207f;
  t127_n196: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t127_n200;
  t127_n197: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t127_n199;
  t127_n198: return 0.023947078734636307f;
  t127_n199: return 0.00852191261947155f;
  t127_n200: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t127_n236;
  t127_n201: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t127_n235;
  t127_n202: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t127_n210;
  t127_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t127_n207;
  t127_n204: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n206;
  t127_n205: return 0.1283305138349533f;
  t127_n206: return -0.013218902051448822f;
  t127_n207: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t127_n209;
  t127_n208: return -0.10420950502157211f;
  t127_n209: return 0.13114315271377563f;
  t127_n210: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t127_n212;
  t127_n211: return 0.03403455391526222f;
  t127_n212: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t127_n232;
  t127_n213: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t127_n225;
  t127_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t127_n222;
  t127_n215: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t127_n221;
  t127_n216: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t127_n218;
  t127_n217: return 0.023044511675834656f;
  t127_n218: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t127_n220;
  t127_n219: return -0.37912628054618835f;
  t127_n220: return 0.13337060809135437f;
  t127_n221: return 0.06631387025117874f;
  t127_n222: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t127_n224;
  t127_n223: return -0.062318556010723114f;
  t127_n224: return 0.14634741842746735f;
  t127_n225: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t127_n227;
  t127_n226: return 0.05160817503929138f;
  t127_n227: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t127_n229;
  t127_n228: return 0.08877972513437271f;
  t127_n229: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t127_n231;
  t127_n230: return 0.11619845032691956f;
  t127_n231: return 0.1200096532702446f;
  t127_n232: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t127_n234;
  t127_n233: return -0.13350805640220642f;
  t127_n234: return 0.11391918361186981f;
  t127_n235: return -0.004362533800303936f;
  t127_n236: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t127_n238;
  t127_n237: return 0.06096503511071205f;
  t127_n238: return 0.04986904188990593f;
  t127_n239: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t127_n241;
  t127_n240: return -0.04113997519016266f;
  t127_n241: return -0.02806910127401352f;
  t127_n242: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t127_n252;
  t127_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t127_n245;
  t127_n244: return 0.008860036730766296f;
  t127_n245: if (E.getNumReferences() >= 3300909056 /*1535.0*/) goto t127_n247;
  t127_n246: return -0.008322239853441715f;
  t127_n247: if (E.getNumReferences() >= 3300937728 /*1538.5*/) goto t127_n251;
  t127_n248: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t127_n250;
  t127_n249: return -0.11209427565336227f;
  t127_n250: return 0.13109566271305084f;
  t127_n251: return 0.026091426610946655f;
  t127_n252: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t127_n254;
  t127_n253: return -0.009172139689326286f;
  t127_n254: return 0.009060784243047237f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree128(const Example& E) {
  t128_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t128_n204;
  t128_n1: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t128_n55;
  t128_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t128_n4;
  t128_n3: return -0.00015902244194876403f;
  t128_n4: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t128_n54;
  t128_n5: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t128_n15;
  t128_n6: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t128_n8;
  t128_n7: return 0.011330310255289078f;
  t128_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t128_n12;
  t128_n9: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t128_n11;
  t128_n10: return 0.1111166849732399f;
  t128_n11: return 0.023510359227657318f;
  t128_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n14;
  t128_n13: return 0.10327266901731491f;
  t128_n14: return -0.013657504692673683f;
  t128_n15: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t128_n17;
  t128_n16: return 0.010089710354804993f;
  t128_n17: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t128_n39;
  t128_n18: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t128_n20;
  t128_n19: return -0.0022073364816606045f;
  t128_n20: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t128_n30;
  t128_n21: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n29;
  t128_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t128_n28;
  t128_n23: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n25;
  t128_n24: return -0.008823536336421967f;
  t128_n25: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t128_n27;
  t128_n26: return -0.10186967253684998f;
  t128_n27: return 0.10385872423648834f;
  t128_n28: return 0.06966374069452286f;
  t128_n29: return -0.005219741724431515f;
  t128_n30: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t128_n36;
  t128_n31: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t128_n35;
  t128_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n34;
  t128_n33: return 0.11049573123455048f;
  t128_n34: return 0.037248704582452774f;
  t128_n35: return 0.1273273080587387f;
  t128_n36: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t128_n38;
  t128_n37: return 0.0862593874335289f;
  t128_n38: return 0.0216072928160429f;
  t128_n39: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n51;
  t128_n40: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t128_n48;
  t128_n41: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t128_n43;
  t128_n42: return 0.06766404211521149f;
  t128_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n47;
  t128_n44: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t128_n46;
  t128_n45: return 0.09923706948757172f;
  t128_n46: return 0.09146406501531601f;
  t128_n47: return 0.04765641316771507f;
  t128_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t128_n50;
  t128_n49: return 0.06822864711284637f;
  t128_n50: return 0.22095943987369537f;
  t128_n51: if (E.getNumReferences() >= 3287121920 /*475.0*/) goto t128_n53;
  t128_n52: return 0.00347784161567688f;
  t128_n53: return 0.08352558314800262f;
  t128_n54: return 0.00013891924754716456f;
  t128_n55: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t128_n65;
  t128_n56: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t128_n58;
  t128_n57: return -0.19301681220531464f;
  t128_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t128_n60;
  t128_n59: return 0.02651609666645527f;
  t128_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t128_n62;
  t128_n61: return -0.02786865271627903f;
  t128_n62: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t128_n64;
  t128_n63: return 0.12716445326805115f;
  t128_n64: return -0.011153320781886578f;
  t128_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t128_n67;
  t128_n66: return -0.029334690421819687f;
  t128_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t128_n187;
  t128_n68: if (E.getSymbolScopeDistance() >= 3245342720 /*15.0*/) goto t128_n172;
  t128_n69: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t128_n85;
  t128_n70: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t128_n84;
  t128_n71: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t128_n73;
  t128_n72: return 0.0072152563370764256f;
  t128_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t128_n83;
  t128_n74: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n76;
  t128_n75: return 0.27110031247138977f;
  t128_n76: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t128_n82;
  t128_n77: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t128_n81;
  t128_n78: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t128_n80;
  t128_n79: return 0.1360194981098175f;
  t128_n80: return 0.12327463924884796f;
  t128_n81: return 0.6690322160720825f;
  t128_n82: return 0.05652303248643875f;
  t128_n83: return 0.07710374891757965f;
  t128_n84: return -0.09964330494403839f;
  t128_n85: if (E.getNumReferences() >= 3264217088 /*72.0*/) goto t128_n167;
  t128_n86: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t128_n148;
  t128_n87: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n89;
  t128_n88: return -0.027512043714523315f;
  t128_n89: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t128_n135;
  t128_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n92;
  t128_n91: return 0.09890950471162796f;
  t128_n92: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t128_n118;
  t128_n93: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t128_n113;
  t128_n94: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t128_n112;
  t128_n95: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t128_n105;
  t128_n96: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n104;
  t128_n97: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t128_n99;
  t128_n98: return 0.08737918734550476f;
  t128_n99: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t128_n101;
  t128_n100: return -0.13280943036079407f;
  t128_n101: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t128_n103;
  t128_n102: return 0.12385116517543793f;
  t128_n103: return 0.0749073326587677f;
  t128_n104: return 0.050544336438179016f;
  t128_n105: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t128_n111;
  t128_n106: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t128_n108;
  t128_n107: return 0.13585436344146729f;
  t128_n108: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t128_n110;
  t128_n109: return 0.13491596281528473f;
  t128_n110: return 0.07420816272497177f;
  t128_n111: return -0.19481852650642395f;
  t128_n112: return -0.004661059007048607f;
  t128_n113: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n115;
  t128_n114: return 0.008821586146950722f;
  t128_n115: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t128_n117;
  t128_n116: return 0.14105838537216187f;
  t128_n117: return 0.0465388223528862f;
  t128_n118: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t128_n120;
  t128_n119: return -0.8048356771469116f;
  t128_n120: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t128_n124;
  t128_n121: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t128_n123;
  t128_n122: return 0.022077729925513268f;
  t128_n123: return 0.1368601769208908f;
  t128_n124: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t128_n134;
  t128_n125: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t128_n127;
  t128_n126: return -0.5372982621192932f;
  t128_n127: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t128_n129;
  t128_n128: return 0.12958396971225739f;
  t128_n129: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t128_n133;
  t128_n130: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t128_n132;
  t128_n131: return 0.08321269601583481f;
  t128_n132: return 0.10969071835279465f;
  t128_n133: return 0.017842065542936325f;
  t128_n134: return 0.02464677393436432f;
  t128_n135: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t128_n137;
  t128_n136: return 0.03597107157111168f;
  t128_n137: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t128_n147;
  t128_n138: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t128_n146;
  t128_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t128_n145;
  t128_n140: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t128_n142;
  t128_n141: return -0.528736412525177f;
  t128_n142: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t128_n144;
  t128_n143: return 0.02766071818768978f;
  t128_n144: return 0.11291050910949707f;
  t128_n145: return 0.25306209921836853f;
  t128_n146: return 0.1126372218132019f;
  t128_n147: return 0.04580110311508179f;
  t128_n148: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t128_n150;
  t128_n149: return 0.1125451996922493f;
  t128_n150: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t128_n158;
  t128_n151: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n153;
  t128_n152: return -0.18597392737865448f;
  t128_n153: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t128_n157;
  t128_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n156;
  t128_n155: return -0.11089203506708145f;
  t128_n156: return 0.16411824524402618f;
  t128_n157: return -0.14211556315422058f;
  t128_n158: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t128_n160;
  t128_n159: return 0.1046842485666275f;
  t128_n160: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t128_n164;
  t128_n161: if (E.getNumReferences() >= 3256352768 /*38.0*/) goto t128_n163;
  t128_n162: return 0.2239556908607483f;
  t128_n163: return -0.011268915608525276f;
  t128_n164: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t128_n166;
  t128_n165: return 0.05609806999564171f;
  t128_n166: return 0.11201556026935577f;
  t128_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n171;
  t128_n168: if (E.getNumReferences() >= 3324914176 /*11146.5*/) goto t128_n170;
  t128_n169: return 0.551651120185852f;
  t128_n170: return 0.08897928893566132f;
  t128_n171: return -0.022844547405838966f;
  t128_n172: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t128_n174;
  t128_n173: return -0.060091521590948105f;
  t128_n174: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t128_n182;
  t128_n175: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t128_n179;
  t128_n176: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n178;
  t128_n177: return -0.10154004395008087f;
  t128_n178: return 0.1148194670677185f;
  t128_n179: if (E.getNumReferences() >= 3272343552 /*140.0*/) goto t128_n181;
  t128_n180: return 0.39715927839279175f;
  t128_n181: return -0.2383345365524292f;
  t128_n182: if (E.getNumReferences() >= 3272802304 /*147.0*/) goto t128_n184;
  t128_n183: return 0.1668335646390915f;
  t128_n184: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t128_n186;
  t128_n185: return 0.07968764007091522f;
  t128_n186: return -0.12976323068141937f;
  t128_n187: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t128_n195;
  t128_n188: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t128_n194;
  t128_n189: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t128_n191;
  t128_n190: return 0.13778620958328247f;
  t128_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n193;
  t128_n192: return -0.12792856991291046f;
  t128_n193: return 0.19353531301021576f;
  t128_n194: return -0.02724071405827999f;
  t128_n195: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n201;
  t128_n196: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n200;
  t128_n197: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n199;
  t128_n198: return 0.180546373128891f;
  t128_n199: return 0.12238924950361252f;
  t128_n200: return 0.06792907416820526f;
  t128_n201: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n203;
  t128_n202: return -0.3112095594406128f;
  t128_n203: return 0.10983582586050034f;
  t128_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t128_n234;
  t128_n205: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t128_n229;
  t128_n206: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t128_n208;
  t128_n207: return 0.12025420367717743f;
  t128_n208: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t128_n210;
  t128_n209: return -0.2309470921754837f;
  t128_n210: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t128_n228;
  t128_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t128_n219;
  t128_n212: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n214;
  t128_n213: return -0.1080026850104332f;
  t128_n214: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n218;
  t128_n215: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t128_n217;
  t128_n216: return 0.06882044672966003f;
  t128_n217: return -0.0023249133955687284f;
  t128_n218: return -0.46891945600509644f;
  t128_n219: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t128_n223;
  t128_n220: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t128_n222;
  t128_n221: return 0.019726762548089027f;
  t128_n222: return -0.30739331245422363f;
  t128_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t128_n225;
  t128_n224: return -0.31483229994773865f;
  t128_n225: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n227;
  t128_n226: return 0.09750599414110184f;
  t128_n227: return 0.05900188535451889f;
  t128_n228: return -0.2129601091146469f;
  t128_n229: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t128_n233;
  t128_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t128_n232;
  t128_n231: return -0.10753372311592102f;
  t128_n232: return -1.7491044998168945f;
  t128_n233: return 0.014280424453318119f;
  t128_n234: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t128_n240;
  t128_n235: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t128_n237;
  t128_n236: return 0.08289521187543869f;
  t128_n237: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t128_n239;
  t128_n238: return -0.1667795330286026f;
  t128_n239: return 0.08990631997585297f;
  t128_n240: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t128_n242;
  t128_n241: return -0.07343727350234985f;
  t128_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t128_n254;
  t128_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t128_n249;
  t128_n244: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t128_n246;
  t128_n245: return 0.006598724517971277f;
  t128_n246: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t128_n248;
  t128_n247: return 0.057102020829916f;
  t128_n248: return 0.09699983894824982f;
  t128_n249: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t128_n251;
  t128_n250: return 0.10274520516395569f;
  t128_n251: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t128_n253;
  t128_n252: return 0.10669198632240295f;
  t128_n253: return -0.21558444201946259f;
  t128_n254: return 0.026346761733293533f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree129(const Example& E) {
  t129_n0: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t129_n254;
  t129_n1: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t129_n3;
  t129_n2: return -0.007691659964621067f;
  t129_n3: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t129_n109;
  t129_n4: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t129_n94;
  t129_n5: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t129_n45;
  t129_n6: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t129_n44;
  t129_n7: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t129_n11;
  t129_n8: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n10;
  t129_n9: return 0.03797664865851402f;
  t129_n10: return 0.008537189103662968f;
  t129_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t129_n19;
  t129_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t129_n14;
  t129_n13: return -0.19508744776248932f;
  t129_n14: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t129_n16;
  t129_n15: return -0.03931058570742607f;
  t129_n16: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t129_n18;
  t129_n17: return 0.09913968294858932f;
  t129_n18: return 0.034488387405872345f;
  t129_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t129_n33;
  t129_n20: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n26;
  t129_n21: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t129_n23;
  t129_n22: return 0.015164351090788841f;
  t129_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t129_n25;
  t129_n24: return -0.57021164894104f;
  t129_n25: return -0.013413242995738983f;
  t129_n26: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t129_n32;
  t129_n27: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t129_n31;
  t129_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t129_n30;
  t129_n29: return 0.04978952929377556f;
  t129_n30: return 0.06933823972940445f;
  t129_n31: return 0.09993742406368256f;
  t129_n32: return -0.13248507678508759f;
  t129_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t129_n43;
  t129_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t129_n40;
  t129_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t129_n37;
  t129_n36: return -0.0557456910610199f;
  t129_n37: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t129_n39;
  t129_n38: return 0.06242829188704491f;
  t129_n39: return 0.09922176599502563f;
  t129_n40: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t129_n42;
  t129_n41: return 0.501682460308075f;
  t129_n42: return 0.11642182618379593f;
  t129_n43: return 0.036644600331783295f;
  t129_n44: return -0.004359783139079809f;
  t129_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t129_n65;
  t129_n46: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t129_n58;
  t129_n47: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t129_n57;
  t129_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t129_n50;
  t129_n49: return 0.023589113727211952f;
  t129_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t129_n56;
  t129_n51: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n55;
  t129_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t129_n54;
  t129_n53: return -0.19565369188785553f;
  t129_n54: return 0.08846700191497803f;
  t129_n55: return 0.08369872719049454f;
  t129_n56: return 0.02093617431819439f;
  t129_n57: return 0.024689285084605217f;
  t129_n58: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t129_n60;
  t129_n59: return 0.014795291237533092f;
  t129_n60: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t129_n64;
  t129_n61: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t129_n63;
  t129_n62: return -0.022713622078299522f;
  t129_n63: return -0.08399244397878647f;
  t129_n64: return 0.01220256369560957f;
  t129_n65: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n81;
  t129_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t129_n68;
  t129_n67: return 0.021887045353651047f;
  t129_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t129_n80;
  t129_n69: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t129_n79;
  t129_n70: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t129_n78;
  t129_n71: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t129_n73;
  t129_n72: return -0.07201103866100311f;
  t129_n73: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t129_n77;
  t129_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t129_n76;
  t129_n75: return -0.17525553703308105f;
  t129_n76: return 0.13435927033424377f;
  t129_n77: return -0.4067257046699524f;
  t129_n78: return -0.12532950937747955f;
  t129_n79: return -0.10391449928283691f;
  t129_n80: return -0.00952683761715889f;
  t129_n81: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t129_n83;
  t129_n82: return 0.02367999404668808f;
  t129_n83: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t129_n91;
  t129_n84: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t129_n86;
  t129_n85: return -0.18867696821689606f;
  t129_n86: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t129_n88;
  t129_n87: return -0.05312175676226616f;
  t129_n88: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t129_n90;
  t129_n89: return -0.1275336891412735f;
  t129_n90: return 0.11044471710920334f;
  t129_n91: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t129_n93;
  t129_n92: return 0.04071556776762009f;
  t129_n93: return 0.11939764767885208f;
  t129_n94: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t129_n98;
  t129_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t129_n97;
  t129_n96: return -0.016267811879515648f;
  t129_n97: return -0.0027695607859641314f;
  t129_n98: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n102;
  t129_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t129_n101;
  t129_n100: return -0.07554813474416733f;
  t129_n101: return -0.008187953382730484f;
  t129_n102: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t129_n108;
  t129_n103: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t129_n107;
  t129_n104: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t129_n106;
  t129_n105: return 0.03060128539800644f;
  t129_n106: return -0.012189654633402824f;
  t129_n107: return 0.011047044768929482f;
  t129_n108: return 0.04454689100384712f;
  t129_n109: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t129_n239;
  t129_n110: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t129_n202;
  t129_n111: if (E.getNumReferences() >= 3286056960 /*442.5*/) goto t129_n165;
  t129_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t129_n152;
  t129_n113: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t129_n127;
  t129_n114: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t129_n116;
  t129_n115: return 0.007436295039951801f;
  t129_n116: if (E.getNumReferences() >= 3284910080 /*407.5*/) goto t129_n122;
  t129_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t129_n119;
  t129_n118: return -0.05383143573999405f;
  t129_n119: if (E.getNumReferences() >= 3280683008 /*278.5*/) goto t129_n121;
  t129_n120: return 0.018672190606594086f;
  t129_n121: return 0.09435654431581497f;
  t129_n122: if (E.getNumReferences() >= 3285647360 /*430.0*/) goto t129_n126;
  t129_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t129_n125;
  t129_n124: return 0.05368529260158539f;
  t129_n125: return 0.11294212937355042f;
  t129_n126: return -0.4787428379058838f;
  t129_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t129_n131;
  t129_n128: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t129_n130;
  t129_n129: return -0.12939129769802094f;
  t129_n130: return 0.038174472749233246f;
  t129_n131: if (E.getNumReferences() >= 3273687040 /*160.5*/) goto t129_n151;
  t129_n132: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t129_n138;
  t129_n133: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t129_n135;
  t129_n134: return 0.10660149157047272f;
  t129_n135: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t129_n137;
  t129_n136: return 0.014599831774830818f;
  t129_n137: return 0.1159631758928299f;
  t129_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t129_n142;
  t129_n139: if (E.getNumReferences() >= 3273392128 /*156.0*/) goto t129_n141;
  t129_n140: return 0.043844010680913925f;
  t129_n141: return 0.11333557218313217f;
  t129_n142: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t129_n150;
  t129_n143: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t129_n145;
  t129_n144: return 0.11499449610710144f;
  t129_n145: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t129_n149;
  t129_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t129_n148;
  t129_n147: return 0.06375163048505783f;
  t129_n148: return 0.10614784061908722f;
  t129_n149: return -0.01280986424535513f;
  t129_n150: return -0.028974639251828194f;
  t129_n151: return -0.0282574575394392f;
  t129_n152: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t129_n154;
  t129_n153: return 0.005984603427350521f;
  t129_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t129_n158;
  t129_n155: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t129_n157;
  t129_n156: return 0.10986614972352982f;
  t129_n157: return 0.08775491267442703f;
  t129_n158: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t129_n160;
  t129_n159: return 0.031155792996287346f;
  t129_n160: if (E.getNumReferences() >= 3279290368 /*246.0*/) goto t129_n162;
  t129_n161: return 0.07441180944442749f;
  t129_n162: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t129_n164;
  t129_n163: return 0.15960188210010529f;
  t129_n164: return 0.05742013081908226f;
  t129_n165: if (E.getNumReferences() >= 3291652096 /*714.5*/) goto t129_n193;
  t129_n166: if (E.getNumReferences() >= 3291406336 /*699.5*/) goto t129_n190;
  t129_n167: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t129_n189;
  t129_n168: if (E.getNumReferences() >= 3288621056 /*529.5*/) goto t129_n186;
  t129_n169: if (E.getNumReferences() >= 3288506368 /*522.5*/) goto t129_n183;
  t129_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t129_n172;
  t129_n171: return -0.20733429491519928f;
  t129_n172: if (E.getNumReferences() >= 3288236032 /*509.0*/) goto t129_n182;
  t129_n173: if (E.getNumReferences() >= 3288088576 /*504.5*/) goto t129_n181;
  t129_n174: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n178;
  t129_n175: if (E.getNumReferences() >= 3287302144 /*480.5*/) goto t129_n177;
  t129_n176: return 0.09001745283603668f;
  t129_n177: return 0.11221414804458618f;
  t129_n178: if (E.getNumReferences() >= 3286155264 /*445.5*/) goto t129_n180;
  t129_n179: return 0.1829158216714859f;
  t129_n180: return 0.030791547149419785f;
  t129_n181: return 0.11794731765985489f;
  t129_n182: return -0.30431389808654785f;
  t129_n183: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t129_n185;
  t129_n184: return 0.07530451565980911f;
  t129_n185: return 0.1236434057354927f;
  t129_n186: if (E.getNumReferences() >= 3291095040 /*680.5*/) goto t129_n188;
  t129_n187: return -0.015266263857483864f;
  t129_n188: return 0.10801044851541519f;
  t129_n189: return 0.03746005892753601f;
  t129_n190: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t129_n192;
  t129_n191: return 0.13463523983955383f;
  t129_n192: return 0.07794809341430664f;
  t129_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t129_n195;
  t129_n194: return 0.0022847920190542936f;
  t129_n195: if (E.getNumReferences() >= 3293192192 /*808.5*/) goto t129_n201;
  t129_n196: if (E.getNumReferences() >= 3292332032 /*756.0*/) goto t129_n198;
  t129_n197: return -0.15403933823108673f;
  t129_n198: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t129_n200;
  t129_n199: return 0.11970552057027817f;
  t129_n200: return 0.10228637605905533f;
  t129_n201: return 0.05808211490511894f;
  t129_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t129_n216;
  t129_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t129_n205;
  t129_n204: return 0.07025919109582901f;
  t129_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t129_n207;
  t129_n206: return 0.06281587481498718f;
  t129_n207: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t129_n215;
  t129_n208: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t129_n214;
  t129_n209: if (E.getNumReferences() >= 3273981952 /*165.0*/) goto t129_n211;
  t129_n210: return 0.1211313009262085f;
  t129_n211: if (E.getNumReferences() >= 3288653824 /*531.5*/) goto t129_n213;
  t129_n212: return -0.022730126976966858f;
  t129_n213: return 0.11782926321029663f;
  t129_n214: return 0.12047471106052399f;
  t129_n215: return 0.03771568462252617f;
  t129_n216: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t129_n218;
  t129_n217: return 0.0613037534058094f;
  t129_n218: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t129_n224;
  t129_n219: if (E.getNumReferences() >= 3264020480 /*70.5*/) goto t129_n223;
  t129_n220: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t129_n222;
  t129_n221: return 0.1030334010720253f;
  t129_n222: return 0.06092708557844162f;
  t129_n223: return 0.12551316618919373f;
  t129_n224: if (E.getNumReferences() >= 3275816960 /*193.0*/) goto t129_n230;
  t129_n225: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n229;
  t129_n226: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t129_n228;
  t129_n227: return 0.10439064353704453f;
  t129_n228: return 0.08449821174144745f;
  t129_n229: return -0.021648483350872993f;
  t129_n230: if (E.getNumReferences() >= 3279126528 /*243.5*/) goto t129_n232;
  t129_n231: return 0.11214737594127655f;
  t129_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t129_n234;
  t129_n233: return 0.06785409897565842f;
  t129_n234: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t129_n236;
  t129_n235: return -0.13176950812339783f;
  t129_n236: if (E.getNumReferences() >= 3288571904 /*526.5*/) goto t129_n238;
  t129_n237: return 0.1025642454624176f;
  t129_n238: return 0.12511710822582245f;
  t129_n239: if (E.getSymbolScopeDistance() >= 3246915584 /*17.0*/) goto t129_n241;
  t129_n240: return 0.02368789166212082f;
  t129_n241: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t129_n243;
  t129_n242: return 0.004314618185162544f;
  t129_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t129_n245;
  t129_n244: return -0.13367033004760742f;
  t129_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t129_n251;
  t129_n246: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t129_n248;
  t129_n247: return 0.10417942702770233f;
  t129_n248: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t129_n250;
  t129_n249: return 0.11251435428857803f;
  t129_n250: return 0.07041535526514053f;
  t129_n251: if (E.getNumReferences() >= 3269132288 /*109.5*/) goto t129_n253;
  t129_n252: return 0.17372679710388184f;
  t129_n253: return -0.09710928052663803f;
  t129_n254: return -0.001023133983835578f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree130(const Example& E) {
  t130_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t130_n238;
  t130_n1: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t130_n235;
  t130_n2: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t130_n212;
  t130_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t130_n145;
  t130_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t130_n6;
  t130_n5: return -0.002948935143649578f;
  t130_n6: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t130_n64;
  t130_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t130_n61;
  t130_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t130_n30;
  t130_n9: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t130_n29;
  t130_n10: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t130_n16;
  t130_n11: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t130_n13;
  t130_n12: return 0.00016591935127507895f;
  t130_n13: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t130_n15;
  t130_n14: return -0.031554218381643295f;
  t130_n15: return -0.08683695644140244f;
  t130_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t130_n18;
  t130_n17: return -0.0369434654712677f;
  t130_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t130_n20;
  t130_n19: return -0.010871464386582375f;
  t130_n20: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t130_n24;
  t130_n21: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t130_n23;
  t130_n22: return 0.009204646572470665f;
  t130_n23: return -0.5822681784629822f;
  t130_n24: if (E.getNumReferences() >= 3262382080 /*61.0*/) goto t130_n26;
  t130_n25: return 0.06427311152219772f;
  t130_n26: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t130_n28;
  t130_n27: return 0.10910850763320923f;
  t130_n28: return -0.41323423385620117f;
  t130_n29: return 0.006626317277550697f;
  t130_n30: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t130_n54;
  t130_n31: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t130_n47;
  t130_n32: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t130_n40;
  t130_n33: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t130_n35;
  t130_n34: return 0.033613771200180054f;
  t130_n35: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t130_n39;
  t130_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t130_n38;
  t130_n37: return 0.043627530336380005f;
  t130_n38: return 0.08494244515895844f;
  t130_n39: return -0.1362394243478775f;
  t130_n40: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t130_n42;
  t130_n41: return -0.004106019623577595f;
  t130_n42: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t130_n44;
  t130_n43: return -0.4852466285228729f;
  t130_n44: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t130_n46;
  t130_n45: return -0.31864532828330994f;
  t130_n46: return 0.057939693331718445f;
  t130_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t130_n49;
  t130_n48: return -0.022795360535383224f;
  t130_n49: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t130_n53;
  t130_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t130_n52;
  t130_n51: return 0.09376374632120132f;
  t130_n52: return 0.05036347731947899f;
  t130_n53: return -0.10311231017112732f;
  t130_n54: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t130_n60;
  t130_n55: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t130_n59;
  t130_n56: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t130_n58;
  t130_n57: return 0.11039972305297852f;
  t130_n58: return -0.14481811225414276f;
  t130_n59: return 0.11389802396297455f;
  t130_n60: return 0.02404838241636753f;
  t130_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t130_n63;
  t130_n62: return -0.11719664931297302f;
  t130_n63: return 0.01594984345138073f;
  t130_n64: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t130_n144;
  t130_n65: if (E.getNumReferences() >= 3290251264 /*629.0*/) goto t130_n139;
  t130_n66: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t130_n108;
  t130_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t130_n77;
  t130_n68: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t130_n72;
  t130_n69: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t130_n71;
  t130_n70: return -0.12603099644184113f;
  t130_n71: return -0.6878109574317932f;
  t130_n72: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t130_n74;
  t130_n73: return 0.015119596384465694f;
  t130_n74: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t130_n76;
  t130_n75: return 0.10136393457651138f;
  t130_n76: return 0.06667456775903702f;
  t130_n77: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t130_n79;
  t130_n78: return -0.009225786663591862f;
  t130_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t130_n85;
  t130_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t130_n84;
  t130_n81: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t130_n83;
  t130_n82: return -0.0875082015991211f;
  t130_n83: return -0.03166820481419563f;
  t130_n84: return -0.011955315247178078f;
  t130_n85: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t130_n95;
  t130_n86: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t130_n88;
  t130_n87: return -0.024192897602915764f;
  t130_n88: if (E.getNumReferences() >= 3282337792 /*329.0*/) goto t130_n94;
  t130_n89: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t130_n93;
  t130_n90: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t130_n92;
  t130_n91: return 0.07601521909236908f;
  t130_n92: return 0.11851166188716888f;
  t130_n93: return 0.025585994124412537f;
  t130_n94: return 0.10365032404661179f;
  t130_n95: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t130_n107;
  t130_n96: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t130_n104;
  t130_n97: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t130_n103;
  t130_n98: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t130_n100;
  t130_n99: return -0.2270313948392868f;
  t130_n100: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t130_n102;
  t130_n101: return 0.06282704323530197f;
  t130_n102: return -0.219752699136734f;
  t130_n103: return -0.09138701111078262f;
  t130_n104: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t130_n106;
  t130_n105: return 0.1261095553636551f;
  t130_n106: return 0.053385891020298004f;
  t130_n107: return -0.13257446885108948f;
  t130_n108: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t130_n110;
  t130_n109: return 0.01129173394292593f;
  t130_n110: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t130_n138;
  t130_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t130_n135;
  t130_n112: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t130_n114;
  t130_n113: return -0.057876937091350555f;
  t130_n114: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t130_n128;
  t130_n115: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t130_n127;
  t130_n116: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t130_n124;
  t130_n117: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t130_n121;
  t130_n118: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t130_n120;
  t130_n119: return 0.06323469430208206f;
  t130_n120: return -0.2629467248916626f;
  t130_n121: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t130_n123;
  t130_n122: return 0.14127756655216217f;
  t130_n123: return 0.03948942944407463f;
  t130_n124: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t130_n126;
  t130_n125: return 0.13805744051933289f;
  t130_n126: return 0.044473662972450256f;
  t130_n127: return -0.04719221591949463f;
  t130_n128: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t130_n132;
  t130_n129: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t130_n131;
  t130_n130: return -0.8755866289138794f;
  t130_n131: return 0.03390796482563019f;
  t130_n132: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t130_n134;
  t130_n133: return 0.12129152566194534f;
  t130_n134: return 0.05631513521075249f;
  t130_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t130_n137;
  t130_n136: return -0.17107143998146057f;
  t130_n137: return 0.13522234559059143f;
  t130_n138: return -0.013871905393898487f;
  t130_n139: if (E.getNumReferences() >= 3291791360 /*723.0*/) goto t130_n143;
  t130_n140: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t130_n142;
  t130_n141: return 0.10409152507781982f;
  t130_n142: return 0.1292324811220169f;
  t130_n143: return 0.00013861303159501404f;
  t130_n144: return 0.0013663654681295156f;
  t130_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t130_n207;
  t130_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t130_n176;
  t130_n147: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t130_n159;
  t130_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t130_n150;
  t130_n149: return 0.0045145731419324875f;
  t130_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t130_n152;
  t130_n151: return 0.023907802999019623f;
  t130_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t130_n154;
  t130_n153: return 0.010977627709507942f;
  t130_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t130_n156;
  t130_n155: return 0.04206571727991104f;
  t130_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t130_n158;
  t130_n157: return 0.0791878029704094f;
  t130_n158: return 0.06751847267150879f;
  t130_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t130_n167;
  t130_n160: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t130_n164;
  t130_n161: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t130_n163;
  t130_n162: return -0.05879712477326393f;
  t130_n163: return -0.05097723379731178f;
  t130_n164: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t130_n166;
  t130_n165: return -0.05274703726172447f;
  t130_n166: return -0.029834533110260963f;
  t130_n167: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t130_n175;
  t130_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t130_n170;
  t130_n169: return -0.003338867099955678f;
  t130_n170: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t130_n172;
  t130_n171: return 0.0029067222494632006f;
  t130_n172: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t130_n174;
  t130_n173: return -0.15658728778362274f;
  t130_n174: return 0.02829454280436039f;
  t130_n175: return 0.015800995752215385f;
  t130_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t130_n180;
  t130_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t130_n179;
  t130_n178: return 0.001132429693825543f;
  t130_n179: return 0.07831817865371704f;
  t130_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t130_n198;
  t130_n181: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t130_n183;
  t130_n182: return -0.10815229266881943f;
  t130_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t130_n187;
  t130_n184: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t130_n186;
  t130_n185: return 0.010004518553614616f;
  t130_n186: return 0.060571663081645966f;
  t130_n187: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t130_n197;
  t130_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t130_n190;
  t130_n189: return 0.12000086158514023f;
  t130_n190: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t130_n192;
  t130_n191: return 0.21851027011871338f;
  t130_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t130_n194;
  t130_n193: return 0.07631996273994446f;
  t130_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t130_n196;
  t130_n195: return 0.1442285180091858f;
  t130_n196: return 0.14332698285579681f;
  t130_n197: return 0.04765865579247475f;
  t130_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t130_n200;
  t130_n199: return 0.07696270197629929f;
  t130_n200: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t130_n206;
  t130_n201: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t130_n205;
  t130_n202: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t130_n204;
  t130_n203: return 0.21277908980846405f;
  t130_n204: return 0.21190407872200012f;
  t130_n205: return 0.23484379053115845f;
  t130_n206: return 0.003019941970705986f;
  t130_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t130_n211;
  t130_n208: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t130_n210;
  t130_n209: return 0.11241426318883896f;
  t130_n210: return -0.016642140224575996f;
  t130_n211: return 0.0070789470337331295f;
  t130_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t130_n216;
  t130_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t130_n215;
  t130_n214: return -0.04124343395233154f;
  t130_n215: return -0.036187317222356796f;
  t130_n216: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t130_n218;
  t130_n217: return -0.001354633248411119f;
  t130_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t130_n234;
  t130_n219: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t130_n221;
  t130_n220: return -0.01977895386517048f;
  t130_n221: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t130_n233;
  t130_n222: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t130_n232;
  t130_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t130_n227;
  t130_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t130_n226;
  t130_n225: return 0.03457697853446007f;
  t130_n226: return 0.041850745677948f;
  t130_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t130_n229;
  t130_n228: return 0.046971965581178665f;
  t130_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t130_n231;
  t130_n230: return 0.047512609511613846f;
  t130_n231: return 0.08105888217687607f;
  t130_n232: return -0.003076889319345355f;
  t130_n233: return 0.03939313441514969f;
  t130_n234: return 0.09340789914131165f;
  t130_n235: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t130_n237;
  t130_n236: return -0.11572147160768509f;
  t130_n237: return -0.08440274000167847f;
  t130_n238: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t130_n254;
  t130_n239: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t130_n251;
  t130_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t130_n244;
  t130_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t130_n243;
  t130_n242: return -0.03744393214583397f;
  t130_n243: return 0.06985469162464142f;
  t130_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t130_n248;
  t130_n245: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t130_n247;
  t130_n246: return 0.07309644669294357f;
  t130_n247: return 0.10619419813156128f;
  t130_n248: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t130_n250;
  t130_n249: return 0.09155163913965225f;
  t130_n250: return -0.11558487266302109f;
  t130_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t130_n253;
  t130_n252: return -0.0069737969897687435f;
  t130_n253: return 0.08267975598573685f;
  t130_n254: return 0.02389529161155224f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree131(const Example& E) {
  t131_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t131_n2;
  t131_n1: return -0.0003603216027840972f;
  t131_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t131_n4;
  t131_n3: return -0.005927770398557186f;
  t131_n4: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t131_n146;
  t131_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t131_n125;
  t131_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t131_n14;
  t131_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t131_n9;
  t131_n8: return -0.04417499154806137f;
  t131_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n11;
  t131_n10: return 0.011501467786729336f;
  t131_n11: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t131_n13;
  t131_n12: return 0.11795762926340103f;
  t131_n13: return 0.06489533185958862f;
  t131_n14: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t131_n16;
  t131_n15: return 0.001566210645250976f;
  t131_n16: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t131_n22;
  t131_n17: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t131_n19;
  t131_n18: return 0.04376630857586861f;
  t131_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n21;
  t131_n20: return 0.12924714386463165f;
  t131_n21: return 0.09300102293491364f;
  t131_n22: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t131_n124;
  t131_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t131_n59;
  t131_n24: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t131_n34;
  t131_n25: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t131_n27;
  t131_n26: return -0.13779930770397186f;
  t131_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t131_n29;
  t131_n28: return 0.04029922932386398f;
  t131_n29: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t131_n33;
  t131_n30: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n32;
  t131_n31: return 0.10075443238019943f;
  t131_n32: return 0.08466066420078278f;
  t131_n33: return 0.04164939373731613f;
  t131_n34: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t131_n58;
  t131_n35: if (E.getNumReferences() >= 3352615936 /*108984.0*/) goto t131_n37;
  t131_n36: return 0.04528266564011574f;
  t131_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n55;
  t131_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t131_n54;
  t131_n39: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t131_n47;
  t131_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t131_n42;
  t131_n41: return -0.12507465481758118f;
  t131_n42: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n46;
  t131_n43: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t131_n45;
  t131_n44: return -0.10164414346218109f;
  t131_n45: return 0.11607784032821655f;
  t131_n46: return -0.12962056696414948f;
  t131_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n49;
  t131_n48: return 0.084864042699337f;
  t131_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t131_n51;
  t131_n50: return -0.011194691993296146f;
  t131_n51: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t131_n53;
  t131_n52: return 0.129576176404953f;
  t131_n53: return 0.086077980697155f;
  t131_n54: return -0.13184835016727448f;
  t131_n55: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t131_n57;
  t131_n56: return 0.11302101612091064f;
  t131_n57: return 0.09585867077112198f;
  t131_n58: return 0.005898073315620422f;
  t131_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t131_n61;
  t131_n60: return -0.12185569852590561f;
  t131_n61: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t131_n93;
  t131_n62: if (E.getNumReferences() >= 3359032704 /*187158.0*/) goto t131_n72;
  t131_n63: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n65;
  t131_n64: return -0.009420318529009819f;
  t131_n65: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t131_n71;
  t131_n66: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t131_n70;
  t131_n67: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t131_n69;
  t131_n68: return 0.11917590349912643f;
  t131_n69: return 0.07925869524478912f;
  t131_n70: return 0.10985764861106873f;
  t131_n71: return 0.04125822335481644f;
  t131_n72: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n92;
  t131_n73: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t131_n81;
  t131_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t131_n76;
  t131_n75: return 0.031143270432949066f;
  t131_n76: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t131_n80;
  t131_n77: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t131_n79;
  t131_n78: return 0.07727304100990295f;
  t131_n79: return 0.11294378340244293f;
  t131_n80: return -0.24834240972995758f;
  t131_n81: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t131_n91;
  t131_n82: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t131_n90;
  t131_n83: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t131_n85;
  t131_n84: return 0.035175714641809464f;
  t131_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t131_n87;
  t131_n86: return -0.27166351675987244f;
  t131_n87: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t131_n89;
  t131_n88: return -0.11513693630695343f;
  t131_n89: return 0.10969401150941849f;
  t131_n90: return 0.05191243067383766f;
  t131_n91: return 0.12951821088790894f;
  t131_n92: return 0.04285501688718796f;
  t131_n93: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t131_n95;
  t131_n94: return -0.050002723932266235f;
  t131_n95: if (E.getNumReferences() >= 3367700464 /*383039.5*/) goto t131_n115;
  t131_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t131_n98;
  t131_n97: return -0.17568399012088776f;
  t131_n98: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t131_n100;
  t131_n99: return 0.03869755566120148f;
  t131_n100: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t131_n102;
  t131_n101: return -0.1856314092874527f;
  t131_n102: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t131_n114;
  t131_n103: if (E.getNumReferences() >= 3365641360 /*318692.5*/) goto t131_n109;
  t131_n104: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t131_n108;
  t131_n105: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n107;
  t131_n106: return 0.12017865478992462f;
  t131_n107: return 0.1091117113828659f;
  t131_n108: return -0.05335460230708122f;
  t131_n109: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n113;
  t131_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t131_n112;
  t131_n111: return -0.19133485853672028f;
  t131_n112: return 0.10407386720180511f;
  t131_n113: return 0.0999177098274231f;
  t131_n114: return -0.31616127490997314f;
  t131_n115: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t131_n123;
  t131_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n122;
  t131_n117: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t131_n119;
  t131_n118: return 0.026913488283753395f;
  t131_n119: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t131_n121;
  t131_n120: return 0.08861899375915527f;
  t131_n121: return 0.09922938793897629f;
  t131_n122: return -0.2237602323293686f;
  t131_n123: return -0.006464318372309208f;
  t131_n124: return -0.02886549010872841f;
  t131_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t131_n145;
  t131_n126: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t131_n134;
  t131_n127: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t131_n129;
  t131_n128: return 0.08867527544498444f;
  t131_n129: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n131;
  t131_n130: return 0.05749361962080002f;
  t131_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t131_n133;
  t131_n132: return 0.10754286497831345f;
  t131_n133: return 0.10741882771253586f;
  t131_n134: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t131_n136;
  t131_n135: return 0.11484185606241226f;
  t131_n136: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n138;
  t131_n137: return -0.01610996574163437f;
  t131_n138: if (E.getNumReferences() >= 3334782720 /*25183.5*/) goto t131_n140;
  t131_n139: return -0.1464831680059433f;
  t131_n140: if (E.getNumReferences() >= 3335060480 /*25726.0*/) goto t131_n144;
  t131_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t131_n143;
  t131_n142: return 0.014440156519412994f;
  t131_n143: return 0.10218120366334915f;
  t131_n144: return 0.024396678432822227f;
  t131_n145: return 0.030461158603429794f;
  t131_n146: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t131_n248;
  t131_n147: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t131_n221;
  t131_n148: if (E.getNumReferences() >= 3345968640 /*61294.0*/) goto t131_n196;
  t131_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t131_n159;
  t131_n150: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t131_n158;
  t131_n151: if (E.getNumReferences() >= 3338538752 /*32519.5*/) goto t131_n153;
  t131_n152: return -0.04704482853412628f;
  t131_n153: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t131_n155;
  t131_n154: return -0.00896223820745945f;
  t131_n155: if (E.getNumReferences() >= 3338736000 /*33041.5*/) goto t131_n157;
  t131_n156: return 0.12483098357915878f;
  t131_n157: return -0.0021671403665095568f;
  t131_n158: return -0.06821350753307343f;
  t131_n159: if (E.getNumReferences() >= 3336061952 /*27682.0*/) goto t131_n173;
  t131_n160: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t131_n172;
  t131_n161: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t131_n163;
  t131_n162: return -0.08106474578380585f;
  t131_n163: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t131_n165;
  t131_n164: return 0.05035281553864479f;
  t131_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t131_n167;
  t131_n166: return 0.059115756303071976f;
  t131_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n169;
  t131_n168: return 0.16439983248710632f;
  t131_n169: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t131_n171;
  t131_n170: return 0.11612065136432648f;
  t131_n171: return 0.10894308984279633f;
  t131_n172: return -0.19035710394382477f;
  t131_n173: if (E.getNumReferences() >= 3341475968 /*43744.5*/) goto t131_n193;
  t131_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t131_n190;
  t131_n175: if (E.getNumReferences() >= 3336492544 /*28523.0*/) goto t131_n181;
  t131_n176: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n178;
  t131_n177: return 0.09252206981182098f;
  t131_n178: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n180;
  t131_n179: return 0.13529548048973083f;
  t131_n180: return 0.07451623678207397f;
  t131_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t131_n185;
  t131_n182: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n184;
  t131_n183: return -0.005304524675011635f;
  t131_n184: return 0.0583963580429554f;
  t131_n185: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t131_n189;
  t131_n186: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t131_n188;
  t131_n187: return 0.03915403038263321f;
  t131_n188: return 0.11361493170261383f;
  t131_n189: return 0.05797029659152031f;
  t131_n190: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t131_n192;
  t131_n191: return 0.04020101577043533f;
  t131_n192: return 0.12158134579658508f;
  t131_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t131_n195;
  t131_n194: return -0.021119985729455948f;
  t131_n195: return 0.06477037817239761f;
  t131_n196: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t131_n206;
  t131_n197: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n203;
  t131_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t131_n200;
  t131_n199: return -0.053808338940143585f;
  t131_n200: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t131_n202;
  t131_n201: return 0.03514924272894859f;
  t131_n202: return 0.11422066390514374f;
  t131_n203: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t131_n205;
  t131_n204: return 0.1116797924041748f;
  t131_n205: return 0.1238069161772728f;
  t131_n206: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t131_n208;
  t131_n207: return 0.012073070742189884f;
  t131_n208: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t131_n210;
  t131_n209: return -0.07273460179567337f;
  t131_n210: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t131_n220;
  t131_n211: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t131_n219;
  t131_n212: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n218;
  t131_n213: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t131_n215;
  t131_n214: return 0.1194237694144249f;
  t131_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t131_n217;
  t131_n216: return 0.12102095782756805f;
  t131_n217: return 0.026126712560653687f;
  t131_n218: return 0.04853149503469467f;
  t131_n219: return -0.1035323217511177f;
  t131_n220: return 0.01858234405517578f;
  t131_n221: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t131_n247;
  t131_n222: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t131_n242;
  t131_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t131_n233;
  t131_n224: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t131_n232;
  t131_n225: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t131_n231;
  t131_n226: if (E.getNumReferences() >= 3334007808 /*23670.0*/) goto t131_n230;
  t131_n227: if (E.getNumReferences() >= 3333936384 /*23530.5*/) goto t131_n229;
  t131_n228: return 0.104581817984581f;
  t131_n229: return 0.11011823266744614f;
  t131_n230: return 0.06714744865894318f;
  t131_n231: return 0.05444567650556564f;
  t131_n232: return -0.004656864795833826f;
  t131_n233: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t131_n239;
  t131_n234: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t131_n236;
  t131_n235: return 0.10439599305391312f;
  t131_n236: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n238;
  t131_n237: return 0.07678703218698502f;
  t131_n238: return 0.09560355544090271f;
  t131_n239: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t131_n241;
  t131_n240: return 0.07558206468820572f;
  t131_n241: return 0.11327574402093887f;
  t131_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t131_n244;
  t131_n243: return -0.20026522874832153f;
  t131_n244: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t131_n246;
  t131_n245: return 0.03419800475239754f;
  t131_n246: return -0.23914828896522522f;
  t131_n247: return 0.12865585088729858f;
  t131_n248: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t131_n250;
  t131_n249: return -0.06017472967505455f;
  t131_n250: if (E.getNumReferences() >= 3351127744 /*97357.5*/) goto t131_n254;
  t131_n251: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n253;
  t131_n252: return 0.14087285101413727f;
  t131_n253: return 0.12002420425415039f;
  t131_n254: return 0.009505398571491241f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree132(const Example& E) {
  t132_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t132_n2;
  t132_n1: return -0.00023079494712874293f;
  t132_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t132_n4;
  t132_n3: return -0.000370038760593161f;
  t132_n4: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t132_n238;
  t132_n5: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t132_n173;
  t132_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t132_n134;
  t132_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t132_n31;
  t132_n8: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n30;
  t132_n9: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t132_n25;
  t132_n10: if (E.getNumReferences() >= 3353375936 /*114921.5*/) goto t132_n24;
  t132_n11: if (E.getNumReferences() >= 3352615936 /*108984.0*/) goto t132_n13;
  t132_n12: return 0.02094973251223564f;
  t132_n13: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t132_n21;
  t132_n14: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n16;
  t132_n15: return 0.12740810215473175f;
  t132_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t132_n18;
  t132_n17: return 0.009752071462571621f;
  t132_n18: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t132_n20;
  t132_n19: return 0.1262541264295578f;
  t132_n20: return 0.0863729864358902f;
  t132_n21: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n23;
  t132_n22: return 0.10526528209447861f;
  t132_n23: return 0.07772671431303024f;
  t132_n24: return -0.012636400759220123f;
  t132_n25: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t132_n27;
  t132_n26: return -0.12618687748908997f;
  t132_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t132_n29;
  t132_n28: return -0.2382706105709076f;
  t132_n29: return 0.02957635372877121f;
  t132_n30: return -0.03816269338130951f;
  t132_n31: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t132_n111;
  t132_n32: if (E.getNumReferences() >= 3360198688 /*205376.5*/) goto t132_n102;
  t132_n33: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t132_n35;
  t132_n34: return 0.11150722950696945f;
  t132_n35: if (E.getNumReferences() >= 3356314496 /*144686.0*/) goto t132_n101;
  t132_n36: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t132_n38;
  t132_n37: return -0.11951316148042679f;
  t132_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n56;
  t132_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t132_n41;
  t132_n40: return -0.015636321157217026f;
  t132_n41: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t132_n49;
  t132_n42: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t132_n48;
  t132_n43: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t132_n47;
  t132_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t132_n46;
  t132_n45: return -0.13387039303779602f;
  t132_n46: return 0.10677402466535568f;
  t132_n47: return 0.059135209769010544f;
  t132_n48: return -0.015675770118832588f;
  t132_n49: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t132_n55;
  t132_n50: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t132_n52;
  t132_n51: return 0.1024903878569603f;
  t132_n52: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t132_n54;
  t132_n53: return 0.1490076780319214f;
  t132_n54: return 0.09665880352258682f;
  t132_n55: return 0.0015752374893054366f;
  t132_n56: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t132_n100;
  t132_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t132_n59;
  t132_n58: return -0.13378240168094635f;
  t132_n59: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t132_n91;
  t132_n60: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t132_n88;
  t132_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t132_n73;
  t132_n62: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t132_n68;
  t132_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t132_n67;
  t132_n64: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t132_n66;
  t132_n65: return 0.03875603526830673f;
  t132_n66: return -0.4043794572353363f;
  t132_n67: return 0.06827171891927719f;
  t132_n68: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t132_n72;
  t132_n69: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t132_n71;
  t132_n70: return 0.12378012388944626f;
  t132_n71: return 0.07612214982509613f;
  t132_n72: return -0.12261688709259033f;
  t132_n73: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t132_n87;
  t132_n74: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t132_n78;
  t132_n75: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t132_n77;
  t132_n76: return 0.10380011796951294f;
  t132_n77: return 0.0666559562087059f;
  t132_n78: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t132_n82;
  t132_n79: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t132_n81;
  t132_n80: return -0.16225512325763702f;
  t132_n81: return 0.11756531149148941f;
  t132_n82: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t132_n86;
  t132_n83: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t132_n85;
  t132_n84: return 0.1069502979516983f;
  t132_n85: return 0.09089995920658112f;
  t132_n86: return 0.08599149435758591f;
  t132_n87: return -0.0807671919465065f;
  t132_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t132_n90;
  t132_n89: return -0.4660658538341522f;
  t132_n90: return 0.0938781127333641f;
  t132_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t132_n93;
  t132_n92: return -0.45359006524086f;
  t132_n93: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t132_n95;
  t132_n94: return 0.008756319992244244f;
  t132_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t132_n97;
  t132_n96: return 0.06890810281038284f;
  t132_n97: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t132_n99;
  t132_n98: return 0.09900934249162674f;
  t132_n99: return 0.09237090498209f;
  t132_n100: return 0.026850711554288864f;
  t132_n101: return -0.13444438576698303f;
  t132_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n106;
  t132_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t132_n105;
  t132_n104: return 0.07655394077301025f;
  t132_n105: return 0.06526625156402588f;
  t132_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t132_n108;
  t132_n107: return -0.04312387853860855f;
  t132_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t132_n110;
  t132_n109: return -0.23941729962825775f;
  t132_n110: return 0.04038716480135918f;
  t132_n111: if (E.getNumReferences() >= 3364277024 /*276057.0*/) goto t132_n113;
  t132_n112: return -0.12491898983716965f;
  t132_n113: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t132_n115;
  t132_n114: return 0.020413119345903397f;
  t132_n115: if (E.getNumReferences() >= 3364974544 /*297854.5*/) goto t132_n125;
  t132_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n118;
  t132_n117: return 0.021145647391676903f;
  t132_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t132_n122;
  t132_n119: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t132_n121;
  t132_n120: return 0.009499656036496162f;
  t132_n121: return 0.19517827033996582f;
  t132_n122: if (E.getNumReferences() >= 3364292576 /*276543.0*/) goto t132_n124;
  t132_n123: return 0.15393130481243134f;
  t132_n124: return 0.11826571822166443f;
  t132_n125: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t132_n133;
  t132_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t132_n132;
  t132_n127: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t132_n129;
  t132_n128: return -0.07975386828184128f;
  t132_n129: if (E.getNumReferences() >= 3368194704 /*398484.5*/) goto t132_n131;
  t132_n130: return -0.2305002063512802f;
  t132_n131: return 0.06887318938970566f;
  t132_n132: return -0.010413216426968575f;
  t132_n133: return 0.020718201994895935f;
  t132_n134: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t132_n172;
  t132_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t132_n141;
  t132_n136: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t132_n138;
  t132_n137: return -0.054807811975479126f;
  t132_n138: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n140;
  t132_n139: return 0.12469664216041565f;
  t132_n140: return 0.03205430135130882f;
  t132_n141: if (E.getNumReferences() >= 3363872672 /*263421.0*/) goto t132_n159;
  t132_n142: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n144;
  t132_n143: return 0.04732026904821396f;
  t132_n144: if (E.getNumReferences() >= 3358908544 /*185218.0*/) goto t132_n158;
  t132_n145: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t132_n157;
  t132_n146: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t132_n156;
  t132_n147: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t132_n155;
  t132_n148: if (E.getNumReferences() >= 3356993440 /*155294.5*/) goto t132_n150;
  t132_n149: return 0.08277637511491776f;
  t132_n150: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t132_n152;
  t132_n151: return 0.08481331914663315f;
  t132_n152: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n154;
  t132_n153: return 0.09604128450155258f;
  t132_n154: return 0.10964702069759369f;
  t132_n155: return 0.11594053357839584f;
  t132_n156: return -0.09088559448719025f;
  t132_n157: return 0.1180669516324997f;
  t132_n158: return -0.4370654225349426f;
  t132_n159: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n163;
  t132_n160: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t132_n162;
  t132_n161: return -0.026341529563069344f;
  t132_n162: return 0.08491241931915283f;
  t132_n163: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t132_n169;
  t132_n164: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t132_n168;
  t132_n165: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t132_n167;
  t132_n166: return 0.09579815715551376f;
  t132_n167: return 0.09167357534170151f;
  t132_n168: return 0.04617942124605179f;
  t132_n169: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t132_n171;
  t132_n170: return 0.10915204137563705f;
  t132_n171: return 0.019150977954268456f;
  t132_n172: return 0.10868129134178162f;
  t132_n173: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t132_n207;
  t132_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t132_n188;
  t132_n175: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t132_n185;
  t132_n176: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t132_n184;
  t132_n177: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n179;
  t132_n178: return 0.007463013753294945f;
  t132_n179: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t132_n183;
  t132_n180: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t132_n182;
  t132_n181: return 0.17742329835891724f;
  t132_n182: return -0.03821028769016266f;
  t132_n183: return 0.12313332408666611f;
  t132_n184: return 0.176448255777359f;
  t132_n185: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t132_n187;
  t132_n186: return -0.11459717154502869f;
  t132_n187: return 0.024958185851573944f;
  t132_n188: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t132_n206;
  t132_n189: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t132_n205;
  t132_n190: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t132_n192;
  t132_n191: return -0.7604097723960876f;
  t132_n192: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n202;
  t132_n193: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t132_n199;
  t132_n194: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t132_n198;
  t132_n195: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t132_n197;
  t132_n196: return 0.07932901382446289f;
  t132_n197: return 0.10823021829128265f;
  t132_n198: return -0.11763890832662582f;
  t132_n199: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t132_n201;
  t132_n200: return 0.11272784322500229f;
  t132_n201: return 0.0885295569896698f;
  t132_n202: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t132_n204;
  t132_n203: return 0.10095072537660599f;
  t132_n204: return 0.0022033816203475f;
  t132_n205: return 0.05364092439413071f;
  t132_n206: return 0.036674778908491135f;
  t132_n207: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t132_n209;
  t132_n208: return -0.04845842346549034f;
  t132_n209: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t132_n237;
  t132_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t132_n212;
  t132_n211: return -0.11431209743022919f;
  t132_n212: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t132_n236;
  t132_n213: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t132_n215;
  t132_n214: return 0.0003297704679425806f;
  t132_n215: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t132_n225;
  t132_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n224;
  t132_n217: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t132_n223;
  t132_n218: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t132_n220;
  t132_n219: return -0.020127873867750168f;
  t132_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t132_n222;
  t132_n221: return 0.07981470227241516f;
  t132_n222: return 0.07835733890533447f;
  t132_n223: return -0.00782192125916481f;
  t132_n224: return -0.34331536293029785f;
  t132_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n229;
  t132_n226: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t132_n228;
  t132_n227: return 0.10033934563398361f;
  t132_n228: return 0.07124831527471542f;
  t132_n229: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t132_n231;
  t132_n230: return 0.10772485285997391f;
  t132_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t132_n233;
  t132_n232: return 0.14022020995616913f;
  t132_n233: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t132_n235;
  t132_n234: return 0.10327988117933273f;
  t132_n235: return 0.1060648187994957f;
  t132_n236: return -0.04050632193684578f;
  t132_n237: return -0.08772735297679901f;
  t132_n238: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t132_n254;
  t132_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n249;
  t132_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t132_n242;
  t132_n241: return 0.09181050956249237f;
  t132_n242: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t132_n244;
  t132_n243: return 0.11663446575403214f;
  t132_n244: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t132_n246;
  t132_n245: return 0.0668034702539444f;
  t132_n246: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t132_n248;
  t132_n247: return 0.1429954171180725f;
  t132_n248: return -0.039259228855371475f;
  t132_n249: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t132_n253;
  t132_n250: if (E.getNumReferences() >= 3350572224 /*93017.5*/) goto t132_n252;
  t132_n251: return -0.013364232145249844f;
  t132_n252: return 0.10676288604736328f;
  t132_n253: return 0.13169772922992706f;
  t132_n254: return 0.005715334787964821f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree133(const Example& E) {
  t133_n0: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t133_n218;
  t133_n1: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t133_n211;
  t133_n2: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t133_n100;
  t133_n3: if (E.getNumReferences() >= 3358365376 /*176731.0*/) goto t133_n99;
  t133_n4: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t133_n98;
  t133_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n7;
  t133_n6: return -0.00877845287322998f;
  t133_n7: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t133_n93;
  t133_n8: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t133_n34;
  t133_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n11;
  t133_n10: return 0.01130644790828228f;
  t133_n11: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t133_n31;
  t133_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t133_n16;
  t133_n13: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t133_n15;
  t133_n14: return 0.007402205839753151f;
  t133_n15: return 0.039278965443372726f;
  t133_n16: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t133_n30;
  t133_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t133_n19;
  t133_n18: return 0.036251652985811234f;
  t133_n19: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t133_n29;
  t133_n20: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n28;
  t133_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t133_n23;
  t133_n22: return 0.04599998891353607f;
  t133_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t133_n27;
  t133_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t133_n26;
  t133_n25: return -0.14591257274150848f;
  t133_n26: return 0.11093499511480331f;
  t133_n27: return 0.1260286420583725f;
  t133_n28: return 0.008199135772883892f;
  t133_n29: return -0.047670070081949234f;
  t133_n30: return 0.02572455070912838f;
  t133_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t133_n33;
  t133_n32: return -0.05616479367017746f;
  t133_n33: return -0.005264881066977978f;
  t133_n34: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t133_n76;
  t133_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t133_n37;
  t133_n36: return -0.009399202652275562f;
  t133_n37: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t133_n51;
  t133_n38: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t133_n50;
  t133_n39: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t133_n49;
  t133_n40: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t133_n44;
  t133_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t133_n43;
  t133_n42: return -0.2155727744102478f;
  t133_n43: return 0.03463761508464813f;
  t133_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t133_n46;
  t133_n45: return -0.31235912442207336f;
  t133_n46: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n48;
  t133_n47: return 0.11745324730873108f;
  t133_n48: return 0.050132714211940765f;
  t133_n49: return -0.06991612166166306f;
  t133_n50: return 0.050839539617300034f;
  t133_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t133_n53;
  t133_n52: return 0.040467519313097f;
  t133_n53: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t133_n75;
  t133_n54: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t133_n58;
  t133_n55: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t133_n57;
  t133_n56: return 0.09319140017032623f;
  t133_n57: return 0.03778776526451111f;
  t133_n58: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t133_n72;
  t133_n59: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t133_n61;
  t133_n60: return 0.12043103575706482f;
  t133_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n67;
  t133_n62: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t133_n66;
  t133_n63: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t133_n65;
  t133_n64: return 0.1269398182630539f;
  t133_n65: return 0.012581050395965576f;
  t133_n66: return -0.1396813988685608f;
  t133_n67: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t133_n69;
  t133_n68: return 0.08169324696063995f;
  t133_n69: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t133_n71;
  t133_n70: return 0.09909620881080627f;
  t133_n71: return 0.14038144052028656f;
  t133_n72: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t133_n74;
  t133_n73: return 0.12771810591220856f;
  t133_n74: return -0.09332259744405746f;
  t133_n75: return -0.28287214040756226f;
  t133_n76: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t133_n78;
  t133_n77: return 0.006310472264885902f;
  t133_n78: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t133_n92;
  t133_n79: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t133_n91;
  t133_n80: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t133_n82;
  t133_n81: return 0.03945862874388695f;
  t133_n82: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t133_n90;
  t133_n83: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t133_n85;
  t133_n84: return 0.05746820196509361f;
  t133_n85: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t133_n89;
  t133_n86: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n88;
  t133_n87: return 0.1381571739912033f;
  t133_n88: return -0.04181099683046341f;
  t133_n89: return 0.04945766553282738f;
  t133_n90: return 0.037565141916275024f;
  t133_n91: return -0.01639365404844284f;
  t133_n92: return 0.10738912969827652f;
  t133_n93: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t133_n95;
  t133_n94: return 0.018982725217938423f;
  t133_n95: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t133_n97;
  t133_n96: return 0.10571694374084473f;
  t133_n97: return 0.03637830913066864f;
  t133_n98: return -0.000919215613976121f;
  t133_n99: return -0.14139601588249207f;
  t133_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t133_n154;
  t133_n101: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t133_n141;
  t133_n102: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t133_n126;
  t133_n103: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t133_n125;
  t133_n104: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t133_n108;
  t133_n105: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n107;
  t133_n106: return -0.012179065495729446f;
  t133_n107: return 0.059305619448423386f;
  t133_n108: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t133_n120;
  t133_n109: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n113;
  t133_n110: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t133_n112;
  t133_n111: return 0.0359310582280159f;
  t133_n112: return 0.08014608919620514f;
  t133_n113: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n119;
  t133_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t133_n116;
  t133_n115: return 0.050183385610580444f;
  t133_n116: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t133_n118;
  t133_n117: return 0.10777033120393753f;
  t133_n118: return 0.01933145336806774f;
  t133_n119: return -0.2673371136188507f;
  t133_n120: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t133_n122;
  t133_n121: return -0.17546118795871735f;
  t133_n122: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n124;
  t133_n123: return 0.0576317124068737f;
  t133_n124: return 0.14401264488697052f;
  t133_n125: return -0.16914312541484833f;
  t133_n126: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n132;
  t133_n127: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t133_n129;
  t133_n128: return 0.025926623493433f;
  t133_n129: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t133_n131;
  t133_n130: return 0.10505885630846024f;
  t133_n131: return 0.049464281648397446f;
  t133_n132: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t133_n140;
  t133_n133: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t133_n139;
  t133_n134: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t133_n136;
  t133_n135: return 0.048541031777858734f;
  t133_n136: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n138;
  t133_n137: return -0.14133009314537048f;
  t133_n138: return 0.044319868087768555f;
  t133_n139: return 0.04037921875715256f;
  t133_n140: return 0.06859810650348663f;
  t133_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t133_n143;
  t133_n142: return -0.004268605262041092f;
  t133_n143: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n145;
  t133_n144: return 0.06278946250677109f;
  t133_n145: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t133_n151;
  t133_n146: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t133_n148;
  t133_n147: return -0.008774851448833942f;
  t133_n148: if (E.getNumReferences() >= 3361193824 /*220925.5*/) goto t133_n150;
  t133_n149: return 0.11016172915697098f;
  t133_n150: return 0.05477721244096756f;
  t133_n151: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n153;
  t133_n152: return 0.14864996075630188f;
  t133_n153: return 0.11221860349178314f;
  t133_n154: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t133_n204;
  t133_n155: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t133_n177;
  t133_n156: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t133_n164;
  t133_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t133_n159;
  t133_n158: return 0.0394953228533268f;
  t133_n159: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t133_n163;
  t133_n160: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n162;
  t133_n161: return 0.1056072935461998f;
  t133_n162: return 0.06995072215795517f;
  t133_n163: return 0.03734789043664932f;
  t133_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t133_n166;
  t133_n165: return -0.09681340306997299f;
  t133_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n168;
  t133_n167: return 0.005836401600390673f;
  t133_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t133_n174;
  t133_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t133_n171;
  t133_n170: return 0.03806673735380173f;
  t133_n171: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t133_n173;
  t133_n172: return 0.09493647515773773f;
  t133_n173: return 0.05397256463766098f;
  t133_n174: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t133_n176;
  t133_n175: return 0.0943216010928154f;
  t133_n176: return 0.0027263257652521133f;
  t133_n177: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t133_n203;
  t133_n178: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n202;
  t133_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t133_n181;
  t133_n180: return 0.011522280052304268f;
  t133_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t133_n201;
  t133_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n184;
  t133_n183: return 0.11275701224803925f;
  t133_n184: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t133_n200;
  t133_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t133_n193;
  t133_n186: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t133_n192;
  t133_n187: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t133_n191;
  t133_n188: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t133_n190;
  t133_n189: return -0.11408363282680511f;
  t133_n190: return 0.10798834264278412f;
  t133_n191: return 0.06029871106147766f;
  t133_n192: return 0.07039657980203629f;
  t133_n193: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t133_n195;
  t133_n194: return -0.2928747236728668f;
  t133_n195: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t133_n197;
  t133_n196: return 0.119465172290802f;
  t133_n197: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t133_n199;
  t133_n198: return -0.32809239625930786f;
  t133_n199: return 0.10725073516368866f;
  t133_n200: return 0.0387493297457695f;
  t133_n201: return 0.006100911647081375f;
  t133_n202: return -0.1870645433664322f;
  t133_n203: return 0.12239577621221542f;
  t133_n204: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t133_n210;
  t133_n205: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t133_n209;
  t133_n206: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n208;
  t133_n207: return 0.1075863242149353f;
  t133_n208: return 0.06948912888765335f;
  t133_n209: return 0.027647975832223892f;
  t133_n210: return 0.11800745129585266f;
  t133_n211: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t133_n213;
  t133_n212: return -0.10019996017217636f;
  t133_n213: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t133_n215;
  t133_n214: return -0.05735429748892784f;
  t133_n215: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t133_n217;
  t133_n216: return -0.14541539549827576f;
  t133_n217: return 0.10832113027572632f;
  t133_n218: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t133_n236;
  t133_n219: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t133_n221;
  t133_n220: return 0.02157176099717617f;
  t133_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t133_n223;
  t133_n222: return 0.013454900123178959f;
  t133_n223: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t133_n227;
  t133_n224: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n226;
  t133_n225: return 0.07732607424259186f;
  t133_n226: return 0.05403336137533188f;
  t133_n227: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t133_n235;
  t133_n228: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n234;
  t133_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n231;
  t133_n230: return -0.15946055948734283f;
  t133_n231: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t133_n233;
  t133_n232: return -0.15938948094844818f;
  t133_n233: return 0.06053916737437248f;
  t133_n234: return 0.021026764065027237f;
  t133_n235: return 0.09404709935188293f;
  t133_n236: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t133_n238;
  t133_n237: return -0.0065467930398881435f;
  t133_n238: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t133_n254;
  t133_n239: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t133_n245;
  t133_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t133_n242;
  t133_n241: return 0.008940257132053375f;
  t133_n242: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t133_n244;
  t133_n243: return -0.23059743642807007f;
  t133_n244: return 0.10125628858804703f;
  t133_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t133_n247;
  t133_n246: return 0.08233146369457245f;
  t133_n247: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t133_n251;
  t133_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t133_n250;
  t133_n249: return 0.06321302801370621f;
  t133_n250: return 0.10176944732666016f;
  t133_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t133_n253;
  t133_n252: return 0.052333783358335495f;
  t133_n253: return 0.1063307672739029f;
  t133_n254: return -0.8691563010215759f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree134(const Example& E) {
  t134_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t134_n90;
  t134_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t134_n3;
  t134_n2: return -0.0007464553345926106f;
  t134_n3: if (E.getNumReferences() >= 3338172416 /*31804.0*/) goto t134_n57;
  t134_n4: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t134_n48;
  t134_n5: if (E.getNumReferences() >= 3327652864 /*13821.0*/) goto t134_n9;
  t134_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t134_n8;
  t134_n7: return -0.005171888507902622f;
  t134_n8: return 0.0059379031881690025f;
  t134_n9: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t134_n31;
  t134_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t134_n24;
  t134_n11: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n15;
  t134_n12: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t134_n14;
  t134_n13: return 0.06563541293144226f;
  t134_n14: return 0.11302883923053741f;
  t134_n15: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t134_n19;
  t134_n16: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t134_n18;
  t134_n17: return 0.13165242969989777f;
  t134_n18: return 0.18910378217697144f;
  t134_n19: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t134_n21;
  t134_n20: return 0.0829041376709938f;
  t134_n21: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t134_n23;
  t134_n22: return 0.10028422623872757f;
  t134_n23: return 0.10378947854042053f;
  t134_n24: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t134_n28;
  t134_n25: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t134_n27;
  t134_n26: return 0.09631536155939102f;
  t134_n27: return 0.05877811834216118f;
  t134_n28: if (E.getNumReferences() >= 3329037312 /*15173.0*/) goto t134_n30;
  t134_n29: return 0.10350564867258072f;
  t134_n30: return -0.08533814549446106f;
  t134_n31: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t134_n41;
  t134_n32: if (E.getNumReferences() >= 3334924800 /*25461.0*/) goto t134_n36;
  t134_n33: if (E.getNumReferences() >= 3333992192 /*23639.5*/) goto t134_n35;
  t134_n34: return 0.01965772546827793f;
  t134_n35: return -0.309079647064209f;
  t134_n36: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t134_n40;
  t134_n37: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t134_n39;
  t134_n38: return 0.13551492989063263f;
  t134_n39: return 0.23504088819026947f;
  t134_n40: return 0.021541401743888855f;
  t134_n41: if (E.getNumReferences() >= 3336049664 /*27658.0*/) goto t134_n43;
  t134_n42: return -0.30969271063804626f;
  t134_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t134_n45;
  t134_n44: return -0.2111920565366745f;
  t134_n45: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t134_n47;
  t134_n46: return 0.07766643911600113f;
  t134_n47: return -0.00735506322234869f;
  t134_n48: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t134_n50;
  t134_n49: return 0.03928476199507713f;
  t134_n50: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t134_n54;
  t134_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t134_n53;
  t134_n52: return 0.09820032864809036f;
  t134_n53: return 0.10337287932634354f;
  t134_n54: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t134_n56;
  t134_n55: return 0.05594823881983757f;
  t134_n56: return 0.09668688476085663f;
  t134_n57: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t134_n61;
  t134_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t134_n60;
  t134_n59: return -0.0794244036078453f;
  t134_n60: return -0.4314276874065399f;
  t134_n61: if (E.getNumReferences() >= 3343006592 /*49723.5*/) goto t134_n89;
  t134_n62: if (E.getNumReferences() >= 3341699072 /*44616.0*/) goto t134_n76;
  t134_n63: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t134_n67;
  t134_n64: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t134_n66;
  t134_n65: return -0.1754973977804184f;
  t134_n66: return 0.10951381176710129f;
  t134_n67: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t134_n75;
  t134_n68: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t134_n74;
  t134_n69: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t134_n71;
  t134_n70: return -0.04536154493689537f;
  t134_n71: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n73;
  t134_n72: return 0.09659086167812347f;
  t134_n73: return 0.07882536202669144f;
  t134_n74: return -0.18539579212665558f;
  t134_n75: return -0.06292502582073212f;
  t134_n76: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t134_n86;
  t134_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t134_n83;
  t134_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t134_n80;
  t134_n79: return -0.037532515823841095f;
  t134_n80: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t134_n82;
  t134_n81: return 0.1266029179096222f;
  t134_n82: return 0.06795568764209747f;
  t134_n83: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t134_n85;
  t134_n84: return 0.1128680482506752f;
  t134_n85: return 0.09510345011949539f;
  t134_n86: if (E.getNumReferences() >= 3342374144 /*47253.0*/) goto t134_n88;
  t134_n87: return 0.15121124684810638f;
  t134_n88: return -0.04833952710032463f;
  t134_n89: return -0.06589698791503906f;
  t134_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t134_n254;
  t134_n91: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t134_n93;
  t134_n92: return -0.024020085111260414f;
  t134_n93: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t134_n217;
  t134_n94: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t134_n206;
  t134_n95: if (E.getNumReferences() >= 3354631552 /*124731.0*/) goto t134_n181;
  t134_n96: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t134_n172;
  t134_n97: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t134_n103;
  t134_n98: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t134_n100;
  t134_n99: return 0.007033037021756172f;
  t134_n100: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t134_n102;
  t134_n101: return 0.06360513716936111f;
  t134_n102: return -0.14270612597465515f;
  t134_n103: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t134_n111;
  t134_n104: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t134_n106;
  t134_n105: return -0.0532340370118618f;
  t134_n106: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n110;
  t134_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t134_n109;
  t134_n108: return -0.25599539279937744f;
  t134_n109: return 0.1325787454843521f;
  t134_n110: return 0.07963566482067108f;
  t134_n111: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t134_n171;
  t134_n112: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t134_n168;
  t134_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t134_n127;
  t134_n114: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t134_n126;
  t134_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t134_n125;
  t134_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t134_n118;
  t134_n117: return -0.12780800461769104f;
  t134_n118: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t134_n120;
  t134_n119: return 0.08308865875005722f;
  t134_n120: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t134_n124;
  t134_n121: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n123;
  t134_n122: return 0.10583813488483429f;
  t134_n123: return 0.10725466161966324f;
  t134_n124: return 0.03880598768591881f;
  t134_n125: return 0.03311096504330635f;
  t134_n126: return 0.009997289627790451f;
  t134_n127: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t134_n137;
  t134_n128: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t134_n130;
  t134_n129: return -0.0864177718758583f;
  t134_n130: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t134_n132;
  t134_n131: return 0.022255277261137962f;
  t134_n132: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t134_n134;
  t134_n133: return -0.010309705510735512f;
  t134_n134: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t134_n136;
  t134_n135: return 0.10981258749961853f;
  t134_n136: return -0.05553881824016571f;
  t134_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t134_n139;
  t134_n138: return -0.2221139371395111f;
  t134_n139: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t134_n161;
  t134_n140: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n158;
  t134_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t134_n147;
  t134_n142: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t134_n144;
  t134_n143: return 0.08959823846817017f;
  t134_n144: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t134_n146;
  t134_n145: return 0.11374002695083618f;
  t134_n146: return -0.23174560070037842f;
  t134_n147: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t134_n155;
  t134_n148: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t134_n154;
  t134_n149: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t134_n151;
  t134_n150: return 0.01242063008248806f;
  t134_n151: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t134_n153;
  t134_n152: return -0.10144463181495667f;
  t134_n153: return 0.11279049515724182f;
  t134_n154: return 0.040216896682977676f;
  t134_n155: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t134_n157;
  t134_n156: return 0.14501942694187164f;
  t134_n157: return 0.11724871397018433f;
  t134_n158: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t134_n160;
  t134_n159: return 0.10744389146566391f;
  t134_n160: return 0.0797119289636612f;
  t134_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n167;
  t134_n162: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t134_n166;
  t134_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t134_n165;
  t134_n164: return 0.07698245346546173f;
  t134_n165: return 0.11059416085481644f;
  t134_n166: return -0.10629978030920029f;
  t134_n167: return 0.08223118633031845f;
  t134_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t134_n170;
  t134_n169: return -0.1780545711517334f;
  t134_n170: return 0.06615174561738968f;
  t134_n171: return -0.0843518003821373f;
  t134_n172: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n180;
  t134_n173: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t134_n179;
  t134_n174: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t134_n178;
  t134_n175: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t134_n177;
  t134_n176: return 0.11126333475112915f;
  t134_n177: return 0.07023420184850693f;
  t134_n178: return 0.13991780579090118f;
  t134_n179: return 0.041131243109703064f;
  t134_n180: return 0.04149789363145828f;
  t134_n181: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t134_n183;
  t134_n182: return -0.06117378547787666f;
  t134_n183: if (E.getNumReferences() >= 3357836960 /*168474.5*/) goto t134_n189;
  t134_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t134_n186;
  t134_n185: return -0.16975349187850952f;
  t134_n186: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n188;
  t134_n187: return 0.2005840688943863f;
  t134_n188: return 0.08761175721883774f;
  t134_n189: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t134_n205;
  t134_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t134_n192;
  t134_n191: return 0.028597798198461533f;
  t134_n192: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t134_n196;
  t134_n193: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t134_n195;
  t134_n194: return 0.013882085680961609f;
  t134_n195: return 0.09693077951669693f;
  t134_n196: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n198;
  t134_n197: return -0.053440071642398834f;
  t134_n198: if (E.getNumReferences() >= 3358763328 /*182949.0*/) goto t134_n204;
  t134_n199: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t134_n203;
  t134_n200: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t134_n202;
  t134_n201: return 0.09144182503223419f;
  t134_n202: return 0.14392127096652985f;
  t134_n203: return 0.012805439531803131f;
  t134_n204: return -0.0035164623986929655f;
  t134_n205: return -0.05655677989125252f;
  t134_n206: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t134_n216;
  t134_n207: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t134_n213;
  t134_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t134_n210;
  t134_n209: return -0.09847434610128403f;
  t134_n210: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t134_n212;
  t134_n211: return -0.004798772279173136f;
  t134_n212: return 0.08859509974718094f;
  t134_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t134_n215;
  t134_n214: return 0.009640056639909744f;
  t134_n215: return 0.07753787189722061f;
  t134_n216: return -0.023093337193131447f;
  t134_n217: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t134_n221;
  t134_n218: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t134_n220;
  t134_n219: return -0.045552391558885574f;
  t134_n220: return -0.1372712403535843f;
  t134_n221: if (E.getNumReferences() >= 3364158064 /*272339.5*/) goto t134_n237;
  t134_n222: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t134_n224;
  t134_n223: return -0.03673452138900757f;
  t134_n224: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t134_n230;
  t134_n225: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n229;
  t134_n226: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t134_n228;
  t134_n227: return -0.13616344332695007f;
  t134_n228: return 0.1619339883327484f;
  t134_n229: return 0.11241341382265091f;
  t134_n230: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t134_n236;
  t134_n231: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t134_n233;
  t134_n232: return 0.08543886989355087f;
  t134_n233: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n235;
  t134_n234: return 0.10209627449512482f;
  t134_n235: return 0.040983039885759354f;
  t134_n236: return 0.042756952345371246f;
  t134_n237: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t134_n239;
  t134_n238: return -0.1486048698425293f;
  t134_n239: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t134_n249;
  t134_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t134_n248;
  t134_n241: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t134_n243;
  t134_n242: return -0.062384769320487976f;
  t134_n243: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t134_n245;
  t134_n244: return -0.06118899583816528f;
  t134_n245: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t134_n247;
  t134_n246: return 0.0827207863330841f;
  t134_n247: return 0.0858810544013977f;
  t134_n248: return 0.04974903166294098f;
  t134_n249: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t134_n253;
  t134_n250: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t134_n252;
  t134_n251: return -0.012264951132237911f;
  t134_n252: return -0.1614484041929245f;
  t134_n253: return 0.003463745815679431f;
  t134_n254: return 0.013051550835371017f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree135(const Example& E) {
  t135_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t135_n54;
  t135_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n3;
  t135_n2: return -0.0021089385263621807f;
  t135_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t135_n23;
  t135_n4: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t135_n22;
  t135_n5: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t135_n21;
  t135_n6: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t135_n20;
  t135_n7: if (E.getNumReferences() >= 3277881344 /*224.5*/) goto t135_n17;
  t135_n8: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t135_n14;
  t135_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n11;
  t135_n10: return 0.008232341147959232f;
  t135_n11: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t135_n13;
  t135_n12: return -0.04186754673719406f;
  t135_n13: return -0.008332477882504463f;
  t135_n14: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t135_n16;
  t135_n15: return -0.025212887674570084f;
  t135_n16: return -0.2064337432384491f;
  t135_n17: if (E.getNumReferences() >= 3278962688 /*241.0*/) goto t135_n19;
  t135_n18: return 0.10995641350746155f;
  t135_n19: return 0.02341580018401146f;
  t135_n20: return -0.0008484895224682987f;
  t135_n21: return -0.027157362550497055f;
  t135_n22: return -0.020787471905350685f;
  t135_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t135_n53;
  t135_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t135_n50;
  t135_n25: if (E.getNumReferences() >= 3330629120 /*17071.0*/) goto t135_n49;
  t135_n26: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t135_n42;
  t135_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t135_n41;
  t135_n28: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t135_n30;
  t135_n29: return -0.018389597535133362f;
  t135_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t135_n34;
  t135_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t135_n33;
  t135_n32: return -0.17627766728401184f;
  t135_n33: return -0.05318787321448326f;
  t135_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n40;
  t135_n35: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t135_n39;
  t135_n36: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t135_n38;
  t135_n37: return 0.10126155614852905f;
  t135_n38: return 0.056737978011369705f;
  t135_n39: return 0.059149209409952164f;
  t135_n40: return 0.006463069934397936f;
  t135_n41: return -0.11120324581861496f;
  t135_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t135_n44;
  t135_n43: return -0.11682059615850449f;
  t135_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t135_n48;
  t135_n45: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t135_n47;
  t135_n46: return -0.005697611253708601f;
  t135_n47: return -0.1136716976761818f;
  t135_n48: return 0.030773071572184563f;
  t135_n49: return -0.7472226619720459f;
  t135_n50: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t135_n52;
  t135_n51: return 0.013264436274766922f;
  t135_n52: return 0.096340112388134f;
  t135_n53: return 0.004099064040929079f;
  t135_n54: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t135_n94;
  t135_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t135_n57;
  t135_n56: return -0.00044875554158352315f;
  t135_n57: if (E.getNumReferences() >= 3333867264 /*23395.5*/) goto t135_n79;
  t135_n58: if (E.getNumReferences() >= 3333808640 /*23281.0*/) goto t135_n68;
  t135_n59: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t135_n61;
  t135_n60: return 0.05267957225441933f;
  t135_n61: if (E.getNumReferences() >= 3332078080 /*19901.0*/) goto t135_n67;
  t135_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n64;
  t135_n63: return 0.10440721362829208f;
  t135_n64: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t135_n66;
  t135_n65: return 0.048898402601480484f;
  t135_n66: return 0.09944974631071091f;
  t135_n67: return -0.0026261373423039913f;
  t135_n68: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n78;
  t135_n69: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t135_n75;
  t135_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n74;
  t135_n71: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t135_n73;
  t135_n72: return 0.12438957393169403f;
  t135_n73: return -0.10119323432445526f;
  t135_n74: return -0.37086474895477295f;
  t135_n75: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t135_n77;
  t135_n76: return -0.025653447955846786f;
  t135_n77: return 0.11892315000295639f;
  t135_n78: return 0.10786789655685425f;
  t135_n79: if (E.getNumReferences() >= 3339934592 /*37723.5*/) goto t135_n81;
  t135_n80: return -0.007594764232635498f;
  t135_n81: if (E.getNumReferences() >= 3340748416 /*40902.5*/) goto t135_n93;
  t135_n82: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t135_n90;
  t135_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t135_n85;
  t135_n84: return -0.11064919084310532f;
  t135_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n89;
  t135_n86: if (E.getNumReferences() >= 3340364160 /*39401.5*/) goto t135_n88;
  t135_n87: return 0.09643872827291489f;
  t135_n88: return 0.10850390791893005f;
  t135_n89: return -0.18826353549957275f;
  t135_n90: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n92;
  t135_n91: return 0.11357448995113373f;
  t135_n92: return -0.08463254570960999f;
  t135_n93: return 0.012243642471730709f;
  t135_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t135_n154;
  t135_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t135_n107;
  t135_n96: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t135_n98;
  t135_n97: return -0.0018047706689685583f;
  t135_n98: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t135_n100;
  t135_n99: return 0.01211974024772644f;
  t135_n100: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t135_n102;
  t135_n101: return 0.10285189002752304f;
  t135_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t135_n104;
  t135_n103: return 0.10958916693925858f;
  t135_n104: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t135_n106;
  t135_n105: return 0.09533464163541794f;
  t135_n106: return 0.04801257699728012f;
  t135_n107: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t135_n153;
  t135_n108: if (E.getNumReferences() >= 3359807328 /*199261.5*/) goto t135_n142;
  t135_n109: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n111;
  t135_n110: return 0.03386818990111351f;
  t135_n111: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t135_n139;
  t135_n112: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t135_n136;
  t135_n113: if (E.getNumReferences() >= 3335927040 /*27418.5*/) goto t135_n121;
  t135_n114: if (E.getNumReferences() >= 3333156096 /*22006.5*/) goto t135_n120;
  t135_n115: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t135_n117;
  t135_n116: return -0.15328176319599152f;
  t135_n117: if (E.getNumReferences() >= 3332416512 /*20562.0*/) goto t135_n119;
  t135_n118: return 0.13490478694438934f;
  t135_n119: return 0.1432102918624878f;
  t135_n120: return -0.06415287405252457f;
  t135_n121: if (E.getNumReferences() >= 3341598080 /*44221.5*/) goto t135_n135;
  t135_n122: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t135_n134;
  t135_n123: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n131;
  t135_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t135_n128;
  t135_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n127;
  t135_n126: return 0.03914293274283409f;
  t135_n127: return 0.06583912670612335f;
  t135_n128: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t135_n130;
  t135_n129: return 0.1058318167924881f;
  t135_n130: return 0.04894065111875534f;
  t135_n131: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n133;
  t135_n132: return 0.1261790692806244f;
  t135_n133: return 0.051879629492759705f;
  t135_n134: return 0.11145196855068207f;
  t135_n135: return 0.023428449407219887f;
  t135_n136: if (E.getNumReferences() >= 3332303360 /*20341.0*/) goto t135_n138;
  t135_n137: return -0.30400151014328003f;
  t135_n138: return 0.12246407568454742f;
  t135_n139: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t135_n141;
  t135_n140: return -0.0553986020386219f;
  t135_n141: return 0.056402456015348434f;
  t135_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t135_n148;
  t135_n143: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n145;
  t135_n144: return 0.1161680519580841f;
  t135_n145: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t135_n147;
  t135_n146: return 0.16083143651485443f;
  t135_n147: return -0.05397263914346695f;
  t135_n148: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t135_n152;
  t135_n149: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t135_n151;
  t135_n150: return 0.10046636313199997f;
  t135_n151: return 0.022482572123408318f;
  t135_n152: return 0.1183708980679512f;
  t135_n153: return 0.0017854197649285197f;
  t135_n154: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t135_n222;
  t135_n155: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t135_n157;
  t135_n156: return 0.10213374346494675f;
  t135_n157: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t135_n181;
  t135_n158: if (E.getNumReferences() >= 3349616960 /*85554.5*/) goto t135_n178;
  t135_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t135_n161;
  t135_n160: return -0.10065914690494537f;
  t135_n161: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t135_n165;
  t135_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n164;
  t135_n163: return -0.18331879377365112f;
  t135_n164: return 0.10296192020177841f;
  t135_n165: if (E.getNumReferences() >= 3338441472 /*32329.5*/) goto t135_n171;
  t135_n166: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t135_n168;
  t135_n167: return -0.1405489146709442f;
  t135_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n170;
  t135_n169: return 0.09215538203716278f;
  t135_n170: return -0.13801966607570648f;
  t135_n171: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n177;
  t135_n172: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t135_n176;
  t135_n173: if (E.getNumReferences() >= 3341527296 /*43945.0*/) goto t135_n175;
  t135_n174: return 0.11032579839229584f;
  t135_n175: return 0.045861583203077316f;
  t135_n176: return 0.10396573692560196f;
  t135_n177: return 0.002374693052843213f;
  t135_n178: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n180;
  t135_n179: return 0.08826849609613419f;
  t135_n180: return 0.11319912225008011f;
  t135_n181: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t135_n207;
  t135_n182: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t135_n204;
  t135_n183: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t135_n197;
  t135_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n192;
  t135_n185: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t135_n187;
  t135_n186: return -0.008645984344184399f;
  t135_n187: if (E.getNumReferences() >= 3343032192 /*49823.5*/) goto t135_n191;
  t135_n188: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n190;
  t135_n189: return 0.11881081014871597f;
  t135_n190: return 0.03287316486239433f;
  t135_n191: return 0.07110555469989777f;
  t135_n192: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t135_n194;
  t135_n193: return -0.08744924515485764f;
  t135_n194: if (E.getNumReferences() >= 3353292736 /*114271.5*/) goto t135_n196;
  t135_n195: return 0.1110357940196991f;
  t135_n196: return 0.09598883986473083f;
  t135_n197: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n201;
  t135_n198: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t135_n200;
  t135_n199: return 0.11661810427904129f;
  t135_n200: return 0.0956185907125473f;
  t135_n201: if (E.getNumReferences() >= 3334472192 /*24577.0*/) goto t135_n203;
  t135_n202: return 0.10994937270879745f;
  t135_n203: return 0.046335335820913315f;
  t135_n204: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t135_n206;
  t135_n205: return 0.10340097546577454f;
  t135_n206: return 0.07512765377759933f;
  t135_n207: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t135_n221;
  t135_n208: if (E.getNumReferences() >= 3347630656 /*70036.5*/) goto t135_n220;
  t135_n209: if (E.getNumReferences() >= 3337714176 /*30909.0*/) goto t135_n219;
  t135_n210: if (E.getNumReferences() >= 3334173440 /*23993.5*/) goto t135_n212;
  t135_n211: return 0.024326352402567863f;
  t135_n212: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n214;
  t135_n213: return 0.0004012669378425926f;
  t135_n214: if (E.getNumReferences() >= 3334637824 /*24900.5*/) goto t135_n218;
  t135_n215: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t135_n217;
  t135_n216: return 0.19341494143009186f;
  t135_n217: return 0.1153712347149849f;
  t135_n218: return 0.07956889271736145f;
  t135_n219: return -0.12607945501804352f;
  t135_n220: return 0.08734706044197083f;
  t135_n221: return -0.621349036693573f;
  t135_n222: if (E.getNumReferences() >= 3337423104 /*30340.5*/) goto t135_n232;
  t135_n223: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t135_n225;
  t135_n224: return 0.05712977424263954f;
  t135_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t135_n231;
  t135_n226: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t135_n230;
  t135_n227: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t135_n229;
  t135_n228: return 0.13455964624881744f;
  t135_n229: return -0.09894262999296188f;
  t135_n230: return 0.11623034626245499f;
  t135_n231: return -0.02186611294746399f;
  t135_n232: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t135_n252;
  t135_n233: if (E.getNumReferences() >= 3338507264 /*32458.0*/) goto t135_n235;
  t135_n234: return -0.13097307085990906f;
  t135_n235: if (E.getNumReferences() >= 3339033984 /*34205.5*/) goto t135_n247;
  t135_n236: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t135_n238;
  t135_n237: return -0.0838562473654747f;
  t135_n238: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t135_n242;
  t135_n239: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t135_n241;
  t135_n240: return 0.2642424404621124f;
  t135_n241: return -0.13989073038101196f;
  t135_n242: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t135_n246;
  t135_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n245;
  t135_n244: return 0.12830020487308502f;
  t135_n245: return 0.1646413803100586f;
  t135_n246: return -0.06035400927066803f;
  t135_n247: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t135_n249;
  t135_n248: return -0.014833031222224236f;
  t135_n249: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t135_n251;
  t135_n250: return 0.09735125303268433f;
  t135_n251: return 0.016183391213417053f;
  t135_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n254;
  t135_n253: return -0.3679846525192261f;
  t135_n254: return 0.12613099813461304f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree136(const Example& E) {
  t136_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t136_n2;
  t136_n1: return -0.0005164127796888351f;
  t136_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t136_n6;
  t136_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t136_n5;
  t136_n4: return 0.008386295288801193f;
  t136_n5: return 0.02391325682401657f;
  t136_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t136_n8;
  t136_n7: return -0.008150143548846245f;
  t136_n8: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t136_n86;
  t136_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t136_n33;
  t136_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t136_n12;
  t136_n11: return -0.02124478667974472f;
  t136_n12: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t136_n16;
  t136_n13: if (E.getNumReferences() >= 3366869888 /*357084.0*/) goto t136_n15;
  t136_n14: return 0.03531802445650101f;
  t136_n15: return 0.0622725673019886f;
  t136_n16: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t136_n32;
  t136_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t136_n27;
  t136_n18: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t136_n26;
  t136_n19: if (E.getNumReferences() >= 3299053568 /*1308.5*/) goto t136_n25;
  t136_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t136_n22;
  t136_n21: return 0.109754279255867f;
  t136_n22: if (E.getNumReferences() >= 3298709504 /*1266.5*/) goto t136_n24;
  t136_n23: return 0.10606526583433151f;
  t136_n24: return 0.11783777177333832f;
  t136_n25: return 0.03169209882616997f;
  t136_n26: return 0.087729312479496f;
  t136_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t136_n29;
  t136_n28: return -0.19503436982631683f;
  t136_n29: if (E.getNumReferences() >= 3308058624 /*2767.5*/) goto t136_n31;
  t136_n30: return -0.01315764058381319f;
  t136_n31: return 0.11681945621967316f;
  t136_n32: return -0.027165241539478302f;
  t136_n33: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t136_n67;
  t136_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t136_n36;
  t136_n35: return -0.0023707658983767033f;
  t136_n36: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t136_n62;
  t136_n37: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t136_n61;
  t136_n38: if (E.getNumReferences() >= 3299151872 /*1320.5*/) goto t136_n50;
  t136_n39: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t136_n43;
  t136_n40: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t136_n42;
  t136_n41: return -0.04394848644733429f;
  t136_n42: return 0.12583348155021667f;
  t136_n43: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t136_n49;
  t136_n44: if (E.getNumReferences() >= 3298639872 /*1258.0*/) goto t136_n48;
  t136_n45: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t136_n47;
  t136_n46: return 0.13495425879955292f;
  t136_n47: return 0.11774317920207977f;
  t136_n48: return -0.1003042533993721f;
  t136_n49: return -0.11459790170192719f;
  t136_n50: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t136_n60;
  t136_n51: if (E.getNumReferences() >= 3303550976 /*1857.5*/) goto t136_n53;
  t136_n52: return -0.06700169295072556f;
  t136_n53: if (E.getNumReferences() >= 3303952384 /*1906.5*/) goto t136_n57;
  t136_n54: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t136_n56;
  t136_n55: return 0.11033707857131958f;
  t136_n56: return 0.06434668600559235f;
  t136_n57: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t136_n59;
  t136_n58: return 0.04427896440029144f;
  t136_n59: return 0.09406217932701111f;
  t136_n60: return -0.09585505723953247f;
  t136_n61: return 0.002987888641655445f;
  t136_n62: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t136_n66;
  t136_n63: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t136_n65;
  t136_n64: return 0.08908488601446152f;
  t136_n65: return 0.14503760635852814f;
  t136_n66: return 0.08204282820224762f;
  t136_n67: if (E.getNumReferences() >= 3316423680 /*5523.5*/) goto t136_n69;
  t136_n68: return -0.015185941010713577f;
  t136_n69: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t136_n79;
  t136_n70: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t136_n72;
  t136_n71: return 0.10494459420442581f;
  t136_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t136_n78;
  t136_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n75;
  t136_n74: return -0.02995757758617401f;
  t136_n75: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t136_n77;
  t136_n76: return 0.04824414104223251f;
  t136_n77: return 0.10788051038980484f;
  t136_n78: return 0.09554312378168106f;
  t136_n79: if (E.getNumReferences() >= 3317987328 /*6287.0*/) goto t136_n85;
  t136_n80: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t136_n84;
  t136_n81: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t136_n83;
  t136_n82: return 0.14045697450637817f;
  t136_n83: return 0.1262287199497223f;
  t136_n84: return 0.15626949071884155f;
  t136_n85: return 0.028192996978759766f;
  t136_n86: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t136_n96;
  t136_n87: if (E.getNumReferences() >= 3332129024 /*20000.5*/) goto t136_n89;
  t136_n88: return -0.013971316628158092f;
  t136_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t136_n91;
  t136_n90: return -0.0215836763381958f;
  t136_n91: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t136_n95;
  t136_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t136_n94;
  t136_n93: return -0.21957257390022278f;
  t136_n94: return 0.11422505974769592f;
  t136_n95: return 0.027487918734550476f;
  t136_n96: if (E.getNumReferences() >= 3346171648 /*62087.0*/) goto t136_n228;
  t136_n97: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t136_n207;
  t136_n98: if (E.getNumReferences() >= 3315700736 /*5170.5*/) goto t136_n100;
  t136_n99: return 0.006933867931365967f;
  t136_n100: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t136_n108;
  t136_n101: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t136_n107;
  t136_n102: if (E.getNumReferences() >= 3315727360 /*5183.5*/) goto t136_n106;
  t136_n103: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t136_n105;
  t136_n104: return 0.1161312460899353f;
  t136_n105: return 0.07837703824043274f;
  t136_n106: return 0.12948378920555115f;
  t136_n107: return -0.12839336693286896f;
  t136_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t136_n110;
  t136_n109: return -0.0390033982694149f;
  t136_n110: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t136_n114;
  t136_n111: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t136_n113;
  t136_n112: return 0.10945384204387665f;
  t136_n113: return -0.627169668674469f;
  t136_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t136_n206;
  t136_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t136_n159;
  t136_n116: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t136_n152;
  t136_n117: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t136_n139;
  t136_n118: if (E.getNumReferences() >= 3334899200 /*25411.0*/) goto t136_n136;
  t136_n119: if (E.getNumReferences() >= 3334023936 /*23701.5*/) goto t136_n123;
  t136_n120: if (E.getNumReferences() >= 3334015488 /*23685.0*/) goto t136_n122;
  t136_n121: return 0.01497621089220047f;
  t136_n122: return -0.3207433819770813f;
  t136_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t136_n125;
  t136_n124: return 0.029508672654628754f;
  t136_n125: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t136_n135;
  t136_n126: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t136_n132;
  t136_n127: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t136_n131;
  t136_n128: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n130;
  t136_n129: return 0.18122579157352448f;
  t136_n130: return 0.08862487226724625f;
  t136_n131: return 0.10272087901830673f;
  t136_n132: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t136_n134;
  t136_n133: return 0.1129559874534607f;
  t136_n134: return 0.02317632921040058f;
  t136_n135: return -0.04416244477033615f;
  t136_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t136_n138;
  t136_n137: return -0.08607053756713867f;
  t136_n138: return 0.0909438356757164f;
  t136_n139: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t136_n151;
  t136_n140: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t136_n144;
  t136_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t136_n143;
  t136_n142: return -0.11425014585256577f;
  t136_n143: return 0.04370420426130295f;
  t136_n144: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n150;
  t136_n145: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t136_n147;
  t136_n146: return 0.03640285134315491f;
  t136_n147: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t136_n149;
  t136_n148: return 0.046863242983818054f;
  t136_n149: return 0.12568870186805725f;
  t136_n150: return 0.08019688725471497f;
  t136_n151: return -0.10989776253700256f;
  t136_n152: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t136_n158;
  t136_n153: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t136_n155;
  t136_n154: return 0.017252527177333832f;
  t136_n155: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n157;
  t136_n156: return 0.10923302918672562f;
  t136_n157: return 0.11393396556377411f;
  t136_n158: return 0.037438903003931046f;
  t136_n159: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t136_n205;
  t136_n160: if (E.getNumReferences() >= 3315857408 /*5247.0*/) goto t136_n162;
  t136_n161: return 0.18166124820709229f;
  t136_n162: if (E.getNumReferences() >= 3319414784 /*6984.0*/) goto t136_n164;
  t136_n163: return 0.0058874087408185005f;
  t136_n164: if (E.getNumReferences() >= 3319603200 /*7076.0*/) goto t136_n166;
  t136_n165: return 0.13733001053333282f;
  t136_n166: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t136_n170;
  t136_n167: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n169;
  t136_n168: return -0.10442070662975311f;
  t136_n169: return 0.10722457617521286f;
  t136_n170: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t136_n178;
  t136_n171: if (E.getNumReferences() >= 3319705600 /*7126.0*/) goto t136_n177;
  t136_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t136_n174;
  t136_n173: return -3.027648745046463e-06f;
  t136_n174: if (E.getNumReferences() >= 3319669760 /*7108.5*/) goto t136_n176;
  t136_n175: return -0.1282409131526947f;
  t136_n176: return 0.11329738795757294f;
  t136_n177: return 0.021026337519288063f;
  t136_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t136_n194;
  t136_n179: if (E.getNumReferences() >= 3322916352 /*9195.5*/) goto t136_n193;
  t136_n180: if (E.getNumReferences() >= 3322621952 /*8908.0*/) goto t136_n188;
  t136_n181: if (E.getNumReferences() >= 3321944576 /*8246.5*/) goto t136_n183;
  t136_n182: return 0.06161767616868019f;
  t136_n183: if (E.getNumReferences() >= 3322048000 /*8347.5*/) goto t136_n187;
  t136_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t136_n186;
  t136_n185: return 0.1175752803683281f;
  t136_n186: return -0.16057994961738586f;
  t136_n187: return 0.06223843991756439f;
  t136_n188: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n190;
  t136_n189: return 0.13586276769638062f;
  t136_n190: if (E.getNumReferences() >= 3322737152 /*9020.5*/) goto t136_n192;
  t136_n191: return -0.2576340436935425f;
  t136_n192: return 0.1248709037899971f;
  t136_n193: return 0.03856479004025459f;
  t136_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t136_n196;
  t136_n195: return -0.21391896903514862f;
  t136_n196: if (E.getNumReferences() >= 3333346816 /*22379.0*/) goto t136_n200;
  t136_n197: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t136_n199;
  t136_n198: return 0.1485084593296051f;
  t136_n199: return -0.2173568457365036f;
  t136_n200: if (E.getNumReferences() >= 3340838912 /*41256.0*/) goto t136_n202;
  t136_n201: return 0.044647183269262314f;
  t136_n202: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n204;
  t136_n203: return 0.13147187232971191f;
  t136_n204: return 0.05315902456641197f;
  t136_n205: return 0.015908125787973404f;
  t136_n206: return 0.07433861494064331f;
  t136_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t136_n209;
  t136_n208: return 0.03849953040480614f;
  t136_n209: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t136_n223;
  t136_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n214;
  t136_n211: if (E.getNumReferences() >= 3340838912 /*41256.0*/) goto t136_n213;
  t136_n212: return -0.0410333126783371f;
  t136_n213: return 0.10561399161815643f;
  t136_n214: if (E.getNumReferences() >= 3302932480 /*1782.0*/) goto t136_n218;
  t136_n215: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t136_n217;
  t136_n216: return 0.11482374370098114f;
  t136_n217: return -0.1412556916475296f;
  t136_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t136_n220;
  t136_n219: return 0.06600792706012726f;
  t136_n220: if (E.getNumReferences() >= 3325197824 /*11423.5*/) goto t136_n222;
  t136_n221: return -0.10870546847581863f;
  t136_n222: return 0.10351809114217758f;
  t136_n223: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t136_n227;
  t136_n224: if (E.getNumReferences() >= 3308046336 /*2764.5*/) goto t136_n226;
  t136_n225: return 0.11424470692873001f;
  t136_n226: return 0.09265170991420746f;
  t136_n227: return 0.021307360380887985f;
  t136_n228: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t136_n238;
  t136_n229: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t136_n233;
  t136_n230: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t136_n232;
  t136_n231: return -0.11613266915082932f;
  t136_n232: return 0.10140012204647064f;
  t136_n233: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t136_n237;
  t136_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t136_n236;
  t136_n235: return -0.1389663815498352f;
  t136_n236: return 0.10642670840024948f;
  t136_n237: return 0.009310307912528515f;
  t136_n238: if (E.getNumReferences() >= 3355687776 /*134893.5*/) goto t136_n254;
  t136_n239: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t136_n241;
  t136_n240: return -0.015718236565589905f;
  t136_n241: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t136_n243;
  t136_n242: return 0.10351094603538513f;
  t136_n243: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t136_n249;
  t136_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t136_n246;
  t136_n245: return 0.012480378150939941f;
  t136_n246: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t136_n248;
  t136_n247: return 0.06164690479636192f;
  t136_n248: return -0.6861299276351929f;
  t136_n249: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t136_n253;
  t136_n250: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t136_n252;
  t136_n251: return 0.10372002422809601f;
  t136_n252: return 0.05092005804181099f;
  t136_n253: return 0.04066962003707886f;
  t136_n254: return -0.029133232310414314f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree137(const Example& E) {
  t137_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t137_n224;
  t137_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t137_n223;
  t137_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t137_n4;
  t137_n3: return -0.006784456316381693f;
  t137_n4: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t137_n204;
  t137_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t137_n87;
  t137_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t137_n8;
  t137_n7: return 0.010482413694262505f;
  t137_n8: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t137_n40;
  t137_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t137_n15;
  t137_n10: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t137_n12;
  t137_n11: return 0.007585149724036455f;
  t137_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t137_n14;
  t137_n13: return -0.12676404416561127f;
  t137_n14: return 0.04204960912466049f;
  t137_n15: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t137_n29;
  t137_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t137_n18;
  t137_n17: return 0.03179262951016426f;
  t137_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t137_n28;
  t137_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t137_n21;
  t137_n20: return 0.03416925296187401f;
  t137_n21: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t137_n25;
  t137_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t137_n24;
  t137_n23: return -0.07352160662412643f;
  t137_n24: return 0.09639039635658264f;
  t137_n25: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t137_n27;
  t137_n26: return 0.12342202663421631f;
  t137_n27: return -0.11241787672042847f;
  t137_n28: return 0.07406735420227051f;
  t137_n29: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t137_n31;
  t137_n30: return 0.01827516034245491f;
  t137_n31: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t137_n35;
  t137_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t137_n34;
  t137_n33: return -0.12523336708545685f;
  t137_n34: return 0.14315165579319f;
  t137_n35: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t137_n39;
  t137_n36: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t137_n38;
  t137_n37: return 0.06841137260198593f;
  t137_n38: return 0.15519477427005768f;
  t137_n39: return 0.012633887119591236f;
  t137_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t137_n42;
  t137_n41: return -0.0513511560857296f;
  t137_n42: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t137_n46;
  t137_n43: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t137_n45;
  t137_n44: return -0.007386655546724796f;
  t137_n45: return -0.05097606033086777f;
  t137_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t137_n48;
  t137_n47: return -0.02439088001847267f;
  t137_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t137_n56;
  t137_n49: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t137_n53;
  t137_n50: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t137_n52;
  t137_n51: return -0.06949274241924286f;
  t137_n52: return 0.09687129408121109f;
  t137_n53: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t137_n55;
  t137_n54: return 0.1480541080236435f;
  t137_n55: return 0.004054448567330837f;
  t137_n56: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t137_n80;
  t137_n57: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t137_n77;
  t137_n58: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t137_n60;
  t137_n59: return 0.08639699220657349f;
  t137_n60: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t137_n62;
  t137_n61: return -0.2906073331832886f;
  t137_n62: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t137_n76;
  t137_n63: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t137_n69;
  t137_n64: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t137_n68;
  t137_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t137_n67;
  t137_n66: return -0.17285862565040588f;
  t137_n67: return 0.11044507473707199f;
  t137_n68: return -0.010727915912866592f;
  t137_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t137_n71;
  t137_n70: return -0.049420252442359924f;
  t137_n71: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t137_n73;
  t137_n72: return 0.12426140904426575f;
  t137_n73: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t137_n75;
  t137_n74: return -0.47926053404808044f;
  t137_n75: return 0.2740961015224457f;
  t137_n76: return -0.5330658555030823f;
  t137_n77: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t137_n79;
  t137_n78: return 0.0251061599701643f;
  t137_n79: return 0.09625256061553955f;
  t137_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t137_n82;
  t137_n81: return 0.004501820541918278f;
  t137_n82: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t137_n84;
  t137_n83: return 0.14016743004322052f;
  t137_n84: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t137_n86;
  t137_n85: return -0.6272240281105042f;
  t137_n86: return 0.14058300852775574f;
  t137_n87: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t137_n143;
  t137_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t137_n90;
  t137_n89: return -0.008727162145078182f;
  t137_n90: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t137_n104;
  t137_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t137_n99;
  t137_n92: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t137_n98;
  t137_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t137_n97;
  t137_n94: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t137_n96;
  t137_n95: return -0.267622172832489f;
  t137_n96: return 0.0909530520439148f;
  t137_n97: return -0.027410294860601425f;
  t137_n98: return 0.029282527044415474f;
  t137_n99: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t137_n101;
  t137_n100: return 0.06785530596971512f;
  t137_n101: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t137_n103;
  t137_n102: return -0.025132164359092712f;
  t137_n103: return 0.08478694409132004f;
  t137_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t137_n118;
  t137_n105: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t137_n117;
  t137_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t137_n108;
  t137_n107: return 0.03839338198304176f;
  t137_n108: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t137_n110;
  t137_n109: return 0.012443636544048786f;
  t137_n110: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t137_n116;
  t137_n111: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t137_n115;
  t137_n112: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t137_n114;
  t137_n113: return 0.12891529500484467f;
  t137_n114: return 0.10574504733085632f;
  t137_n115: return 0.10029064118862152f;
  t137_n116: return -0.1156492605805397f;
  t137_n117: return 0.026810036972165108f;
  t137_n118: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t137_n142;
  t137_n119: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t137_n121;
  t137_n120: return 0.04914729297161102f;
  t137_n121: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t137_n139;
  t137_n122: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t137_n124;
  t137_n123: return 0.11795090138912201f;
  t137_n124: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t137_n138;
  t137_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t137_n137;
  t137_n126: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t137_n134;
  t137_n127: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t137_n133;
  t137_n128: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t137_n132;
  t137_n129: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t137_n131;
  t137_n130: return 0.09778846800327301f;
  t137_n131: return 0.16408704221248627f;
  t137_n132: return -0.14373822510242462f;
  t137_n133: return -0.006489576306194067f;
  t137_n134: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t137_n136;
  t137_n135: return 0.07813960313796997f;
  t137_n136: return 0.13492532074451447f;
  t137_n137: return 0.1064232662320137f;
  t137_n138: return 0.0015057780547067523f;
  t137_n139: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t137_n141;
  t137_n140: return 0.12472505867481232f;
  t137_n141: return -0.09361130744218826f;
  t137_n142: return -0.2685827314853668f;
  t137_n143: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t137_n165;
  t137_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t137_n162;
  t137_n145: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t137_n147;
  t137_n146: return 0.002007697941735387f;
  t137_n147: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t137_n149;
  t137_n148: return 0.029523266479372978f;
  t137_n149: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t137_n151;
  t137_n150: return 0.035948898643255234f;
  t137_n151: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t137_n161;
  t137_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t137_n160;
  t137_n153: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t137_n155;
  t137_n154: return -0.030473969876766205f;
  t137_n155: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t137_n159;
  t137_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t137_n158;
  t137_n157: return 0.057114724069833755f;
  t137_n158: return 0.12529215216636658f;
  t137_n159: return -0.10361336916685104f;
  t137_n160: return 0.14024153351783752f;
  t137_n161: return 0.024910826236009598f;
  t137_n162: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t137_n164;
  t137_n163: return -0.12257131189107895f;
  t137_n164: return 0.032131217420101166f;
  t137_n165: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t137_n203;
  t137_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t137_n202;
  t137_n167: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t137_n199;
  t137_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t137_n170;
  t137_n169: return -0.13371559977531433f;
  t137_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t137_n188;
  t137_n171: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t137_n173;
  t137_n172: return 0.031002353876829147f;
  t137_n173: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t137_n183;
  t137_n174: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t137_n178;
  t137_n175: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t137_n177;
  t137_n176: return 0.053144022822380066f;
  t137_n177: return 0.1245851218700409f;
  t137_n178: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t137_n182;
  t137_n179: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t137_n181;
  t137_n180: return -0.12663160264492035f;
  t137_n181: return 0.13331051170825958f;
  t137_n182: return 0.060769155621528625f;
  t137_n183: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t137_n185;
  t137_n184: return -0.1651700735092163f;
  t137_n185: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t137_n187;
  t137_n186: return 0.160080224275589f;
  t137_n187: return 0.0935988575220108f;
  t137_n188: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t137_n190;
  t137_n189: return -0.003671912243589759f;
  t137_n190: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t137_n192;
  t137_n191: return 0.5694182515144348f;
  t137_n192: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t137_n194;
  t137_n193: return -0.06977544724941254f;
  t137_n194: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t137_n196;
  t137_n195: return 0.0776682123541832f;
  t137_n196: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t137_n198;
  t137_n197: return 0.09258375316858292f;
  t137_n198: return -0.013218323700129986f;
  t137_n199: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t137_n201;
  t137_n200: return 0.08581152558326721f;
  t137_n201: return -0.11089219897985458f;
  t137_n202: return -0.04055776819586754f;
  t137_n203: return 0.10628848522901535f;
  t137_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t137_n220;
  t137_n205: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t137_n207;
  t137_n206: return 0.017400206997990608f;
  t137_n207: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t137_n217;
  t137_n208: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t137_n212;
  t137_n209: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t137_n211;
  t137_n210: return 0.11717648804187775f;
  t137_n211: return 0.03550538420677185f;
  t137_n212: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t137_n214;
  t137_n213: return -0.1076115071773529f;
  t137_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t137_n216;
  t137_n215: return -0.08720636367797852f;
  t137_n216: return 0.1470232605934143f;
  t137_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t137_n219;
  t137_n218: return -0.2455192357301712f;
  t137_n219: return 0.03945760056376457f;
  t137_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t137_n222;
  t137_n221: return 0.061150841414928436f;
  t137_n222: return 0.0261967945843935f;
  t137_n223: return -0.0012098001316189766f;
  t137_n224: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t137_n226;
  t137_n225: return -0.005928732454776764f;
  t137_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t137_n236;
  t137_n227: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t137_n235;
  t137_n228: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t137_n234;
  t137_n229: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t137_n231;
  t137_n230: return 0.10793446004390717f;
  t137_n231: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t137_n233;
  t137_n232: return 0.09463182091712952f;
  t137_n233: return -0.020754415541887283f;
  t137_n234: return 0.11408918350934982f;
  t137_n235: return 0.010663012973964214f;
  t137_n236: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t137_n254;
  t137_n237: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t137_n251;
  t137_n238: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t137_n244;
  t137_n239: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t137_n241;
  t137_n240: return 0.018183359876275063f;
  t137_n241: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t137_n243;
  t137_n242: return 0.11126412451267242f;
  t137_n243: return 0.12046452611684799f;
  t137_n244: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t137_n246;
  t137_n245: return 0.01425148919224739f;
  t137_n246: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t137_n250;
  t137_n247: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t137_n249;
  t137_n248: return 0.17009437084197998f;
  t137_n249: return -0.10507209599018097f;
  t137_n250: return 0.03720647469162941f;
  t137_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t137_n253;
  t137_n252: return 0.09539894014596939f;
  t137_n253: return 0.107129767537117f;
  t137_n254: return 0.011465990915894508f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree138(const Example& E) {
  t138_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t138_n166;
  t138_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t138_n3;
  t138_n2: return -0.0007724555907770991f;
  t138_n3: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t138_n165;
  t138_n4: if (E.getNumReferences() >= 3327652864 /*13821.0*/) goto t138_n118;
  t138_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t138_n7;
  t138_n6: return -0.005701020359992981f;
  t138_n7: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t138_n77;
  t138_n8: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t138_n10;
  t138_n9: return 0.010722859762609005f;
  t138_n10: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t138_n28;
  t138_n11: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t138_n17;
  t138_n12: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t138_n14;
  t138_n13: return -0.12389856576919556f;
  t138_n14: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t138_n16;
  t138_n15: return -0.29655706882476807f;
  t138_n16: return 0.10428669303655624f;
  t138_n17: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t138_n23;
  t138_n18: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t138_n22;
  t138_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t138_n21;
  t138_n20: return 0.03488518297672272f;
  t138_n21: return 0.10447019338607788f;
  t138_n22: return -0.13864538073539734f;
  t138_n23: if (E.getNumReferences() >= 3309795328 /*3191.5*/) goto t138_n27;
  t138_n24: if (E.getNumReferences() >= 3309611008 /*3146.5*/) goto t138_n26;
  t138_n25: return 0.05218896269798279f;
  t138_n26: return 0.14711160957813263f;
  t138_n27: return -0.16186389327049255f;
  t138_n28: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t138_n30;
  t138_n29: return 0.005086042452603579f;
  t138_n30: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t138_n34;
  t138_n31: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t138_n33;
  t138_n32: return -1.5383135080337524f;
  t138_n33: return 0.02632301114499569f;
  t138_n34: if (E.getNumReferences() >= 3278733312 /*237.5*/) goto t138_n76;
  t138_n35: if (E.getNumReferences() >= 3278307328 /*231.0*/) goto t138_n73;
  t138_n36: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t138_n60;
  t138_n37: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t138_n57;
  t138_n38: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t138_n48;
  t138_n39: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t138_n41;
  t138_n40: return 0.07417742908000946f;
  t138_n41: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t138_n45;
  t138_n42: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t138_n44;
  t138_n43: return 0.12119223177433014f;
  t138_n44: return -0.14553698897361755f;
  t138_n45: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t138_n47;
  t138_n46: return 0.2104472666978836f;
  t138_n47: return 0.10361972451210022f;
  t138_n48: if (E.getNumReferences() >= 3268739072 /*106.5*/) goto t138_n50;
  t138_n49: return -0.16436487436294556f;
  t138_n50: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t138_n52;
  t138_n51: return 0.1394404023885727f;
  t138_n52: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t138_n56;
  t138_n53: if (E.getNumReferences() >= 3273687040 /*160.5*/) goto t138_n55;
  t138_n54: return 0.11144914478063583f;
  t138_n55: return -0.11836748570203781f;
  t138_n56: return -0.23089967668056488f;
  t138_n57: if (E.getNumReferences() >= 3275128832 /*182.5*/) goto t138_n59;
  t138_n58: return 0.11858359724283218f;
  t138_n59: return 0.008985819295048714f;
  t138_n60: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t138_n62;
  t138_n61: return 0.040789514780044556f;
  t138_n62: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t138_n66;
  t138_n63: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t138_n65;
  t138_n64: return -0.2644260823726654f;
  t138_n65: return 0.12670621275901794f;
  t138_n66: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t138_n68;
  t138_n67: return 0.06623811274766922f;
  t138_n68: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t138_n70;
  t138_n69: return -0.11708545684814453f;
  t138_n70: if (E.getNumReferences() >= 3274473472 /*172.5*/) goto t138_n72;
  t138_n71: return 0.12248381972312927f;
  t138_n72: return 0.08444467186927795f;
  t138_n73: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t138_n75;
  t138_n74: return 0.11569450050592422f;
  t138_n75: return 0.10699772834777832f;
  t138_n76: return 0.018350273370742798f;
  t138_n77: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t138_n89;
  t138_n78: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t138_n86;
  t138_n79: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t138_n81;
  t138_n80: return -0.022036153823137283f;
  t138_n81: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t138_n83;
  t138_n82: return 0.0719277411699295f;
  t138_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t138_n85;
  t138_n84: return -0.3594520390033722f;
  t138_n85: return 0.5295704007148743f;
  t138_n86: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t138_n88;
  t138_n87: return -0.008871777914464474f;
  t138_n88: return -0.04945468530058861f;
  t138_n89: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t138_n117;
  t138_n90: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t138_n108;
  t138_n91: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t138_n93;
  t138_n92: return 0.008343550376594067f;
  t138_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t138_n103;
  t138_n94: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t138_n98;
  t138_n95: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t138_n97;
  t138_n96: return -0.015479793772101402f;
  t138_n97: return 0.02915956638753414f;
  t138_n98: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t138_n102;
  t138_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Namespace))) goto t138_n101;
  t138_n100: return -0.0008285543881356716f;
  t138_n101: return 0.06250505149364471f;
  t138_n102: return -0.016040923073887825f;
  t138_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t138_n107;
  t138_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t138_n106;
  t138_n105: return -4.06507682800293f;
  t138_n106: return -0.012873885221779346f;
  t138_n107: return 0.015089508146047592f;
  t138_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t138_n110;
  t138_n109: return -0.0009451155783608556f;
  t138_n110: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t138_n112;
  t138_n111: return 0.023914899677038193f;
  t138_n112: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t138_n116;
  t138_n113: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t138_n115;
  t138_n114: return 0.07546931505203247f;
  t138_n115: return 0.04770367220044136f;
  t138_n116: return 0.018747596070170403f;
  t138_n117: return -0.2660566568374634f;
  t138_n118: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t138_n138;
  t138_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t138_n133;
  t138_n120: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t138_n124;
  t138_n121: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t138_n123;
  t138_n122: return 0.05935997515916824f;
  t138_n123: return 0.10147859156131744f;
  t138_n124: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t138_n128;
  t138_n125: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t138_n127;
  t138_n126: return 0.13201573491096497f;
  t138_n127: return 0.19513648748397827f;
  t138_n128: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t138_n130;
  t138_n129: return 0.06790991872549057f;
  t138_n130: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t138_n132;
  t138_n131: return 0.10057190805673599f;
  t138_n132: return 0.1016656830906868f;
  t138_n133: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t138_n135;
  t138_n134: return 0.09205907583236694f;
  t138_n135: if (E.getNumReferences() >= 3329037312 /*15173.0*/) goto t138_n137;
  t138_n136: return 0.1013917326927185f;
  t138_n137: return -0.07842633128166199f;
  t138_n138: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t138_n140;
  t138_n139: return -0.10024245083332062f;
  t138_n140: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t138_n164;
  t138_n141: if (E.getNumReferences() >= 3331505664 /*18783.0*/) goto t138_n143;
  t138_n142: return -0.06278415769338608f;
  t138_n143: if (E.getNumReferences() >= 3331936768 /*19625.0*/) goto t138_n147;
  t138_n144: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t138_n146;
  t138_n145: return 0.11401360481977463f;
  t138_n146: return 0.0766739472746849f;
  t138_n147: if (E.getNumReferences() >= 3334924800 /*25461.0*/) goto t138_n149;
  t138_n148: return -0.008690974675118923f;
  t138_n149: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t138_n153;
  t138_n150: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t138_n152;
  t138_n151: return 0.12574049830436707f;
  t138_n152: return 0.13680772483348846f;
  t138_n153: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t138_n163;
  t138_n154: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t138_n156;
  t138_n155: return -0.007531364448368549f;
  t138_n156: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t138_n160;
  t138_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t138_n159;
  t138_n158: return -0.38653722405433655f;
  t138_n159: return 0.04880162328481674f;
  t138_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t138_n162;
  t138_n161: return 0.08775895833969116f;
  t138_n162: return 0.09895258396863937f;
  t138_n163: return -0.2182459533214569f;
  t138_n164: return -0.0030753971077501774f;
  t138_n165: return -0.07470909506082535f;
  t138_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t138_n170;
  t138_n167: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t138_n169;
  t138_n168: return 0.010199818760156631f;
  t138_n169: return -0.02873804233968258f;
  t138_n170: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t138_n202;
  t138_n171: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t138_n187;
  t138_n172: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t138_n174;
  t138_n173: return -0.07856068015098572f;
  t138_n174: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t138_n176;
  t138_n175: return 0.20096388459205627f;
  t138_n176: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t138_n184;
  t138_n177: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t138_n183;
  t138_n178: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t138_n180;
  t138_n179: return 0.08023542165756226f;
  t138_n180: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t138_n182;
  t138_n181: return 0.11956530064344406f;
  t138_n182: return -0.5837963223457336f;
  t138_n183: return -0.18654920160770416f;
  t138_n184: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t138_n186;
  t138_n185: return 0.11830539256334305f;
  t138_n186: return 0.1893777698278427f;
  t138_n187: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t138_n189;
  t138_n188: return 0.11072154343128204f;
  t138_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t138_n193;
  t138_n190: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t138_n192;
  t138_n191: return 0.05622564256191254f;
  t138_n192: return 0.11271099746227264f;
  t138_n193: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t138_n195;
  t138_n194: return 0.08693580329418182f;
  t138_n195: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t138_n201;
  t138_n196: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t138_n200;
  t138_n197: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t138_n199;
  t138_n198: return 0.09665334969758987f;
  t138_n199: return 0.11204490065574646f;
  t138_n200: return 0.10109641402959824f;
  t138_n201: return 0.08439411222934723f;
  t138_n202: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t138_n204;
  t138_n203: return -0.0812164917588234f;
  t138_n204: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t138_n206;
  t138_n205: return -0.06541159749031067f;
  t138_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t138_n244;
  t138_n207: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t138_n211;
  t138_n208: if (E.getNumReferences() >= 3342177536 /*46485.0*/) goto t138_n210;
  t138_n209: return -0.1458313763141632f;
  t138_n210: return 0.00873592495918274f;
  t138_n211: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t138_n243;
  t138_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t138_n234;
  t138_n213: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t138_n233;
  t138_n214: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t138_n232;
  t138_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t138_n231;
  t138_n216: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t138_n222;
  t138_n217: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t138_n221;
  t138_n218: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t138_n220;
  t138_n219: return -0.10717799514532089f;
  t138_n220: return 0.11291225254535675f;
  t138_n221: return -0.1311616748571396f;
  t138_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t138_n224;
  t138_n223: return -0.17661897838115692f;
  t138_n224: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t138_n226;
  t138_n225: return 0.05925723910331726f;
  t138_n226: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t138_n230;
  t138_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t138_n229;
  t138_n228: return 0.040629126131534576f;
  t138_n229: return 0.1037616953253746f;
  t138_n230: return 0.08175888657569885f;
  t138_n231: return 0.013501527719199657f;
  t138_n232: return -0.07197187095880508f;
  t138_n233: return -0.006951607298105955f;
  t138_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t138_n240;
  t138_n235: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t138_n239;
  t138_n236: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t138_n238;
  t138_n237: return 0.08852169662714005f;
  t138_n238: return 0.11152675002813339f;
  t138_n239: return 0.04314926266670227f;
  t138_n240: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t138_n242;
  t138_n241: return 0.22408905625343323f;
  t138_n242: return -0.18479949235916138f;
  t138_n243: return 0.12375987321138382f;
  t138_n244: if (E.getNumReferences() >= 3342077440 /*46094.0*/) goto t138_n254;
  t138_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t138_n247;
  t138_n246: return 0.09927480667829514f;
  t138_n247: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t138_n253;
  t138_n248: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t138_n250;
  t138_n249: return 0.14196032285690308f;
  t138_n250: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t138_n252;
  t138_n251: return 0.04642779007554054f;
  t138_n252: return 0.10909327119588852f;
  t138_n253: return 0.1016545221209526f;
  t138_n254: return 0.014301563613116741f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree139(const Example& E) {
  t139_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t139_n254;
  t139_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t139_n143;
  t139_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t139_n4;
  t139_n3: return -0.018384454771876335f;
  t139_n4: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t139_n124;
  t139_n5: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t139_n7;
  t139_n6: return -0.004253596533089876f;
  t139_n7: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t139_n55;
  t139_n8: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t139_n14;
  t139_n9: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t139_n13;
  t139_n10: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t139_n12;
  t139_n11: return -0.08169001340866089f;
  t139_n12: return 0.09945235401391983f;
  t139_n13: return 0.03370939940214157f;
  t139_n14: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t139_n22;
  t139_n15: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t139_n21;
  t139_n16: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t139_n18;
  t139_n17: return 0.047203440219163895f;
  t139_n18: if (E.getFilterLength() >= 3245867008 /*15.5*/) goto t139_n20;
  t139_n19: return 0.12218774855136871f;
  t139_n20: return 0.11740966141223907f;
  t139_n21: return -0.010177774354815483f;
  t139_n22: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t139_n24;
  t139_n23: return 0.004547168966382742f;
  t139_n24: if (E.getNumReferences() >= 3347692736 /*70521.5*/) goto t139_n54;
  t139_n25: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t139_n53;
  t139_n26: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t139_n46;
  t139_n27: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t139_n39;
  t139_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t139_n36;
  t139_n29: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t139_n31;
  t139_n30: return -0.14833597838878632f;
  t139_n31: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t139_n33;
  t139_n32: return 0.06671947985887527f;
  t139_n33: if (E.getNumReferences() >= 3279716352 /*252.5*/) goto t139_n35;
  t139_n34: return 0.12343072146177292f;
  t139_n35: return 0.05949155613780022f;
  t139_n36: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t139_n38;
  t139_n37: return 0.025242434814572334f;
  t139_n38: return -0.27463284134864807f;
  t139_n39: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t139_n43;
  t139_n40: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t139_n42;
  t139_n41: return 0.11059103906154633f;
  t139_n42: return -0.08072938024997711f;
  t139_n43: if (E.getNumReferences() >= 3252158464 /*27.0*/) goto t139_n45;
  t139_n44: return 0.13635294139385223f;
  t139_n45: return 0.093729667365551f;
  t139_n46: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t139_n50;
  t139_n47: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t139_n49;
  t139_n48: return 0.0915154218673706f;
  t139_n49: return 0.14541581273078918f;
  t139_n50: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t139_n52;
  t139_n51: return 0.057077743113040924f;
  t139_n52: return 0.1098184585571289f;
  t139_n53: return 0.0280531607568264f;
  t139_n54: return 0.12161555141210556f;
  t139_n55: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t139_n115;
  t139_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t139_n66;
  t139_n57: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t139_n65;
  t139_n58: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t139_n64;
  t139_n59: if (E.getNumReferences() >= 3253731328 /*30.0*/) goto t139_n61;
  t139_n60: return 0.013816497288644314f;
  t139_n61: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t139_n63;
  t139_n62: return 0.10013727098703384f;
  t139_n63: return -0.1457962691783905f;
  t139_n64: return -0.02300512231886387f;
  t139_n65: return -1.863906741142273f;
  t139_n66: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t139_n102;
  t139_n67: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t139_n97;
  t139_n68: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t139_n90;
  t139_n69: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t139_n81;
  t139_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t139_n72;
  t139_n71: return 0.0855269581079483f;
  t139_n72: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t139_n80;
  t139_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t139_n75;
  t139_n74: return 0.06316065788269043f;
  t139_n75: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t139_n79;
  t139_n76: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t139_n78;
  t139_n77: return -0.12551608681678772f;
  t139_n78: return 0.12768417596817017f;
  t139_n79: return 0.059449851512908936f;
  t139_n80: return 0.07312171161174774f;
  t139_n81: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t139_n83;
  t139_n82: return -0.015837883576750755f;
  t139_n83: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t139_n89;
  t139_n84: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t139_n86;
  t139_n85: return -0.01689411886036396f;
  t139_n86: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t139_n88;
  t139_n87: return 0.13402986526489258f;
  t139_n88: return -0.17376291751861572f;
  t139_n89: return 0.06420429050922394f;
  t139_n90: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t139_n92;
  t139_n91: return 0.1588079333305359f;
  t139_n92: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t139_n96;
  t139_n93: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t139_n95;
  t139_n94: return 0.13702543079853058f;
  t139_n95: return 0.039951618760824203f;
  t139_n96: return 0.10910559445619583f;
  t139_n97: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t139_n101;
  t139_n98: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t139_n100;
  t139_n99: return 0.11511901766061783f;
  t139_n100: return -0.2303636521100998f;
  t139_n101: return -0.01937801204621792f;
  t139_n102: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t139_n114;
  t139_n103: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t139_n105;
  t139_n104: return 0.07644256204366684f;
  t139_n105: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t139_n109;
  t139_n106: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t139_n108;
  t139_n107: return -0.1439039260149002f;
  t139_n108: return 0.13152876496315002f;
  t139_n109: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t139_n113;
  t139_n110: if (E.getNumReferences() >= 3285483520 /*425.0*/) goto t139_n112;
  t139_n111: return 0.6284003853797913f;
  t139_n112: return 0.11207885295152664f;
  t139_n113: return 0.05354832857847214f;
  t139_n114: return -0.08490142971277237f;
  t139_n115: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t139_n117;
  t139_n116: return -0.03713218867778778f;
  t139_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t139_n123;
  t139_n118: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t139_n122;
  t139_n119: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t139_n121;
  t139_n120: return 0.1741107553243637f;
  t139_n121: return 0.11977539211511612f;
  t139_n122: return 0.05885745584964752f;
  t139_n123: return 0.03174600005149841f;
  t139_n124: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t139_n126;
  t139_n125: return 0.005562969017773867f;
  t139_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t139_n128;
  t139_n127: return -0.06149500980973244f;
  t139_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t139_n134;
  t139_n129: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t139_n131;
  t139_n130: return 0.013821377418935299f;
  t139_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t139_n133;
  t139_n132: return 0.05288488045334816f;
  t139_n133: return 0.007274182979017496f;
  t139_n134: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t139_n142;
  t139_n135: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t139_n141;
  t139_n136: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t139_n140;
  t139_n137: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t139_n139;
  t139_n138: return 0.09868999570608139f;
  t139_n139: return 0.10143256932497025f;
  t139_n140: return 0.07287311553955078f;
  t139_n141: return 0.06841184943914413f;
  t139_n142: return -0.044711172580718994f;
  t139_n143: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t139_n145;
  t139_n144: return -0.053343579173088074f;
  t139_n145: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t139_n237;
  t139_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t139_n148;
  t139_n147: return 0.0007021354977041483f;
  t139_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t139_n152;
  t139_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t139_n151;
  t139_n150: return -0.11067859828472137f;
  t139_n151: return 0.003512233728542924f;
  t139_n152: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t139_n154;
  t139_n153: return 0.008088372647762299f;
  t139_n154: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t139_n164;
  t139_n155: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t139_n163;
  t139_n156: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t139_n160;
  t139_n157: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t139_n159;
  t139_n158: return -0.008938190527260303f;
  t139_n159: return -0.030797917395830154f;
  t139_n160: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t139_n162;
  t139_n161: return -0.03257538378238678f;
  t139_n162: return 0.007024771999567747f;
  t139_n163: return 0.02559307962656021f;
  t139_n164: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t139_n180;
  t139_n165: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t139_n179;
  t139_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t139_n178;
  t139_n167: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t139_n169;
  t139_n168: return -0.03254048526287079f;
  t139_n169: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t139_n177;
  t139_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t139_n172;
  t139_n171: return -0.13407059013843536f;
  t139_n172: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t139_n174;
  t139_n173: return -0.17986012995243073f;
  t139_n174: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t139_n176;
  t139_n175: return 0.09789270162582397f;
  t139_n176: return -0.00011314953735563904f;
  t139_n177: return -0.1762036383152008f;
  t139_n178: return -0.017564935609698296f;
  t139_n179: return 0.0741783082485199f;
  t139_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t139_n184;
  t139_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t139_n183;
  t139_n182: return -0.03189030662178993f;
  t139_n183: return 0.0396646223962307f;
  t139_n184: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t139_n236;
  t139_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t139_n233;
  t139_n186: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t139_n192;
  t139_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t139_n189;
  t139_n188: return 0.06994058936834335f;
  t139_n189: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t139_n191;
  t139_n190: return -0.13025543093681335f;
  t139_n191: return 0.09085720777511597f;
  t139_n192: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t139_n228;
  t139_n193: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t139_n209;
  t139_n194: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t139_n204;
  t139_n195: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t139_n199;
  t139_n196: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t139_n198;
  t139_n197: return 0.07727500051259995f;
  t139_n198: return -0.018773090094327927f;
  t139_n199: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t139_n203;
  t139_n200: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t139_n202;
  t139_n201: return -0.1325111836194992f;
  t139_n202: return 0.10144128650426865f;
  t139_n203: return 0.0637061670422554f;
  t139_n204: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t139_n208;
  t139_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t139_n207;
  t139_n206: return 0.12825541198253632f;
  t139_n207: return 0.12288645654916763f;
  t139_n208: return 0.047262173146009445f;
  t139_n209: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t139_n221;
  t139_n210: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t139_n212;
  t139_n211: return 0.07823525369167328f;
  t139_n212: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t139_n220;
  t139_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t139_n215;
  t139_n214: return 0.08274500072002411f;
  t139_n215: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t139_n219;
  t139_n216: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t139_n218;
  t139_n217: return -0.11995347589254379f;
  t139_n218: return 0.12059272080659866f;
  t139_n219: return 0.13593368232250214f;
  t139_n220: return -0.044229134917259216f;
  t139_n221: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t139_n225;
  t139_n222: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t139_n224;
  t139_n223: return 0.05281137675046921f;
  t139_n224: return 0.1130647361278534f;
  t139_n225: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t139_n227;
  t139_n226: return -0.019327523186802864f;
  t139_n227: return 0.11692661792039871f;
  t139_n228: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t139_n230;
  t139_n229: return 0.05554017424583435f;
  t139_n230: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t139_n232;
  t139_n231: return -0.055477458983659744f;
  t139_n232: return 0.19137047231197357f;
  t139_n233: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t139_n235;
  t139_n234: return 0.046292442828416824f;
  t139_n235: return -0.0773678570985794f;
  t139_n236: return -0.10411252826452255f;
  t139_n237: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t139_n241;
  t139_n238: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t139_n240;
  t139_n239: return 0.003010950982570648f;
  t139_n240: return -0.07518351823091507f;
  t139_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t139_n253;
  t139_n242: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t139_n244;
  t139_n243: return -0.005300991237163544f;
  t139_n244: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t139_n250;
  t139_n245: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t139_n249;
  t139_n246: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t139_n248;
  t139_n247: return 0.015173152089118958f;
  t139_n248: return 0.03825343772768974f;
  t139_n249: return -0.017184924334287643f;
  t139_n250: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t139_n252;
  t139_n251: return 0.0249615665525198f;
  t139_n252: return 0.04505009576678276f;
  t139_n253: return 0.010236939415335655f;
  t139_n254: return -0.04702233895659447f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree140(const Example& E) {
  t140_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t140_n2;
  t140_n1: return -0.00034147530095651746f;
  t140_n2: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t140_n192;
  t140_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t140_n5;
  t140_n4: return -0.0006226508994586766f;
  t140_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t140_n69;
  t140_n6: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t140_n64;
  t140_n7: if (E.getNumReferences() >= 3349883520 /*87637.0*/) goto t140_n19;
  t140_n8: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t140_n18;
  t140_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n13;
  t140_n10: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t140_n12;
  t140_n11: return 0.01869836263358593f;
  t140_n12: return 0.2470342516899109f;
  t140_n13: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t140_n15;
  t140_n14: return 0.026692422106862068f;
  t140_n15: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t140_n17;
  t140_n16: return 0.10252829641103745f;
  t140_n17: return 0.10555864125490189f;
  t140_n18: return -0.022632397711277008f;
  t140_n19: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t140_n31;
  t140_n20: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t140_n26;
  t140_n21: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n23;
  t140_n22: return -0.10470467060804367f;
  t140_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n25;
  t140_n24: return 0.11027631163597107f;
  t140_n25: return 0.10115274786949158f;
  t140_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n30;
  t140_n27: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t140_n29;
  t140_n28: return 0.1885467767715454f;
  t140_n29: return -0.33489421010017395f;
  t140_n30: return 0.06033853441476822f;
  t140_n31: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t140_n63;
  t140_n32: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t140_n34;
  t140_n33: return -0.06327182054519653f;
  t140_n34: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t140_n46;
  t140_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n45;
  t140_n36: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t140_n44;
  t140_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t140_n41;
  t140_n38: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t140_n40;
  t140_n39: return 0.12275151163339615f;
  t140_n40: return 0.09565731137990952f;
  t140_n41: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t140_n43;
  t140_n42: return -1.9190890789031982f;
  t140_n43: return 0.09267310798168182f;
  t140_n44: return -0.6240440607070923f;
  t140_n45: return 0.07645323872566223f;
  t140_n46: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n62;
  t140_n47: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t140_n51;
  t140_n48: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t140_n50;
  t140_n49: return 0.037009309977293015f;
  t140_n50: return 0.09593233466148376f;
  t140_n51: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t140_n53;
  t140_n52: return -0.682624101638794f;
  t140_n53: if (E.getNumReferences() >= 3368810912 /*417741.0*/) goto t140_n59;
  t140_n54: if (E.getNumReferences() >= 3365641360 /*318692.5*/) goto t140_n56;
  t140_n55: return 0.02889098785817623f;
  t140_n56: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t140_n58;
  t140_n57: return 0.04625469818711281f;
  t140_n58: return 0.12102112174034119f;
  t140_n59: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t140_n61;
  t140_n60: return -0.17713116109371185f;
  t140_n61: return 0.011174670420587063f;
  t140_n62: return 0.013868148438632488f;
  t140_n63: return -0.02772345393896103f;
  t140_n64: if (E.getNumReferences() >= 3370129424 /*458944.5*/) goto t140_n68;
  t140_n65: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t140_n67;
  t140_n66: return 0.2572278678417206f;
  t140_n67: return -0.07841795682907104f;
  t140_n68: return -0.22497984766960144f;
  t140_n69: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t140_n157;
  t140_n70: if (E.getNumReferences() >= 3350811072 /*94883.5*/) goto t140_n156;
  t140_n71: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t140_n117;
  t140_n72: if (E.getNumReferences() >= 3348238784 /*74787.5*/) goto t140_n96;
  t140_n73: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t140_n93;
  t140_n74: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t140_n76;
  t140_n75: return 0.02859710343182087f;
  t140_n76: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t140_n86;
  t140_n77: if (E.getNumReferences() >= 3346171136 /*62085.0*/) goto t140_n85;
  t140_n78: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t140_n80;
  t140_n79: return 0.002952534006908536f;
  t140_n80: if (E.getNumReferences() >= 3332418304 /*20565.5*/) goto t140_n82;
  t140_n81: return 0.09038684517145157f;
  t140_n82: if (E.getNumReferences() >= 3334534144 /*24698.0*/) goto t140_n84;
  t140_n83: return -0.7106515765190125f;
  t140_n84: return -0.16675066947937012f;
  t140_n85: return -1.0669751167297363f;
  t140_n86: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t140_n88;
  t140_n87: return -0.10447824001312256f;
  t140_n88: if (E.getNumReferences() >= 3340538496 /*40082.5*/) goto t140_n90;
  t140_n89: return 0.10025584697723389f;
  t140_n90: if (E.getNumReferences() >= 3345400960 /*59076.5*/) goto t140_n92;
  t140_n91: return 0.10922681540250778f;
  t140_n92: return -0.019177230075001717f;
  t140_n93: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n95;
  t140_n94: return -0.17479005455970764f;
  t140_n95: return 0.057817015796899796f;
  t140_n96: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t140_n112;
  t140_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t140_n103;
  t140_n98: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t140_n102;
  t140_n99: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t140_n101;
  t140_n100: return -0.03375506401062012f;
  t140_n101: return 0.13148252665996552f;
  t140_n102: return -0.08243200182914734f;
  t140_n103: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t140_n105;
  t140_n104: return -0.008069777861237526f;
  t140_n105: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n109;
  t140_n106: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t140_n108;
  t140_n107: return 0.07730647176504135f;
  t140_n108: return 0.10559394210577011f;
  t140_n109: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t140_n111;
  t140_n110: return 0.09301245957612991f;
  t140_n111: return -0.014198646880686283f;
  t140_n112: if (E.getNumReferences() >= 3350460992 /*92148.5*/) goto t140_n114;
  t140_n113: return 0.016943499445915222f;
  t140_n114: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n116;
  t140_n115: return 0.05701713263988495f;
  t140_n116: return 0.06280618906021118f;
  t140_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t140_n141;
  t140_n118: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t140_n140;
  t140_n119: if (E.getNumReferences() >= 3340106752 /*38396.0*/) goto t140_n131;
  t140_n120: if (E.getNumReferences() >= 3336351232 /*28247.0*/) goto t140_n130;
  t140_n121: if (E.getNumReferences() >= 3336193792 /*27939.5*/) goto t140_n129;
  t140_n122: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t140_n128;
  t140_n123: if (E.getNumReferences() >= 3333474560 /*22628.5*/) goto t140_n125;
  t140_n124: return -0.02094852551817894f;
  t140_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n127;
  t140_n126: return 0.11638307571411133f;
  t140_n127: return -0.41425928473472595f;
  t140_n128: return 0.04892871156334877f;
  t140_n129: return 0.47732478380203247f;
  t140_n130: return -0.11426212638616562f;
  t140_n131: if (E.getNumReferences() >= 3341427584 /*43555.5*/) goto t140_n133;
  t140_n132: return 0.11271502077579498f;
  t140_n133: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t140_n135;
  t140_n134: return 0.2102934718132019f;
  t140_n135: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n137;
  t140_n136: return 0.13019384443759918f;
  t140_n137: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t140_n139;
  t140_n138: return 0.11757270246744156f;
  t140_n139: return -0.004294759593904018f;
  t140_n140: return -0.04327978566288948f;
  t140_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n147;
  t140_n142: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t140_n146;
  t140_n143: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t140_n145;
  t140_n144: return 0.052496593445539474f;
  t140_n145: return 0.10420368611812592f;
  t140_n146: return 0.13397644460201263f;
  t140_n147: if (E.getNumReferences() >= 3346358272 /*62816.0*/) goto t140_n153;
  t140_n148: if (E.getNumReferences() >= 3334260992 /*24164.5*/) goto t140_n150;
  t140_n149: return 0.021952908486127853f;
  t140_n150: if (E.getNumReferences() >= 3334637824 /*24900.5*/) goto t140_n152;
  t140_n151: return 0.10813838988542557f;
  t140_n152: return 0.10930529981851578f;
  t140_n153: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n155;
  t140_n154: return -1.4928148984909058f;
  t140_n155: return -0.02452990412712097f;
  t140_n156: return -0.03114793635904789f;
  t140_n157: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t140_n167;
  t140_n158: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t140_n166;
  t140_n159: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t140_n161;
  t140_n160: return 0.016811447218060493f;
  t140_n161: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t140_n163;
  t140_n162: return 0.16472765803337097f;
  t140_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n165;
  t140_n164: return 0.1301960051059723f;
  t140_n165: return 0.12288934737443924f;
  t140_n166: return -0.11950868368148804f;
  t140_n167: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t140_n191;
  t140_n168: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t140_n178;
  t140_n169: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t140_n177;
  t140_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t140_n172;
  t140_n171: return -0.014706188812851906f;
  t140_n172: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t140_n176;
  t140_n173: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n175;
  t140_n174: return 0.10422506183385849f;
  t140_n175: return 0.04010577127337456f;
  t140_n176: return -0.10906124860048294f;
  t140_n177: return 0.033121999353170395f;
  t140_n178: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n186;
  t140_n179: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t140_n185;
  t140_n180: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t140_n184;
  t140_n181: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t140_n183;
  t140_n182: return 0.035444580018520355f;
  t140_n183: return 0.07950285077095032f;
  t140_n184: return 0.047200266271829605f;
  t140_n185: return 0.07644045352935791f;
  t140_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t140_n188;
  t140_n187: return 0.025895489379763603f;
  t140_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n190;
  t140_n189: return 0.08002832531929016f;
  t140_n190: return 0.03668691962957382f;
  t140_n191: return -0.036835379898548126f;
  t140_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t140_n196;
  t140_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t140_n195;
  t140_n194: return 0.004024907946586609f;
  t140_n195: return 0.023482557386159897f;
  t140_n196: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t140_n240;
  t140_n197: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t140_n199;
  t140_n198: return 0.10112787783145905f;
  t140_n199: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t140_n219;
  t140_n200: if (E.getNumReferences() >= 3349616960 /*85554.5*/) goto t140_n216;
  t140_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t140_n203;
  t140_n202: return -0.08510429412126541f;
  t140_n203: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t140_n207;
  t140_n204: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n206;
  t140_n205: return -0.10160898417234421f;
  t140_n206: return 0.11866551637649536f;
  t140_n207: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n215;
  t140_n208: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t140_n214;
  t140_n209: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t140_n211;
  t140_n210: return 0.013823929242789745f;
  t140_n211: if (E.getNumReferences() >= 3341667584 /*44493.0*/) goto t140_n213;
  t140_n212: return 0.0965941920876503f;
  t140_n213: return 0.027185847982764244f;
  t140_n214: return 0.10151797533035278f;
  t140_n215: return -0.042628709226846695f;
  t140_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t140_n218;
  t140_n217: return 0.08383802324533463f;
  t140_n218: return 0.11055430769920349f;
  t140_n219: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t140_n237;
  t140_n220: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t140_n234;
  t140_n221: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t140_n227;
  t140_n222: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t140_n224;
  t140_n223: return 0.06957527250051498f;
  t140_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t140_n226;
  t140_n225: return 0.08669121563434601f;
  t140_n226: return 0.0954883024096489f;
  t140_n227: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n231;
  t140_n228: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t140_n230;
  t140_n229: return 0.11553587764501572f;
  t140_n230: return 0.09360872209072113f;
  t140_n231: if (E.getNumReferences() >= 3334472192 /*24577.0*/) goto t140_n233;
  t140_n232: return 0.10938163101673126f;
  t140_n233: return 0.047873739153146744f;
  t140_n234: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t140_n236;
  t140_n235: return 0.10242418944835663f;
  t140_n236: return 0.07018275558948517f;
  t140_n237: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t140_n239;
  t140_n238: return 0.04703441634774208f;
  t140_n239: return -0.4283779561519623f;
  t140_n240: if (E.getNumReferences() >= 3337423104 /*30340.5*/) goto t140_n248;
  t140_n241: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t140_n243;
  t140_n242: return 0.052250489592552185f;
  t140_n243: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t140_n247;
  t140_n244: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t140_n246;
  t140_n245: return 0.11794160306453705f;
  t140_n246: return -0.007347887847572565f;
  t140_n247: return -0.013378801755607128f;
  t140_n248: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t140_n252;
  t140_n249: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t140_n251;
  t140_n250: return -0.16596433520317078f;
  t140_n251: return -0.0014557801187038422f;
  t140_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n254;
  t140_n253: return -0.3019437789916992f;
  t140_n254: return 0.11954367160797119f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree141(const Example& E) {
  t141_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t141_n162;
  t141_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t141_n19;
  t141_n2: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t141_n4;
  t141_n3: return 0.0010205128928646445f;
  t141_n4: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t141_n10;
  t141_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t141_n7;
  t141_n6: return 0.004833218175917864f;
  t141_n7: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t141_n9;
  t141_n8: return -0.11980519443750381f;
  t141_n9: return 0.02279859222471714f;
  t141_n10: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t141_n12;
  t141_n11: return 0.10515967756509781f;
  t141_n12: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t141_n18;
  t141_n13: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t141_n15;
  t141_n14: return 0.019585464149713516f;
  t141_n15: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t141_n17;
  t141_n16: return 0.04292409121990204f;
  t141_n17: return -0.014569812454283237f;
  t141_n18: return 0.040495485067367554f;
  t141_n19: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t141_n109;
  t141_n20: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t141_n22;
  t141_n21: return -0.018853923305869102f;
  t141_n22: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t141_n24;
  t141_n23: return -0.007411425467580557f;
  t141_n24: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t141_n44;
  t141_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t141_n27;
  t141_n26: return -0.0069656819105148315f;
  t141_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t141_n29;
  t141_n28: return -0.09804453700780869f;
  t141_n29: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n43;
  t141_n30: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t141_n32;
  t141_n31: return 0.0243188738822937f;
  t141_n32: if (E.getNumReferences() >= 3335751680 /*27076.0*/) goto t141_n42;
  t141_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t141_n35;
  t141_n34: return 0.022419463843107224f;
  t141_n35: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t141_n41;
  t141_n36: if (E.getSymbolScopeDistance() >= 3244294144 /*14.0*/) goto t141_n38;
  t141_n37: return 0.11854279041290283f;
  t141_n38: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t141_n40;
  t141_n39: return 0.10182730108499527f;
  t141_n40: return 0.04966916888952255f;
  t141_n41: return 0.01555416639894247f;
  t141_n42: return 0.12074726819992065f;
  t141_n43: return 0.0017263167537748814f;
  t141_n44: if (E.getNumReferences() >= 3280912384 /*285.5*/) goto t141_n106;
  t141_n45: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t141_n105;
  t141_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t141_n48;
  t141_n47: return -0.05707995221018791f;
  t141_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t141_n52;
  t141_n49: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t141_n51;
  t141_n50: return 0.03051414154469967f;
  t141_n51: return 0.042999569326639175f;
  t141_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t141_n58;
  t141_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t141_n55;
  t141_n54: return -0.04750862345099449f;
  t141_n55: if (E.getSymbolScopeDistance() >= 3249012736 /*21.0*/) goto t141_n57;
  t141_n56: return 0.128861665725708f;
  t141_n57: return 0.12039552628993988f;
  t141_n58: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t141_n60;
  t141_n59: return 0.03017568215727806f;
  t141_n60: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t141_n104;
  t141_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t141_n63;
  t141_n62: return 0.013486954383552074f;
  t141_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t141_n103;
  t141_n64: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t141_n80;
  t141_n65: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t141_n67;
  t141_n66: return 0.05812166631221771f;
  t141_n67: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t141_n79;
  t141_n68: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t141_n70;
  t141_n69: return 0.07234231382608414f;
  t141_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t141_n72;
  t141_n71: return 0.06472468376159668f;
  t141_n72: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t141_n74;
  t141_n73: return 0.10668689757585526f;
  t141_n74: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t141_n76;
  t141_n75: return -0.03250705450773239f;
  t141_n76: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t141_n78;
  t141_n77: return 0.10864849388599396f;
  t141_n78: return -0.13955895602703094f;
  t141_n79: return 0.029859324917197227f;
  t141_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t141_n88;
  t141_n81: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t141_n87;
  t141_n82: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t141_n86;
  t141_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t141_n85;
  t141_n84: return -0.16848501563072205f;
  t141_n85: return 0.10110755264759064f;
  t141_n86: return 0.019740642979741096f;
  t141_n87: return 0.08141844719648361f;
  t141_n88: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t141_n102;
  t141_n89: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t141_n97;
  t141_n90: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t141_n92;
  t141_n91: return 0.10444959998130798f;
  t141_n92: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t141_n96;
  t141_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t141_n95;
  t141_n94: return -0.11573834717273712f;
  t141_n95: return 0.11927691102027893f;
  t141_n96: return 0.051413968205451965f;
  t141_n97: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t141_n99;
  t141_n98: return -0.15290215611457825f;
  t141_n99: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t141_n101;
  t141_n100: return 0.12450128048658371f;
  t141_n101: return 0.12333116680383682f;
  t141_n102: return 0.1256067305803299f;
  t141_n103: return 0.02682838961482048f;
  t141_n104: return -0.1081579253077507f;
  t141_n105: return -0.04206463322043419f;
  t141_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t141_n108;
  t141_n107: return 0.04760146141052246f;
  t141_n108: return 0.09680846333503723f;
  t141_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t141_n145;
  t141_n110: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t141_n144;
  t141_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t141_n113;
  t141_n112: return -0.03594433143734932f;
  t141_n113: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t141_n133;
  t141_n114: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t141_n132;
  t141_n115: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t141_n117;
  t141_n116: return 0.0306314118206501f;
  t141_n117: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t141_n131;
  t141_n118: if (E.getNumReferences() >= 3292512256 /*767.0*/) goto t141_n130;
  t141_n119: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t141_n125;
  t141_n120: if (E.getNumReferences() >= 3271819264 /*132.0*/) goto t141_n122;
  t141_n121: return -0.013725324533879757f;
  t141_n122: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t141_n124;
  t141_n123: return -0.10681411623954773f;
  t141_n124: return 0.10993590205907822f;
  t141_n125: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t141_n129;
  t141_n126: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t141_n128;
  t141_n127: return 0.12249863892793655f;
  t141_n128: return 0.3229580223560333f;
  t141_n129: return 0.09624335914850235f;
  t141_n130: return 0.10153920948505402f;
  t141_n131: return 0.056536734104156494f;
  t141_n132: return -0.08343935757875443f;
  t141_n133: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t141_n135;
  t141_n134: return -0.013374140486121178f;
  t141_n135: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t141_n143;
  t141_n136: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n138;
  t141_n137: return 0.011583571322262287f;
  t141_n138: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t141_n142;
  t141_n139: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t141_n141;
  t141_n140: return 0.11164886504411697f;
  t141_n141: return -0.008429521694779396f;
  t141_n142: return 0.011401367373764515f;
  t141_n143: return 0.034791938960552216f;
  t141_n144: return -0.010815444402396679f;
  t141_n145: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t141_n153;
  t141_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t141_n150;
  t141_n147: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t141_n149;
  t141_n148: return 0.004901782609522343f;
  t141_n149: return -0.009287248365581036f;
  t141_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t141_n152;
  t141_n151: return 0.09995558112859726f;
  t141_n152: return -0.0015392544446513057f;
  t141_n153: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t141_n161;
  t141_n154: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t141_n156;
  t141_n155: return -0.10053147375583649f;
  t141_n156: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t141_n158;
  t141_n157: return 0.10526394098997116f;
  t141_n158: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n160;
  t141_n159: return 0.0983576700091362f;
  t141_n160: return -0.004502694588154554f;
  t141_n161: return 0.04169416427612305f;
  t141_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t141_n222;
  t141_n163: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t141_n177;
  t141_n164: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t141_n168;
  t141_n165: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n167;
  t141_n166: return -0.07669582217931747f;
  t141_n167: return 0.19441568851470947f;
  t141_n168: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t141_n176;
  t141_n169: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t141_n175;
  t141_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t141_n174;
  t141_n171: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n173;
  t141_n172: return 0.1100158840417862f;
  t141_n173: return 0.1000387966632843f;
  t141_n174: return 0.08800184726715088f;
  t141_n175: return -0.027762161567807198f;
  t141_n176: return -0.15232890844345093f;
  t141_n177: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t141_n179;
  t141_n178: return 0.0003793254727497697f;
  t141_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t141_n215;
  t141_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t141_n214;
  t141_n181: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n213;
  t141_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t141_n184;
  t141_n183: return 0.11300131678581238f;
  t141_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t141_n208;
  t141_n185: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t141_n207;
  t141_n186: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t141_n206;
  t141_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t141_n189;
  t141_n188: return 0.030432865023612976f;
  t141_n189: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t141_n201;
  t141_n190: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t141_n192;
  t141_n191: return 0.09973432868719101f;
  t141_n192: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t141_n196;
  t141_n193: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t141_n195;
  t141_n194: return 0.10055503994226456f;
  t141_n195: return 0.006970573682337999f;
  t141_n196: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t141_n198;
  t141_n197: return 0.10015841573476791f;
  t141_n198: if (E.getNumReferences() >= 3353810176 /*118314.0*/) goto t141_n200;
  t141_n199: return 0.10512777417898178f;
  t141_n200: return 0.052973147481679916f;
  t141_n201: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t141_n203;
  t141_n202: return -0.15089042484760284f;
  t141_n203: if (E.getNumReferences() >= 3353810176 /*118314.0*/) goto t141_n205;
  t141_n204: return 0.12454226613044739f;
  t141_n205: return 0.08526529371738434f;
  t141_n206: return 0.01184102613478899f;
  t141_n207: return 0.015864327549934387f;
  t141_n208: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t141_n212;
  t141_n209: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t141_n211;
  t141_n210: return 0.08509473502635956f;
  t141_n211: return 0.11372477561235428f;
  t141_n212: return 0.038655612617731094f;
  t141_n213: return -0.10292454808950424f;
  t141_n214: return 0.10932771861553192f;
  t141_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t141_n221;
  t141_n216: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t141_n220;
  t141_n217: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t141_n219;
  t141_n218: return 0.026236290112137794f;
  t141_n219: return 0.13157805800437927f;
  t141_n220: return -0.12488171458244324f;
  t141_n221: return -0.10732851922512054f;
  t141_n222: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t141_n254;
  t141_n223: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n233;
  t141_n224: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t141_n226;
  t141_n225: return 0.011607903987169266f;
  t141_n226: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t141_n228;
  t141_n227: return -0.004664773587137461f;
  t141_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t141_n232;
  t141_n229: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t141_n231;
  t141_n230: return 0.15890507400035858f;
  t141_n231: return -0.10491856932640076f;
  t141_n232: return 0.04463159665465355f;
  t141_n233: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t141_n241;
  t141_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t141_n240;
  t141_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t141_n237;
  t141_n236: return 0.0488264299929142f;
  t141_n237: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t141_n239;
  t141_n238: return 0.12927216291427612f;
  t141_n239: return 0.0369529090821743f;
  t141_n240: return -0.39127597212791443f;
  t141_n241: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t141_n249;
  t141_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t141_n246;
  t141_n243: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t141_n245;
  t141_n244: return 0.1578780859708786f;
  t141_n245: return 0.1133488193154335f;
  t141_n246: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t141_n248;
  t141_n247: return 0.12989018857479095f;
  t141_n248: return 0.08454027771949768f;
  t141_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t141_n253;
  t141_n250: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t141_n252;
  t141_n251: return 0.09229575097560883f;
  t141_n252: return 0.16822104156017303f;
  t141_n253: return 0.11226730793714523f;
  t141_n254: return 0.008480455726385117f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree142(const Example& E) {
  t142_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t142_n208;
  t142_n1: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t142_n3;
  t142_n2: return -0.0007742340676486492f;
  t142_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t142_n7;
  t142_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t142_n6;
  t142_n5: return 0.008263060823082924f;
  t142_n6: return 0.023236557841300964f;
  t142_n7: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t142_n9;
  t142_n8: return -0.0032550166361033916f;
  t142_n9: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t142_n201;
  t142_n10: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t142_n170;
  t142_n11: if (E.getNumReferences() >= 3315681280 /*5161.0*/) goto t142_n59;
  t142_n12: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t142_n58;
  t142_n13: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t142_n15;
  t142_n14: return -0.01820977032184601f;
  t142_n15: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t142_n17;
  t142_n16: return 0.006414564326405525f;
  t142_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t142_n47;
  t142_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t142_n20;
  t142_n19: return 0.028731055557727814f;
  t142_n20: if (E.getNumReferences() >= 3307925504 /*2735.0*/) goto t142_n22;
  t142_n21: return 0.022682957351207733f;
  t142_n22: if (E.getNumReferences() >= 3308326912 /*2833.0*/) goto t142_n28;
  t142_n23: if (E.getNumReferences() >= 3308234752 /*2810.5*/) goto t142_n27;
  t142_n24: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t142_n26;
  t142_n25: return 0.14861692488193512f;
  t142_n26: return -0.356219619512558f;
  t142_n27: return 0.11090154200792313f;
  t142_n28: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t142_n46;
  t142_n29: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t142_n31;
  t142_n30: return -0.007563568186014891f;
  t142_n31: if (E.getNumReferences() >= 3313252352 /*4035.5*/) goto t142_n39;
  t142_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t142_n34;
  t142_n33: return -0.2074689418077469f;
  t142_n34: if (E.getNumReferences() >= 3310622720 /*3393.5*/) goto t142_n38;
  t142_n35: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t142_n37;
  t142_n36: return 0.12968353927135468f;
  t142_n37: return 0.10021825134754181f;
  t142_n38: return -0.1219141036272049f;
  t142_n39: if (E.getNumReferences() >= 3313750016 /*4218.0*/) goto t142_n41;
  t142_n40: return 0.11803414672613144f;
  t142_n41: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t142_n43;
  t142_n42: return 0.013061326928436756f;
  t142_n43: if (E.getNumReferences() >= 3314864128 /*4762.0*/) goto t142_n45;
  t142_n44: return 0.10264204442501068f;
  t142_n45: return 0.13529297709465027f;
  t142_n46: return -0.07841387391090393f;
  t142_n47: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t142_n53;
  t142_n48: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t142_n50;
  t142_n49: return 0.05651649832725525f;
  t142_n50: if (E.getNumReferences() >= 3306643456 /*2422.0*/) goto t142_n52;
  t142_n51: return 0.10863620042800903f;
  t142_n52: return 0.041586898267269135f;
  t142_n53: if (E.getNumReferences() >= 3304992768 /*2033.5*/) goto t142_n55;
  t142_n54: return -0.1003488153219223f;
  t142_n55: if (E.getNumReferences() >= 3308046336 /*2764.5*/) goto t142_n57;
  t142_n56: return 0.11049307882785797f;
  t142_n57: return -0.14916367828845978f;
  t142_n58: return 0.061979297548532486f;
  t142_n59: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t142_n69;
  t142_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t142_n66;
  t142_n61: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t142_n63;
  t142_n62: return 0.0013331928057596087f;
  t142_n63: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t142_n65;
  t142_n64: return 0.1163831576704979f;
  t142_n65: return -0.1259361207485199f;
  t142_n66: if (E.getNumReferences() >= 3315727360 /*5183.5*/) goto t142_n68;
  t142_n67: return 0.09971169382333755f;
  t142_n68: return 0.1279975324869156f;
  t142_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t142_n71;
  t142_n70: return 0.01917993277311325f;
  t142_n71: if (E.getNumReferences() >= 3334023936 /*23701.5*/) goto t142_n157;
  t142_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t142_n80;
  t142_n73: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t142_n77;
  t142_n74: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t142_n76;
  t142_n75: return -0.19359630346298218f;
  t142_n76: return 0.06237225607037544f;
  t142_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t142_n79;
  t142_n78: return -0.05085595324635506f;
  t142_n79: return 0.03860773518681526f;
  t142_n80: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t142_n84;
  t142_n81: if (E.getNumReferences() >= 3322151424 /*8448.5*/) goto t142_n83;
  t142_n82: return 0.1418684422969818f;
  t142_n83: return -0.188652902841568f;
  t142_n84: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t142_n156;
  t142_n85: if (E.getNumReferences() >= 3329426944 /*15553.5*/) goto t142_n143;
  t142_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t142_n88;
  t142_n87: return -0.02707483060657978f;
  t142_n88: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t142_n98;
  t142_n89: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t142_n93;
  t142_n90: if (E.getNumReferences() >= 3316420608 /*5522.0*/) goto t142_n92;
  t142_n91: return 0.15248826146125793f;
  t142_n92: return 0.014328856021165848f;
  t142_n93: if (E.getNumReferences() >= 3322974720 /*9252.5*/) goto t142_n97;
  t142_n94: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t142_n96;
  t142_n95: return -0.12639206647872925f;
  t142_n96: return 0.10485595464706421f;
  t142_n97: return 0.12919610738754272f;
  t142_n98: if (E.getNumReferences() >= 3321896960 /*8200.0*/) goto t142_n112;
  t142_n99: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t142_n101;
  t142_n100: return -0.010461743921041489f;
  t142_n101: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t142_n103;
  t142_n102: return 0.04186265170574188f;
  t142_n103: if (E.getNumReferences() >= 3317264384 /*5934.0*/) goto t142_n105;
  t142_n104: return 0.12537159025669098f;
  t142_n105: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t142_n107;
  t142_n106: return 0.023482976481318474f;
  t142_n107: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t142_n111;
  t142_n108: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t142_n110;
  t142_n109: return 0.10694635659456253f;
  t142_n110: return -0.16518071293830872f;
  t142_n111: return 0.10279097408056259f;
  t142_n112: if (E.getNumReferences() >= 3321991168 /*8292.0*/) goto t142_n114;
  t142_n113: return 0.11580953747034073f;
  t142_n114: if (E.getNumReferences() >= 3324665856 /*10904.0*/) goto t142_n142;
  t142_n115: if (E.getNumReferences() >= 3324570112 /*10810.5*/) goto t142_n141;
  t142_n116: if (E.getNumReferences() >= 3324087808 /*10339.5*/) goto t142_n130;
  t142_n117: if (E.getNumReferences() >= 3323522048 /*9787.0*/) goto t142_n127;
  t142_n118: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t142_n120;
  t142_n119: return 0.035993095487356186f;
  t142_n120: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t142_n124;
  t142_n121: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t142_n123;
  t142_n122: return -0.10608511418104172f;
  t142_n123: return 0.11199961602687836f;
  t142_n124: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t142_n126;
  t142_n125: return 0.13304394483566284f;
  t142_n126: return 0.0978306233882904f;
  t142_n127: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t142_n129;
  t142_n128: return -0.013875915668904781f;
  t142_n129: return -0.8290230631828308f;
  t142_n130: if (E.getNumReferences() >= 3324409856 /*10654.0*/) goto t142_n140;
  t142_n131: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t142_n139;
  t142_n132: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t142_n138;
  t142_n133: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t142_n137;
  t142_n134: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t142_n136;
  t142_n135: return 0.581957221031189f;
  t142_n136: return 0.10704021900892258f;
  t142_n137: return 0.12452743202447891f;
  t142_n138: return 0.08219154179096222f;
  t142_n139: return 0.05071550980210304f;
  t142_n140: return -0.2852509617805481f;
  t142_n141: return 0.12257318943738937f;
  t142_n142: return 0.008337553590536118f;
  t142_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t142_n145;
  t142_n144: return 0.04637017846107483f;
  t142_n145: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t142_n151;
  t142_n146: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t142_n148;
  t142_n147: return 0.11786479502916336f;
  t142_n148: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t142_n150;
  t142_n149: return 0.007941885851323605f;
  t142_n150: return 0.09777942299842834f;
  t142_n151: if (E.getNumReferences() >= 3331808000 /*19373.5*/) goto t142_n153;
  t142_n152: return 0.040049389004707336f;
  t142_n153: if (E.getNumReferences() >= 3332234496 /*20206.5*/) goto t142_n155;
  t142_n154: return 0.09698224812746048f;
  t142_n155: return 0.046153292059898376f;
  t142_n156: return 0.11277983337640762f;
  t142_n157: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t142_n169;
  t142_n158: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t142_n166;
  t142_n159: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t142_n161;
  t142_n160: return 0.10354695469141006f;
  t142_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t142_n165;
  t142_n162: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t142_n164;
  t142_n163: return -0.3180624544620514f;
  t142_n164: return 0.09063656628131866f;
  t142_n165: return 0.11557430028915405f;
  t142_n166: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t142_n168;
  t142_n167: return 0.10846473276615143f;
  t142_n168: return 0.0731944665312767f;
  t142_n169: return 0.0016502419020980597f;
  t142_n170: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t142_n200;
  t142_n171: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t142_n175;
  t142_n172: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t142_n174;
  t142_n173: return -0.017681891098618507f;
  t142_n174: return 0.004289797507226467f;
  t142_n175: if (E.getNumReferences() >= 3368655888 /*412896.5*/) goto t142_n179;
  t142_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t142_n178;
  t142_n177: return 0.06351368874311447f;
  t142_n178: return 0.10569840669631958f;
  t142_n179: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t142_n189;
  t142_n180: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t142_n188;
  t142_n181: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t142_n185;
  t142_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t142_n184;
  t142_n183: return 0.0018393052741885185f;
  t142_n184: return 0.09271302819252014f;
  t142_n185: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t142_n187;
  t142_n186: return -0.02107340283691883f;
  t142_n187: return -0.15778349339962006f;
  t142_n188: return 0.0519767589867115f;
  t142_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t142_n191;
  t142_n190: return 0.06361785531044006f;
  t142_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t142_n193;
  t142_n192: return 0.02113969437777996f;
  t142_n193: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t142_n199;
  t142_n194: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t142_n196;
  t142_n195: return 0.11321821808815002f;
  t142_n196: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t142_n198;
  t142_n197: return 0.025139085948467255f;
  t142_n198: return 0.12164279073476791f;
  t142_n199: return 0.0683988481760025f;
  t142_n200: return 0.04386598616838455f;
  t142_n201: if (E.getNumReferences() >= 3306448896 /*2374.5*/) goto t142_n203;
  t142_n202: return 0.0055405194871127605f;
  t142_n203: if (E.getNumReferences() >= 3306622976 /*2417.0*/) goto t142_n207;
  t142_n204: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t142_n206;
  t142_n205: return 0.11280570924282074f;
  t142_n206: return 0.022210512310266495f;
  t142_n207: return 0.03769202157855034f;
  t142_n208: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t142_n242;
  t142_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t142_n229;
  t142_n210: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t142_n226;
  t142_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t142_n215;
  t142_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t142_n214;
  t142_n213: return -0.1989021599292755f;
  t142_n214: return 0.09830502420663834f;
  t142_n215: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t142_n221;
  t142_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t142_n220;
  t142_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t142_n219;
  t142_n218: return -0.04378124326467514f;
  t142_n219: return 0.006679334677755833f;
  t142_n220: return 0.10053851455450058f;
  t142_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t142_n223;
  t142_n222: return -0.007010164204984903f;
  t142_n223: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t142_n225;
  t142_n224: return 0.038671620190143585f;
  t142_n225: return -0.02630310319364071f;
  t142_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t142_n228;
  t142_n227: return -0.008261547423899174f;
  t142_n228: return 0.002949565416201949f;
  t142_n229: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t142_n237;
  t142_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t142_n236;
  t142_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t142_n233;
  t142_n232: return 0.005629157647490501f;
  t142_n233: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t142_n235;
  t142_n234: return 0.016665019094944f;
  t142_n235: return 0.00822881143540144f;
  t142_n236: return 0.06863389909267426f;
  t142_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t142_n241;
  t142_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t142_n240;
  t142_n239: return -0.7198639512062073f;
  t142_n240: return -2.6612045764923096f;
  t142_n241: return -0.15490002930164337f;
  t142_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t142_n250;
  t142_n243: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t142_n247;
  t142_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t142_n246;
  t142_n245: return 0.03357064351439476f;
  t142_n246: return -0.265762060880661f;
  t142_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t142_n249;
  t142_n248: return 0.0876532569527626f;
  t142_n249: return -0.0631071925163269f;
  t142_n250: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t142_n252;
  t142_n251: return -2.9090194702148438f;
  t142_n252: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t142_n254;
  t142_n253: return 0.09276982396841049f;
  t142_n254: return 0.009132345207035542f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree143(const Example& E) {
  t143_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t143_n2;
  t143_n1: return -0.00022247483138926327f;
  t143_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t143_n234;
  t143_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t143_n5;
  t143_n4: return -0.03138437867164612f;
  t143_n5: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t143_n163;
  t143_n6: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t143_n126;
  t143_n7: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t143_n89;
  t143_n8: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t143_n80;
  t143_n9: if (E.getNumReferences() >= 3353375936 /*114921.5*/) goto t143_n79;
  t143_n10: if (E.getNumReferences() >= 3352895680 /*111169.5*/) goto t143_n62;
  t143_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t143_n31;
  t143_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t143_n14;
  t143_n13: return -0.00466281408444047f;
  t143_n14: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t143_n30;
  t143_n15: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t143_n29;
  t143_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n18;
  t143_n17: return 0.08208692073822021f;
  t143_n18: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t143_n24;
  t143_n19: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t143_n23;
  t143_n20: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t143_n22;
  t143_n21: return 0.09420761466026306f;
  t143_n22: return 0.12053915113210678f;
  t143_n23: return 0.029351484030485153f;
  t143_n24: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t143_n28;
  t143_n25: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t143_n27;
  t143_n26: return 0.04663468524813652f;
  t143_n27: return 0.11308499425649643f;
  t143_n28: return -0.10391171276569366f;
  t143_n29: return -0.5522753000259399f;
  t143_n30: return 0.19600655138492584f;
  t143_n31: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t143_n35;
  t143_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t143_n34;
  t143_n33: return -0.17059458792209625f;
  t143_n34: return 0.03962619975209236f;
  t143_n35: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t143_n45;
  t143_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t143_n38;
  t143_n37: return -0.007212852127850056f;
  t143_n38: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t143_n42;
  t143_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n41;
  t143_n40: return 0.10276860743761063f;
  t143_n41: return 0.07947981357574463f;
  t143_n42: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t143_n44;
  t143_n43: return 0.05556093901395798f;
  t143_n44: return -0.3318637013435364f;
  t143_n45: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n55;
  t143_n46: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t143_n48;
  t143_n47: return 0.017967475578188896f;
  t143_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t143_n50;
  t143_n49: return -0.1272299885749817f;
  t143_n50: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t143_n52;
  t143_n51: return 0.03811832144856453f;
  t143_n52: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t143_n54;
  t143_n53: return 0.12457208335399628f;
  t143_n54: return 0.1290520876646042f;
  t143_n55: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t143_n57;
  t143_n56: return 0.05126141384243965f;
  t143_n57: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t143_n61;
  t143_n58: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t143_n60;
  t143_n59: return 0.10452830046415329f;
  t143_n60: return 0.09173852205276489f;
  t143_n61: return 0.06475502252578735f;
  t143_n62: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t143_n76;
  t143_n63: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t143_n75;
  t143_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t143_n66;
  t143_n65: return -0.17278435826301575f;
  t143_n66: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t143_n70;
  t143_n67: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t143_n69;
  t143_n68: return -0.10289919376373291f;
  t143_n69: return 0.10598640888929367f;
  t143_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n72;
  t143_n71: return 0.049864958971738815f;
  t143_n72: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t143_n74;
  t143_n73: return 0.16841985285282135f;
  t143_n74: return 0.07952222228050232f;
  t143_n75: return -0.19218555092811584f;
  t143_n76: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t143_n78;
  t143_n77: return 0.1102161854505539f;
  t143_n78: return 0.09237099438905716f;
  t143_n79: return -0.038184769451618195f;
  t143_n80: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t143_n84;
  t143_n81: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t143_n83;
  t143_n82: return -0.12162468582391739f;
  t143_n83: return 0.12936906516551971f;
  t143_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t143_n86;
  t143_n85: return -0.15791502594947815f;
  t143_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n88;
  t143_n87: return 0.14086225628852844f;
  t143_n88: return 0.0824810042977333f;
  t143_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t143_n109;
  t143_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t143_n92;
  t143_n91: return 0.12566275894641876f;
  t143_n92: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t143_n108;
  t143_n93: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t143_n107;
  t143_n94: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t143_n106;
  t143_n95: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t143_n97;
  t143_n96: return 0.07936488091945648f;
  t143_n97: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t143_n103;
  t143_n98: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n102;
  t143_n99: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t143_n101;
  t143_n100: return 0.10628225654363632f;
  t143_n101: return 0.10284800827503204f;
  t143_n102: return 0.10134081542491913f;
  t143_n103: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t143_n105;
  t143_n104: return 0.10441312938928604f;
  t143_n105: return 0.03377911448478699f;
  t143_n106: return -0.0032284304033964872f;
  t143_n107: return 0.01636168360710144f;
  t143_n108: return 0.030186673626303673f;
  t143_n109: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t143_n125;
  t143_n110: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t143_n116;
  t143_n111: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t143_n113;
  t143_n112: return 0.03628518059849739f;
  t143_n113: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t143_n115;
  t143_n114: return 0.12223518639802933f;
  t143_n115: return 0.019432341679930687f;
  t143_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n122;
  t143_n117: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t143_n121;
  t143_n118: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t143_n120;
  t143_n119: return 0.10997273027896881f;
  t143_n120: return 0.06727943569421768f;
  t143_n121: return 0.13819976150989532f;
  t143_n122: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t143_n124;
  t143_n123: return -0.08506565541028976f;
  t143_n124: return 0.13506391644477844f;
  t143_n125: return -0.04603518173098564f;
  t143_n126: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t143_n158;
  t143_n127: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t143_n155;
  t143_n128: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t143_n130;
  t143_n129: return -0.03390534967184067f;
  t143_n130: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t143_n154;
  t143_n131: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t143_n147;
  t143_n132: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t143_n142;
  t143_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t143_n135;
  t143_n134: return 0.12092006206512451f;
  t143_n135: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t143_n141;
  t143_n136: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t143_n138;
  t143_n137: return -0.2733423113822937f;
  t143_n138: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n140;
  t143_n139: return 0.18455851078033447f;
  t143_n140: return -0.22000953555107117f;
  t143_n141: return 0.4870801568031311f;
  t143_n142: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n146;
  t143_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t143_n145;
  t143_n144: return 0.06881660968065262f;
  t143_n145: return 0.10201101005077362f;
  t143_n146: return -0.03454107046127319f;
  t143_n147: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t143_n153;
  t143_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t143_n152;
  t143_n149: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t143_n151;
  t143_n150: return 0.08295854926109314f;
  t143_n151: return -0.052502695471048355f;
  t143_n152: return 0.10326103121042252f;
  t143_n153: return 0.1062367707490921f;
  t143_n154: return -0.10480666905641556f;
  t143_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t143_n157;
  t143_n156: return -0.2965274453163147f;
  t143_n157: return 0.011074583046138287f;
  t143_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t143_n160;
  t143_n159: return 0.011836057528853416f;
  t143_n160: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t143_n162;
  t143_n161: return 0.06343349069356918f;
  t143_n162: return -0.11679304391145706f;
  t143_n163: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t143_n189;
  t143_n164: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t143_n188;
  t143_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t143_n167;
  t143_n166: return -0.08269952237606049f;
  t143_n167: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t143_n187;
  t143_n168: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t143_n178;
  t143_n169: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t143_n171;
  t143_n170: return -0.03019111417233944f;
  t143_n171: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n177;
  t143_n172: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t143_n176;
  t143_n173: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t143_n175;
  t143_n174: return 0.09698840230703354f;
  t143_n175: return 0.07761142402887344f;
  t143_n176: return -0.10217228531837463f;
  t143_n177: return -0.26099029183387756f;
  t143_n178: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t143_n180;
  t143_n179: return -0.1807221919298172f;
  t143_n180: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t143_n186;
  t143_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n183;
  t143_n182: return 0.11781508475542068f;
  t143_n183: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t143_n185;
  t143_n184: return -0.17197012901306152f;
  t143_n185: return 0.10741209983825684f;
  t143_n186: return -0.21005961298942566f;
  t143_n187: return -0.13084575533866882f;
  t143_n188: return -0.12572525441646576f;
  t143_n189: if (E.getNumReferences() >= 3364158064 /*272339.5*/) goto t143_n205;
  t143_n190: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t143_n192;
  t143_n191: return -0.03179435059428215f;
  t143_n192: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t143_n198;
  t143_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n197;
  t143_n194: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t143_n196;
  t143_n195: return -0.11982420831918716f;
  t143_n196: return 0.16138091683387756f;
  t143_n197: return 0.11120646446943283f;
  t143_n198: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t143_n204;
  t143_n199: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t143_n201;
  t143_n200: return 0.08037571609020233f;
  t143_n201: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n203;
  t143_n202: return 0.09623783826828003f;
  t143_n203: return 0.03664757311344147f;
  t143_n204: return 0.0476493239402771f;
  t143_n205: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t143_n207;
  t143_n206: return -0.1424131542444229f;
  t143_n207: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t143_n217;
  t143_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t143_n216;
  t143_n209: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t143_n211;
  t143_n210: return -0.05233699828386307f;
  t143_n211: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t143_n213;
  t143_n212: return -0.04389231652021408f;
  t143_n213: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t143_n215;
  t143_n214: return 0.08135604113340378f;
  t143_n215: return 0.08539951592683792f;
  t143_n216: return 0.04736502096056938f;
  t143_n217: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t143_n219;
  t143_n218: return -0.005195758771151304f;
  t143_n219: if (E.getNumReferences() >= 3367337376 /*371693.0*/) goto t143_n223;
  t143_n220: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t143_n222;
  t143_n221: return -0.33777323365211487f;
  t143_n222: return -0.18445390462875366f;
  t143_n223: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t143_n233;
  t143_n224: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n226;
  t143_n225: return 0.051098279654979706f;
  t143_n226: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t143_n228;
  t143_n227: return 0.0048950244672596455f;
  t143_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t143_n230;
  t143_n229: return -0.3086641728878021f;
  t143_n230: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t143_n232;
  t143_n231: return 0.12003791332244873f;
  t143_n232: return -0.04418885335326195f;
  t143_n233: return -0.04141870513558388f;
  t143_n234: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t143_n236;
  t143_n235: return 0.010455294512212276f;
  t143_n236: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t143_n254;
  t143_n237: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t143_n247;
  t143_n238: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t143_n240;
  t143_n239: return -0.025301750749349594f;
  t143_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t143_n244;
  t143_n241: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t143_n243;
  t143_n242: return 0.09967547655105591f;
  t143_n243: return 0.016138644888997078f;
  t143_n244: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t143_n246;
  t143_n245: return 0.09272236377000809f;
  t143_n246: return 0.12135990709066391f;
  t143_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t143_n253;
  t143_n248: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t143_n250;
  t143_n249: return -0.10599112510681152f;
  t143_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t143_n252;
  t143_n251: return -0.9023605585098267f;
  t143_n252: return 0.10979258269071579f;
  t143_n253: return 0.11901802569627762f;
  t143_n254: return -0.0006104487692937255f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree144(const Example& E) {
  t144_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t144_n38;
  t144_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t144_n37;
  t144_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t144_n4;
  t144_n3: return -0.007177260704338551f;
  t144_n4: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t144_n10;
  t144_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n9;
  t144_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t144_n8;
  t144_n7: return 0.006674942094832659f;
  t144_n8: return 0.018368560820817947f;
  t144_n9: return -0.002472211606800556f;
  t144_n10: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t144_n36;
  t144_n11: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t144_n13;
  t144_n12: return 0.019252624362707138f;
  t144_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t144_n23;
  t144_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t144_n16;
  t144_n15: return 0.06262745708227158f;
  t144_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t144_n18;
  t144_n17: return 0.05689617618918419f;
  t144_n18: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t144_n22;
  t144_n19: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t144_n21;
  t144_n20: return 0.11198407411575317f;
  t144_n21: return 0.11626409739255905f;
  t144_n22: return 0.0370333269238472f;
  t144_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n25;
  t144_n24: return 0.05569954961538315f;
  t144_n25: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t144_n31;
  t144_n26: if (E.getNumReferences() >= 3264020480 /*70.5*/) goto t144_n30;
  t144_n27: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t144_n29;
  t144_n28: return 0.09999780356884003f;
  t144_n29: return 0.07204645872116089f;
  t144_n30: return 0.12492299824953079f;
  t144_n31: if (E.getNumReferences() >= 3275816960 /*193.0*/) goto t144_n33;
  t144_n32: return 0.04419565200805664f;
  t144_n33: if (E.getNumReferences() >= 3279126528 /*243.5*/) goto t144_n35;
  t144_n34: return 0.10733070224523544f;
  t144_n35: return 0.08973536640405655f;
  t144_n36: return 0.015253346413373947f;
  t144_n37: return -0.001292180037125945f;
  t144_n38: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t144_n40;
  t144_n39: return 0.002649355912581086f;
  t144_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t144_n46;
  t144_n41: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t144_n43;
  t144_n42: return -0.10448475927114487f;
  t144_n43: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t144_n45;
  t144_n44: return -0.03329630196094513f;
  t144_n45: return 0.10526712238788605f;
  t144_n46: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t144_n246;
  t144_n47: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t144_n163;
  t144_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t144_n132;
  t144_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t144_n63;
  t144_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t144_n52;
  t144_n51: return -0.011235314421355724f;
  t144_n52: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t144_n62;
  t144_n53: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t144_n55;
  t144_n54: return -0.009104610420763493f;
  t144_n55: if (E.getNumReferences() >= 3350811072 /*94883.5*/) goto t144_n61;
  t144_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t144_n58;
  t144_n57: return 0.10080836713314056f;
  t144_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t144_n60;
  t144_n59: return 0.09838616847991943f;
  t144_n60: return 0.08322466164827347f;
  t144_n61: return 0.031136404722929f;
  t144_n62: return 0.027715055271983147f;
  t144_n63: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t144_n131;
  t144_n64: if (E.getNumReferences() >= 3360198688 /*205376.5*/) goto t144_n110;
  t144_n65: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t144_n67;
  t144_n66: return 0.10742373764514923f;
  t144_n67: if (E.getNumReferences() >= 3356314496 /*144686.0*/) goto t144_n109;
  t144_n68: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n80;
  t144_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t144_n71;
  t144_n70: return -0.02341577038168907f;
  t144_n71: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t144_n73;
  t144_n72: return 0.026946403086185455f;
  t144_n73: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t144_n79;
  t144_n74: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t144_n76;
  t144_n75: return 0.19153042137622833f;
  t144_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t144_n78;
  t144_n77: return -0.14387303590774536f;
  t144_n78: return 0.1284315139055252f;
  t144_n79: return 0.04928546026349068f;
  t144_n80: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t144_n90;
  t144_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t144_n83;
  t144_n82: return -0.09639541804790497f;
  t144_n83: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t144_n85;
  t144_n84: return 0.05724112316966057f;
  t144_n85: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t144_n87;
  t144_n86: return -0.003734510624781251f;
  t144_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t144_n89;
  t144_n88: return -0.0007100976072251797f;
  t144_n89: return 0.08953233808279037f;
  t144_n90: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t144_n92;
  t144_n91: return -0.2419901341199875f;
  t144_n92: if (E.getNumReferences() >= 3355834112 /*137180.0*/) goto t144_n104;
  t144_n93: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t144_n95;
  t144_n94: return 0.00570674566552043f;
  t144_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t144_n99;
  t144_n96: if (E.getNumReferences() >= 3355264064 /*129672.5*/) goto t144_n98;
  t144_n97: return -0.15086965262889862f;
  t144_n98: return 0.11300969123840332f;
  t144_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t144_n101;
  t144_n100: return -0.4481494128704071f;
  t144_n101: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t144_n103;
  t144_n102: return -0.20690159499645233f;
  t144_n103: return 0.07705467194318771f;
  t144_n104: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n106;
  t144_n105: return -0.038930103182792664f;
  t144_n106: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t144_n108;
  t144_n107: return 0.1094435378909111f;
  t144_n108: return 0.0662936195731163f;
  t144_n109: return -0.11201857775449753f;
  t144_n110: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n130;
  t144_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t144_n113;
  t144_n112: return 0.06404571980237961f;
  t144_n113: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t144_n115;
  t144_n114: return 0.043247371912002563f;
  t144_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t144_n117;
  t144_n116: return 0.019374847412109375f;
  t144_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t144_n129;
  t144_n118: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t144_n124;
  t144_n119: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t144_n121;
  t144_n120: return -0.12019730359315872f;
  t144_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t144_n123;
  t144_n122: return -0.11703018099069595f;
  t144_n123: return 0.1019483432173729f;
  t144_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t144_n128;
  t144_n125: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t144_n127;
  t144_n126: return 0.05577322468161583f;
  t144_n127: return 0.11409588158130646f;
  t144_n128: return 0.11498460173606873f;
  t144_n129: return -0.187926784157753f;
  t144_n130: return 0.024832243099808693f;
  t144_n131: return 0.0049558160826563835f;
  t144_n132: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t144_n162;
  t144_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t144_n135;
  t144_n134: return -0.03128013014793396f;
  t144_n135: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t144_n141;
  t144_n136: if (E.getNumReferences() >= 3358908544 /*185218.0*/) goto t144_n140;
  t144_n137: if (E.getNumReferences() >= 3356993440 /*155294.5*/) goto t144_n139;
  t144_n138: return -0.10218759626150131f;
  t144_n139: return 0.1254744678735733f;
  t144_n140: return -0.7972574830055237f;
  t144_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n145;
  t144_n142: if (E.getNumReferences() >= 3363872672 /*263421.0*/) goto t144_n144;
  t144_n143: return 0.06244036555290222f;
  t144_n144: return 0.054909512400627136f;
  t144_n145: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n161;
  t144_n146: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t144_n160;
  t144_n147: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t144_n159;
  t144_n148: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t144_n158;
  t144_n149: if (E.getNumReferences() >= 3358908544 /*185218.0*/) goto t144_n153;
  t144_n150: if (E.getNumReferences() >= 3356993440 /*155294.5*/) goto t144_n152;
  t144_n151: return 0.08233324438333511f;
  t144_n152: return 0.09246832877397537f;
  t144_n153: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t144_n157;
  t144_n154: if (E.getNumReferences() >= 3363872672 /*263421.0*/) goto t144_n156;
  t144_n155: return -0.2070544958114624f;
  t144_n156: return 0.10533653944730759f;
  t144_n157: return 0.02807369828224182f;
  t144_n158: return 0.10068035125732422f;
  t144_n159: return -0.0054720924235880375f;
  t144_n160: return 0.11366824805736542f;
  t144_n161: return 0.033954720944166183f;
  t144_n162: return 0.10622710734605789f;
  t144_n163: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t144_n207;
  t144_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t144_n188;
  t144_n165: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t144_n177;
  t144_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t144_n168;
  t144_n167: return 0.055492103099823f;
  t144_n168: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t144_n170;
  t144_n169: return 0.14302153885364532f;
  t144_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n176;
  t144_n171: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n175;
  t144_n172: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t144_n174;
  t144_n173: return -0.14636772871017456f;
  t144_n174: return 0.2844131886959076f;
  t144_n175: return 0.1632729470729828f;
  t144_n176: return 0.05444084480404854f;
  t144_n177: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t144_n179;
  t144_n178: return -0.1668754369020462f;
  t144_n179: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t144_n187;
  t144_n180: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t144_n184;
  t144_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n183;
  t144_n182: return -0.0032370772678405046f;
  t144_n183: return 0.13430732488632202f;
  t144_n184: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t144_n186;
  t144_n185: return 0.14579525589942932f;
  t144_n186: return 0.14262470602989197f;
  t144_n187: return -0.007096884772181511f;
  t144_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n202;
  t144_n189: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t144_n199;
  t144_n190: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t144_n196;
  t144_n191: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t144_n195;
  t144_n192: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t144_n194;
  t144_n193: return 0.06724292039871216f;
  t144_n194: return 0.1040879562497139f;
  t144_n195: return -0.11405796557664871f;
  t144_n196: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t144_n198;
  t144_n197: return 0.10978472232818604f;
  t144_n198: return 0.08189026266336441f;
  t144_n199: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t144_n201;
  t144_n200: return -0.01610756292939186f;
  t144_n201: return 0.0876929759979248f;
  t144_n202: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t144_n206;
  t144_n203: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n205;
  t144_n204: return 0.08622101694345474f;
  t144_n205: return 0.029982229694724083f;
  t144_n206: return -0.10113069415092468f;
  t144_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t144_n209;
  t144_n208: return -0.10928681492805481f;
  t144_n209: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t144_n231;
  t144_n210: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t144_n230;
  t144_n211: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t144_n219;
  t144_n212: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t144_n218;
  t144_n213: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t144_n215;
  t144_n214: return 0.07357488572597504f;
  t144_n215: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t144_n217;
  t144_n216: return 0.1139201894402504f;
  t144_n217: return 0.026525050401687622f;
  t144_n218: return -0.14067600667476654f;
  t144_n219: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t144_n225;
  t144_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n224;
  t144_n221: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t144_n223;
  t144_n222: return -0.15031376481056213f;
  t144_n223: return 0.1292661428451538f;
  t144_n224: return 0.07167471200227737f;
  t144_n225: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t144_n227;
  t144_n226: return 0.0335591621696949f;
  t144_n227: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t144_n229;
  t144_n228: return 0.05839749425649643f;
  t144_n229: return -0.014461904764175415f;
  t144_n230: return -0.1554875522851944f;
  t144_n231: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t144_n245;
  t144_n232: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t144_n244;
  t144_n233: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t144_n235;
  t144_n234: return 0.0634060725569725f;
  t144_n235: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t144_n239;
  t144_n236: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n238;
  t144_n237: return 0.08435211330652237f;
  t144_n238: return 0.019440477713942528f;
  t144_n239: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t144_n243;
  t144_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n242;
  t144_n241: return 0.1368524134159088f;
  t144_n242: return 0.08886601775884628f;
  t144_n243: return -0.24404621124267578f;
  t144_n244: return 0.014778465032577515f;
  t144_n245: return -0.08106445521116257f;
  t144_n246: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t144_n254;
  t144_n247: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n251;
  t144_n248: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t144_n250;
  t144_n249: return 0.11115584522485733f;
  t144_n250: return 0.08797184377908707f;
  t144_n251: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t144_n253;
  t144_n252: return 0.06090034916996956f;
  t144_n253: return 0.12850725650787354f;
  t144_n254: return 0.006193504203110933f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree145(const Example& E) {
  t145_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t145_n6;
  t145_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t145_n3;
  t145_n2: return -0.000675576739013195f;
  t145_n3: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t145_n5;
  t145_n4: return 0.003828794928267598f;
  t145_n5: return -0.044586408883333206f;
  t145_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t145_n8;
  t145_n7: return 0.0014810938155278563f;
  t145_n8: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t145_n212;
  t145_n9: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t145_n155;
  t145_n10: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t145_n100;
  t145_n11: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t145_n89;
  t145_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t145_n40;
  t145_n13: if (E.getNumReferences() >= 3353375936 /*114921.5*/) goto t145_n39;
  t145_n14: if (E.getNumReferences() >= 3352895680 /*111169.5*/) goto t145_n22;
  t145_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t145_n17;
  t145_n16: return 0.0019574412144720554f;
  t145_n17: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t145_n19;
  t145_n18: return 0.0539587140083313f;
  t145_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n21;
  t145_n20: return -0.18277420103549957f;
  t145_n21: return 0.22949498891830444f;
  t145_n22: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t145_n36;
  t145_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n35;
  t145_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t145_n26;
  t145_n25: return -0.12247178703546524f;
  t145_n26: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n34;
  t145_n27: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t145_n33;
  t145_n28: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t145_n32;
  t145_n29: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t145_n31;
  t145_n30: return -0.17564435303211212f;
  t145_n31: return 0.12355650216341019f;
  t145_n32: return -0.019478069618344307f;
  t145_n33: return 0.12971550226211548f;
  t145_n34: return 0.10485226660966873f;
  t145_n35: return -0.19469821453094482f;
  t145_n36: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t145_n38;
  t145_n37: return 0.09699560701847076f;
  t145_n38: return 0.09557920694351196f;
  t145_n39: return -0.039426352828741074f;
  t145_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t145_n42;
  t145_n41: return -0.03955107554793358f;
  t145_n42: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t145_n76;
  t145_n43: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t145_n67;
  t145_n44: if (E.getNumReferences() >= 3354093056 /*120524.0*/) goto t145_n66;
  t145_n45: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t145_n65;
  t145_n46: if (E.getNumReferences() >= 3352615936 /*108984.0*/) goto t145_n58;
  t145_n47: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t145_n51;
  t145_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t145_n50;
  t145_n49: return -0.12487131357192993f;
  t145_n50: return 0.102289117872715f;
  t145_n51: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n53;
  t145_n52: return 0.008819935843348503f;
  t145_n53: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t145_n57;
  t145_n54: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t145_n56;
  t145_n55: return -0.024231011047959328f;
  t145_n56: return 0.10710014402866364f;
  t145_n57: return 0.003952501341700554f;
  t145_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t145_n60;
  t145_n59: return -0.11470875889062881f;
  t145_n60: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n64;
  t145_n61: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t145_n63;
  t145_n62: return -0.10279306769371033f;
  t145_n63: return 0.1039445698261261f;
  t145_n64: return -0.1579461246728897f;
  t145_n65: return 0.009137528948485851f;
  t145_n66: return -0.05941716954112053f;
  t145_n67: if (E.getNumReferences() >= 3356904640 /*153907.0*/) goto t145_n75;
  t145_n68: if (E.getNumReferences() >= 3352615936 /*108984.0*/) goto t145_n72;
  t145_n69: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t145_n71;
  t145_n70: return 0.07088401168584824f;
  t145_n71: return -0.11666266620159149f;
  t145_n72: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t145_n74;
  t145_n73: return 0.02414862811565399f;
  t145_n74: return 0.08121688663959503f;
  t145_n75: return -0.2075628936290741f;
  t145_n76: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t145_n80;
  t145_n77: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t145_n79;
  t145_n78: return 0.015421253629028797f;
  t145_n79: return 0.19972604513168335f;
  t145_n80: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t145_n84;
  t145_n81: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t145_n83;
  t145_n82: return 0.1684507131576538f;
  t145_n83: return 0.106744185090065f;
  t145_n84: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t145_n88;
  t145_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t145_n87;
  t145_n86: return -0.13760749995708466f;
  t145_n87: return 0.11336708813905716f;
  t145_n88: return 0.020543130114674568f;
  t145_n89: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t145_n93;
  t145_n90: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n92;
  t145_n91: return -0.12133265286684036f;
  t145_n92: return 0.12277676165103912f;
  t145_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t145_n95;
  t145_n94: return -0.1419445276260376f;
  t145_n95: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t145_n97;
  t145_n96: return 0.06894233077764511f;
  t145_n97: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t145_n99;
  t145_n98: return 0.10437966883182526f;
  t145_n99: return 0.04686615988612175f;
  t145_n100: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t145_n136;
  t145_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t145_n119;
  t145_n102: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t145_n118;
  t145_n103: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t145_n111;
  t145_n104: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t145_n110;
  t145_n105: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n107;
  t145_n106: return -0.0033449972979724407f;
  t145_n107: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t145_n109;
  t145_n108: return 0.11730262637138367f;
  t145_n109: return 0.010279039852321148f;
  t145_n110: return 0.1451217085123062f;
  t145_n111: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t145_n115;
  t145_n112: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n114;
  t145_n113: return -0.054985810071229935f;
  t145_n114: return 0.12988494336605072f;
  t145_n115: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n117;
  t145_n116: return 0.13825589418411255f;
  t145_n117: return 0.043613702058792114f;
  t145_n118: return -0.10737399756908417f;
  t145_n119: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t145_n135;
  t145_n120: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t145_n134;
  t145_n121: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t145_n133;
  t145_n122: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t145_n124;
  t145_n123: return 0.0726427212357521f;
  t145_n124: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t145_n130;
  t145_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n129;
  t145_n126: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t145_n128;
  t145_n127: return 0.10263639688491821f;
  t145_n128: return 0.1010546013712883f;
  t145_n129: return 0.0998024269938469f;
  t145_n130: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t145_n132;
  t145_n131: return 0.10442744195461273f;
  t145_n132: return 0.030655520036816597f;
  t145_n133: return 0.00011253944103373215f;
  t145_n134: return 0.021698391065001488f;
  t145_n135: return 0.018885886296629906f;
  t145_n136: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t145_n138;
  t145_n137: return -0.03683772310614586f;
  t145_n138: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t145_n154;
  t145_n139: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n149;
  t145_n140: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t145_n146;
  t145_n141: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t145_n145;
  t145_n142: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t145_n144;
  t145_n143: return 0.10197755694389343f;
  t145_n144: return 0.057006314396858215f;
  t145_n145: return 0.11867091804742813f;
  t145_n146: if (E.getNumReferences() >= 3350572224 /*93017.5*/) goto t145_n148;
  t145_n147: return -0.2539672255516052f;
  t145_n148: return 0.1291910707950592f;
  t145_n149: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t145_n153;
  t145_n150: if (E.getNumReferences() >= 3350572224 /*93017.5*/) goto t145_n152;
  t145_n151: return -0.1066669225692749f;
  t145_n152: return 0.09572631865739822f;
  t145_n153: return 0.12058857083320618f;
  t145_n154: return -0.05217938870191574f;
  t145_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t145_n189;
  t145_n156: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t145_n176;
  t145_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t145_n161;
  t145_n158: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t145_n160;
  t145_n159: return -0.01833438128232956f;
  t145_n160: return 0.058936066925525665f;
  t145_n161: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t145_n163;
  t145_n162: return 0.032590389251708984f;
  t145_n163: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t145_n175;
  t145_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n170;
  t145_n165: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t145_n167;
  t145_n166: return 0.12723635137081146f;
  t145_n167: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t145_n169;
  t145_n168: return -0.05615357682108879f;
  t145_n169: return 0.09583796560764313f;
  t145_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t145_n172;
  t145_n171: return -0.05247432366013527f;
  t145_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t145_n174;
  t145_n173: return 0.061720918864011765f;
  t145_n174: return 0.1045474261045456f;
  t145_n175: return -0.2868620455265045f;
  t145_n176: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t145_n188;
  t145_n177: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n179;
  t145_n178: return 0.036063358187675476f;
  t145_n179: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t145_n187;
  t145_n180: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t145_n182;
  t145_n181: return -0.17688331007957458f;
  t145_n182: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t145_n184;
  t145_n183: return 0.04132293164730072f;
  t145_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t145_n186;
  t145_n185: return 0.024166135117411613f;
  t145_n186: return 0.08375168591737747f;
  t145_n187: return 0.06843555718660355f;
  t145_n188: return 0.012601910158991814f;
  t145_n189: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t145_n191;
  t145_n190: return 0.0251962561160326f;
  t145_n191: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t145_n211;
  t145_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t145_n210;
  t145_n193: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t145_n209;
  t145_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t145_n204;
  t145_n195: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t145_n203;
  t145_n196: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n202;
  t145_n197: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t145_n199;
  t145_n198: return -0.11819904297590256f;
  t145_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t145_n201;
  t145_n200: return -0.11017901450395584f;
  t145_n201: return 0.09958828240633011f;
  t145_n202: return 0.048835474997758865f;
  t145_n203: return 0.0545014888048172f;
  t145_n204: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t145_n206;
  t145_n205: return -0.11509360373020172f;
  t145_n206: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t145_n208;
  t145_n207: return 0.10136791318655014f;
  t145_n208: return -0.1861058473587036f;
  t145_n209: return 0.009314138442277908f;
  t145_n210: return -0.15962418913841248f;
  t145_n211: return 0.11318431049585342f;
  t145_n212: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t145_n214;
  t145_n213: return -0.15148550271987915f;
  t145_n214: if (E.getNumReferences() >= 3364158064 /*272339.5*/) goto t145_n228;
  t145_n215: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n217;
  t145_n216: return -0.04789147898554802f;
  t145_n217: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t145_n219;
  t145_n218: return -0.04057147726416588f;
  t145_n219: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t145_n223;
  t145_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n222;
  t145_n221: return 0.1459929645061493f;
  t145_n222: return 0.10956182330846786f;
  t145_n223: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t145_n227;
  t145_n224: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t145_n226;
  t145_n225: return 0.07296978682279587f;
  t145_n226: return 0.11401046812534332f;
  t145_n227: return 0.04207754135131836f;
  t145_n228: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t145_n230;
  t145_n229: return -0.08787219971418381f;
  t145_n230: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t145_n254;
  t145_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t145_n233;
  t145_n232: return -0.008604584261775017f;
  t145_n233: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t145_n237;
  t145_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n236;
  t145_n235: return 0.06822729855775833f;
  t145_n236: return 0.0359327532351017f;
  t145_n237: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t145_n243;
  t145_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t145_n240;
  t145_n239: return -0.06830073893070221f;
  t145_n240: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t145_n242;
  t145_n241: return 0.12789775431156158f;
  t145_n242: return 0.06736735254526138f;
  t145_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t145_n253;
  t145_n244: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t145_n252;
  t145_n245: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n251;
  t145_n246: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t145_n248;
  t145_n247: return -0.017284035682678223f;
  t145_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t145_n250;
  t145_n249: return -0.13563001155853271f;
  t145_n250: return -0.029478473588824272f;
  t145_n251: return 0.0394623689353466f;
  t145_n252: return 0.09599869698286057f;
  t145_n253: return 0.16775017976760864f;
  t145_n254: return 0.00313093070872128f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree146(const Example& E) {
  t146_n0: if (E.getNumReferences() >= 3305437184 /*2127.5*/) goto t146_n2;
  t146_n1: return -0.00045815849443897605f;
  t146_n2: if (E.getNumReferences() >= 3305449472 /*2130.5*/) goto t146_n8;
  t146_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t146_n7;
  t146_n4: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n6;
  t146_n5: return -0.072431780397892f;
  t146_n6: return 0.10569024085998535f;
  t146_n7: return 0.3553738594055176f;
  t146_n8: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t146_n22;
  t146_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t146_n11;
  t146_n10: return 0.009852997958660126f;
  t146_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t146_n13;
  t146_n12: return 0.022580280900001526f;
  t146_n13: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t146_n15;
  t146_n14: return -0.025662612169981003f;
  t146_n15: if (E.getNumReferences() >= 3318562816 /*6568.0*/) goto t146_n21;
  t146_n16: if (E.getNumReferences() >= 3314761728 /*4712.0*/) goto t146_n18;
  t146_n17: return -0.21221092343330383f;
  t146_n18: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t146_n20;
  t146_n19: return 0.16733849048614502f;
  t146_n20: return 0.1397455334663391f;
  t146_n21: return -0.03511923924088478f;
  t146_n22: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t146_n26;
  t146_n23: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t146_n25;
  t146_n24: return -0.0018592342967167497f;
  t146_n25: return -0.023492993786931038f;
  t146_n26: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t146_n244;
  t146_n27: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t146_n227;
  t146_n28: if (E.getNumReferences() >= 3315681280 /*5161.0*/) goto t146_n46;
  t146_n29: if (E.getNumReferences() >= 3305551872 /*2155.5*/) goto t146_n39;
  t146_n30: if (E.getNumReferences() >= 3305539584 /*2152.5*/) goto t146_n32;
  t146_n31: return -0.004596408922225237f;
  t146_n32: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t146_n38;
  t146_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t146_n35;
  t146_n34: return -0.03088812530040741f;
  t146_n35: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t146_n37;
  t146_n36: return -0.0359032079577446f;
  t146_n37: return 0.11610159277915955f;
  t146_n38: return 0.12161815166473389f;
  t146_n39: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t146_n41;
  t146_n40: return 3.8981830584816635e-05f;
  t146_n41: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t146_n43;
  t146_n42: return 0.10599441081285477f;
  t146_n43: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n45;
  t146_n44: return -0.018557395786046982f;
  t146_n45: return 0.11415594816207886f;
  t146_n46: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t146_n56;
  t146_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t146_n53;
  t146_n48: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n50;
  t146_n49: return 0.005639952141791582f;
  t146_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t146_n52;
  t146_n51: return 0.10737285763025284f;
  t146_n52: return -0.12320470809936523f;
  t146_n53: if (E.getNumReferences() >= 3315727360 /*5183.5*/) goto t146_n55;
  t146_n54: return 0.09869677573442459f;
  t146_n55: return 0.12660686671733856f;
  t146_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t146_n128;
  t146_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t146_n89;
  t146_n58: if (E.getNumReferences() >= 3316641792 /*5630.0*/) goto t146_n62;
  t146_n59: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t146_n61;
  t146_n60: return 0.19374851882457733f;
  t146_n61: return -0.3065454065799713f;
  t146_n62: if (E.getNumReferences() >= 3329391104 /*15518.5*/) goto t146_n88;
  t146_n63: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t146_n75;
  t146_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t146_n66;
  t146_n65: return -0.09109583497047424f;
  t146_n66: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t146_n74;
  t146_n67: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n69;
  t146_n68: return 0.005694903898984194f;
  t146_n69: if (E.getNumReferences() >= 3328288256 /*14441.5*/) goto t146_n73;
  t146_n70: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t146_n72;
  t146_n71: return 0.067308709025383f;
  t146_n72: return -0.10774162411689758f;
  t146_n73: return 0.10691352188587189f;
  t146_n74: return -1.5354560613632202f;
  t146_n75: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t146_n77;
  t146_n76: return 0.04228074103593826f;
  t146_n77: if (E.getNumReferences() >= 3321165824 /*7839.0*/) goto t146_n79;
  t146_n78: return -0.014529695734381676f;
  t146_n79: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n83;
  t146_n80: if (E.getNumReferences() >= 3323752960 /*10012.5*/) goto t146_n82;
  t146_n81: return 0.09415304660797119f;
  t146_n82: return 0.0025700365658849478f;
  t146_n83: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t146_n85;
  t146_n84: return 0.07599849998950958f;
  t146_n85: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t146_n87;
  t146_n86: return 0.14632359147071838f;
  t146_n87: return 0.11701926589012146f;
  t146_n88: return -0.09817404299974442f;
  t146_n89: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t146_n91;
  t146_n90: return 0.01907159760594368f;
  t146_n91: if (E.getNumReferences() >= 3332022528 /*19792.5*/) goto t146_n97;
  t146_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t146_n96;
  t146_n93: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n95;
  t146_n94: return 0.11102046072483063f;
  t146_n95: return 0.1041112169623375f;
  t146_n96: return -0.10204457491636276f;
  t146_n97: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t146_n123;
  t146_n98: if (E.getNumReferences() >= 3333845504 /*23353.0*/) goto t146_n122;
  t146_n99: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t146_n107;
  t146_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t146_n102;
  t146_n101: return -0.027696285396814346f;
  t146_n102: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t146_n104;
  t146_n103: return 0.0914522036910057f;
  t146_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n106;
  t146_n105: return -0.7221584320068359f;
  t146_n106: return 0.12460901588201523f;
  t146_n107: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t146_n109;
  t146_n108: return 0.03568730875849724f;
  t146_n109: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n121;
  t146_n110: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t146_n120;
  t146_n111: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t146_n117;
  t146_n112: if (E.getNumReferences() >= 3333150720 /*21996.0*/) goto t146_n114;
  t146_n113: return -0.45706605911254883f;
  t146_n114: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t146_n116;
  t146_n115: return 0.14544525742530823f;
  t146_n116: return 0.10278749465942383f;
  t146_n117: if (E.getNumReferences() >= 3332934144 /*21573.0*/) goto t146_n119;
  t146_n118: return 0.16873504221439362f;
  t146_n119: return -0.6633085608482361f;
  t146_n120: return 0.0755399689078331f;
  t146_n121: return 0.03708116337656975f;
  t146_n122: return -0.050247445702552795f;
  t146_n123: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t146_n127;
  t146_n124: if (E.getNumReferences() >= 3332429312 /*20587.0*/) goto t146_n126;
  t146_n125: return 0.13683924078941345f;
  t146_n126: return 0.054418280720710754f;
  t146_n127: return 0.05272141471505165f;
  t146_n128: if (E.getNumReferences() >= 3334023936 /*23701.5*/) goto t146_n212;
  t146_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t146_n175;
  t146_n130: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t146_n132;
  t146_n131: return 0.05162372067570686f;
  t146_n132: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t146_n148;
  t146_n133: if (E.getNumReferences() >= 3327639040 /*13807.5*/) goto t146_n145;
  t146_n134: if (E.getNumReferences() >= 3323017216 /*9294.0*/) goto t146_n142;
  t146_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t146_n137;
  t146_n136: return -0.11379683762788773f;
  t146_n137: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n139;
  t146_n138: return -0.2677822411060333f;
  t146_n139: if (E.getNumReferences() >= 3319199744 /*6879.0*/) goto t146_n141;
  t146_n140: return -0.11673147976398468f;
  t146_n141: return 0.11528196185827255f;
  t146_n142: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t146_n144;
  t146_n143: return -0.21260038018226624f;
  t146_n144: return 0.09916316717863083f;
  t146_n145: if (E.getNumReferences() >= 3327672832 /*13840.5*/) goto t146_n147;
  t146_n146: return 0.1947464495897293f;
  t146_n147: return 0.002918862272053957f;
  t146_n148: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t146_n156;
  t146_n149: if (E.getNumReferences() >= 3321062400 /*7788.5*/) goto t146_n155;
  t146_n150: if (E.getNumReferences() >= 3320159232 /*7347.5*/) goto t146_n154;
  t146_n151: if (E.getNumReferences() >= 3315995648 /*5314.5*/) goto t146_n153;
  t146_n152: return 0.17838045954704285f;
  t146_n153: return 0.09242171794176102f;
  t146_n154: return 0.11499562859535217f;
  t146_n155: return -0.1302732229232788f;
  t146_n156: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t146_n170;
  t146_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t146_n159;
  t146_n158: return -0.007889126427471638f;
  t146_n159: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n161;
  t146_n160: return 0.07118996232748032f;
  t146_n161: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t146_n165;
  t146_n162: if (E.getNumReferences() >= 3332404480 /*20538.5*/) goto t146_n164;
  t146_n163: return 0.11765909194946289f;
  t146_n164: return 0.1019158661365509f;
  t146_n165: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t146_n169;
  t146_n166: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t146_n168;
  t146_n167: return 0.09995637089014053f;
  t146_n168: return 0.10100322216749191f;
  t146_n169: return 0.07464684545993805f;
  t146_n170: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t146_n172;
  t146_n171: return -0.035683147609233856f;
  t146_n172: if (E.getNumReferences() >= 3331892480 /*19538.5*/) goto t146_n174;
  t146_n173: return 0.11559838056564331f;
  t146_n174: return -0.1550024151802063f;
  t146_n175: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t146_n177;
  t146_n176: return 0.14873726665973663f;
  t146_n177: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t146_n211;
  t146_n178: if (E.getNumReferences() >= 3321896960 /*8200.0*/) goto t146_n208;
  t146_n179: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n185;
  t146_n180: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t146_n182;
  t146_n181: return 0.0225831288844347f;
  t146_n182: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t146_n184;
  t146_n183: return -0.051980361342430115f;
  t146_n184: return -0.5461257100105286f;
  t146_n185: if (E.getNumReferences() >= 3320443904 /*7486.5*/) goto t146_n207;
  t146_n186: if (E.getNumReferences() >= 3319744512 /*7145.0*/) goto t146_n198;
  t146_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t146_n189;
  t146_n188: return 0.03173929825425148f;
  t146_n189: if (E.getNumReferences() >= 3315877888 /*5257.0*/) goto t146_n193;
  t146_n190: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t146_n192;
  t146_n191: return 0.10265905410051346f;
  t146_n192: return 0.0903639942407608f;
  t146_n193: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t146_n195;
  t146_n194: return 0.03138994053006172f;
  t146_n195: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t146_n197;
  t146_n196: return 0.11227679252624512f;
  t146_n197: return -0.33878710865974426f;
  t146_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t146_n204;
  t146_n199: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t146_n203;
  t146_n200: if (E.getNumReferences() >= 3320094720 /*7316.0*/) goto t146_n202;
  t146_n201: return 0.10333114862442017f;
  t146_n202: return 0.06252143532037735f;
  t146_n203: return 0.04031367227435112f;
  t146_n204: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t146_n206;
  t146_n205: return 0.105662040412426f;
  t146_n206: return 0.09733472764492035f;
  t146_n207: return -0.260355144739151f;
  t146_n208: if (E.getNumReferences() >= 3321991168 /*8292.0*/) goto t146_n210;
  t146_n209: return 0.11503271013498306f;
  t146_n210: return 0.05124371126294136f;
  t146_n211: return 0.1097242683172226f;
  t146_n212: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t146_n224;
  t146_n213: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t146_n221;
  t146_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n216;
  t146_n215: return 0.09287599474191666f;
  t146_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t146_n220;
  t146_n217: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t146_n219;
  t146_n218: return -0.2388419210910797f;
  t146_n219: return 0.08848465234041214f;
  t146_n220: return 0.11488284915685654f;
  t146_n221: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n223;
  t146_n222: return 0.10880213975906372f;
  t146_n223: return 0.07375877350568771f;
  t146_n224: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n226;
  t146_n225: return 0.11163507401943207f;
  t146_n226: return -0.24990403652191162f;
  t146_n227: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t146_n243;
  t146_n228: if (E.getNumReferences() >= 3335010048 /*25627.5*/) goto t146_n230;
  t146_n229: return -0.07028772681951523f;
  t146_n230: if (E.getNumReferences() >= 3335170304 /*25940.5*/) goto t146_n234;
  t146_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t146_n233;
  t146_n232: return 0.06519964337348938f;
  t146_n233: return 0.10270313173532486f;
  t146_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t146_n236;
  t146_n235: return -0.007614204194396734f;
  t146_n236: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t146_n242;
  t146_n237: if (E.getNumReferences() >= 3346571264 /*63648.0*/) goto t146_n241;
  t146_n238: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t146_n240;
  t146_n239: return 0.06668416410684586f;
  t146_n240: return 0.12243681401014328f;
  t146_n241: return -0.051838286221027374f;
  t146_n242: return 0.030144095420837402f;
  t146_n243: return 0.04235474765300751f;
  t146_n244: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t146_n254;
  t146_n245: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t146_n251;
  t146_n246: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t146_n248;
  t146_n247: return 0.014738406985998154f;
  t146_n248: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t146_n250;
  t146_n249: return 0.10506380349397659f;
  t146_n250: return 0.06312283873558044f;
  t146_n251: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t146_n253;
  t146_n252: return 0.10232427716255188f;
  t146_n253: return 0.05024126544594765f;
  t146_n254: return 0.011573518626391888f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree147(const Example& E) {
  t147_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t147_n174;
  t147_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t147_n153;
  t147_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t147_n80;
  t147_n3: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t147_n79;
  t147_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t147_n68;
  t147_n5: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t147_n7;
  t147_n6: return 0.007224816828966141f;
  t147_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t147_n55;
  t147_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t147_n10;
  t147_n9: return -0.01246443297713995f;
  t147_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t147_n54;
  t147_n11: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t147_n19;
  t147_n12: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t147_n18;
  t147_n13: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t147_n15;
  t147_n14: return 0.034670233726501465f;
  t147_n15: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t147_n17;
  t147_n16: return -0.04501857981085777f;
  t147_n17: return 0.04934874176979065f;
  t147_n18: return -0.019126735627651215f;
  t147_n19: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t147_n23;
  t147_n20: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t147_n22;
  t147_n21: return 0.04161086678504944f;
  t147_n22: return 0.07863400876522064f;
  t147_n23: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t147_n29;
  t147_n24: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t147_n28;
  t147_n25: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t147_n27;
  t147_n26: return -0.15371906757354736f;
  t147_n27: return 0.11093053221702576f;
  t147_n28: return 0.06849713623523712f;
  t147_n29: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t147_n51;
  t147_n30: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t147_n50;
  t147_n31: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t147_n33;
  t147_n32: return 0.006792205385863781f;
  t147_n33: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t147_n35;
  t147_n34: return 0.11178760230541229f;
  t147_n35: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t147_n47;
  t147_n36: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t147_n44;
  t147_n37: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t147_n43;
  t147_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t147_n40;
  t147_n39: return -0.22795699536800385f;
  t147_n40: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t147_n42;
  t147_n41: return 0.12332064658403397f;
  t147_n42: return -1.2346017360687256f;
  t147_n43: return 0.11236856877803802f;
  t147_n44: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t147_n46;
  t147_n45: return 0.0005969775374978781f;
  t147_n46: return 0.11055459082126617f;
  t147_n47: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t147_n49;
  t147_n48: return 0.12035014480352402f;
  t147_n49: return 0.14380256831645966f;
  t147_n50: return 0.0014315573498606682f;
  t147_n51: if (E.getNumReferences() >= 3253731328 /*30.0*/) goto t147_n53;
  t147_n52: return -0.13975003361701965f;
  t147_n53: return 0.09393573552370071f;
  t147_n54: return 0.0023917220532894135f;
  t147_n55: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n59;
  t147_n56: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t147_n58;
  t147_n57: return 0.0843241810798645f;
  t147_n58: return -0.17026367783546448f;
  t147_n59: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t147_n61;
  t147_n60: return 0.02637612260878086f;
  t147_n61: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t147_n67;
  t147_n62: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t147_n66;
  t147_n63: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t147_n65;
  t147_n64: return 0.08224224299192429f;
  t147_n65: return 0.06324923783540726f;
  t147_n66: return 0.1139756515622139f;
  t147_n67: return -0.045362688601017f;
  t147_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t147_n74;
  t147_n69: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n71;
  t147_n70: return -0.06031837686896324f;
  t147_n71: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t147_n73;
  t147_n72: return 0.05171460285782814f;
  t147_n73: return 0.004713577684015036f;
  t147_n74: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n78;
  t147_n75: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t147_n77;
  t147_n76: return 0.09698983281850815f;
  t147_n77: return -0.023166531696915627f;
  t147_n78: return 0.027925625443458557f;
  t147_n79: return -0.0051334938034415245f;
  t147_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t147_n102;
  t147_n81: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t147_n101;
  t147_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n84;
  t147_n83: return -0.041384007781744f;
  t147_n84: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t147_n86;
  t147_n85: return -0.009143070317804813f;
  t147_n86: if (E.getNumReferences() >= 3273785344 /*162.0*/) goto t147_n88;
  t147_n87: return 0.10315146297216415f;
  t147_n88: if (E.getNumReferences() >= 3324753920 /*10990.0*/) goto t147_n100;
  t147_n89: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t147_n97;
  t147_n90: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t147_n92;
  t147_n91: return -0.0314883254468441f;
  t147_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t147_n94;
  t147_n93: return 0.03268376737833023f;
  t147_n94: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t147_n96;
  t147_n95: return 0.11617247015237808f;
  t147_n96: return 0.09265437722206116f;
  t147_n97: if (E.getNumReferences() >= 3324366336 /*10611.5*/) goto t147_n99;
  t147_n98: return 0.025298085063695908f;
  t147_n99: return 0.12180893123149872f;
  t147_n100: return -0.4274612069129944f;
  t147_n101: return 0.10567212104797363f;
  t147_n102: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t147_n152;
  t147_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t147_n105;
  t147_n104: return 0.004868334159255028f;
  t147_n105: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t147_n151;
  t147_n106: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n108;
  t147_n107: return 0.046076349914073944f;
  t147_n108: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t147_n150;
  t147_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t147_n119;
  t147_n110: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t147_n114;
  t147_n111: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t147_n113;
  t147_n112: return -0.09431491047143936f;
  t147_n113: return -0.00418156199157238f;
  t147_n114: if (E.getNumReferences() >= 3322876928 /*9157.0*/) goto t147_n118;
  t147_n115: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t147_n117;
  t147_n116: return 0.09230279177427292f;
  t147_n117: return -0.04978897050023079f;
  t147_n118: return -0.6909665465354919f;
  t147_n119: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t147_n147;
  t147_n120: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t147_n124;
  t147_n121: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t147_n123;
  t147_n122: return 0.0744759663939476f;
  t147_n123: return 0.024837730452418327f;
  t147_n124: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t147_n136;
  t147_n125: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t147_n127;
  t147_n126: return 0.09479384124279022f;
  t147_n127: if (E.getNumReferences() >= 3261333504 /*57.0*/) goto t147_n135;
  t147_n128: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t147_n132;
  t147_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t147_n131;
  t147_n130: return -0.07656212151050568f;
  t147_n131: return 0.12861740589141846f;
  t147_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t147_n134;
  t147_n133: return 0.0807235985994339f;
  t147_n134: return 0.12182985246181488f;
  t147_n135: return 0.031705208122730255f;
  t147_n136: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t147_n140;
  t147_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t147_n139;
  t147_n138: return -0.5015990138053894f;
  t147_n139: return 0.12535367906093597f;
  t147_n140: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t147_n142;
  t147_n141: return -0.12759608030319214f;
  t147_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t147_n146;
  t147_n143: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t147_n145;
  t147_n144: return 0.10577497631311417f;
  t147_n145: return 0.10955731570720673f;
  t147_n146: return 0.14136949181556702f;
  t147_n147: if (E.getNumReferences() >= 3319705600 /*7126.0*/) goto t147_n149;
  t147_n148: return 0.012767213396728039f;
  t147_n149: return -0.16392552852630615f;
  t147_n150: return 0.10688207298517227f;
  t147_n151: return -0.03646790608763695f;
  t147_n152: return -0.05132443085312843f;
  t147_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t147_n159;
  t147_n154: if (E.getNumReferences() >= 3329839104 /*15956.0*/) goto t147_n156;
  t147_n155: return -0.004169469699263573f;
  t147_n156: if (E.getNumReferences() >= 3330029056 /*16141.5*/) goto t147_n158;
  t147_n157: return 0.09946689754724503f;
  t147_n158: return 0.08321340382099152f;
  t147_n159: if (E.getNumReferences() >= 3330547456 /*16911.5*/) goto t147_n171;
  t147_n160: if (E.getNumReferences() >= 3330192896 /*16301.5*/) goto t147_n162;
  t147_n161: return 0.002910482930019498f;
  t147_n162: if (E.getNumReferences() >= 3330237440 /*16345.0*/) goto t147_n170;
  t147_n163: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t147_n167;
  t147_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t147_n166;
  t147_n165: return -0.03919889032840729f;
  t147_n166: return 0.11200354993343353f;
  t147_n167: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t147_n169;
  t147_n168: return 0.13116230070590973f;
  t147_n169: return 0.10449494421482086f;
  t147_n170: return 0.009746669791638851f;
  t147_n171: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t147_n173;
  t147_n172: return -0.050192028284072876f;
  t147_n173: return -0.17393121123313904f;
  t147_n174: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t147_n178;
  t147_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t147_n177;
  t147_n176: return 0.0003179831837769598f;
  t147_n177: return 0.012273721396923065f;
  t147_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t147_n200;
  t147_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t147_n181;
  t147_n180: return 0.007290302310138941f;
  t147_n181: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t147_n197;
  t147_n182: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t147_n184;
  t147_n183: return 0.02769569680094719f;
  t147_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t147_n196;
  t147_n185: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t147_n195;
  t147_n186: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t147_n194;
  t147_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n189;
  t147_n188: return -0.12474669516086578f;
  t147_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t147_n193;
  t147_n190: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t147_n192;
  t147_n191: return -0.19993895292282104f;
  t147_n192: return 0.11798761039972305f;
  t147_n193: return 0.12582440674304962f;
  t147_n194: return 0.1193784698843956f;
  t147_n195: return 0.013348007574677467f;
  t147_n196: return 0.11147676408290863f;
  t147_n197: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t147_n199;
  t147_n198: return 0.03841691091656685f;
  t147_n199: return -0.03815574571490288f;
  t147_n200: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t147_n246;
  t147_n201: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t147_n203;
  t147_n202: return 0.09950779378414154f;
  t147_n203: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t147_n225;
  t147_n204: if (E.getNumReferences() >= 3349616960 /*85554.5*/) goto t147_n222;
  t147_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t147_n207;
  t147_n206: return -0.08021234720945358f;
  t147_n207: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t147_n211;
  t147_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t147_n210;
  t147_n209: return -0.17384028434753418f;
  t147_n210: return 0.11964276432991028f;
  t147_n211: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t147_n221;
  t147_n212: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t147_n220;
  t147_n213: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t147_n217;
  t147_n214: if (E.getNumReferences() >= 3337714176 /*30909.0*/) goto t147_n216;
  t147_n215: return -0.14175349473953247f;
  t147_n216: return 0.05210711061954498f;
  t147_n217: if (E.getNumReferences() >= 3341667584 /*44493.0*/) goto t147_n219;
  t147_n218: return 0.09028156846761703f;
  t147_n219: return 0.03518333286046982f;
  t147_n220: return 0.10032728314399719f;
  t147_n221: return -0.04269767552614212f;
  t147_n222: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t147_n224;
  t147_n223: return 0.08024250715970993f;
  t147_n224: return 0.10665880143642426f;
  t147_n225: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t147_n245;
  t147_n226: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t147_n242;
  t147_n227: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t147_n235;
  t147_n228: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t147_n230;
  t147_n229: return 0.0658583715558052f;
  t147_n230: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t147_n232;
  t147_n231: return -0.08947884291410446f;
  t147_n232: if (E.getNumReferences() >= 3334173440 /*23993.5*/) goto t147_n234;
  t147_n233: return 0.07408567517995834f;
  t147_n234: return 0.09721650183200836f;
  t147_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n239;
  t147_n236: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t147_n238;
  t147_n237: return 0.11410452425479889f;
  t147_n238: return 0.0772741436958313f;
  t147_n239: if (E.getNumReferences() >= 3334472192 /*24577.0*/) goto t147_n241;
  t147_n240: return 0.10842452943325043f;
  t147_n241: return 0.04311281442642212f;
  t147_n242: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t147_n244;
  t147_n243: return 0.10071521997451782f;
  t147_n244: return 0.06743597239255905f;
  t147_n245: return 0.03532329946756363f;
  t147_n246: if (E.getNumReferences() >= 3337423104 /*30340.5*/) goto t147_n254;
  t147_n247: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t147_n249;
  t147_n248: return 0.043191976845264435f;
  t147_n249: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t147_n253;
  t147_n250: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t147_n252;
  t147_n251: return 0.11437606066465378f;
  t147_n252: return -0.013974405825138092f;
  t147_n253: return -0.02463645301759243f;
  t147_n254: return -0.0045295050367712975f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree148(const Example& E) {
  t148_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t148_n248;
  t148_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t148_n159;
  t148_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t148_n118;
  t148_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t148_n5;
  t148_n4: return -0.050965387374162674f;
  t148_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t148_n7;
  t148_n6: return -0.06713027507066727f;
  t148_n7: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t148_n77;
  t148_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t148_n16;
  t148_n9: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t148_n11;
  t148_n10: return -0.05475429445505142f;
  t148_n11: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t148_n13;
  t148_n12: return 0.0022602397948503494f;
  t148_n13: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n15;
  t148_n14: return 0.05283045768737793f;
  t148_n15: return 0.09994453191757202f;
  t148_n16: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t148_n20;
  t148_n17: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t148_n19;
  t148_n18: return 0.0030634566210210323f;
  t148_n19: return -0.06577198207378387f;
  t148_n20: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t148_n60;
  t148_n21: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n47;
  t148_n22: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t148_n42;
  t148_n23: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t148_n41;
  t148_n24: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t148_n40;
  t148_n25: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t148_n27;
  t148_n26: return 0.03533452749252319f;
  t148_n27: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t148_n39;
  t148_n28: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t148_n32;
  t148_n29: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t148_n31;
  t148_n30: return -0.030650872737169266f;
  t148_n31: return 0.10481618344783783f;
  t148_n32: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t148_n34;
  t148_n33: return 0.11643832176923752f;
  t148_n34: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t148_n38;
  t148_n35: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t148_n37;
  t148_n36: return 0.13324452936649323f;
  t148_n37: return 0.049498915672302246f;
  t148_n38: return 0.10422489792108536f;
  t148_n39: return 0.025382790714502335f;
  t148_n40: return -0.08620157837867737f;
  t148_n41: return 0.11361361294984818f;
  t148_n42: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t148_n44;
  t148_n43: return 0.053426213562488556f;
  t148_n44: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n46;
  t148_n45: return -0.08623027056455612f;
  t148_n46: return -0.007874797098338604f;
  t148_n47: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n59;
  t148_n48: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t148_n54;
  t148_n49: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t148_n51;
  t148_n50: return 0.1089111715555191f;
  t148_n51: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t148_n53;
  t148_n52: return -0.010670170187950134f;
  t148_n53: return -0.9007749557495117f;
  t148_n54: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t148_n56;
  t148_n55: return -0.29599079489707947f;
  t148_n56: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t148_n58;
  t148_n57: return 0.08208005875349045f;
  t148_n58: return -0.1519237458705902f;
  t148_n59: return 0.014958684332668781f;
  t148_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n62;
  t148_n61: return 0.06371717154979706f;
  t148_n62: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t148_n64;
  t148_n63: return -0.035984549671411514f;
  t148_n64: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t148_n68;
  t148_n65: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t148_n67;
  t148_n66: return 0.03113090805709362f;
  t148_n67: return 0.000634010590147227f;
  t148_n68: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t148_n70;
  t148_n69: return -0.05615963414311409f;
  t148_n70: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t148_n74;
  t148_n71: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t148_n73;
  t148_n72: return 0.11193366348743439f;
  t148_n73: return 0.07072174549102783f;
  t148_n74: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t148_n76;
  t148_n75: return 0.08602093160152435f;
  t148_n76: return 0.10723141580820084f;
  t148_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t148_n105;
  t148_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t148_n80;
  t148_n79: return 0.004488517064601183f;
  t148_n80: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n96;
  t148_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n83;
  t148_n82: return 0.03636199235916138f;
  t148_n83: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t148_n87;
  t148_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t148_n86;
  t148_n85: return -0.07739447802305222f;
  t148_n86: return 0.01531211193650961f;
  t148_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t148_n89;
  t148_n88: return 0.03803395852446556f;
  t148_n89: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t148_n91;
  t148_n90: return 0.04623677209019661f;
  t148_n91: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t148_n93;
  t148_n92: return 0.10901346802711487f;
  t148_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n95;
  t148_n94: return 0.08151531964540482f;
  t148_n95: return 0.04943395406007767f;
  t148_n96: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n98;
  t148_n97: return 0.011283899657428265f;
  t148_n98: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n104;
  t148_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t148_n101;
  t148_n100: return -0.028278788551688194f;
  t148_n101: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t148_n103;
  t148_n102: return 0.047162383794784546f;
  t148_n103: return -1.612094759941101f;
  t148_n104: return 0.0017139703268185258f;
  t148_n105: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t148_n117;
  t148_n106: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n116;
  t148_n107: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n111;
  t148_n108: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n110;
  t148_n109: return 0.09711949527263641f;
  t148_n110: return 0.07331234961748123f;
  t148_n111: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n115;
  t148_n112: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t148_n114;
  t148_n113: return 0.10012771189212799f;
  t148_n114: return 0.08779837191104889f;
  t148_n115: return 0.058075517416000366f;
  t148_n116: return 0.06965059041976929f;
  t148_n117: return -0.041346874088048935f;
  t148_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t148_n158;
  t148_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n157;
  t148_n120: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t148_n156;
  t148_n121: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t148_n147;
  t148_n122: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t148_n134;
  t148_n123: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t148_n127;
  t148_n124: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t148_n126;
  t148_n125: return -0.17325147986412048f;
  t148_n126: return -0.0253861416131258f;
  t148_n127: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t148_n131;
  t148_n128: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t148_n130;
  t148_n129: return 0.09918765723705292f;
  t148_n130: return 0.10774707794189453f;
  t148_n131: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t148_n133;
  t148_n132: return -0.1427324265241623f;
  t148_n133: return 0.037042856216430664f;
  t148_n134: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t148_n146;
  t148_n135: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t148_n137;
  t148_n136: return -0.006464327219873667f;
  t148_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t148_n145;
  t148_n138: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n142;
  t148_n139: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t148_n141;
  t148_n140: return -0.18812572956085205f;
  t148_n141: return 0.06968636065721512f;
  t148_n142: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t148_n144;
  t148_n143: return 0.03134389594197273f;
  t148_n144: return 0.13529737293720245f;
  t148_n145: return -0.007200266700237989f;
  t148_n146: return 0.02040208876132965f;
  t148_n147: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t148_n155;
  t148_n148: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n154;
  t148_n149: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t148_n151;
  t148_n150: return 0.0387800969183445f;
  t148_n151: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t148_n153;
  t148_n152: return 0.17895007133483887f;
  t148_n153: return 0.11905362457036972f;
  t148_n154: return -0.055809590965509415f;
  t148_n155: return -0.09428589791059494f;
  t148_n156: return -0.07961750775575638f;
  t148_n157: return -0.012739147059619427f;
  t148_n158: return 0.004228373523801565f;
  t148_n159: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t148_n237;
  t148_n160: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t148_n174;
  t148_n161: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n163;
  t148_n162: return -0.03548884391784668f;
  t148_n163: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t148_n165;
  t148_n164: return -0.1364622265100479f;
  t148_n165: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t148_n167;
  t148_n166: return 0.08764481544494629f;
  t148_n167: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t148_n173;
  t148_n168: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t148_n172;
  t148_n169: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t148_n171;
  t148_n170: return 0.17450515925884247f;
  t148_n171: return 0.34965580701828003f;
  t148_n172: return 0.0813017413020134f;
  t148_n173: return 0.09253803640604019f;
  t148_n174: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t148_n176;
  t148_n175: return 0.0037296998780220747f;
  t148_n176: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t148_n194;
  t148_n177: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t148_n179;
  t148_n178: return 0.018440546467900276f;
  t148_n179: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t148_n191;
  t148_n180: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t148_n184;
  t148_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t148_n183;
  t148_n182: return 0.030520964413881302f;
  t148_n183: return 0.08926144987344742f;
  t148_n184: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t148_n190;
  t148_n185: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t148_n189;
  t148_n186: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t148_n188;
  t148_n187: return -0.09374897181987762f;
  t148_n188: return 0.13182547688484192f;
  t148_n189: return 0.11083108931779861f;
  t148_n190: return 0.019317930564284325f;
  t148_n191: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t148_n193;
  t148_n192: return 0.00013349844084586948f;
  t148_n193: return 0.09233938902616501f;
  t148_n194: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t148_n228;
  t148_n195: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t148_n227;
  t148_n196: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t148_n222;
  t148_n197: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t148_n201;
  t148_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t148_n200;
  t148_n199: return -0.034009672701358795f;
  t148_n200: return 0.027932588011026382f;
  t148_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t148_n203;
  t148_n202: return 0.07879769057035446f;
  t148_n203: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t148_n221;
  t148_n204: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t148_n220;
  t148_n205: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t148_n207;
  t148_n206: return -0.06653700023889542f;
  t148_n207: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t148_n209;
  t148_n208: return 0.10751330852508545f;
  t148_n209: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t148_n217;
  t148_n210: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t148_n212;
  t148_n211: return -0.10048659890890121f;
  t148_n212: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t148_n214;
  t148_n213: return -0.10223215073347092f;
  t148_n214: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t148_n216;
  t148_n215: return 0.12639640271663666f;
  t148_n216: return 0.08304692804813385f;
  t148_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n219;
  t148_n218: return 2.3630285263061523f;
  t148_n219: return 0.1325722187757492f;
  t148_n220: return 0.11783198267221451f;
  t148_n221: return 0.13517692685127258f;
  t148_n222: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t148_n226;
  t148_n223: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t148_n225;
  t148_n224: return 0.1782185286283493f;
  t148_n225: return -0.25922277569770813f;
  t148_n226: return 0.113111712038517f;
  t148_n227: return 0.04628433659672737f;
  t148_n228: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t148_n236;
  t148_n229: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t148_n231;
  t148_n230: return -0.011215032078325748f;
  t148_n231: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t148_n235;
  t148_n232: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t148_n234;
  t148_n233: return 0.0870058611035347f;
  t148_n234: return 0.11089789122343063f;
  t148_n235: return 0.04269547015428543f;
  t148_n236: return -0.020709030330181122f;
  t148_n237: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t148_n239;
  t148_n238: return -0.035571224987506866f;
  t148_n239: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t148_n241;
  t148_n240: return 0.004867872688919306f;
  t148_n241: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n243;
  t148_n242: return -0.050456441938877106f;
  t148_n243: if (E.getNumReferences() >= 3297144832 /*1075.5*/) goto t148_n245;
  t148_n244: return 0.03497907519340515f;
  t148_n245: if (E.getNumReferences() >= 3297366016 /*1102.5*/) goto t148_n247;
  t148_n246: return 0.10004538297653198f;
  t148_n247: return 0.018766652792692184f;
  t148_n248: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t148_n252;
  t148_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n251;
  t148_n250: return 0.008016569539904594f;
  t148_n251: return 0.022118939086794853f;
  t148_n252: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t148_n254;
  t148_n253: return -0.0071126436814665794f;
  t148_n254: return 0.0074642556719481945f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree149(const Example& E) {
  t149_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t149_n50;
  t149_n1: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t149_n33;
  t149_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t149_n4;
  t149_n3: return -0.0002643822517711669f;
  t149_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t149_n6;
  t149_n5: return -0.006857994012534618f;
  t149_n6: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t149_n32;
  t149_n7: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t149_n25;
  t149_n8: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t149_n24;
  t149_n9: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t149_n23;
  t149_n10: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t149_n22;
  t149_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t149_n13;
  t149_n12: return -0.2274857461452484f;
  t149_n13: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n21;
  t149_n14: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t149_n16;
  t149_n15: return -0.04875296354293823f;
  t149_n16: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t149_n20;
  t149_n17: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t149_n19;
  t149_n18: return 0.8068740963935852f;
  t149_n19: return -0.1509336680173874f;
  t149_n20: return 0.1147775948047638f;
  t149_n21: return -0.0375070758163929f;
  t149_n22: return -0.18833313882350922f;
  t149_n23: return 0.011243580840528011f;
  t149_n24: return 0.016997335478663445f;
  t149_n25: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t149_n29;
  t149_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t149_n28;
  t149_n27: return -0.013922257348895073f;
  t149_n28: return 0.02323256805539131f;
  t149_n29: if (E.getNumReferences() >= 3235905536 /*7.0*/) goto t149_n31;
  t149_n30: return 0.004431792069226503f;
  t149_n31: return -0.20844599604606628f;
  t149_n32: return -0.09421487152576447f;
  t149_n33: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t149_n39;
  t149_n34: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t149_n38;
  t149_n35: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t149_n37;
  t149_n36: return -0.11307530105113983f;
  t149_n37: return -0.21562062203884125f;
  t149_n38: return -0.08248334378004074f;
  t149_n39: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t149_n49;
  t149_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t149_n46;
  t149_n41: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t149_n43;
  t149_n42: return -0.08465345203876495f;
  t149_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t149_n45;
  t149_n44: return 0.0850568562746048f;
  t149_n45: return -0.07374591380357742f;
  t149_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t149_n48;
  t149_n47: return 0.07963357865810394f;
  t149_n48: return 0.08137170970439911f;
  t149_n49: return -0.12966547906398773f;
  t149_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t149_n52;
  t149_n51: return 0.0016632442129775882f;
  t149_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t149_n58;
  t149_n53: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t149_n55;
  t149_n54: return -0.09349971264600754f;
  t149_n55: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t149_n57;
  t149_n56: return -0.03351889178156853f;
  t149_n57: return 0.09919758886098862f;
  t149_n58: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t149_n238;
  t149_n59: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t149_n183;
  t149_n60: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t149_n150;
  t149_n61: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t149_n131;
  t149_n62: if (E.getNumReferences() >= 3353375936 /*114921.5*/) goto t149_n130;
  t149_n63: if (E.getNumReferences() >= 3352895680 /*111169.5*/) goto t149_n103;
  t149_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t149_n66;
  t149_n65: return 0.012819850817322731f;
  t149_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t149_n68;
  t149_n67: return -0.1114858090877533f;
  t149_n68: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t149_n72;
  t149_n69: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t149_n71;
  t149_n70: return -0.17387154698371887f;
  t149_n71: return 0.04732527211308479f;
  t149_n72: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t149_n80;
  t149_n73: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t149_n79;
  t149_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t149_n76;
  t149_n75: return 0.06810735166072845f;
  t149_n76: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n78;
  t149_n77: return 0.09701944887638092f;
  t149_n78: return 0.013921594247221947f;
  t149_n79: return 0.002729157917201519f;
  t149_n80: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t149_n92;
  t149_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n83;
  t149_n82: return 0.0020447184797376394f;
  t149_n83: if (E.getNumReferences() >= 3351834112 /*102876.0*/) goto t149_n91;
  t149_n84: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t149_n86;
  t149_n85: return 0.042546022683382034f;
  t149_n86: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t149_n90;
  t149_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t149_n89;
  t149_n88: return 0.02614416368305683f;
  t149_n89: return 0.09472779184579849f;
  t149_n90: return 0.055712006986141205f;
  t149_n91: return -0.34893813729286194f;
  t149_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t149_n94;
  t149_n93: return 0.03715353086590767f;
  t149_n94: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t149_n100;
  t149_n95: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t149_n97;
  t149_n96: return 0.06030631065368652f;
  t149_n97: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t149_n99;
  t149_n98: return 0.10857461392879486f;
  t149_n99: return 0.09729068726301193f;
  t149_n100: if (E.getNumReferences() >= 3351432768 /*99740.5*/) goto t149_n102;
  t149_n101: return 0.1047767698764801f;
  t149_n102: return 0.08707249909639359f;
  t149_n103: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t149_n129;
  t149_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t149_n106;
  t149_n105: return -0.08757995069026947f;
  t149_n106: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t149_n120;
  t149_n107: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t149_n119;
  t149_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t149_n116;
  t149_n109: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t149_n115;
  t149_n110: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t149_n112;
  t149_n111: return -0.10253655910491943f;
  t149_n112: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n114;
  t149_n113: return 0.09537949413061142f;
  t149_n114: return -0.03550711274147034f;
  t149_n115: return -0.19645565748214722f;
  t149_n116: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t149_n118;
  t149_n117: return -0.13614758849143982f;
  t149_n118: return 0.12447983026504517f;
  t149_n119: return 0.10901852697134018f;
  t149_n120: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t149_n126;
  t149_n121: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n123;
  t149_n122: return 0.027397075667977333f;
  t149_n123: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t149_n125;
  t149_n124: return 0.1780054271221161f;
  t149_n125: return 0.06329836696386337f;
  t149_n126: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t149_n128;
  t149_n127: return 0.11157738417387009f;
  t149_n128: return 0.024082116782665253f;
  t149_n129: return -0.029716037213802338f;
  t149_n130: return -0.019629433751106262f;
  t149_n131: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t149_n139;
  t149_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t149_n136;
  t149_n133: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t149_n135;
  t149_n134: return 0.09280543029308319f;
  t149_n135: return -0.12347834557294846f;
  t149_n136: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t149_n138;
  t149_n137: return -0.18987390398979187f;
  t149_n138: return 0.1187906414270401f;
  t149_n139: if (E.getNumReferences() >= 3359621216 /*196353.5*/) goto t149_n149;
  t149_n140: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t149_n146;
  t149_n141: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t149_n145;
  t149_n142: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t149_n144;
  t149_n143: return -0.15158121287822723f;
  t149_n144: return 0.044353634119033813f;
  t149_n145: return 0.11878652125597f;
  t149_n146: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t149_n148;
  t149_n147: return 0.02873404696583748f;
  t149_n148: return 0.09449708461761475f;
  t149_n149: return -0.16902178525924683f;
  t149_n150: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t149_n172;
  t149_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t149_n165;
  t149_n152: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t149_n164;
  t149_n153: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t149_n159;
  t149_n154: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t149_n158;
  t149_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t149_n157;
  t149_n156: return -0.0011367765255272388f;
  t149_n157: return 0.0929136872291565f;
  t149_n158: return 0.13937778770923615f;
  t149_n159: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t149_n161;
  t149_n160: return 0.09496501088142395f;
  t149_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n163;
  t149_n162: return 0.13563145697116852f;
  t149_n163: return 0.03999195620417595f;
  t149_n164: return -0.06627853959798813f;
  t149_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t149_n171;
  t149_n166: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t149_n170;
  t149_n167: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t149_n169;
  t149_n168: return 0.0901634693145752f;
  t149_n169: return 0.0007215062505565584f;
  t149_n170: return 0.024499593302607536f;
  t149_n171: return 0.016270296648144722f;
  t149_n172: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t149_n174;
  t149_n173: return -0.020930949598550797f;
  t149_n174: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t149_n182;
  t149_n175: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n177;
  t149_n176: return 0.09292130172252655f;
  t149_n177: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t149_n181;
  t149_n178: if (E.getNumReferences() >= 3350572224 /*93017.5*/) goto t149_n180;
  t149_n179: return -0.08174887299537659f;
  t149_n180: return 0.0931299552321434f;
  t149_n181: return 0.1168966293334961f;
  t149_n182: return -0.03182857111096382f;
  t149_n183: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t149_n195;
  t149_n184: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t149_n194;
  t149_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t149_n187;
  t149_n186: return -0.12810692191123962f;
  t149_n187: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n193;
  t149_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t149_n190;
  t149_n189: return 0.0028650974854826927f;
  t149_n190: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t149_n192;
  t149_n191: return 0.11056247353553772f;
  t149_n192: return -0.1507454663515091f;
  t149_n193: return 0.0013588363071903586f;
  t149_n194: return 0.05559517443180084f;
  t149_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t149_n197;
  t149_n196: return -0.008980144746601582f;
  t149_n197: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t149_n203;
  t149_n198: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t149_n200;
  t149_n199: return 0.016443580389022827f;
  t149_n200: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n202;
  t149_n201: return 0.09901008754968643f;
  t149_n202: return -0.32759222388267517f;
  t149_n203: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t149_n237;
  t149_n204: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n236;
  t149_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t149_n215;
  t149_n206: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t149_n214;
  t149_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t149_n213;
  t149_n208: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t149_n212;
  t149_n209: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t149_n211;
  t149_n210: return 0.1441962569952011f;
  t149_n211: return 0.022702660411596298f;
  t149_n212: return 0.12839458882808685f;
  t149_n213: return 0.12005742639303207f;
  t149_n214: return 0.028451241552829742f;
  t149_n215: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t149_n221;
  t149_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t149_n218;
  t149_n217: return 0.028802866116166115f;
  t149_n218: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t149_n220;
  t149_n219: return 0.09192001074552536f;
  t149_n220: return 0.04430681839585304f;
  t149_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t149_n223;
  t149_n222: return 0.014822795055806637f;
  t149_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t149_n235;
  t149_n224: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t149_n234;
  t149_n225: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t149_n233;
  t149_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t149_n232;
  t149_n227: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t149_n231;
  t149_n228: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t149_n230;
  t149_n229: return -0.1154065951704979f;
  t149_n230: return 0.09786130487918854f;
  t149_n231: return 0.0606323778629303f;
  t149_n232: return 0.11710742115974426f;
  t149_n233: return 0.052104681730270386f;
  t149_n234: return 0.10883364826440811f;
  t149_n235: return -0.12545783817768097f;
  t149_n236: return 0.022928794845938683f;
  t149_n237: return -0.25795337557792664f;
  t149_n238: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t149_n240;
  t149_n239: return -0.14942023158073425f;
  t149_n240: if (E.getNumReferences() >= 3364158064 /*272339.5*/) goto t149_n252;
  t149_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t149_n243;
  t149_n242: return -0.03722875192761421f;
  t149_n243: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t149_n245;
  t149_n244: return -0.03091396950185299f;
  t149_n245: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t149_n251;
  t149_n246: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t149_n250;
  t149_n247: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t149_n249;
  t149_n248: return 0.07757174223661423f;
  t149_n249: return 0.11043311655521393f;
  t149_n250: return 0.07558739185333252f;
  t149_n251: return 0.039009615778923035f;
  t149_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t149_n254;
  t149_n253: return 0.00032219698186963797f;
  t149_n254: return 0.016836218535900116f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree150(const Example& E) {
  t150_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t150_n78;
  t150_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t150_n53;
  t150_n2: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t150_n4;
  t150_n3: return 0.0011707284720614552f;
  t150_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t150_n36;
  t150_n5: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t150_n35;
  t150_n6: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t150_n10;
  t150_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t150_n9;
  t150_n8: return -0.10690581798553467f;
  t150_n9: return -0.0020876643247902393f;
  t150_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t150_n20;
  t150_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n13;
  t150_n12: return -0.018970167264342308f;
  t150_n13: if (E.getNumReferences() >= 3311441920 /*3593.5*/) goto t150_n19;
  t150_n14: if (E.getNumReferences() >= 3309668352 /*3160.5*/) goto t150_n16;
  t150_n15: return -0.08817681670188904f;
  t150_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t150_n18;
  t150_n17: return -0.34247881174087524f;
  t150_n18: return 0.11002915352582932f;
  t150_n19: return -0.5183537602424622f;
  t150_n20: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t150_n32;
  t150_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t150_n29;
  t150_n22: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t150_n24;
  t150_n23: return 0.007093534804880619f;
  t150_n24: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t150_n26;
  t150_n25: return 0.08743412792682648f;
  t150_n26: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t150_n28;
  t150_n27: return 0.11887326836585999f;
  t150_n28: return -0.5982344150543213f;
  t150_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n31;
  t150_n30: return 0.09981773793697357f;
  t150_n31: return -0.23650872707366943f;
  t150_n32: if (E.getNumReferences() >= 3330339840 /*16506.0*/) goto t150_n34;
  t150_n33: return -0.04660456255078316f;
  t150_n34: return 0.12160250544548035f;
  t150_n35: return 0.024273885414004326f;
  t150_n36: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t150_n50;
  t150_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t150_n39;
  t150_n38: return 0.022662553936243057f;
  t150_n39: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t150_n49;
  t150_n40: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t150_n44;
  t150_n41: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n43;
  t150_n42: return -0.6818764805793762f;
  t150_n43: return 0.013818936422467232f;
  t150_n44: if (E.getNumReferences() >= 3325212160 /*11437.5*/) goto t150_n46;
  t150_n45: return 0.03413369879126549f;
  t150_n46: if (E.getNumReferences() >= 3326160384 /*12363.5*/) goto t150_n48;
  t150_n47: return 0.16014890372753143f;
  t150_n48: return 0.06470304727554321f;
  t150_n49: return -0.012741642072796822f;
  t150_n50: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t150_n52;
  t150_n51: return 0.015162190422415733f;
  t150_n52: return -0.0733974352478981f;
  t150_n53: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t150_n55;
  t150_n54: return 2.5274759536841884e-05f;
  t150_n55: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t150_n77;
  t150_n56: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t150_n58;
  t150_n57: return 0.011121781542897224f;
  t150_n58: if (E.getNumReferences() >= 3327494144 /*13666.0*/) goto t150_n72;
  t150_n59: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t150_n61;
  t150_n60: return -0.0976223573088646f;
  t150_n61: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t150_n63;
  t150_n62: return -0.03445763140916824f;
  t150_n63: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t150_n71;
  t150_n64: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t150_n66;
  t150_n65: return 0.010427202098071575f;
  t150_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t150_n68;
  t150_n67: return -0.0015980610623955727f;
  t150_n68: if (E.getNumReferences() >= 3324599296 /*10839.0*/) goto t150_n70;
  t150_n69: return 0.0696302279829979f;
  t150_n70: return -0.19121207296848297f;
  t150_n71: return -0.014520417898893356f;
  t150_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t150_n74;
  t150_n73: return -0.21319067478179932f;
  t150_n74: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n76;
  t150_n75: return 0.11018542945384979f;
  t150_n76: return 0.15173949301242828f;
  t150_n77: return -0.027248015627264977f;
  t150_n78: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t150_n106;
  t150_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t150_n81;
  t150_n80: return 0.0031977184116840363f;
  t150_n81: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t150_n99;
  t150_n82: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t150_n94;
  t150_n83: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t150_n85;
  t150_n84: return 0.1101030707359314f;
  t150_n85: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t150_n91;
  t150_n86: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t150_n90;
  t150_n87: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t150_n89;
  t150_n88: return 0.0864504799246788f;
  t150_n89: return 0.11597326397895813f;
  t150_n90: return 0.05415669456124306f;
  t150_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t150_n93;
  t150_n92: return 0.12075425684452057f;
  t150_n93: return 0.11468927562236786f;
  t150_n94: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n96;
  t150_n95: return 0.09820887446403503f;
  t150_n96: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t150_n98;
  t150_n97: return 0.04887231066823006f;
  t150_n98: return 0.0931621640920639f;
  t150_n99: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n105;
  t150_n100: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t150_n102;
  t150_n101: return -0.5560339093208313f;
  t150_n102: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t150_n104;
  t150_n103: return 0.13695985078811646f;
  t150_n104: return 0.13416096568107605f;
  t150_n105: return 0.003992708865553141f;
  t150_n106: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t150_n214;
  t150_n107: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t150_n109;
  t150_n108: return -0.01206845324486494f;
  t150_n109: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n111;
  t150_n110: return 0.00030944752506911755f;
  t150_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t150_n191;
  t150_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t150_n132;
  t150_n113: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t150_n117;
  t150_n114: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t150_n116;
  t150_n115: return -0.034213900566101074f;
  t150_n116: return -0.43526872992515564f;
  t150_n117: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t150_n131;
  t150_n118: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t150_n128;
  t150_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t150_n127;
  t150_n120: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t150_n122;
  t150_n121: return -0.20384475588798523f;
  t150_n122: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t150_n126;
  t150_n123: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t150_n125;
  t150_n124: return 0.03306260704994202f;
  t150_n125: return 0.09411657601594925f;
  t150_n126: return -0.1286967396736145f;
  t150_n127: return 0.12860938906669617f;
  t150_n128: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t150_n130;
  t150_n129: return 0.053510881960392f;
  t150_n130: return 0.11304157227277756f;
  t150_n131: return 0.005185876041650772f;
  t150_n132: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t150_n186;
  t150_n133: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t150_n181;
  t150_n134: if (E.getNumReferences() >= 3332416512 /*20562.0*/) goto t150_n138;
  t150_n135: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t150_n137;
  t150_n136: return -0.060468174517154694f;
  t150_n137: return 0.13166160881519318f;
  t150_n138: if (E.getNumReferences() >= 3335927040 /*27418.5*/) goto t150_n142;
  t150_n139: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t150_n141;
  t150_n140: return -0.11650042235851288f;
  t150_n141: return -0.388493150472641f;
  t150_n142: if (E.getNumReferences() >= 3338736000 /*33041.5*/) goto t150_n158;
  t150_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t150_n157;
  t150_n144: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t150_n146;
  t150_n145: return -0.21701936423778534f;
  t150_n146: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t150_n154;
  t150_n147: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t150_n151;
  t150_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t150_n150;
  t150_n149: return -1.5501021146774292f;
  t150_n150: return 0.11095596104860306f;
  t150_n151: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t150_n153;
  t150_n152: return 0.0645664855837822f;
  t150_n153: return 0.1041783019900322f;
  t150_n154: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t150_n156;
  t150_n155: return -0.001278663519769907f;
  t150_n156: return 0.12792128324508667f;
  t150_n157: return 0.10393139719963074f;
  t150_n158: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t150_n164;
  t150_n159: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t150_n163;
  t150_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t150_n162;
  t150_n161: return -0.32930123805999756f;
  t150_n162: return -0.0009310460300184786f;
  t150_n163: return 0.05284285172820091f;
  t150_n164: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t150_n174;
  t150_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t150_n173;
  t150_n166: if (E.getNumReferences() >= 3343484032 /*51588.5*/) goto t150_n168;
  t150_n167: return -0.0798761248588562f;
  t150_n168: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t150_n170;
  t150_n169: return 0.10612176358699799f;
  t150_n170: if (E.getNumReferences() >= 3357991456 /*170888.5*/) goto t150_n172;
  t150_n171: return -0.06398488581180573f;
  t150_n172: return 0.10439679026603699f;
  t150_n173: return 0.10920193791389465f;
  t150_n174: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t150_n176;
  t150_n175: return -0.05812719836831093f;
  t150_n176: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t150_n178;
  t150_n177: return -0.018046220764517784f;
  t150_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t150_n180;
  t150_n179: return -0.008671884424984455f;
  t150_n180: return 0.10808101296424866f;
  t150_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t150_n185;
  t150_n182: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t150_n184;
  t150_n183: return 0.11163900792598724f;
  t150_n184: return 0.025316262617707253f;
  t150_n185: return 0.11550372838973999f;
  t150_n186: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t150_n190;
  t150_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t150_n189;
  t150_n188: return -0.12523376941680908f;
  t150_n189: return 0.002932610223069787f;
  t150_n190: return 0.07693403214216232f;
  t150_n191: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t150_n199;
  t150_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t150_n194;
  t150_n193: return -0.0009887396590784192f;
  t150_n194: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t150_n198;
  t150_n195: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t150_n197;
  t150_n196: return 0.09697303175926208f;
  t150_n197: return 0.07438036054372787f;
  t150_n198: return 0.06862947344779968f;
  t150_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t150_n201;
  t150_n200: return -0.15804216265678406f;
  t150_n201: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t150_n203;
  t150_n202: return -0.014707721769809723f;
  t150_n203: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t150_n207;
  t150_n204: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t150_n206;
  t150_n205: return 0.1281338632106781f;
  t150_n206: return 0.10507019609212875f;
  t150_n207: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t150_n209;
  t150_n208: return 0.049932919442653656f;
  t150_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t150_n213;
  t150_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t150_n212;
  t150_n211: return 0.11634672433137894f;
  t150_n212: return -0.09112243354320526f;
  t150_n213: return 0.021478325128555298f;
  t150_n214: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t150_n216;
  t150_n215: return 0.008777842856943607f;
  t150_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t150_n248;
  t150_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t150_n237;
  t150_n218: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t150_n236;
  t150_n219: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t150_n235;
  t150_n220: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n230;
  t150_n221: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t150_n225;
  t150_n222: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t150_n224;
  t150_n223: return 0.06954573094844818f;
  t150_n224: return 1.1355143785476685f;
  t150_n225: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t150_n229;
  t150_n226: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t150_n228;
  t150_n227: return -0.3887336552143097f;
  t150_n228: return 0.1222376748919487f;
  t150_n229: return 0.05816386640071869f;
  t150_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t150_n234;
  t150_n231: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t150_n233;
  t150_n232: return 0.05354287102818489f;
  t150_n233: return -0.1968984156847f;
  t150_n234: return -0.08129319548606873f;
  t150_n235: return -0.07054781168699265f;
  t150_n236: return 0.11678200215101242f;
  t150_n237: if (E.getNumReferences() >= 3336251648 /*28052.5*/) goto t150_n247;
  t150_n238: if (E.getNumReferences() >= 3334339584 /*24318.0*/) goto t150_n242;
  t150_n239: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t150_n241;
  t150_n240: return -0.09479056298732758f;
  t150_n241: return 0.0936460867524147f;
  t150_n242: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t150_n246;
  t150_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n245;
  t150_n244: return -0.13159222900867462f;
  t150_n245: return 0.1069289967417717f;
  t150_n246: return 0.11075947433710098f;
  t150_n247: return 0.029492901638150215f;
  t150_n248: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t150_n254;
  t150_n249: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t150_n251;
  t150_n250: return -0.09056193381547928f;
  t150_n251: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t150_n253;
  t150_n252: return 0.1235378310084343f;
  t150_n253: return -0.12095549702644348f;
  t150_n254: return -0.06885196268558502f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree151(const Example& E) {
  t151_n0: if (E.getNumReferences() >= 3306797056 /*2459.5*/) goto t151_n2;
  t151_n1: return -0.00043545279186218977f;
  t151_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t151_n16;
  t151_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t151_n5;
  t151_n4: return 0.009738503023982048f;
  t151_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t151_n7;
  t151_n6: return 0.0216587632894516f;
  t151_n7: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t151_n15;
  t151_n8: if (E.getNumReferences() >= 3314761728 /*4712.0*/) goto t151_n10;
  t151_n9: return -0.18813075125217438f;
  t151_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t151_n12;
  t151_n11: return 0.10095684975385666f;
  t151_n12: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t151_n14;
  t151_n13: return 0.1442340463399887f;
  t151_n14: return 0.13841280341148376f;
  t151_n15: return -0.008962706662714481f;
  t151_n16: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t151_n18;
  t151_n17: return -0.002806692849844694f;
  t151_n18: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t151_n218;
  t151_n19: if (E.getNumReferences() >= 3315681280 /*5161.0*/) goto t151_n27;
  t151_n20: if (E.getNumReferences() >= 3306835968 /*2469.0*/) goto t151_n24;
  t151_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t151_n23;
  t151_n22: return 0.0392635315656662f;
  t151_n23: return 0.11539028584957123f;
  t151_n24: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t151_n26;
  t151_n25: return 0.004707269836217165f;
  t151_n26: return 0.08556046336889267f;
  t151_n27: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t151_n37;
  t151_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t151_n34;
  t151_n29: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n31;
  t151_n30: return -0.00035908666905015707f;
  t151_n31: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t151_n33;
  t151_n32: return 0.09908497333526611f;
  t151_n33: return -0.12234605103731155f;
  t151_n34: if (E.getNumReferences() >= 3315727360 /*5183.5*/) goto t151_n36;
  t151_n35: return 0.09724979102611542f;
  t151_n36: return 0.12582451105117798f;
  t151_n37: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t151_n203;
  t151_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t151_n94;
  t151_n39: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t151_n69;
  t151_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t151_n42;
  t151_n41: return -0.028094368055462837f;
  t151_n42: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t151_n58;
  t151_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t151_n45;
  t151_n44: return -0.02266014739871025f;
  t151_n45: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t151_n47;
  t151_n46: return -0.1736333817243576f;
  t151_n47: if (E.getNumReferences() >= 3324282368 /*10529.5*/) goto t151_n55;
  t151_n48: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n50;
  t151_n49: return 0.12406112253665924f;
  t151_n50: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t151_n52;
  t151_n51: return -0.1138983890414238f;
  t151_n52: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t151_n54;
  t151_n53: return 0.12314701080322266f;
  t151_n54: return 0.12981046736240387f;
  t151_n55: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t151_n57;
  t151_n56: return 0.08505978435277939f;
  t151_n57: return 0.10323630273342133f;
  t151_n58: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t151_n60;
  t151_n59: return -0.008383593522012234f;
  t151_n60: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t151_n68;
  t151_n61: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t151_n67;
  t151_n62: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t151_n64;
  t151_n63: return -0.1045675128698349f;
  t151_n64: if (E.getNumReferences() >= 3322096640 /*8395.0*/) goto t151_n66;
  t151_n65: return 0.03487173467874527f;
  t151_n66: return 0.16220690310001373f;
  t151_n67: return 0.1257304698228836f;
  t151_n68: return 0.10031621903181076f;
  t151_n69: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t151_n73;
  t151_n70: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t151_n72;
  t151_n71: return 0.003204312175512314f;
  t151_n72: return 0.11287324875593185f;
  t151_n73: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t151_n75;
  t151_n74: return 0.021554457023739815f;
  t151_n75: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t151_n93;
  t151_n76: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t151_n80;
  t151_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t151_n79;
  t151_n78: return 0.12217453867197037f;
  t151_n79: return 0.11495719105005264f;
  t151_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t151_n92;
  t151_n81: if (E.getNumReferences() >= 3317499904 /*6049.0*/) goto t151_n85;
  t151_n82: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t151_n84;
  t151_n83: return 0.11090273410081863f;
  t151_n84: return 0.10590197890996933f;
  t151_n85: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n89;
  t151_n86: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t151_n88;
  t151_n87: return -0.1363116204738617f;
  t151_n88: return 0.09934008121490479f;
  t151_n89: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t151_n91;
  t151_n90: return 0.10390619933605194f;
  t151_n91: return -0.08971324563026428f;
  t151_n92: return 0.10325489193201065f;
  t151_n93: return -0.13354074954986572f;
  t151_n94: if (E.getNumReferences() >= 3334023936 /*23701.5*/) goto t151_n188;
  t151_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t151_n159;
  t151_n96: if (E.getNumReferences() >= 3321819136 /*8158.0*/) goto t151_n152;
  t151_n97: if (E.getNumReferences() >= 3321606144 /*8054.0*/) goto t151_n149;
  t151_n98: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t151_n112;
  t151_n99: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t151_n101;
  t151_n100: return -0.03210652992129326f;
  t151_n101: if (E.getNumReferences() >= 3319636992 /*7092.5*/) goto t151_n107;
  t151_n102: if (E.getNumReferences() >= 3317832704 /*6211.5*/) goto t151_n106;
  t151_n103: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t151_n105;
  t151_n104: return 0.15778163075447083f;
  t151_n105: return 0.11472880095243454f;
  t151_n106: return -0.2576814889907837f;
  t151_n107: if (E.getNumReferences() >= 3320252416 /*7393.0*/) goto t151_n109;
  t151_n108: return 0.13108162581920624f;
  t151_n109: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t151_n111;
  t151_n110: return 0.10325673222541809f;
  t151_n111: return -0.10644271224737167f;
  t151_n112: if (E.getNumReferences() >= 3319918592 /*7230.0*/) goto t151_n130;
  t151_n113: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t151_n129;
  t151_n114: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t151_n128;
  t151_n115: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t151_n117;
  t151_n116: return -0.07646097987890244f;
  t151_n117: if (E.getNumReferences() >= 3317490688 /*6044.5*/) goto t151_n119;
  t151_n118: return -0.2299100160598755f;
  t151_n119: if (E.getNumReferences() >= 3317757952 /*6175.0*/) goto t151_n121;
  t151_n120: return 0.11940469592809677f;
  t151_n121: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t151_n127;
  t151_n122: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t151_n126;
  t151_n123: if (E.getNumReferences() >= 3319047168 /*6804.5*/) goto t151_n125;
  t151_n124: return 0.11104380339384079f;
  t151_n125: return -0.1519901156425476f;
  t151_n126: return -0.13099172711372375f;
  t151_n127: return 0.09456785768270493f;
  t151_n128: return 0.0032177830580621958f;
  t151_n129: return -0.05092566832900047f;
  t151_n130: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n138;
  t151_n131: if (E.getNumReferences() >= 3320159232 /*7347.5*/) goto t151_n135;
  t151_n132: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t151_n134;
  t151_n133: return -0.1079171821475029f;
  t151_n134: return 0.12493585050106049f;
  t151_n135: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t151_n137;
  t151_n136: return 0.030855905264616013f;
  t151_n137: return -0.5332649350166321f;
  t151_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t151_n146;
  t151_n139: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t151_n145;
  t151_n140: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t151_n142;
  t151_n141: return -0.1298578828573227f;
  t151_n142: if (E.getNumReferences() >= 3321062400 /*7788.5*/) goto t151_n144;
  t151_n143: return 0.11092390865087509f;
  t151_n144: return 0.11525065451860428f;
  t151_n145: return 0.07176414877176285f;
  t151_n146: if (E.getNumReferences() >= 3320749056 /*7635.5*/) goto t151_n148;
  t151_n147: return -0.10113594681024551f;
  t151_n148: return 0.11716372519731522f;
  t151_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t151_n151;
  t151_n150: return -0.11664937436580658f;
  t151_n151: return 0.1199507862329483f;
  t151_n152: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t151_n154;
  t151_n153: return -0.016833893954753876f;
  t151_n154: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t151_n156;
  t151_n155: return 0.02717766910791397f;
  t151_n156: if (E.getNumReferences() >= 3331729664 /*19220.5*/) goto t151_n158;
  t151_n157: return 0.11538873612880707f;
  t151_n158: return -0.02647900953888893f;
  t151_n159: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t151_n161;
  t151_n160: return 0.151762917637825f;
  t151_n161: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t151_n187;
  t151_n162: if (E.getNumReferences() >= 3321896960 /*8200.0*/) goto t151_n184;
  t151_n163: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n165;
  t151_n164: return -0.00024124662741087377f;
  t151_n165: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t151_n167;
  t151_n166: return 0.10437799245119095f;
  t151_n167: if (E.getNumReferences() >= 3320443904 /*7486.5*/) goto t151_n183;
  t151_n168: if (E.getNumReferences() >= 3319744512 /*7145.0*/) goto t151_n178;
  t151_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t151_n171;
  t151_n170: return 0.027755053713917732f;
  t151_n171: if (E.getNumReferences() >= 3315877888 /*5257.0*/) goto t151_n173;
  t151_n172: return 0.0996299535036087f;
  t151_n173: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t151_n175;
  t151_n174: return 0.026929736137390137f;
  t151_n175: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t151_n177;
  t151_n176: return 0.11499323695898056f;
  t151_n177: return -0.28481945395469666f;
  t151_n178: if (E.getNumReferences() >= 3319828480 /*7186.0*/) goto t151_n182;
  t151_n179: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t151_n181;
  t151_n180: return 0.10258269309997559f;
  t151_n181: return 0.09472787380218506f;
  t151_n182: return 0.07248102873563766f;
  t151_n183: return -0.1875799596309662f;
  t151_n184: if (E.getNumReferences() >= 3321991168 /*8292.0*/) goto t151_n186;
  t151_n185: return 0.11319059878587723f;
  t151_n186: return 0.04715369641780853f;
  t151_n187: return 0.1045333594083786f;
  t151_n188: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t151_n202;
  t151_n189: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t151_n199;
  t151_n190: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t151_n192;
  t151_n191: return 0.08689802139997482f;
  t151_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t151_n198;
  t151_n193: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t151_n195;
  t151_n194: return -0.1010102704167366f;
  t151_n195: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t151_n197;
  t151_n196: return 0.09916798770427704f;
  t151_n197: return 0.06570155918598175f;
  t151_n198: return 0.11416072398424149f;
  t151_n199: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t151_n201;
  t151_n200: return 0.10945098102092743f;
  t151_n201: return 0.06989581882953644f;
  t151_n202: return 0.03216373175382614f;
  t151_n203: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t151_n217;
  t151_n204: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t151_n206;
  t151_n205: return -0.15238215029239655f;
  t151_n206: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n216;
  t151_n207: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t151_n209;
  t151_n208: return -0.10554506629705429f;
  t151_n209: if (E.getNumReferences() >= 3324040704 /*10293.5*/) goto t151_n215;
  t151_n210: if (E.getNumReferences() >= 3319302144 /*6929.0*/) goto t151_n214;
  t151_n211: if (E.getNumReferences() >= 3318825984 /*6696.5*/) goto t151_n213;
  t151_n212: return 0.10347791761159897f;
  t151_n213: return -0.11744607985019684f;
  t151_n214: return 0.09905122965574265f;
  t151_n215: return 0.05031636357307434f;
  t151_n216: return -0.0442984513938427f;
  t151_n217: return 0.04481038078665733f;
  t151_n218: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t151_n254;
  t151_n219: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t151_n251;
  t151_n220: if (E.getNumReferences() >= 3335010048 /*25627.5*/) goto t151_n226;
  t151_n221: if (E.getNumReferences() >= 3334899200 /*25411.0*/) goto t151_n223;
  t151_n222: return -0.0730506107211113f;
  t151_n223: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t151_n225;
  t151_n224: return 0.0862327367067337f;
  t151_n225: return -0.34384700655937195f;
  t151_n226: if (E.getNumReferences() >= 3335170304 /*25940.5*/) goto t151_n230;
  t151_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t151_n229;
  t151_n228: return -0.29280927777290344f;
  t151_n229: return 0.09988941997289658f;
  t151_n230: if (E.getNumReferences() >= 3366258096 /*337965.5*/) goto t151_n232;
  t151_n231: return -0.013753936626017094f;
  t151_n232: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t151_n238;
  t151_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t151_n235;
  t151_n234: return 0.03028811514377594f;
  t151_n235: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t151_n237;
  t151_n236: return 0.10947556048631668f;
  t151_n237: return 0.033384885638952255f;
  t151_n238: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n240;
  t151_n239: return -0.018235623836517334f;
  t151_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t151_n242;
  t151_n241: return 0.05746462196111679f;
  t151_n242: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t151_n248;
  t151_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t151_n245;
  t151_n244: return 0.05737617611885071f;
  t151_n245: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t151_n247;
  t151_n246: return 0.10585806518793106f;
  t151_n247: return 0.08329249918460846f;
  t151_n248: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t151_n250;
  t151_n249: return 0.07499319314956665f;
  t151_n250: return -0.411899209022522f;
  t151_n251: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t151_n253;
  t151_n252: return -0.026692340150475502f;
  t151_n253: return 0.018174167722463608f;
  t151_n254: return 0.04018937051296234f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree152(const Example& E) {
  t152_n0: if (E.getNumReferences() >= 3324859904 /*11093.5*/) goto t152_n2;
  t152_n1: return -0.0003530648536980152f;
  t152_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t152_n84;
  t152_n3: if (E.getNumReferences() >= 3327362048 /*13537.0*/) goto t152_n47;
  t152_n4: if (E.getNumReferences() >= 3327291904 /*13468.5*/) goto t152_n44;
  t152_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t152_n13;
  t152_n6: if (E.getNumReferences() >= 3327044096 /*13226.5*/) goto t152_n8;
  t152_n7: return 0.027373382821679115f;
  t152_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t152_n10;
  t152_n9: return 0.16997748613357544f;
  t152_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n12;
  t152_n11: return 0.15262165665626526f;
  t152_n12: return 0.10301752388477325f;
  t152_n13: if (E.getNumReferences() >= 3324926976 /*11159.0*/) goto t152_n17;
  t152_n14: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t152_n16;
  t152_n15: return -0.15825772285461426f;
  t152_n16: return 0.14158053696155548f;
  t152_n17: if (E.getNumReferences() >= 3325383680 /*11605.0*/) goto t152_n31;
  t152_n18: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t152_n26;
  t152_n19: if (E.getNumReferences() >= 3325212160 /*11437.5*/) goto t152_n23;
  t152_n20: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t152_n22;
  t152_n21: return 0.03647181764245033f;
  t152_n22: return -0.5331239104270935f;
  t152_n23: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t152_n25;
  t152_n24: return 0.15597553551197052f;
  t152_n25: return 0.06898877769708633f;
  t152_n26: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t152_n30;
  t152_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t152_n29;
  t152_n28: return 0.12941499054431915f;
  t152_n29: return 0.03958865627646446f;
  t152_n30: return -0.14717379212379456f;
  t152_n31: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t152_n33;
  t152_n32: return 0.060859404504299164f;
  t152_n33: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t152_n35;
  t152_n34: return -0.15022780001163483f;
  t152_n35: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t152_n39;
  t152_n36: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t152_n38;
  t152_n37: return 0.0557527132332325f;
  t152_n38: return 0.12655223906040192f;
  t152_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n41;
  t152_n40: return -0.01638045161962509f;
  t152_n41: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t152_n43;
  t152_n42: return 0.11537913978099823f;
  t152_n43: return 0.03253640979528427f;
  t152_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t152_n46;
  t152_n45: return 0.5940304398536682f;
  t152_n46: return 0.12465257197618484f;
  t152_n47: if (E.getNumReferences() >= 3327710208 /*13877.0*/) goto t152_n55;
  t152_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t152_n54;
  t152_n49: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t152_n53;
  t152_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t152_n52;
  t152_n51: return -0.6281301975250244f;
  t152_n52: return -3.4201126098632812f;
  t152_n53: return -0.06005248799920082f;
  t152_n54: return -0.0945759192109108f;
  t152_n55: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t152_n83;
  t152_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t152_n58;
  t152_n57: return 0.005003007128834724f;
  t152_n58: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t152_n60;
  t152_n59: return 0.015102673321962357f;
  t152_n60: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t152_n76;
  t152_n61: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t152_n69;
  t152_n62: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t152_n68;
  t152_n63: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t152_n67;
  t152_n64: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t152_n66;
  t152_n65: return 0.03861706703901291f;
  t152_n66: return 0.13074807822704315f;
  t152_n67: return 0.08017916977405548f;
  t152_n68: return 0.03017689287662506f;
  t152_n69: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t152_n71;
  t152_n70: return 0.0408230721950531f;
  t152_n71: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t152_n75;
  t152_n72: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t152_n74;
  t152_n73: return 0.1136656254529953f;
  t152_n74: return 0.08505445718765259f;
  t152_n75: return 0.06774649769067764f;
  t152_n76: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t152_n82;
  t152_n77: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t152_n79;
  t152_n78: return 0.065132737159729f;
  t152_n79: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t152_n81;
  t152_n80: return -0.15635094046592712f;
  t152_n81: return 0.12502464652061462f;
  t152_n82: return 0.038030777126550674f;
  t152_n83: return 0.008983309380710125f;
  t152_n84: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t152_n88;
  t152_n85: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t152_n87;
  t152_n86: return -0.03454064577817917f;
  t152_n87: return -0.09253742545843124f;
  t152_n88: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t152_n172;
  t152_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t152_n143;
  t152_n90: if (E.getNumReferences() >= 3346195456 /*62180.0*/) goto t152_n112;
  t152_n91: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t152_n107;
  t152_n92: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t152_n106;
  t152_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t152_n95;
  t152_n94: return 0.023194342851638794f;
  t152_n95: if (E.getNumReferences() >= 3330989056 /*17774.0*/) goto t152_n99;
  t152_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t152_n98;
  t152_n97: return 0.07595369964838028f;
  t152_n98: return 0.13957884907722473f;
  t152_n99: if (E.getNumReferences() >= 3339920000 /*37666.5*/) goto t152_n103;
  t152_n100: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t152_n102;
  t152_n101: return 0.07876088470220566f;
  t152_n102: return -0.33111605048179626f;
  t152_n103: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t152_n105;
  t152_n104: return -0.0009367507882416248f;
  t152_n105: return 0.10865053534507751f;
  t152_n106: return 0.005293200258165598f;
  t152_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t152_n109;
  t152_n108: return 0.014587384648621082f;
  t152_n109: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t152_n111;
  t152_n110: return -0.0615391731262207f;
  t152_n111: return 0.11272073537111282f;
  t152_n112: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t152_n128;
  t152_n113: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t152_n115;
  t152_n114: return -0.018988555297255516f;
  t152_n115: if (E.getNumReferences() >= 3348227392 /*74698.5*/) goto t152_n127;
  t152_n116: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t152_n122;
  t152_n117: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t152_n119;
  t152_n118: return -0.11452287435531616f;
  t152_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t152_n121;
  t152_n120: return -0.021892046555876732f;
  t152_n121: return 0.09840931743383408f;
  t152_n122: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t152_n126;
  t152_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t152_n125;
  t152_n124: return -0.12937778234481812f;
  t152_n125: return 0.10188450664281845f;
  t152_n126: return 0.010777843184769154f;
  t152_n127: return -0.02268238551914692f;
  t152_n128: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t152_n142;
  t152_n129: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t152_n131;
  t152_n130: return -0.05618099495768547f;
  t152_n131: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t152_n141;
  t152_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t152_n140;
  t152_n133: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n139;
  t152_n134: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t152_n136;
  t152_n135: return 0.11589735746383667f;
  t152_n136: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t152_n138;
  t152_n137: return 0.11677806824445724f;
  t152_n138: return 0.0048472583293914795f;
  t152_n139: return 0.04653036594390869f;
  t152_n140: return -0.11496122181415558f;
  t152_n141: return 0.01696523278951645f;
  t152_n142: return 0.11526696383953094f;
  t152_n143: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t152_n159;
  t152_n144: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t152_n146;
  t152_n145: return -0.07532991468906403f;
  t152_n146: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t152_n148;
  t152_n147: return 0.021743198856711388f;
  t152_n148: if (E.getNumReferences() >= 3330470656 /*16761.5*/) goto t152_n150;
  t152_n149: return -0.06523853540420532f;
  t152_n150: if (E.getNumReferences() >= 3334795520 /*25208.5*/) goto t152_n154;
  t152_n151: if (E.getNumReferences() >= 3333635072 /*22942.0*/) goto t152_n153;
  t152_n152: return 0.8742266297340393f;
  t152_n153: return 0.11896016448736191f;
  t152_n154: if (E.getNumReferences() >= 3339882752 /*37521.0*/) goto t152_n156;
  t152_n155: return -0.26804670691490173f;
  t152_n156: if (E.getNumReferences() >= 3341543680 /*44009.0*/) goto t152_n158;
  t152_n157: return 0.27688321471214294f;
  t152_n158: return -0.19440898299217224f;
  t152_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t152_n171;
  t152_n160: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t152_n168;
  t152_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n165;
  t152_n162: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t152_n164;
  t152_n163: return 0.06668546050786972f;
  t152_n164: return 0.10025845468044281f;
  t152_n165: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t152_n167;
  t152_n166: return 0.10778062045574188f;
  t152_n167: return 0.04585035517811775f;
  t152_n168: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t152_n170;
  t152_n169: return 0.11488959193229675f;
  t152_n170: return 0.006126217544078827f;
  t152_n171: return 0.14568382501602173f;
  t152_n172: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t152_n180;
  t152_n173: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n179;
  t152_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t152_n176;
  t152_n175: return -0.3976207375526428f;
  t152_n176: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t152_n178;
  t152_n177: return 0.10254738479852676f;
  t152_n178: return 0.12991948425769806f;
  t152_n179: return 0.07127019762992859f;
  t152_n180: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t152_n254;
  t152_n181: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t152_n253;
  t152_n182: if (E.getNumReferences() >= 3352895680 /*111169.5*/) goto t152_n242;
  t152_n183: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t152_n231;
  t152_n184: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t152_n230;
  t152_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t152_n195;
  t152_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t152_n188;
  t152_n187: return 0.02055664174258709f;
  t152_n188: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t152_n192;
  t152_n189: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t152_n191;
  t152_n190: return 0.08075578510761261f;
  t152_n191: return 0.16008365154266357f;
  t152_n192: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t152_n194;
  t152_n193: return 0.13668805360794067f;
  t152_n194: return 0.04521958902478218f;
  t152_n195: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t152_n215;
  t152_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t152_n198;
  t152_n197: return -0.012252209708094597f;
  t152_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t152_n212;
  t152_n199: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n201;
  t152_n200: return 0.04608755186200142f;
  t152_n201: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t152_n211;
  t152_n202: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t152_n208;
  t152_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t152_n207;
  t152_n204: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t152_n206;
  t152_n205: return 0.1092173308134079f;
  t152_n206: return 0.10891794413328171f;
  t152_n207: return 0.10371187329292297f;
  t152_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t152_n210;
  t152_n209: return 0.04468065872788429f;
  t152_n210: return 0.10597864538431168f;
  t152_n211: return 0.041177522391080856f;
  t152_n212: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t152_n214;
  t152_n213: return 0.07166346907615662f;
  t152_n214: return 0.12355837970972061f;
  t152_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t152_n227;
  t152_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t152_n218;
  t152_n217: return -0.25830554962158203f;
  t152_n218: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t152_n226;
  t152_n219: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t152_n225;
  t152_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t152_n222;
  t152_n221: return 0.06942278146743774f;
  t152_n222: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t152_n224;
  t152_n223: return 0.0826125293970108f;
  t152_n224: return -0.10467147827148438f;
  t152_n225: return 0.08676277101039886f;
  t152_n226: return -0.2314951866865158f;
  t152_n227: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t152_n229;
  t152_n228: return 0.09416785836219788f;
  t152_n229: return 0.09581971913576126f;
  t152_n230: return -0.16317741572856903f;
  t152_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t152_n233;
  t152_n232: return 0.013886811211705208f;
  t152_n233: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n239;
  t152_n234: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t152_n238;
  t152_n235: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t152_n237;
  t152_n236: return 0.04896402731537819f;
  t152_n237: return 0.0777946338057518f;
  t152_n238: return 0.10687519609928131f;
  t152_n239: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t152_n241;
  t152_n240: return -0.008721845224499702f;
  t152_n241: return 0.05415920913219452f;
  t152_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t152_n244;
  t152_n243: return -0.14547978341579437f;
  t152_n244: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t152_n248;
  t152_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t152_n247;
  t152_n246: return 0.09321137517690659f;
  t152_n247: return 0.10611261427402496f;
  t152_n248: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t152_n250;
  t152_n249: return 0.0640607476234436f;
  t152_n250: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t152_n252;
  t152_n251: return 0.10899679362773895f;
  t152_n252: return 0.020039044320583344f;
  t152_n253: return -0.04644935205578804f;
  t152_n254: return 0.008097890764474869f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree153(const Example& E) {
  t153_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t153_n254;
  t153_n1: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t153_n177;
  t153_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t153_n38;
  t153_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t153_n5;
  t153_n4: return -0.0031729235779494047f;
  t153_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t153_n35;
  t153_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t153_n8;
  t153_n7: return -0.006247959099709988f;
  t153_n8: if (E.getNumReferences() >= 3305148416 /*2057.0*/) goto t153_n10;
  t153_n9: return 0.0032853102311491966f;
  t153_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t153_n12;
  t153_n11: return 0.0021876723039895296f;
  t153_n12: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t153_n34;
  t153_n13: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t153_n33;
  t153_n14: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t153_n32;
  t153_n15: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t153_n27;
  t153_n16: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t153_n18;
  t153_n17: return 0.07007061690092087f;
  t153_n18: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t153_n20;
  t153_n19: return 0.06829703599214554f;
  t153_n20: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t153_n22;
  t153_n21: return -0.11299063265323639f;
  t153_n22: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t153_n26;
  t153_n23: if (E.getNumReferences() >= 3331793152 /*19344.5*/) goto t153_n25;
  t153_n24: return 0.114744171500206f;
  t153_n25: return 0.0982092022895813f;
  t153_n26: return -0.1033235415816307f;
  t153_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t153_n31;
  t153_n28: if (E.getNumReferences() >= 3320380416 /*7455.5*/) goto t153_n30;
  t153_n29: return 0.07488538324832916f;
  t153_n30: return 0.11663330346345901f;
  t153_n31: return 0.08261258155107498f;
  t153_n32: return 0.019481852650642395f;
  t153_n33: return 0.014563643373548985f;
  t153_n34: return 0.03364371508359909f;
  t153_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t153_n37;
  t153_n36: return 0.08782549947500229f;
  t153_n37: return 0.03203364089131355f;
  t153_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t153_n40;
  t153_n39: return -0.005524586886167526f;
  t153_n40: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t153_n176;
  t153_n41: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t153_n157;
  t153_n42: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t153_n44;
  t153_n43: return 0.005198133643716574f;
  t153_n44: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t153_n68;
  t153_n45: if (E.getNumReferences() >= 3309795328 /*3191.5*/) goto t153_n67;
  t153_n46: if (E.getNumReferences() >= 3309611008 /*3146.5*/) goto t153_n66;
  t153_n47: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t153_n53;
  t153_n48: if (E.getNumReferences() >= 3283320832 /*359.0*/) goto t153_n50;
  t153_n49: return -0.6057464480400085f;
  t153_n50: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t153_n52;
  t153_n51: return -0.11540663987398148f;
  t153_n52: return 0.07616231590509415f;
  t153_n53: if (E.getNumReferences() >= 3280420864 /*270.5*/) goto t153_n57;
  t153_n54: if (E.getNumReferences() >= 3280207872 /*264.0*/) goto t153_n56;
  t153_n55: return 0.0697777047753334f;
  t153_n56: return 0.1266922652721405f;
  t153_n57: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t153_n65;
  t153_n58: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t153_n62;
  t153_n59: if (E.getNumReferences() >= 3304308736 /*1950.0*/) goto t153_n61;
  t153_n60: return 0.02808588370680809f;
  t153_n61: return 0.08047593384981155f;
  t153_n62: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t153_n64;
  t153_n63: return 0.13215848803520203f;
  t153_n64: return 0.03835746645927429f;
  t153_n65: return 0.009635488502681255f;
  t153_n66: return 0.136430561542511f;
  t153_n67: return -0.12841428816318512f;
  t153_n68: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t153_n118;
  t153_n69: if (E.getNumReferences() >= 3325736448 /*11949.5*/) goto t153_n109;
  t153_n70: if (E.getNumReferences() >= 3324380672 /*10625.5*/) goto t153_n100;
  t153_n71: if (E.getNumReferences() >= 3321964544 /*8266.0*/) goto t153_n73;
  t153_n72: return -0.0008195267291739583f;
  t153_n73: if (E.getNumReferences() >= 3322915840 /*9195.0*/) goto t153_n91;
  t153_n74: if (E.getNumReferences() >= 3322782208 /*9064.5*/) goto t153_n82;
  t153_n75: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t153_n79;
  t153_n76: if (E.getNumReferences() >= 3322376192 /*8668.0*/) goto t153_n78;
  t153_n77: return 0.21268320083618164f;
  t153_n78: return -0.004447044339030981f;
  t153_n79: if (E.getNumReferences() >= 3322603520 /*8890.0*/) goto t153_n81;
  t153_n80: return -0.03420699015259743f;
  t153_n81: return 0.1156013011932373f;
  t153_n82: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t153_n84;
  t153_n83: return 0.05122557654976845f;
  t153_n84: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t153_n90;
  t153_n85: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t153_n89;
  t153_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t153_n88;
  t153_n87: return -0.10488434135913849f;
  t153_n88: return 0.10898370295763016f;
  t153_n89: return 0.11505317687988281f;
  t153_n90: return -0.3665043115615845f;
  t153_n91: if (E.getNumReferences() >= 3323686912 /*9948.0*/) goto t153_n97;
  t153_n92: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t153_n94;
  t153_n93: return -0.12100031226873398f;
  t153_n94: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t153_n96;
  t153_n95: return 0.10013143718242645f;
  t153_n96: return -0.06880068778991699f;
  t153_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t153_n99;
  t153_n98: return 0.045531656593084335f;
  t153_n99: return 0.15762723982334137f;
  t153_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t153_n108;
  t153_n101: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t153_n103;
  t153_n102: return -0.0867738127708435f;
  t153_n103: if (E.getNumReferences() >= 3324703232 /*10940.5*/) goto t153_n105;
  t153_n104: return 0.17834828794002533f;
  t153_n105: if (E.getNumReferences() >= 3325327360 /*11550.0*/) goto t153_n107;
  t153_n106: return -0.028220558539032936f;
  t153_n107: return 0.09184953570365906f;
  t153_n108: return 0.10306137055158615f;
  t153_n109: if (E.getNumReferences() >= 3326164992 /*12368.0*/) goto t153_n117;
  t153_n110: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t153_n116;
  t153_n111: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t153_n115;
  t153_n112: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t153_n114;
  t153_n113: return 0.08938179165124893f;
  t153_n114: return -0.024513965472579002f;
  t153_n115: return -0.19632868468761444f;
  t153_n116: return 0.1148308590054512f;
  t153_n117: return 0.02109580673277378f;
  t153_n118: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t153_n124;
  t153_n119: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t153_n121;
  t153_n120: return 0.04588180407881737f;
  t153_n121: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t153_n123;
  t153_n122: return 0.12137364596128464f;
  t153_n123: return -0.2606065571308136f;
  t153_n124: if (E.getNumReferences() >= 3289612288 /*590.0*/) goto t153_n152;
  t153_n125: if (E.getNumReferences() >= 3288858624 /*544.0*/) goto t153_n147;
  t153_n126: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t153_n140;
  t153_n127: if (E.getNumReferences() >= 3275063296 /*181.5*/) goto t153_n139;
  t153_n128: if (E.getNumReferences() >= 3274866688 /*178.5*/) goto t153_n138;
  t153_n129: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t153_n131;
  t153_n130: return 0.7316809296607971f;
  t153_n131: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t153_n137;
  t153_n132: if (E.getNumReferences() >= 3268739072 /*106.5*/) goto t153_n134;
  t153_n133: return -0.23861224949359894f;
  t153_n134: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t153_n136;
  t153_n135: return 0.1297009438276291f;
  t153_n136: return -0.0831298977136612f;
  t153_n137: return 0.04733744636178017f;
  t153_n138: return 0.11763054877519608f;
  t153_n139: return -0.025285862386226654f;
  t153_n140: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t153_n146;
  t153_n141: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t153_n145;
  t153_n142: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t153_n144;
  t153_n143: return 0.019812554121017456f;
  t153_n144: return 0.11338625848293304f;
  t153_n145: return -0.425989031791687f;
  t153_n146: return 0.058073677122592926f;
  t153_n147: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t153_n149;
  t153_n148: return -0.1187727078795433f;
  t153_n149: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t153_n151;
  t153_n150: return 0.12708903849124908f;
  t153_n151: return 0.08153201639652252f;
  t153_n152: if (E.getNumReferences() >= 3315824640 /*5231.0*/) goto t153_n154;
  t153_n153: return -0.01822534017264843f;
  t153_n154: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t153_n156;
  t153_n155: return 0.08638621866703033f;
  t153_n156: return 0.024140872061252594f;
  t153_n157: if (E.getNumReferences() >= 3337883136 /*31239.0*/) goto t153_n169;
  t153_n158: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t153_n162;
  t153_n159: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t153_n161;
  t153_n160: return -0.1861540526151657f;
  t153_n161: return 0.07245594263076782f;
  t153_n162: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t153_n166;
  t153_n163: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t153_n165;
  t153_n164: return 0.10460945218801498f;
  t153_n165: return 0.10184139013290405f;
  t153_n166: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t153_n168;
  t153_n167: return 0.0417034849524498f;
  t153_n168: return 0.09525726735591888f;
  t153_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t153_n173;
  t153_n170: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t153_n172;
  t153_n171: return -0.46173715591430664f;
  t153_n172: return 0.02902170456945896f;
  t153_n173: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t153_n175;
  t153_n174: return -1.4077237844467163f;
  t153_n175: return 0.05515073984861374f;
  t153_n176: return -0.0344228558242321f;
  t153_n177: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t153_n253;
  t153_n178: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t153_n180;
  t153_n179: return 0.010814950801432133f;
  t153_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t153_n200;
  t153_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t153_n183;
  t153_n182: return 0.048270221799612045f;
  t153_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t153_n185;
  t153_n184: return -0.12443739175796509f;
  t153_n185: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t153_n199;
  t153_n186: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t153_n188;
  t153_n187: return -0.036580875515937805f;
  t153_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t153_n198;
  t153_n189: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t153_n193;
  t153_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t153_n192;
  t153_n191: return -0.10440681874752045f;
  t153_n192: return 0.09679107367992401f;
  t153_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t153_n195;
  t153_n194: return 0.05920964851975441f;
  t153_n195: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t153_n197;
  t153_n196: return 0.09556830674409866f;
  t153_n197: return 0.12153015285730362f;
  t153_n198: return 0.026133818551898003f;
  t153_n199: return -0.01729894056916237f;
  t153_n200: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t153_n242;
  t153_n201: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t153_n237;
  t153_n202: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t153_n214;
  t153_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t153_n205;
  t153_n204: return -0.030463313683867455f;
  t153_n205: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t153_n211;
  t153_n206: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t153_n208;
  t153_n207: return -0.08944382518529892f;
  t153_n208: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t153_n210;
  t153_n209: return 0.04354771971702576f;
  t153_n210: return -0.045583661645650864f;
  t153_n211: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t153_n213;
  t153_n212: return 0.11020254343748093f;
  t153_n213: return 0.019487470388412476f;
  t153_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t153_n222;
  t153_n215: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t153_n217;
  t153_n216: return 0.012735835276544094f;
  t153_n217: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t153_n219;
  t153_n218: return 0.02375917322933674f;
  t153_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t153_n221;
  t153_n220: return 0.07225016504526138f;
  t153_n221: return 0.0026674089021980762f;
  t153_n222: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t153_n236;
  t153_n223: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t153_n235;
  t153_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t153_n226;
  t153_n225: return 0.03519134223461151f;
  t153_n226: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t153_n234;
  t153_n227: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t153_n231;
  t153_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t153_n230;
  t153_n229: return -0.032761987298727036f;
  t153_n230: return 0.03510133922100067f;
  t153_n231: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t153_n233;
  t153_n232: return 0.06268712133169174f;
  t153_n233: return -0.04645251855254173f;
  t153_n234: return 0.11227397620677948f;
  t153_n235: return 0.03889278694987297f;
  t153_n236: return -0.009243992157280445f;
  t153_n237: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t153_n239;
  t153_n238: return -0.11593499034643173f;
  t153_n239: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t153_n241;
  t153_n240: return 0.019750505685806274f;
  t153_n241: return 0.10316935926675797f;
  t153_n242: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t153_n250;
  t153_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t153_n247;
  t153_n244: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t153_n246;
  t153_n245: return 0.09070569276809692f;
  t153_n246: return 0.003227023873478174f;
  t153_n247: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t153_n249;
  t153_n248: return 0.06933560222387314f;
  t153_n249: return 0.11766822636127472f;
  t153_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t153_n252;
  t153_n251: return -0.5529073476791382f;
  t153_n252: return 0.1113298311829567f;
  t153_n253: return -0.002746619749814272f;
  t153_n254: return -0.04222463443875313f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree154(const Example& E) {
  t154_n0: if (E.getNumReferences() >= 3324859904 /*11093.5*/) goto t154_n2;
  t154_n1: return -0.0003422457375563681f;
  t154_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t154_n38;
  t154_n3: if (E.getNumReferences() >= 3325491712 /*11710.5*/) goto t154_n37;
  t154_n4: if (E.getNumReferences() >= 3325368832 /*11590.5*/) goto t154_n26;
  t154_n5: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t154_n17;
  t154_n6: if (E.getNumReferences() >= 3325345280 /*11567.5*/) goto t154_n8;
  t154_n7: return -0.0504334457218647f;
  t154_n8: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n10;
  t154_n9: return 0.21226470172405243f;
  t154_n10: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t154_n14;
  t154_n11: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t154_n13;
  t154_n12: return 0.5644444227218628f;
  t154_n13: return -0.10049070417881012f;
  t154_n14: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t154_n16;
  t154_n15: return 0.2195654958486557f;
  t154_n16: return 0.22135178744792938f;
  t154_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t154_n19;
  t154_n18: return 0.09848613291978836f;
  t154_n19: if (E.getNumReferences() >= 3324926976 /*11159.0*/) goto t154_n21;
  t154_n20: return -0.025454536080360413f;
  t154_n21: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t154_n25;
  t154_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t154_n24;
  t154_n23: return 0.12529347836971283f;
  t154_n24: return 0.036832522600889206f;
  t154_n25: return -0.12650705873966217f;
  t154_n26: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t154_n28;
  t154_n27: return 0.14005374908447266f;
  t154_n28: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t154_n32;
  t154_n29: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t154_n31;
  t154_n30: return -0.22518007457256317f;
  t154_n31: return 0.11344866454601288f;
  t154_n32: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t154_n36;
  t154_n33: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t154_n35;
  t154_n34: return 0.12576517462730408f;
  t154_n35: return 0.17482715845108032f;
  t154_n36: return -0.13254745304584503f;
  t154_n37: return 0.012894229032099247f;
  t154_n38: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t154_n40;
  t154_n39: return -0.035088662058115005f;
  t154_n40: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t154_n190;
  t154_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t154_n167;
  t154_n42: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t154_n86;
  t154_n43: if (E.getNumReferences() >= 3345503360 /*59476.5*/) goto t154_n45;
  t154_n44: return -0.0018909018253907561f;
  t154_n45: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t154_n69;
  t154_n46: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t154_n52;
  t154_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t154_n51;
  t154_n48: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t154_n50;
  t154_n49: return -0.28015032410621643f;
  t154_n50: return -1.5556249618530273f;
  t154_n51: return -0.12782278656959534f;
  t154_n52: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t154_n68;
  t154_n53: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t154_n61;
  t154_n54: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t154_n56;
  t154_n55: return -0.11156712472438812f;
  t154_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t154_n60;
  t154_n57: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t154_n59;
  t154_n58: return -0.10765403509140015f;
  t154_n59: return -0.8781079053878784f;
  t154_n60: return -0.21484880149364471f;
  t154_n61: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t154_n63;
  t154_n62: return -0.236115962266922f;
  t154_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t154_n65;
  t154_n64: return -0.37834998965263367f;
  t154_n65: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t154_n67;
  t154_n66: return 0.008656633086502552f;
  t154_n67: return 0.0718991756439209f;
  t154_n68: return 0.11406990885734558f;
  t154_n69: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t154_n75;
  t154_n70: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t154_n74;
  t154_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t154_n73;
  t154_n72: return -0.3058127760887146f;
  t154_n73: return 0.13526079058647156f;
  t154_n74: return -0.026070652529597282f;
  t154_n75: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t154_n77;
  t154_n76: return -0.09829973429441452f;
  t154_n77: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t154_n85;
  t154_n78: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n84;
  t154_n79: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t154_n81;
  t154_n80: return 0.11383714526891708f;
  t154_n81: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t154_n83;
  t154_n82: return 0.11543654650449753f;
  t154_n83: return 0.004941573832184076f;
  t154_n84: return 0.039364833384752274f;
  t154_n85: return 0.03454019874334335f;
  t154_n86: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t154_n156;
  t154_n87: if (E.getNumReferences() >= 3337711104 /*30903.0*/) goto t154_n91;
  t154_n88: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t154_n90;
  t154_n89: return 0.12975221872329712f;
  t154_n90: return 0.002413001609966159f;
  t154_n91: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t154_n129;
  t154_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t154_n94;
  t154_n93: return -0.03083989769220352f;
  t154_n94: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t154_n128;
  t154_n95: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t154_n103;
  t154_n96: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t154_n102;
  t154_n97: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t154_n101;
  t154_n98: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n100;
  t154_n99: return 0.1197829470038414f;
  t154_n100: return -0.28892722725868225f;
  t154_n101: return 0.0005300117773003876f;
  t154_n102: return -0.09219199419021606f;
  t154_n103: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n105;
  t154_n104: return 0.12632593512535095f;
  t154_n105: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t154_n117;
  t154_n106: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t154_n112;
  t154_n107: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n109;
  t154_n108: return 0.9243380427360535f;
  t154_n109: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t154_n111;
  t154_n110: return -0.07956624031066895f;
  t154_n111: return 0.1325872540473938f;
  t154_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n116;
  t154_n113: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t154_n115;
  t154_n114: return 0.2883203327655792f;
  t154_n115: return 0.1373268961906433f;
  t154_n116: return -0.15104737877845764f;
  t154_n117: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t154_n125;
  t154_n118: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t154_n124;
  t154_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t154_n121;
  t154_n120: return -0.20771870017051697f;
  t154_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t154_n123;
  t154_n122: return 0.06558860838413239f;
  t154_n123: return 0.11837410181760788f;
  t154_n124: return 0.05110177397727966f;
  t154_n125: if (E.getNumReferences() >= 3345281152 /*58608.5*/) goto t154_n127;
  t154_n126: return -0.1048726961016655f;
  t154_n127: return 0.17324738204479218f;
  t154_n128: return 0.027537629008293152f;
  t154_n129: if (E.getNumReferences() >= 3338968320 /*33949.0*/) goto t154_n149;
  t154_n130: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t154_n144;
  t154_n131: if (E.getNumReferences() >= 3338315520 /*32083.5*/) goto t154_n135;
  t154_n132: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n134;
  t154_n133: return 0.09861582517623901f;
  t154_n134: return 0.05960221216082573f;
  t154_n135: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t154_n141;
  t154_n136: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t154_n140;
  t154_n137: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t154_n139;
  t154_n138: return 0.1424623727798462f;
  t154_n139: return -2.308276653289795f;
  t154_n140: return 0.11750476807355881f;
  t154_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n143;
  t154_n142: return -0.11280437558889389f;
  t154_n143: return 0.12173178791999817f;
  t154_n144: if (E.getNumReferences() >= 3338840320 /*33449.0*/) goto t154_n146;
  t154_n145: return -0.1825108379125595f;
  t154_n146: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t154_n148;
  t154_n147: return 0.1252879798412323f;
  t154_n148: return 0.030467551201581955f;
  t154_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t154_n155;
  t154_n150: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t154_n154;
  t154_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t154_n153;
  t154_n152: return -0.14504830539226532f;
  t154_n153: return 0.07269041985273361f;
  t154_n154: return -0.02424033172428608f;
  t154_n155: return 0.10769519954919815f;
  t154_n156: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t154_n158;
  t154_n157: return -0.017346076667308807f;
  t154_n158: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t154_n166;
  t154_n159: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n165;
  t154_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t154_n164;
  t154_n161: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t154_n163;
  t154_n162: return 0.13060881197452545f;
  t154_n163: return 0.12430181354284286f;
  t154_n164: return 0.06350294500589371f;
  t154_n165: return 0.039082106202840805f;
  t154_n166: return 0.057795967906713486f;
  t154_n167: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t154_n177;
  t154_n168: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t154_n170;
  t154_n169: return -0.06581731885671616f;
  t154_n170: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t154_n172;
  t154_n171: return 0.020768875256180763f;
  t154_n172: if (E.getNumReferences() >= 3333936384 /*23530.5*/) goto t154_n174;
  t154_n173: return 0.07377095520496368f;
  t154_n174: if (E.getNumReferences() >= 3335077120 /*25758.5*/) goto t154_n176;
  t154_n175: return 0.11605305224657059f;
  t154_n176: return 0.04137743264436722f;
  t154_n177: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t154_n189;
  t154_n178: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t154_n186;
  t154_n179: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n183;
  t154_n180: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t154_n182;
  t154_n181: return 0.06339897215366364f;
  t154_n182: return 0.0964057520031929f;
  t154_n183: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t154_n185;
  t154_n184: return 0.10675735771656036f;
  t154_n185: return 0.04445425793528557f;
  t154_n186: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t154_n188;
  t154_n187: return 0.11198437958955765f;
  t154_n188: return 0.0038416674360632896f;
  t154_n189: return 0.14275334775447845f;
  t154_n190: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t154_n198;
  t154_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n197;
  t154_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t154_n194;
  t154_n193: return -0.11953405290842056f;
  t154_n194: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t154_n196;
  t154_n195: return 0.09782148897647858f;
  t154_n196: return 0.12914535403251648f;
  t154_n197: return 0.07290966063737869f;
  t154_n198: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t154_n254;
  t154_n199: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t154_n253;
  t154_n200: if (E.getNumReferences() >= 3352895680 /*111169.5*/) goto t154_n250;
  t154_n201: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t154_n241;
  t154_n202: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t154_n240;
  t154_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t154_n211;
  t154_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t154_n206;
  t154_n205: return 0.017162306234240532f;
  t154_n206: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t154_n208;
  t154_n207: return 0.09361385554075241f;
  t154_n208: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n210;
  t154_n209: return 0.11976298689842224f;
  t154_n210: return 0.048279404640197754f;
  t154_n211: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t154_n229;
  t154_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t154_n214;
  t154_n213: return -0.043991684913635254f;
  t154_n214: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t154_n226;
  t154_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n217;
  t154_n216: return 0.04168613627552986f;
  t154_n217: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t154_n223;
  t154_n218: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n220;
  t154_n219: return 0.09218906611204147f;
  t154_n220: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t154_n222;
  t154_n221: return 0.10095103830099106f;
  t154_n222: return -0.3644765019416809f;
  t154_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t154_n225;
  t154_n224: return 0.05464210733771324f;
  t154_n225: return 0.10646592080593109f;
  t154_n226: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t154_n228;
  t154_n227: return 0.06421153247356415f;
  t154_n228: return 0.1216403916478157f;
  t154_n229: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t154_n237;
  t154_n230: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t154_n234;
  t154_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n233;
  t154_n232: return 0.10884034633636475f;
  t154_n233: return 0.09762097895145416f;
  t154_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t154_n236;
  t154_n235: return -0.24127815663814545f;
  t154_n236: return 0.0322609581053257f;
  t154_n237: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t154_n239;
  t154_n238: return 0.029218781739473343f;
  t154_n239: return 0.09187452495098114f;
  t154_n240: return -0.1589706838130951f;
  t154_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t154_n243;
  t154_n242: return 0.008729354478418827f;
  t154_n243: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n249;
  t154_n244: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t154_n248;
  t154_n245: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t154_n247;
  t154_n246: return 0.04967108368873596f;
  t154_n247: return 0.07695050537586212f;
  t154_n248: return 0.10303653031587601f;
  t154_n249: return 0.026984985917806625f;
  t154_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t154_n252;
  t154_n251: return -0.139047309756279f;
  t154_n252: return 0.08233904838562012f;
  t154_n253: return -0.041073575615882874f;
  t154_n254: return 0.007074224296957254f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree155(const Example& E) {
  t155_n0: if (E.getNumReferences() >= 3325298688 /*11522.0*/) goto t155_n6;
  t155_n1: if (E.getNumReferences() >= 3325283328 /*11507.0*/) goto t155_n3;
  t155_n2: return -0.0003330412437207997f;
  t155_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t155_n5;
  t155_n4: return -0.23202653229236603f;
  t155_n5: return -0.25343114137649536f;
  t155_n6: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t155_n252;
  t155_n7: if (E.getNumReferences() >= 3325491712 /*11710.5*/) goto t155_n27;
  t155_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t155_n16;
  t155_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n11;
  t155_n10: return 0.11172674596309662f;
  t155_n11: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t155_n13;
  t155_n12: return 0.12656909227371216f;
  t155_n13: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t155_n15;
  t155_n14: return 0.22432604432106018f;
  t155_n15: return 0.2184760570526123f;
  t155_n16: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t155_n18;
  t155_n17: return 0.13419046998023987f;
  t155_n18: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t155_n22;
  t155_n19: if (E.getNumReferences() >= 3325383680 /*11605.0*/) goto t155_n21;
  t155_n20: return 0.12345612794160843f;
  t155_n21: return -0.14485470950603485f;
  t155_n22: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t155_n26;
  t155_n23: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t155_n25;
  t155_n24: return 0.1282983422279358f;
  t155_n25: return 0.1557273268699646f;
  t155_n26: return -0.09640413522720337f;
  t155_n27: if (E.getNumReferences() >= 3325608960 /*11825.0*/) goto t155_n33;
  t155_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n30;
  t155_n29: return -0.24158278107643127f;
  t155_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n32;
  t155_n31: return -0.19868747889995575f;
  t155_n32: return -1.3018455505371094f;
  t155_n33: if (E.getNumReferences() >= 3327362048 /*13537.0*/) goto t155_n43;
  t155_n34: if (E.getNumReferences() >= 3327291904 /*13468.5*/) goto t155_n42;
  t155_n35: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t155_n39;
  t155_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n38;
  t155_n37: return 0.05743874981999397f;
  t155_n38: return 0.06580660492181778f;
  t155_n39: if (E.getNumReferences() >= 3326233600 /*12435.0*/) goto t155_n41;
  t155_n40: return 0.08723106235265732f;
  t155_n41: return 0.02345559373497963f;
  t155_n42: return 0.24134628474712372f;
  t155_n43: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t155_n227;
  t155_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t155_n150;
  t155_n45: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t155_n131;
  t155_n46: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t155_n108;
  t155_n47: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n93;
  t155_n48: if (E.getNumReferences() >= 3350379712 /*91513.5*/) goto t155_n60;
  t155_n49: if (E.getNumReferences() >= 3345303552 /*58696.0*/) goto t155_n55;
  t155_n50: if (E.getNumReferences() >= 3330356992 /*16539.5*/) goto t155_n54;
  t155_n51: if (E.getNumReferences() >= 3330192896 /*16301.5*/) goto t155_n53;
  t155_n52: return -0.00014906292199157178f;
  t155_n53: return 0.1325244903564453f;
  t155_n54: return 0.010978915728628635f;
  t155_n55: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t155_n59;
  t155_n56: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t155_n58;
  t155_n57: return -0.2368883639574051f;
  t155_n58: return 0.06406964361667633f;
  t155_n59: return -0.04995829984545708f;
  t155_n60: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t155_n66;
  t155_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n65;
  t155_n62: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t155_n64;
  t155_n63: return 0.028117720037698746f;
  t155_n64: return 0.11587534099817276f;
  t155_n65: return -0.0075022270902991295f;
  t155_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t155_n68;
  t155_n67: return -0.5459851622581482f;
  t155_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n90;
  t155_n69: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t155_n71;
  t155_n70: return -0.06834609806537628f;
  t155_n71: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t155_n89;
  t155_n72: if (E.getNumReferences() >= 3361266432 /*222060.0*/) goto t155_n80;
  t155_n73: if (E.getNumReferences() >= 3357822688 /*168251.5*/) goto t155_n79;
  t155_n74: if (E.getNumReferences() >= 3354093056 /*120524.0*/) goto t155_n78;
  t155_n75: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t155_n77;
  t155_n76: return -0.13183839619159698f;
  t155_n77: return 0.06256169825792313f;
  t155_n78: return 0.12222506105899811f;
  t155_n79: return -0.06443629413843155f;
  t155_n80: if (E.getNumReferences() >= 3365641360 /*318692.5*/) goto t155_n88;
  t155_n81: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t155_n87;
  t155_n82: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t155_n86;
  t155_n83: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t155_n85;
  t155_n84: return 0.08198820799589157f;
  t155_n85: return 0.09744373708963394f;
  t155_n86: return 0.030194517225027084f;
  t155_n87: return 0.07187602669000626f;
  t155_n88: return -0.11083336919546127f;
  t155_n89: return 0.0129838977009058f;
  t155_n90: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t155_n92;
  t155_n91: return -0.05812723934650421f;
  t155_n92: return 0.02332879975438118f;
  t155_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n107;
  t155_n94: if (E.getNumReferences() >= 3342114944 /*46240.5*/) goto t155_n96;
  t155_n95: return -0.7054423093795776f;
  t155_n96: if (E.getNumReferences() >= 3343995264 /*53585.5*/) goto t155_n98;
  t155_n97: return 0.08547365665435791f;
  t155_n98: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t155_n104;
  t155_n99: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t155_n103;
  t155_n100: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t155_n102;
  t155_n101: return 0.010487895458936691f;
  t155_n102: return 0.07978886365890503f;
  t155_n103: return -0.24135588109493256f;
  t155_n104: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t155_n106;
  t155_n105: return 0.03500404208898544f;
  t155_n106: return -0.7462210059165955f;
  t155_n107: return 0.024331659078598022f;
  t155_n108: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n112;
  t155_n109: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t155_n111;
  t155_n110: return 0.04415377601981163f;
  t155_n111: return 0.016619164496660233f;
  t155_n112: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n130;
  t155_n113: if (E.getNumReferences() >= 3331562752 /*18894.5*/) goto t155_n117;
  t155_n114: if (E.getNumReferences() >= 3330192896 /*16301.5*/) goto t155_n116;
  t155_n115: return -0.2845477759838104f;
  t155_n116: return 0.11142422258853912f;
  t155_n117: if (E.getNumReferences() >= 3335931904 /*27428.0*/) goto t155_n119;
  t155_n118: return -0.4745120108127594f;
  t155_n119: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t155_n129;
  t155_n120: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t155_n122;
  t155_n121: return -0.03373350575566292f;
  t155_n122: if (E.getNumReferences() >= 3350379712 /*91513.5*/) goto t155_n128;
  t155_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t155_n127;
  t155_n124: if (E.getNumReferences() >= 3344702080 /*56346.5*/) goto t155_n126;
  t155_n125: return 0.06916764378547668f;
  t155_n126: return -0.5226970911026001f;
  t155_n127: return 0.10477609187364578f;
  t155_n128: return 0.01738252490758896f;
  t155_n129: return 0.005186347756534815f;
  t155_n130: return 0.029516682028770447f;
  t155_n131: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t155_n139;
  t155_n132: if (E.getNumReferences() >= 3339920896 /*37670.0*/) goto t155_n136;
  t155_n133: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t155_n135;
  t155_n134: return -0.0269465409219265f;
  t155_n135: return 0.11328831315040588f;
  t155_n136: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n138;
  t155_n137: return 0.12710343301296234f;
  t155_n138: return 0.13660046458244324f;
  t155_n139: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t155_n141;
  t155_n140: return -0.12636719644069672f;
  t155_n141: if (E.getNumReferences() >= 3375095784 /*703998.5*/) goto t155_n143;
  t155_n142: return -0.014123070053756237f;
  t155_n143: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t155_n147;
  t155_n144: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t155_n146;
  t155_n145: return -0.008401167578995228f;
  t155_n146: return 0.07484252005815506f;
  t155_n147: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t155_n149;
  t155_n148: return -0.5246198773384094f;
  t155_n149: return 0.10684089362621307f;
  t155_n150: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t155_n154;
  t155_n151: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n153;
  t155_n152: return 0.0225723497569561f;
  t155_n153: return -0.10437928885221481f;
  t155_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n200;
  t155_n155: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t155_n183;
  t155_n156: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t155_n162;
  t155_n157: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t155_n159;
  t155_n158: return 0.02231159433722496f;
  t155_n159: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n161;
  t155_n160: return 0.13464674353599548f;
  t155_n161: return 0.05604084953665733f;
  t155_n162: if (E.getNumReferences() >= 3346296960 /*62576.5*/) goto t155_n182;
  t155_n163: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t155_n175;
  t155_n164: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t155_n174;
  t155_n165: if (E.getNumReferences() >= 3333474560 /*22628.5*/) goto t155_n167;
  t155_n166: return -0.2443690150976181f;
  t155_n167: if (E.getNumReferences() >= 3333914624 /*23488.0*/) goto t155_n173;
  t155_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t155_n172;
  t155_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n171;
  t155_n170: return 0.10711049288511276f;
  t155_n171: return 0.09626752883195877f;
  t155_n172: return -0.38257917761802673f;
  t155_n173: return -0.10935736447572708f;
  t155_n174: return -0.04660148173570633f;
  t155_n175: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t155_n181;
  t155_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n178;
  t155_n177: return 0.1411653757095337f;
  t155_n178: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t155_n180;
  t155_n179: return 0.12912549078464508f;
  t155_n180: return 0.07467158883810043f;
  t155_n181: return 0.21603921055793762f;
  t155_n182: return -0.16406622529029846f;
  t155_n183: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t155_n189;
  t155_n184: if (E.getNumReferences() >= 3358908544 /*185218.0*/) goto t155_n186;
  t155_n185: return 0.05479435622692108f;
  t155_n186: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n188;
  t155_n187: return -0.2327219545841217f;
  t155_n188: return 0.011266162618994713f;
  t155_n189: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t155_n191;
  t155_n190: return 0.001503068022429943f;
  t155_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n195;
  t155_n192: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t155_n194;
  t155_n193: return 0.11144907772541046f;
  t155_n194: return 0.08266358822584152f;
  t155_n195: if (E.getNumReferences() >= 3334472192 /*24577.0*/) goto t155_n197;
  t155_n196: return 0.1021115779876709f;
  t155_n197: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t155_n199;
  t155_n198: return 0.06082385033369064f;
  t155_n199: return -2.127861499786377f;
  t155_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n214;
  t155_n201: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t155_n209;
  t155_n202: if (E.getNumReferences() >= 3340429568 /*39657.0*/) goto t155_n204;
  t155_n203: return 0.015466378070414066f;
  t155_n204: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t155_n206;
  t155_n205: return -1.5054376125335693f;
  t155_n206: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t155_n208;
  t155_n207: return 0.1104530617594719f;
  t155_n208: return 0.06445584446191788f;
  t155_n209: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t155_n211;
  t155_n210: return -0.1427246481180191f;
  t155_n211: if (E.getNumReferences() >= 3348676224 /*78205.0*/) goto t155_n213;
  t155_n212: return 0.11815992742776871f;
  t155_n213: return 0.1184781864285469f;
  t155_n214: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t155_n216;
  t155_n215: return -0.17375685274600983f;
  t155_n216: if (E.getNumReferences() >= 3337305088 /*30110.0*/) goto t155_n226;
  t155_n217: if (E.getNumReferences() >= 3334173440 /*23993.5*/) goto t155_n223;
  t155_n218: if (E.getNumReferences() >= 3332673792 /*21064.5*/) goto t155_n222;
  t155_n219: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t155_n221;
  t155_n220: return 0.07520441710948944f;
  t155_n221: return 0.1754007190465927f;
  t155_n222: return -0.01732534170150757f;
  t155_n223: if (E.getNumReferences() >= 3334637824 /*24900.5*/) goto t155_n225;
  t155_n224: return 0.11121047288179398f;
  t155_n225: return 0.11557430028915405f;
  t155_n226: return 0.03785169869661331f;
  t155_n227: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n247;
  t155_n228: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t155_n232;
  t155_n229: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t155_n231;
  t155_n230: return 0.017004378139972687f;
  t155_n231: return -0.11832188069820404f;
  t155_n232: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t155_n238;
  t155_n233: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n237;
  t155_n234: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t155_n236;
  t155_n235: return 0.09112371504306793f;
  t155_n236: return -0.10950817912817001f;
  t155_n237: return -0.043492481112480164f;
  t155_n238: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t155_n240;
  t155_n239: return 0.005724979564547539f;
  t155_n240: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n246;
  t155_n241: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t155_n245;
  t155_n242: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t155_n244;
  t155_n243: return 0.008154316805303097f;
  t155_n244: return 0.06893700361251831f;
  t155_n245: return -0.009778168052434921f;
  t155_n246: return -0.006715776864439249f;
  t155_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n251;
  t155_n248: if (E.getNumReferences() >= 3340297728 /*39142.0*/) goto t155_n250;
  t155_n249: return -0.050526831299066544f;
  t155_n250: return -0.17278237640857697f;
  t155_n251: return 0.0065261004492640495f;
  t155_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n254;
  t155_n253: return -0.03167520463466644f;
  t155_n254: return 0.00686180405318737f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree156(const Example& E) {
  t156_n0: if (E.getNumReferences() >= 3324859904 /*11093.5*/) goto t156_n228;
  t156_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t156_n227;
  t156_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t156_n4;
  t156_n3: return -0.005552796181291342f;
  t156_n4: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t156_n76;
  t156_n5: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t156_n75;
  t156_n6: if (E.getNumReferences() >= 3283861504 /*375.5*/) goto t156_n60;
  t156_n7: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t156_n51;
  t156_n8: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t156_n30;
  t156_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t156_n17;
  t156_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t156_n16;
  t156_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t156_n13;
  t156_n12: return 0.017789077013731003f;
  t156_n13: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t156_n15;
  t156_n14: return 0.08791683614253998f;
  t156_n15: return 0.07238683849573135f;
  t156_n16: return 0.0038625579327344894f;
  t156_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t156_n21;
  t156_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t156_n20;
  t156_n19: return -0.024260535836219788f;
  t156_n20: return 0.0536654032766819f;
  t156_n21: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t156_n23;
  t156_n22: return 0.023978229612112045f;
  t156_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t156_n29;
  t156_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t156_n26;
  t156_n25: return -0.1332639455795288f;
  t156_n26: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t156_n28;
  t156_n27: return 0.1214442104101181f;
  t156_n28: return -0.10988786816596985f;
  t156_n29: return 0.041254691779613495f;
  t156_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t156_n34;
  t156_n31: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t156_n33;
  t156_n32: return -0.01312321051955223f;
  t156_n33: return -0.06932412832975388f;
  t156_n34: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t156_n38;
  t156_n35: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t156_n37;
  t156_n36: return 0.023332640528678894f;
  t156_n37: return 0.046047888696193695f;
  t156_n38: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t156_n44;
  t156_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t156_n43;
  t156_n40: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t156_n42;
  t156_n41: return -0.07269974052906036f;
  t156_n42: return 0.06326833367347717f;
  t156_n43: return 0.04305731877684593f;
  t156_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t156_n48;
  t156_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t156_n47;
  t156_n46: return 0.024049928411841393f;
  t156_n47: return 0.10391316562891006f;
  t156_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t156_n50;
  t156_n49: return 0.0878247618675232f;
  t156_n50: return 0.1269710659980774f;
  t156_n51: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t156_n53;
  t156_n52: return 0.01690100133419037f;
  t156_n53: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t156_n59;
  t156_n54: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t156_n58;
  t156_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t156_n57;
  t156_n56: return -0.14970561861991882f;
  t156_n57: return -0.014227651059627533f;
  t156_n58: return -0.05118589848279953f;
  t156_n59: return 0.008535105735063553f;
  t156_n60: if (E.getNumReferences() >= 3288522752 /*523.5*/) goto t156_n74;
  t156_n61: if (E.getNumReferences() >= 3288457216 /*519.5*/) goto t156_n73;
  t156_n62: if (E.getNumReferences() >= 3288088576 /*504.5*/) goto t156_n70;
  t156_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t156_n69;
  t156_n64: if (E.getNumReferences() >= 3284058112 /*381.5*/) goto t156_n68;
  t156_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t156_n67;
  t156_n66: return 0.08631989359855652f;
  t156_n67: return 0.13742434978485107f;
  t156_n68: return 0.05274845287203789f;
  t156_n69: return 0.08533699065446854f;
  t156_n70: if (E.getNumReferences() >= 3288236032 /*509.0*/) goto t156_n72;
  t156_n71: return 0.10811144858598709f;
  t156_n72: return -0.11774814128875732f;
  t156_n73: return 0.12258698791265488f;
  t156_n74: return 0.009981204755604267f;
  t156_n75: return 0.008343472145497799f;
  t156_n76: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t156_n124;
  t156_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t156_n79;
  t156_n78: return -0.0048340498469769955f;
  t156_n79: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t156_n113;
  t156_n80: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t156_n90;
  t156_n81: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t156_n85;
  t156_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t156_n84;
  t156_n83: return 0.007744315080344677f;
  t156_n84: return 0.06582196801900864f;
  t156_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t156_n87;
  t156_n86: return 0.04999323561787605f;
  t156_n87: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t156_n89;
  t156_n88: return 0.11479201167821884f;
  t156_n89: return 0.1142367497086525f;
  t156_n90: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t156_n92;
  t156_n91: return -0.05252506583929062f;
  t156_n92: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t156_n112;
  t156_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t156_n95;
  t156_n94: return 0.003417085623368621f;
  t156_n95: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t156_n97;
  t156_n96: return 0.020829053595662117f;
  t156_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t156_n111;
  t156_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t156_n100;
  t156_n99: return -0.0038994878996163607f;
  t156_n100: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t156_n110;
  t156_n101: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t156_n109;
  t156_n102: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t156_n108;
  t156_n103: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t156_n105;
  t156_n104: return 0.07249993830919266f;
  t156_n105: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t156_n107;
  t156_n106: return 0.12228699028491974f;
  t156_n107: return 0.15423986315727234f;
  t156_n108: return 0.10629996657371521f;
  t156_n109: return -0.16148824989795685f;
  t156_n110: return -0.4671109616756439f;
  t156_n111: return 0.012438582256436348f;
  t156_n112: return -0.08509902656078339f;
  t156_n113: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t156_n117;
  t156_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t156_n116;
  t156_n115: return 0.033611960709095f;
  t156_n116: return 0.10320616513490677f;
  t156_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t156_n123;
  t156_n118: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t156_n122;
  t156_n119: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t156_n121;
  t156_n120: return 0.10456226021051407f;
  t156_n121: return 0.031099602580070496f;
  t156_n122: return 0.10898584127426147f;
  t156_n123: return 0.10960734635591507f;
  t156_n124: if (E.getNumReferences() >= 3324251648 /*10499.5*/) goto t156_n222;
  t156_n125: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t156_n155;
  t156_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t156_n128;
  t156_n127: return -0.04557258263230324f;
  t156_n128: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t156_n146;
  t156_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t156_n131;
  t156_n130: return 0.003134980332106352f;
  t156_n131: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t156_n145;
  t156_n132: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t156_n144;
  t156_n133: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t156_n135;
  t156_n134: return 0.08929223567247391f;
  t156_n135: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t156_n141;
  t156_n136: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t156_n138;
  t156_n137: return -0.1681215912103653f;
  t156_n138: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t156_n140;
  t156_n139: return 0.13766540586948395f;
  t156_n140: return 0.0f;
  t156_n141: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t156_n143;
  t156_n142: return 0.11644511669874191f;
  t156_n143: return 0.12222080677747726f;
  t156_n144: return 0.03498181328177452f;
  t156_n145: return 0.026985757052898407f;
  t156_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t156_n152;
  t156_n147: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t156_n151;
  t156_n148: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t156_n150;
  t156_n149: return -0.00386019516736269f;
  t156_n150: return 0.11790043115615845f;
  t156_n151: return -0.13109032809734344f;
  t156_n152: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t156_n154;
  t156_n153: return -0.019168823957443237f;
  t156_n154: return 0.015078745782375336f;
  t156_n155: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t156_n221;
  t156_n156: if (E.getNumReferences() >= 3273293824 /*154.5*/) goto t156_n184;
  t156_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t156_n161;
  t156_n158: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t156_n160;
  t156_n159: return -0.005714272148907185f;
  t156_n160: return 0.05096711590886116f;
  t156_n161: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t156_n179;
  t156_n162: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t156_n178;
  t156_n163: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t156_n173;
  t156_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t156_n166;
  t156_n165: return -0.19220420718193054f;
  t156_n166: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t156_n170;
  t156_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t156_n169;
  t156_n168: return -0.19549110531806946f;
  t156_n169: return 0.13584163784980774f;
  t156_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t156_n172;
  t156_n171: return 0.9363875985145569f;
  t156_n172: return 0.13397227227687836f;
  t156_n173: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t156_n175;
  t156_n174: return 0.06541800498962402f;
  t156_n175: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t156_n177;
  t156_n176: return 0.138191357254982f;
  t156_n177: return -0.5343223214149475f;
  t156_n178: return 0.017307115718722343f;
  t156_n179: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t156_n183;
  t156_n180: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t156_n182;
  t156_n181: return 0.10959312319755554f;
  t156_n182: return 0.1259302794933319f;
  t156_n183: return 0.06782951205968857f;
  t156_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t156_n194;
  t156_n185: if (E.getNumReferences() >= 3274866688 /*178.5*/) goto t156_n193;
  t156_n186: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t156_n190;
  t156_n187: if (E.getNumReferences() >= 3274768384 /*177.0*/) goto t156_n189;
  t156_n188: return 0.09188767522573471f;
  t156_n189: return 0.12008485198020935f;
  t156_n190: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t156_n192;
  t156_n191: return 0.13421562314033508f;
  t156_n192: return 0.0995500385761261f;
  t156_n193: return 0.0447038859128952f;
  t156_n194: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t156_n206;
  t156_n195: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t156_n203;
  t156_n196: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t156_n198;
  t156_n197: return 0.11889012157917023f;
  t156_n198: if (E.getNumReferences() >= 3289251840 /*568.0*/) goto t156_n200;
  t156_n199: return -0.013077364303171635f;
  t156_n200: if (E.getNumReferences() >= 3292078080 /*740.5*/) goto t156_n202;
  t156_n201: return 0.12673412263393402f;
  t156_n202: return 0.04245030879974365f;
  t156_n203: if (E.getNumReferences() >= 3317816320 /*6203.5*/) goto t156_n205;
  t156_n204: return 0.007561078295111656f;
  t156_n205: return 0.18802718818187714f;
  t156_n206: if (E.getNumReferences() >= 3276570624 /*204.5*/) goto t156_n210;
  t156_n207: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t156_n209;
  t156_n208: return 0.05956302583217621f;
  t156_n209: return 0.1226508840918541f;
  t156_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t156_n212;
  t156_n211: return -0.02531658113002777f;
  t156_n212: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t156_n216;
  t156_n213: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t156_n215;
  t156_n214: return 0.11402322351932526f;
  t156_n215: return 0.09803783893585205f;
  t156_n216: if (E.getNumReferences() >= 3295846400 /*970.5*/) goto t156_n220;
  t156_n217: if (E.getNumReferences() >= 3289186304 /*564.0*/) goto t156_n219;
  t156_n218: return 0.08803922683000565f;
  t156_n219: return 0.12427526712417603f;
  t156_n220: return -0.0840868428349495f;
  t156_n221: return 0.024280255660414696f;
  t156_n222: if (E.getNumReferences() >= 3324598784 /*10838.5*/) goto t156_n226;
  t156_n223: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t156_n225;
  t156_n224: return 0.07901525497436523f;
  t156_n225: return 0.11872357130050659f;
  t156_n226: return -0.003041925374418497f;
  t156_n227: return -0.001269607339054346f;
  t156_n228: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t156_n254;
  t156_n229: if (E.getNumReferences() >= 3325491712 /*11710.5*/) goto t156_n253;
  t156_n230: if (E.getNumReferences() >= 3325368832 /*11590.5*/) goto t156_n242;
  t156_n231: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t156_n233;
  t156_n232: return 0.0009377501555718482f;
  t156_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t156_n235;
  t156_n234: return 0.07862545549869537f;
  t156_n235: if (E.getNumReferences() >= 3324926976 /*11159.0*/) goto t156_n237;
  t156_n236: return -0.029398512095212936f;
  t156_n237: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t156_n241;
  t156_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t156_n240;
  t156_n239: return 0.12216775119304657f;
  t156_n240: return 0.03418388217687607f;
  t156_n241: return -0.0844343975186348f;
  t156_n242: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t156_n244;
  t156_n243: return 0.13050450384616852f;
  t156_n244: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t156_n248;
  t156_n245: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t156_n247;
  t156_n246: return -0.1437915861606598f;
  t156_n247: return 0.11156976968050003f;
  t156_n248: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t156_n252;
  t156_n249: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t156_n251;
  t156_n250: return 0.11470102518796921f;
  t156_n251: return 0.1383165717124939f;
  t156_n252: return -0.09092380106449127f;
  t156_n253: return 0.013344258069992065f;
  t156_n254: return 0.0024742460809648037f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree157(const Example& E) {
  t157_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t157_n2;
  t157_n1: return -0.0002466138103045523f;
  t157_n2: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t157_n4;
  t157_n3: return -0.0025398179423063993f;
  t157_n4: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t157_n254;
  t157_n5: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t157_n239;
  t157_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t157_n226;
  t157_n7: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t157_n23;
  t157_n8: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t157_n12;
  t157_n9: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t157_n11;
  t157_n10: return -0.05168524757027626f;
  t157_n11: return 0.1393503099679947f;
  t157_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t157_n16;
  t157_n13: if (E.getNumReferences() >= 3341699072 /*44616.0*/) goto t157_n15;
  t157_n14: return -0.40740928053855896f;
  t157_n15: return 0.09606412798166275f;
  t157_n16: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t157_n22;
  t157_n17: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t157_n21;
  t157_n18: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t157_n20;
  t157_n19: return 0.0941065177321434f;
  t157_n20: return 0.11023303866386414f;
  t157_n21: return 0.08430939167737961f;
  t157_n22: return 0.09972691535949707f;
  t157_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t157_n197;
  t157_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t157_n26;
  t157_n25: return 0.005798644851893187f;
  t157_n26: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t157_n196;
  t157_n27: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t157_n53;
  t157_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n32;
  t157_n29: if (E.getNumReferences() >= 3345100032 /*57901.0*/) goto t157_n31;
  t157_n30: return 0.023216376081109047f;
  t157_n31: return -0.07635632157325745f;
  t157_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t157_n40;
  t157_n33: if (E.getNumReferences() >= 3346274176 /*62487.5*/) goto t157_n39;
  t157_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t157_n36;
  t157_n35: return 0.011665822938084602f;
  t157_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t157_n38;
  t157_n37: return 0.10824767500162125f;
  t157_n38: return 0.01616464927792549f;
  t157_n39: return -0.4237585663795471f;
  t157_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t157_n46;
  t157_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t157_n43;
  t157_n42: return -0.09177832305431366f;
  t157_n43: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t157_n45;
  t157_n44: return 0.0411396287381649f;
  t157_n45: return 0.10886294394731522f;
  t157_n46: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t157_n50;
  t157_n47: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t157_n49;
  t157_n48: return -0.39328038692474365f;
  t157_n49: return 0.06429648399353027f;
  t157_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t157_n52;
  t157_n51: return 0.10836706310510635f;
  t157_n52: return 0.1645406186580658f;
  t157_n53: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t157_n181;
  t157_n54: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t157_n90;
  t157_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t157_n81;
  t157_n56: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t157_n70;
  t157_n57: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t157_n65;
  t157_n58: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t157_n60;
  t157_n59: return 0.04326950013637543f;
  t157_n60: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t157_n64;
  t157_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n63;
  t157_n62: return 0.07442689687013626f;
  t157_n63: return 0.12703253328800201f;
  t157_n64: return 0.015934649854898453f;
  t157_n65: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t157_n69;
  t157_n66: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t157_n68;
  t157_n67: return 0.11703670024871826f;
  t157_n68: return -0.07977654784917831f;
  t157_n69: return -0.6243160367012024f;
  t157_n70: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t157_n76;
  t157_n71: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t157_n75;
  t157_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t157_n74;
  t157_n73: return -0.19009266793727875f;
  t157_n74: return -0.08339157700538635f;
  t157_n75: return -0.011329744942486286f;
  t157_n76: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t157_n80;
  t157_n77: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t157_n79;
  t157_n78: return 0.09299493581056595f;
  t157_n79: return -0.44664159417152405f;
  t157_n80: return 0.008733956143260002f;
  t157_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t157_n85;
  t157_n82: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t157_n84;
  t157_n83: return -0.3264982998371124f;
  t157_n84: return 0.057274747639894485f;
  t157_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t157_n87;
  t157_n86: return 0.08150310814380646f;
  t157_n87: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t157_n89;
  t157_n88: return 0.08025246858596802f;
  t157_n89: return -0.02631865069270134f;
  t157_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t157_n92;
  t157_n91: return -0.014267508871853352f;
  t157_n92: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t157_n148;
  t157_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t157_n147;
  t157_n94: if (E.getNumReferences() >= 3349201152 /*82306.0*/) goto t157_n96;
  t157_n95: return -0.08404125273227692f;
  t157_n96: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t157_n112;
  t157_n97: if (E.getNumReferences() >= 3349883520 /*87637.0*/) goto t157_n105;
  t157_n98: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t157_n104;
  t157_n99: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t157_n101;
  t157_n100: return 0.07270923256874084f;
  t157_n101: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t157_n103;
  t157_n102: return -0.38584017753601074f;
  t157_n103: return 0.12801839411258698f;
  t157_n104: return -0.21039976179599762f;
  t157_n105: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t157_n111;
  t157_n106: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n110;
  t157_n107: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t157_n109;
  t157_n108: return 0.11314805597066879f;
  t157_n109: return 0.07833459228277206f;
  t157_n110: return -0.05972333997488022f;
  t157_n111: return -0.2661004364490509f;
  t157_n112: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t157_n114;
  t157_n113: return -0.06514474749565125f;
  t157_n114: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t157_n122;
  t157_n115: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t157_n121;
  t157_n116: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t157_n118;
  t157_n117: return 0.11337333172559738f;
  t157_n118: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t157_n120;
  t157_n119: return 0.0876610204577446f;
  t157_n120: return -0.4485947787761688f;
  t157_n121: return -0.4606752097606659f;
  t157_n122: if (E.getNumReferences() >= 3351834112 /*102876.0*/) goto t157_n126;
  t157_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t157_n125;
  t157_n124: return 0.013615940697491169f;
  t157_n125: return -0.48529571294784546f;
  t157_n126: if (E.getNumReferences() >= 3361098688 /*219439.0*/) goto t157_n138;
  t157_n127: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t157_n131;
  t157_n128: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t157_n130;
  t157_n129: return 0.04575599357485771f;
  t157_n130: return -0.29032522439956665f;
  t157_n131: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t157_n133;
  t157_n132: return 0.02356593869626522f;
  t157_n133: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t157_n135;
  t157_n134: return 0.1206127405166626f;
  t157_n135: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t157_n137;
  t157_n136: return -0.29967087507247925f;
  t157_n137: return 0.1461525708436966f;
  t157_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n144;
  t157_n139: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t157_n141;
  t157_n140: return -0.43004199862480164f;
  t157_n141: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t157_n143;
  t157_n142: return -0.011030280031263828f;
  t157_n143: return 0.06010096147656441f;
  t157_n144: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t157_n146;
  t157_n145: return 0.08946111053228378f;
  t157_n146: return -0.030094144865870476f;
  t157_n147: return 0.01087587233632803f;
  t157_n148: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t157_n150;
  t157_n149: return -0.0012449530186131597f;
  t157_n150: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t157_n170;
  t157_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t157_n153;
  t157_n152: return 0.003769572591409087f;
  t157_n153: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t157_n161;
  t157_n154: if (E.getNumReferences() >= 3354093056 /*120524.0*/) goto t157_n160;
  t157_n155: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t157_n157;
  t157_n156: return 0.0969560518860817f;
  t157_n157: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t157_n159;
  t157_n158: return 0.09167060256004333f;
  t157_n159: return -0.1597493290901184f;
  t157_n160: return 0.04233735054731369f;
  t157_n161: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t157_n163;
  t157_n162: return 0.0031390362419188023f;
  t157_n163: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t157_n169;
  t157_n164: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t157_n166;
  t157_n165: return 0.0710136741399765f;
  t157_n166: if (E.getNumReferences() >= 3351432768 /*99740.5*/) goto t157_n168;
  t157_n167: return 0.10207060724496841f;
  t157_n168: return 0.0876091942191124f;
  t157_n169: return -0.0013569432776421309f;
  t157_n170: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n180;
  t157_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t157_n175;
  t157_n172: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t157_n174;
  t157_n173: return 0.07588789612054825f;
  t157_n174: return 0.10406672209501266f;
  t157_n175: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t157_n179;
  t157_n176: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t157_n178;
  t157_n177: return 0.089818574488163f;
  t157_n178: return -0.18036283552646637f;
  t157_n179: return -0.07902860641479492f;
  t157_n180: return -0.08150537312030792f;
  t157_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t157_n183;
  t157_n182: return -0.08756411820650101f;
  t157_n183: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n191;
  t157_n184: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t157_n190;
  t157_n185: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t157_n187;
  t157_n186: return 0.05532050132751465f;
  t157_n187: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t157_n189;
  t157_n188: return 0.10757867991924286f;
  t157_n189: return -0.013711209408938885f;
  t157_n190: return -0.06971310824155807f;
  t157_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t157_n195;
  t157_n192: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t157_n194;
  t157_n193: return 0.05907810851931572f;
  t157_n194: return 0.11656423658132553f;
  t157_n195: return 0.044267598539590836f;
  t157_n196: return 0.004162628669291735f;
  t157_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t157_n221;
  t157_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t157_n200;
  t157_n199: return -0.15974360704421997f;
  t157_n200: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t157_n202;
  t157_n201: return -0.013157675042748451f;
  t157_n202: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t157_n210;
  t157_n203: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t157_n205;
  t157_n204: return 0.030245177447795868f;
  t157_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n209;
  t157_n206: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t157_n208;
  t157_n207: return 0.12613674998283386f;
  t157_n208: return 0.02703837864100933f;
  t157_n209: return -0.04237862676382065f;
  t157_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t157_n214;
  t157_n211: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t157_n213;
  t157_n212: return 0.17940424382686615f;
  t157_n213: return 1.1408016681671143f;
  t157_n214: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t157_n220;
  t157_n215: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t157_n219;
  t157_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t157_n218;
  t157_n217: return 0.1132163479924202f;
  t157_n218: return 0.10794047266244888f;
  t157_n219: return 0.10611958801746368f;
  t157_n220: return -0.06057348847389221f;
  t157_n221: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t157_n223;
  t157_n222: return -0.16978394985198975f;
  t157_n223: if (E.getNumReferences() >= 3351281600 /*98559.5*/) goto t157_n225;
  t157_n224: return 0.14096508920192719f;
  t157_n225: return -1.833134651184082f;
  t157_n226: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t157_n230;
  t157_n227: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t157_n229;
  t157_n228: return -0.11403415352106094f;
  t157_n229: return 0.0432048961520195f;
  t157_n230: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t157_n238;
  t157_n231: if (E.getNumReferences() >= 3347630656 /*70036.5*/) goto t157_n233;
  t157_n232: return -0.0016305531607940793f;
  t157_n233: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t157_n237;
  t157_n234: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t157_n236;
  t157_n235: return 0.09844758361577988f;
  t157_n236: return 0.0786212906241417f;
  t157_n237: return -0.019044851884245872f;
  t157_n238: return -0.04348129406571388f;
  t157_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t157_n249;
  t157_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t157_n242;
  t157_n241: return 0.05863901227712631f;
  t157_n242: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t157_n244;
  t157_n243: return -0.01749468222260475f;
  t157_n244: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t157_n246;
  t157_n245: return 0.23249773681163788f;
  t157_n246: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t157_n248;
  t157_n247: return 0.11619853973388672f;
  t157_n248: return -0.32880133390426636f;
  t157_n249: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t157_n253;
  t157_n250: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t157_n252;
  t157_n251: return 0.04392160102725029f;
  t157_n252: return 0.12205256521701813f;
  t157_n253: return -0.07525356858968735f;
  t157_n254: return -0.0020418744534254074f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree158(const Example& E) {
  t158_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t158_n208;
  t158_n1: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t158_n79;
  t158_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t158_n4;
  t158_n3: return -0.00035648667835630476f;
  t158_n4: if (E.getNumReferences() >= 3340908032 /*41526.0*/) goto t158_n78;
  t158_n5: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t158_n77;
  t158_n6: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t158_n8;
  t158_n7: return 0.009544510394334793f;
  t158_n8: if (E.getNumReferences() >= 3289636864 /*591.5*/) goto t158_n66;
  t158_n9: if (E.getNumReferences() >= 3289464832 /*581.0*/) goto t158_n65;
  t158_n10: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t158_n48;
  t158_n11: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t158_n15;
  t158_n12: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t158_n14;
  t158_n13: return 0.04592522978782654f;
  t158_n14: return -0.15205015242099762f;
  t158_n15: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t158_n47;
  t158_n16: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t158_n18;
  t158_n17: return 0.019671443849802017f;
  t158_n18: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t158_n22;
  t158_n19: if (E.getNumReferences() >= 3283320832 /*359.0*/) goto t158_n21;
  t158_n20: return -0.30163875222206116f;
  t158_n21: return 0.08212631940841675f;
  t158_n22: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t158_n30;
  t158_n23: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t158_n25;
  t158_n24: return 0.10540393739938736f;
  t158_n25: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t158_n29;
  t158_n26: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t158_n28;
  t158_n27: return 0.12254425883293152f;
  t158_n28: return 0.12174694985151291f;
  t158_n29: return -0.10167069733142853f;
  t158_n30: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t158_n44;
  t158_n31: if (E.getNumReferences() >= 3273031680 /*150.5*/) goto t158_n33;
  t158_n32: return 0.06099971383810043f;
  t158_n33: if (E.getNumReferences() >= 3280420864 /*270.5*/) goto t158_n43;
  t158_n34: if (E.getNumReferences() >= 3279962112 /*256.5*/) goto t158_n42;
  t158_n35: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t158_n39;
  t158_n36: if (E.getNumReferences() >= 3278471168 /*233.5*/) goto t158_n38;
  t158_n37: return 0.13999754190444946f;
  t158_n38: return 0.5642324686050415f;
  t158_n39: if (E.getNumReferences() >= 3275128832 /*182.5*/) goto t158_n41;
  t158_n40: return 0.1685699224472046f;
  t158_n41: return -0.08285011351108551f;
  t158_n42: return 0.133170023560524f;
  t158_n43: return 0.08627977967262268f;
  t158_n44: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t158_n46;
  t158_n45: return 0.1500425636768341f;
  t158_n46: return 0.046097803860902786f;
  t158_n47: return -0.009978316724300385f;
  t158_n48: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t158_n50;
  t158_n49: return 0.015061372891068459f;
  t158_n50: if (E.getNumReferences() >= 3288858624 /*544.0*/) goto t158_n60;
  t158_n51: if (E.getNumReferences() >= 3278733312 /*237.5*/) goto t158_n59;
  t158_n52: if (E.getNumReferences() >= 3278307328 /*231.0*/) goto t158_n56;
  t158_n53: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t158_n55;
  t158_n54: return 0.08049249649047852f;
  t158_n55: return 0.00534998020157218f;
  t158_n56: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t158_n58;
  t158_n57: return 0.11289763450622559f;
  t158_n58: return 0.10400954633951187f;
  t158_n59: return 0.008286927826702595f;
  t158_n60: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t158_n62;
  t158_n61: return -0.11500470340251923f;
  t158_n62: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t158_n64;
  t158_n63: return 0.1262802928686142f;
  t158_n64: return 0.08267518877983093f;
  t158_n65: return 0.11537221819162369f;
  t158_n66: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t158_n68;
  t158_n67: return 0.11253779381513596f;
  t158_n68: if (E.getNumReferences() >= 3299790848 /*1398.5*/) goto t158_n70;
  t158_n69: return -0.03488094359636307f;
  t158_n70: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t158_n72;
  t158_n71: return 0.0013766457559540868f;
  t158_n72: if (E.getNumReferences() >= 3315990528 /*5312.0*/) goto t158_n74;
  t158_n73: return 0.0175852719694376f;
  t158_n74: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t158_n76;
  t158_n75: return 0.07702048122882843f;
  t158_n76: return 0.034789856523275375f;
  t158_n77: return -0.0002953008806798607f;
  t158_n78: return -0.5362163186073303f;
  t158_n79: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t158_n91;
  t158_n80: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t158_n82;
  t158_n81: return -0.15608975291252136f;
  t158_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t158_n84;
  t158_n83: return 0.019410336390137672f;
  t158_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t158_n86;
  t158_n85: return -0.024419859051704407f;
  t158_n86: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t158_n90;
  t158_n87: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t158_n89;
  t158_n88: return 0.22639475762844086f;
  t158_n89: return -0.020116442814469337f;
  t158_n90: return -0.0102829085662961f;
  t158_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t158_n199;
  t158_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t158_n102;
  t158_n93: if (E.getNumReferences() >= 3291856896 /*727.0*/) goto t158_n99;
  t158_n94: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t158_n96;
  t158_n95: return 0.03855625540018082f;
  t158_n96: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t158_n98;
  t158_n97: return -0.059553228318691254f;
  t158_n98: return -0.3675500452518463f;
  t158_n99: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t158_n101;
  t158_n100: return -0.29857102036476135f;
  t158_n101: return -0.17165932059288025f;
  t158_n102: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t158_n110;
  t158_n103: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t158_n109;
  t158_n104: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t158_n106;
  t158_n105: return -0.16202597320079803f;
  t158_n106: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t158_n108;
  t158_n107: return 0.09935779124498367f;
  t158_n108: return -0.1265937238931656f;
  t158_n109: return 0.04868816211819649f;
  t158_n110: if (E.getSymbolScopeDistance() >= 3240099840 /*10.0*/) goto t158_n188;
  t158_n111: if (E.getNumReferences() >= 3264217088 /*72.0*/) goto t158_n181;
  t158_n112: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t158_n170;
  t158_n113: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t158_n139;
  t158_n114: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t158_n138;
  t158_n115: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t158_n131;
  t158_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t158_n118;
  t158_n117: return 0.07566077262163162f;
  t158_n118: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t158_n130;
  t158_n119: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t158_n129;
  t158_n120: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t158_n128;
  t158_n121: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t158_n125;
  t158_n122: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t158_n124;
  t158_n123: return 0.06018225476145744f;
  t158_n124: return -0.034492671489715576f;
  t158_n125: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t158_n127;
  t158_n126: return 0.0293938796967268f;
  t158_n127: return 0.12606583535671234f;
  t158_n128: return -0.2494651824235916f;
  t158_n129: return 0.10039737820625305f;
  t158_n130: return -0.662981390953064f;
  t158_n131: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t158_n135;
  t158_n132: if (E.getNumReferences() >= 3246915584 /*17.0*/) goto t158_n134;
  t158_n133: return 0.03832906112074852f;
  t158_n134: return 0.1428592950105667f;
  t158_n135: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t158_n137;
  t158_n136: return 0.12506750226020813f;
  t158_n137: return 0.04588301479816437f;
  t158_n138: return 0.14537672698497772f;
  t158_n139: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t158_n141;
  t158_n140: return -0.006706829182803631f;
  t158_n141: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t158_n143;
  t158_n142: return 0.669197142124176f;
  t158_n143: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t158_n147;
  t158_n144: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t158_n146;
  t158_n145: return -0.03434215486049652f;
  t158_n146: return 0.13845902681350708f;
  t158_n147: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t158_n153;
  t158_n148: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t158_n152;
  t158_n149: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t158_n151;
  t158_n150: return 0.12189557403326035f;
  t158_n151: return 0.07524333149194717f;
  t158_n152: return -0.23501840233802795f;
  t158_n153: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t158_n169;
  t158_n154: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t158_n156;
  t158_n155: return -0.06590747833251953f;
  t158_n156: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t158_n168;
  t158_n157: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t158_n167;
  t158_n158: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t158_n160;
  t158_n159: return 0.0870530977845192f;
  t158_n160: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t158_n164;
  t158_n161: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t158_n163;
  t158_n162: return 0.11753223091363907f;
  t158_n163: return 0.04627035930752754f;
  t158_n164: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t158_n166;
  t158_n165: return 0.026731250807642937f;
  t158_n166: return 0.12981484830379486f;
  t158_n167: return 0.11002780497074127f;
  t158_n168: return 0.027923094108700752f;
  t158_n169: return 0.0034657653886824846f;
  t158_n170: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t158_n172;
  t158_n171: return 0.13397173583507538f;
  t158_n172: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t158_n180;
  t158_n173: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t158_n179;
  t158_n174: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t158_n176;
  t158_n175: return 0.10126297920942307f;
  t158_n176: if (E.getNumReferences() >= 3259498496 /*50.0*/) goto t158_n178;
  t158_n177: return -0.2043817788362503f;
  t158_n178: return 0.2255645990371704f;
  t158_n179: return 0.10180168598890305f;
  t158_n180: return 0.014787736348807812f;
  t158_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t158_n185;
  t158_n182: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t158_n184;
  t158_n183: return 0.11420705914497375f;
  t158_n184: return -0.21410049498081207f;
  t158_n185: if (E.getNumReferences() >= 3324914176 /*11146.5*/) goto t158_n187;
  t158_n186: return -0.005429810844361782f;
  t158_n187: return -0.08292075991630554f;
  t158_n188: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t158_n190;
  t158_n189: return -0.028274888172745705f;
  t158_n190: if (E.getNumReferences() >= 3272802304 /*147.0*/) goto t158_n194;
  t158_n191: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t158_n193;
  t158_n192: return 0.16301122307777405f;
  t158_n193: return 0.12181181460618973f;
  t158_n194: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t158_n198;
  t158_n195: if (E.getNumReferences() >= 3285483520 /*425.0*/) goto t158_n197;
  t158_n196: return -0.13364830613136292f;
  t158_n197: return 0.1029631569981575f;
  t158_n198: return 0.06702594459056854f;
  t158_n199: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t158_n201;
  t158_n200: return -0.08063758909702301f;
  t158_n201: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t158_n205;
  t158_n202: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t158_n204;
  t158_n203: return 0.05667217820882797f;
  t158_n204: return -0.03712747246026993f;
  t158_n205: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t158_n207;
  t158_n206: return -0.022785449400544167f;
  t158_n207: return 0.21868695318698883f;
  t158_n208: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t158_n210;
  t158_n209: return -0.0023497026413679123f;
  t158_n210: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t158_n234;
  t158_n211: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t158_n233;
  t158_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t158_n218;
  t158_n213: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t158_n217;
  t158_n214: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t158_n216;
  t158_n215: return 0.09028798341751099f;
  t158_n216: return 0.10003933310508728f;
  t158_n217: return 0.012191697023808956f;
  t158_n218: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t158_n228;
  t158_n219: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t158_n221;
  t158_n220: return -0.03399860858917236f;
  t158_n221: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t158_n225;
  t158_n222: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t158_n224;
  t158_n223: return 0.10590899735689163f;
  t158_n224: return 0.12497060745954514f;
  t158_n225: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t158_n227;
  t158_n226: return 0.09522832185029984f;
  t158_n227: return 0.01530306227505207f;
  t158_n228: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t158_n232;
  t158_n229: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t158_n231;
  t158_n230: return 0.040771484375f;
  t158_n231: return 0.12031954526901245f;
  t158_n232: return -0.11393717676401138f;
  t158_n233: return 0.00731664290651679f;
  t158_n234: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t158_n236;
  t158_n235: return -0.06113900989294052f;
  t158_n236: if (E.getNumReferences() >= 3347832128 /*71610.5*/) goto t158_n250;
  t158_n237: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t158_n239;
  t158_n238: return 0.02217736281454563f;
  t158_n239: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t158_n243;
  t158_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t158_n242;
  t158_n241: return -0.18194009363651276f;
  t158_n242: return 0.16518326103687286f;
  t158_n243: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t158_n249;
  t158_n244: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t158_n248;
  t158_n245: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t158_n247;
  t158_n246: return 0.10632473975419998f;
  t158_n247: return 0.10335340350866318f;
  t158_n248: return 0.09678038954734802f;
  t158_n249: return -0.05592012777924538f;
  t158_n250: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t158_n254;
  t158_n251: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t158_n253;
  t158_n252: return 0.13139721751213074f;
  t158_n253: return -0.2506224811077118f;
  t158_n254: return 0.13049975037574768f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree159(const Example& E) {
  t159_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t159_n162;
  t159_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t159_n3;
  t159_n2: return -0.0007213916978798807f;
  t159_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t159_n5;
  t159_n4: return -0.004485865589231253f;
  t159_n5: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t159_n7;
  t159_n6: return 0.0048524923622608185f;
  t159_n7: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t159_n87;
  t159_n8: if (E.getNumReferences() >= 3309795328 /*3191.5*/) goto t159_n86;
  t159_n9: if (E.getNumReferences() >= 3309611008 /*3146.5*/) goto t159_n85;
  t159_n10: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t159_n18;
  t159_n11: if (E.getNumReferences() >= 3292184576 /*747.0*/) goto t159_n17;
  t159_n12: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t159_n16;
  t159_n13: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t159_n15;
  t159_n14: return 0.11004521697759628f;
  t159_n15: return -0.0486636608839035f;
  t159_n16: return -0.12191333621740341f;
  t159_n17: return 0.11908582597970963f;
  t159_n18: if (E.getNumReferences() >= 3280420864 /*270.5*/) goto t159_n78;
  t159_n19: if (E.getNumReferences() >= 3280142336 /*262.0*/) goto t159_n77;
  t159_n20: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t159_n72;
  t159_n21: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t159_n69;
  t159_n22: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t159_n26;
  t159_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t159_n25;
  t159_n24: return -0.5171283483505249f;
  t159_n25: return 0.11366263031959534f;
  t159_n26: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t159_n44;
  t159_n27: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t159_n39;
  t159_n28: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t159_n30;
  t159_n29: return -0.1465958058834076f;
  t159_n30: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t159_n38;
  t159_n31: if (E.getNumReferences() >= 3268345856 /*103.5*/) goto t159_n33;
  t159_n32: return 0.06717349588871002f;
  t159_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t159_n35;
  t159_n34: return 0.11340004205703735f;
  t159_n35: if (E.getNumReferences() >= 3270508544 /*120.0*/) goto t159_n37;
  t159_n36: return -0.3423037528991699f;
  t159_n37: return 0.10753943026065826f;
  t159_n38: return -0.023576010018587112f;
  t159_n39: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t159_n41;
  t159_n40: return 0.041440825909376144f;
  t159_n41: if (E.getNumReferences() >= 3271229440 /*125.5*/) goto t159_n43;
  t159_n42: return -0.2255367487668991f;
  t159_n43: return -9.67420482635498f;
  t159_n44: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t159_n50;
  t159_n45: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t159_n47;
  t159_n46: return 0.16988669335842133f;
  t159_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t159_n49;
  t159_n48: return 0.11153396219015121f;
  t159_n49: return 0.11476746201515198f;
  t159_n50: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t159_n62;
  t159_n51: if (E.getNumReferences() >= 3273687040 /*160.5*/) goto t159_n53;
  t159_n52: return 0.06388977915048599f;
  t159_n53: if (E.getNumReferences() >= 3274899456 /*179.0*/) goto t159_n57;
  t159_n54: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t159_n56;
  t159_n55: return 0.35478803515434265f;
  t159_n56: return 0.15880326926708221f;
  t159_n57: if (E.getNumReferences() >= 3278438400 /*233.0*/) goto t159_n59;
  t159_n58: return -0.11897827684879303f;
  t159_n59: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t159_n61;
  t159_n60: return 0.429644376039505f;
  t159_n61: return -0.22701486945152283f;
  t159_n62: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t159_n66;
  t159_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t159_n65;
  t159_n64: return -0.8191495537757874f;
  t159_n65: return 0.04819168522953987f;
  t159_n66: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t159_n68;
  t159_n67: return 0.11218487471342087f;
  t159_n68: return 0.05547690391540527f;
  t159_n69: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t159_n71;
  t159_n70: return 0.12376704812049866f;
  t159_n71: return 0.1174682080745697f;
  t159_n72: if (E.getNumReferences() >= 3277422592 /*217.5*/) goto t159_n74;
  t159_n73: return -0.01736493781208992f;
  t159_n74: if (E.getNumReferences() >= 3278209024 /*229.5*/) goto t159_n76;
  t159_n75: return 0.2850021421909332f;
  t159_n76: return -0.03068721666932106f;
  t159_n77: return 0.12782835960388184f;
  t159_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t159_n80;
  t159_n79: return 0.007894850336015224f;
  t159_n80: if (E.getNumReferences() >= 3297595392 /*1130.5*/) goto t159_n82;
  t159_n81: return 0.009109788574278355f;
  t159_n82: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t159_n84;
  t159_n83: return 0.10957051068544388f;
  t159_n84: return -0.009687227196991444f;
  t159_n85: return 0.13060933351516724f;
  t159_n86: return -0.14273548126220703f;
  t159_n87: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t159_n147;
  t159_n88: if (E.getNumReferences() >= 3325290496 /*11514.0*/) goto t159_n122;
  t159_n89: if (E.getNumReferences() >= 3324380672 /*10625.5*/) goto t159_n119;
  t159_n90: if (E.getNumReferences() >= 3322220544 /*8516.0*/) goto t159_n92;
  t159_n91: return -0.0023063188418745995f;
  t159_n92: if (E.getNumReferences() >= 3322915840 /*9195.0*/) goto t159_n112;
  t159_n93: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t159_n99;
  t159_n94: if (E.getNumReferences() >= 3322782208 /*9064.5*/) goto t159_n98;
  t159_n95: if (E.getNumReferences() >= 3322376192 /*8668.0*/) goto t159_n97;
  t159_n96: return 0.457334041595459f;
  t159_n97: return -0.01106054987758398f;
  t159_n98: return 0.1055828258395195f;
  t159_n99: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t159_n103;
  t159_n100: if (E.getNumReferences() >= 3322734080 /*9017.5*/) goto t159_n102;
  t159_n101: return 0.1065385565161705f;
  t159_n102: return -0.19620737433433533f;
  t159_n103: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t159_n111;
  t159_n104: if (E.getNumReferences() >= 3322603520 /*8890.0*/) goto t159_n106;
  t159_n105: return 0.02687697298824787f;
  t159_n106: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t159_n110;
  t159_n107: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t159_n109;
  t159_n108: return 0.10065958648920059f;
  t159_n109: return 0.10822564363479614f;
  t159_n110: return 0.1104261726140976f;
  t159_n111: return -0.21953436732292175f;
  t159_n112: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t159_n114;
  t159_n113: return -0.023343805223703384f;
  t159_n114: if (E.getNumReferences() >= 3323281920 /*9552.5*/) goto t159_n116;
  t159_n115: return -0.14155493676662445f;
  t159_n116: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t159_n118;
  t159_n117: return 0.10570195317268372f;
  t159_n118: return 0.06599582731723785f;
  t159_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t159_n121;
  t159_n120: return -0.07916168123483658f;
  t159_n121: return 0.10189437866210938f;
  t159_n122: if (E.getNumReferences() >= 3325327360 /*11550.0*/) goto t159_n126;
  t159_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t159_n125;
  t159_n124: return -0.10132777690887451f;
  t159_n125: return 0.1034049242734909f;
  t159_n126: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t159_n146;
  t159_n127: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t159_n135;
  t159_n128: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t159_n130;
  t159_n129: return 0.03673463687300682f;
  t159_n130: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t159_n132;
  t159_n131: return -0.014664932154119015f;
  t159_n132: if (E.getNumReferences() >= 3325685760 /*11900.0*/) goto t159_n134;
  t159_n133: return 0.09643016010522842f;
  t159_n134: return 0.047123853117227554f;
  t159_n135: if (E.getNumReferences() >= 3337883136 /*31239.0*/) goto t159_n145;
  t159_n136: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t159_n138;
  t159_n137: return 0.06755555421113968f;
  t159_n138: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t159_n142;
  t159_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t159_n141;
  t159_n140: return 0.1020844429731369f;
  t159_n141: return 0.0998983308672905f;
  t159_n142: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t159_n144;
  t159_n143: return 0.0359366312623024f;
  t159_n144: return 0.09235578030347824f;
  t159_n145: return 0.010025760158896446f;
  t159_n146: return -0.04007498547434807f;
  t159_n147: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t159_n159;
  t159_n148: if (E.getNumReferences() >= 3289612288 /*590.0*/) goto t159_n156;
  t159_n149: if (E.getNumReferences() >= 3288522752 /*523.5*/) goto t159_n151;
  t159_n150: return 0.0503925085067749f;
  t159_n151: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t159_n153;
  t159_n152: return 0.06649437546730042f;
  t159_n153: if (E.getNumReferences() >= 3289341952 /*573.5*/) goto t159_n155;
  t159_n154: return 0.11340136080980301f;
  t159_n155: return 0.11523929238319397f;
  t159_n156: if (E.getNumReferences() >= 3302944768 /*1783.5*/) goto t159_n158;
  t159_n157: return -0.0357481949031353f;
  t159_n158: return 0.029046611860394478f;
  t159_n159: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t159_n161;
  t159_n160: return 0.11412722617387772f;
  t159_n161: return 0.049172673374414444f;
  t159_n162: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t159_n182;
  t159_n163: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t159_n171;
  t159_n164: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t159_n166;
  t159_n165: return -0.1249488815665245f;
  t159_n166: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t159_n170;
  t159_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t159_n169;
  t159_n168: return 0.0632675513625145f;
  t159_n169: return 0.10527220368385315f;
  t159_n170: return -0.24830248951911926f;
  t159_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t159_n179;
  t159_n172: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t159_n176;
  t159_n173: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t159_n175;
  t159_n174: return 0.15957963466644287f;
  t159_n175: return 0.1320899873971939f;
  t159_n176: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t159_n178;
  t159_n177: return 0.09758303314447403f;
  t159_n178: return 0.06670085340738297f;
  t159_n179: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t159_n181;
  t159_n180: return 0.13168329000473022f;
  t159_n181: return 0.14092890918254852f;
  t159_n182: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t159_n240;
  t159_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t159_n227;
  t159_n184: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t159_n218;
  t159_n185: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t159_n201;
  t159_n186: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t159_n188;
  t159_n187: return -0.07453048229217529f;
  t159_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t159_n190;
  t159_n189: return 0.07559758424758911f;
  t159_n190: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t159_n198;
  t159_n191: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t159_n197;
  t159_n192: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t159_n194;
  t159_n193: return -0.2117002159357071f;
  t159_n194: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t159_n196;
  t159_n195: return 0.10732122510671616f;
  t159_n196: return 0.0949515551328659f;
  t159_n197: return 0.08291737735271454f;
  t159_n198: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t159_n200;
  t159_n199: return 0.0995340347290039f;
  t159_n200: return 0.14073175191879272f;
  t159_n201: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t159_n209;
  t159_n202: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t159_n204;
  t159_n203: return 0.00028218867373652756f;
  t159_n204: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t159_n206;
  t159_n205: return -0.10352936387062073f;
  t159_n206: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t159_n208;
  t159_n207: return 0.14696596562862396f;
  t159_n208: return -0.13591791689395905f;
  t159_n209: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t159_n213;
  t159_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t159_n212;
  t159_n211: return 0.11283876746892929f;
  t159_n212: return 0.08482969552278519f;
  t159_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t159_n217;
  t159_n214: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t159_n216;
  t159_n215: return 0.06969098001718521f;
  t159_n216: return 0.15936517715454102f;
  t159_n217: return 0.11129435151815414f;
  t159_n218: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t159_n220;
  t159_n219: return -0.10507729649543762f;
  t159_n220: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t159_n226;
  t159_n221: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t159_n225;
  t159_n222: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t159_n224;
  t159_n223: return -0.09565455466508865f;
  t159_n224: return 0.10616392642259598f;
  t159_n225: return 0.39794811606407166f;
  t159_n226: return 0.006803792901337147f;
  t159_n227: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t159_n235;
  t159_n228: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t159_n230;
  t159_n229: return -0.026148980483412743f;
  t159_n230: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t159_n234;
  t159_n231: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t159_n233;
  t159_n232: return 0.10522084683179855f;
  t159_n233: return 0.1196797713637352f;
  t159_n234: return 0.046050723642110825f;
  t159_n235: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t159_n239;
  t159_n236: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t159_n238;
  t159_n237: return 0.03675520047545433f;
  t159_n238: return 0.12022635340690613f;
  t159_n239: return -0.11152750253677368f;
  t159_n240: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t159_n242;
  t159_n241: return 0.0037341422867029905f;
  t159_n242: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t159_n244;
  t159_n243: return -0.014871638268232346f;
  t159_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t159_n250;
  t159_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t159_n249;
  t159_n246: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t159_n248;
  t159_n247: return -0.12422781437635422f;
  t159_n248: return 0.125675767660141f;
  t159_n249: return -0.1565522700548172f;
  t159_n250: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t159_n254;
  t159_n251: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t159_n253;
  t159_n252: return 0.1155630424618721f;
  t159_n253: return 0.07728581875562668f;
  t159_n254: return 0.060640085488557816f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree160(const Example& E) {
  t160_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t160_n2;
  t160_n1: return -0.00025012739934027195f;
  t160_n2: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t160_n90;
  t160_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t160_n77;
  t160_n4: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t160_n48;
  t160_n5: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t160_n27;
  t160_n6: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t160_n12;
  t160_n7: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n9;
  t160_n8: return -0.27594301104545593f;
  t160_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n11;
  t160_n10: return 0.12702690064907074f;
  t160_n11: return 0.13593502342700958f;
  t160_n12: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t160_n14;
  t160_n13: return -0.06440415233373642f;
  t160_n14: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n16;
  t160_n15: return 0.06187255680561066f;
  t160_n16: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t160_n24;
  t160_n17: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t160_n23;
  t160_n18: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t160_n20;
  t160_n19: return -0.20277540385723114f;
  t160_n20: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t160_n22;
  t160_n21: return 0.10669231414794922f;
  t160_n22: return 0.0932375118136406f;
  t160_n23: return 0.07818008959293365f;
  t160_n24: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n26;
  t160_n25: return 0.09606359153985977f;
  t160_n26: return 0.1368870586156845f;
  t160_n27: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n35;
  t160_n28: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t160_n30;
  t160_n29: return -0.00013348473294172436f;
  t160_n30: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t160_n32;
  t160_n31: return -0.10316653549671173f;
  t160_n32: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t160_n34;
  t160_n33: return 0.13543006777763367f;
  t160_n34: return -0.13364152610301971f;
  t160_n35: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t160_n41;
  t160_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t160_n40;
  t160_n37: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t160_n39;
  t160_n38: return 0.2285834699869156f;
  t160_n39: return 0.10552281886339188f;
  t160_n40: return 0.0846400260925293f;
  t160_n41: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t160_n45;
  t160_n42: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t160_n44;
  t160_n43: return 0.08068310469388962f;
  t160_n44: return 0.11069901287555695f;
  t160_n45: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t160_n47;
  t160_n46: return 0.13704219460487366f;
  t160_n47: return 0.10690782964229584f;
  t160_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t160_n50;
  t160_n49: return 0.0030648394022136927f;
  t160_n50: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t160_n54;
  t160_n51: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t160_n53;
  t160_n52: return 0.006587551441043615f;
  t160_n53: return -0.217604398727417f;
  t160_n54: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t160_n76;
  t160_n55: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t160_n75;
  t160_n56: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t160_n74;
  t160_n57: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t160_n63;
  t160_n58: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t160_n62;
  t160_n59: if (E.getNumReferences() >= 3352190016 /*105656.5*/) goto t160_n61;
  t160_n60: return -0.10126176476478577f;
  t160_n61: return 0.6847094297409058f;
  t160_n62: return 0.6839396953582764f;
  t160_n63: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n73;
  t160_n64: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t160_n72;
  t160_n65: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t160_n71;
  t160_n66: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t160_n70;
  t160_n67: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t160_n69;
  t160_n68: return 0.0722116082906723f;
  t160_n69: return 0.09702349454164505f;
  t160_n70: return -0.11108992248773575f;
  t160_n71: return 0.105417400598526f;
  t160_n72: return 0.07089179009199142f;
  t160_n73: return 0.07936758548021317f;
  t160_n74: return 0.03440320864319801f;
  t160_n75: return -0.07450464367866516f;
  t160_n76: return 0.03070748597383499f;
  t160_n77: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t160_n85;
  t160_n78: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t160_n80;
  t160_n79: return -0.02571433037519455f;
  t160_n80: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t160_n84;
  t160_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t160_n83;
  t160_n82: return 0.10714258253574371f;
  t160_n83: return 0.11829813569784164f;
  t160_n84: return 0.043866127729415894f;
  t160_n85: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t160_n89;
  t160_n86: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t160_n88;
  t160_n87: return 0.03326878324151039f;
  t160_n88: return 0.11844085901975632f;
  t160_n89: return -0.10935194045305252f;
  t160_n90: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t160_n238;
  t160_n91: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t160_n93;
  t160_n92: return -0.024833472445607185f;
  t160_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t160_n121;
  t160_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t160_n104;
  t160_n95: if (E.getNumReferences() >= 3344562560 /*55801.5*/) goto t160_n103;
  t160_n96: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t160_n98;
  t160_n97: return -0.10004037618637085f;
  t160_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t160_n100;
  t160_n99: return -0.14045003056526184f;
  t160_n100: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n102;
  t160_n101: return 1.125430941581726f;
  t160_n102: return 0.1500311940908432f;
  t160_n103: return -0.05448490008711815f;
  t160_n104: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t160_n106;
  t160_n105: return -0.08756352216005325f;
  t160_n106: if (E.getNumReferences() >= 3345303552 /*58696.0*/) goto t160_n118;
  t160_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n113;
  t160_n108: if (E.getNumReferences() >= 3343995264 /*53585.5*/) goto t160_n110;
  t160_n109: return 0.006161458790302277f;
  t160_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t160_n112;
  t160_n111: return -0.2684008479118347f;
  t160_n112: return 0.17019052803516388f;
  t160_n113: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t160_n117;
  t160_n114: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t160_n116;
  t160_n115: return 0.11139226704835892f;
  t160_n116: return 0.3485051095485687f;
  t160_n117: return 0.09621669352054596f;
  t160_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t160_n120;
  t160_n119: return -0.08408860862255096f;
  t160_n120: return 0.018706249073147774f;
  t160_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t160_n217;
  t160_n122: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t160_n132;
  t160_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t160_n125;
  t160_n124: return 0.09460052847862244f;
  t160_n125: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t160_n131;
  t160_n126: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t160_n130;
  t160_n127: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n129;
  t160_n128: return 0.10504747182130814f;
  t160_n129: return 0.09505123645067215f;
  t160_n130: return 0.027172677218914032f;
  t160_n131: return -0.25123146176338196f;
  t160_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t160_n172;
  t160_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t160_n135;
  t160_n134: return -0.010187320411205292f;
  t160_n135: if (E.getNumReferences() >= 3342301952 /*46971.0*/) goto t160_n149;
  t160_n136: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t160_n138;
  t160_n137: return -0.0008479044190607965f;
  t160_n138: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t160_n140;
  t160_n139: return -0.011363357305526733f;
  t160_n140: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t160_n142;
  t160_n141: return -0.13074061274528503f;
  t160_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t160_n148;
  t160_n143: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t160_n147;
  t160_n144: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t160_n146;
  t160_n145: return 0.11902197450399399f;
  t160_n146: return 0.11004387587308884f;
  t160_n147: return 0.1515369713306427f;
  t160_n148: return 0.10128668695688248f;
  t160_n149: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t160_n153;
  t160_n150: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t160_n152;
  t160_n151: return -0.009331176057457924f;
  t160_n152: return -0.1551159918308258f;
  t160_n153: if (E.getNumReferences() >= 3368655888 /*412896.5*/) goto t160_n163;
  t160_n154: if (E.getNumReferences() >= 3367337376 /*371693.0*/) goto t160_n162;
  t160_n155: if (E.getNumReferences() >= 3365914464 /*327227.0*/) goto t160_n157;
  t160_n156: return 0.03412887454032898f;
  t160_n157: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n159;
  t160_n158: return -0.1770310401916504f;
  t160_n159: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t160_n161;
  t160_n160: return 0.08794160187244415f;
  t160_n161: return 0.08852341026067734f;
  t160_n162: return 0.1027289405465126f;
  t160_n163: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t160_n171;
  t160_n164: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t160_n166;
  t160_n165: return 0.01744440756738186f;
  t160_n166: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n170;
  t160_n167: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t160_n169;
  t160_n168: return 0.056283701211214066f;
  t160_n169: return 0.10025563091039658f;
  t160_n170: return -0.02439514547586441f;
  t160_n171: return -0.023202046751976013f;
  t160_n172: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t160_n216;
  t160_n173: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n181;
  t160_n174: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t160_n180;
  t160_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t160_n177;
  t160_n176: return -0.02111104689538479f;
  t160_n177: if (E.getNumReferences() >= 3344436864 /*55310.5*/) goto t160_n179;
  t160_n178: return -0.21182781457901f;
  t160_n179: return 0.050623174756765366f;
  t160_n180: return 0.04667208343744278f;
  t160_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n195;
  t160_n182: if (E.getNumReferences() >= 3356993440 /*155294.5*/) goto t160_n184;
  t160_n183: return 0.07960161566734314f;
  t160_n184: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t160_n186;
  t160_n185: return 0.11726737767457962f;
  t160_n186: if (E.getNumReferences() >= 3358908544 /*185218.0*/) goto t160_n192;
  t160_n187: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t160_n189;
  t160_n188: return 0.12753896415233612f;
  t160_n189: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t160_n191;
  t160_n190: return 0.11000601947307587f;
  t160_n191: return -0.12458755820989609f;
  t160_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t160_n194;
  t160_n193: return 0.04394553229212761f;
  t160_n194: return 0.08084075897932053f;
  t160_n195: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t160_n211;
  t160_n196: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t160_n206;
  t160_n197: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t160_n205;
  t160_n198: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t160_n200;
  t160_n199: return 0.48464643955230713f;
  t160_n200: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t160_n202;
  t160_n201: return -0.06246822699904442f;
  t160_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t160_n204;
  t160_n203: return 0.1356617957353592f;
  t160_n204: return 0.11027330160140991f;
  t160_n205: return 0.022077884525060654f;
  t160_n206: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t160_n210;
  t160_n207: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t160_n209;
  t160_n208: return 0.14212879538536072f;
  t160_n209: return 0.13613878190517426f;
  t160_n210: return -0.14539562165737152f;
  t160_n211: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t160_n213;
  t160_n212: return 0.056041620671749115f;
  t160_n213: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t160_n215;
  t160_n214: return 0.16130264103412628f;
  t160_n215: return 0.0367644764482975f;
  t160_n216: return 0.005172187928110361f;
  t160_n217: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t160_n225;
  t160_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t160_n220;
  t160_n219: return 0.01775720715522766f;
  t160_n220: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t160_n222;
  t160_n221: return -0.10194127261638641f;
  t160_n222: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t160_n224;
  t160_n223: return -0.9287749528884888f;
  t160_n224: return 0.1370803713798523f;
  t160_n225: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t160_n227;
  t160_n226: return -0.2321503460407257f;
  t160_n227: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t160_n237;
  t160_n228: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t160_n230;
  t160_n229: return 0.16049005091190338f;
  t160_n230: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t160_n236;
  t160_n231: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n235;
  t160_n232: if (E.getNumReferences() >= 3344186496 /*54332.5*/) goto t160_n234;
  t160_n233: return 0.1058088093996048f;
  t160_n234: return 0.08765970915555954f;
  t160_n235: return 0.09953678399324417f;
  t160_n236: return 0.09115869551897049f;
  t160_n237: return 0.12660744786262512f;
  t160_n238: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n244;
  t160_n239: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t160_n243;
  t160_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t160_n242;
  t160_n241: return -0.13186492025852203f;
  t160_n242: return 0.10838191211223602f;
  t160_n243: return -0.05877375230193138f;
  t160_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n250;
  t160_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t160_n249;
  t160_n246: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t160_n248;
  t160_n247: return -0.10549645870923996f;
  t160_n248: return 0.12131460011005402f;
  t160_n249: return -0.1303885132074356f;
  t160_n250: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t160_n254;
  t160_n251: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t160_n253;
  t160_n252: return 0.11371967941522598f;
  t160_n253: return 0.07343246787786484f;
  t160_n254: return 0.05605529993772507f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree161(const Example& E) {
  t161_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t161_n88;
  t161_n1: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t161_n31;
  t161_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t161_n4;
  t161_n3: return -0.0004798454756382853f;
  t161_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t161_n6;
  t161_n5: return -0.01609613187611103f;
  t161_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t161_n10;
  t161_n7: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t161_n9;
  t161_n8: return -0.011253266595304012f;
  t161_n9: return 0.0034415507689118385f;
  t161_n10: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t161_n30;
  t161_n11: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t161_n13;
  t161_n12: return 0.03472308814525604f;
  t161_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t161_n15;
  t161_n14: return 0.10553133487701416f;
  t161_n15: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n27;
  t161_n16: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t161_n22;
  t161_n17: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t161_n19;
  t161_n18: return 0.12077685445547104f;
  t161_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t161_n21;
  t161_n20: return 0.09902116656303406f;
  t161_n21: return 0.12657082080841064f;
  t161_n22: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t161_n24;
  t161_n23: return 0.09388482570648193f;
  t161_n24: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t161_n26;
  t161_n25: return 0.1195414736866951f;
  t161_n26: return 0.16232967376708984f;
  t161_n27: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t161_n29;
  t161_n28: return 0.06538809090852737f;
  t161_n29: return 0.09193558990955353f;
  t161_n30: return -0.016798783093690872f;
  t161_n31: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t161_n33;
  t161_n32: return -0.015338866040110588f;
  t161_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t161_n35;
  t161_n34: return -0.04014303535223007f;
  t161_n35: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n83;
  t161_n36: if (E.getNumReferences() >= 3272671232 /*145.0*/) goto t161_n70;
  t161_n37: if (E.getNumReferences() >= 3272540160 /*143.0*/) goto t161_n69;
  t161_n38: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t161_n54;
  t161_n39: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t161_n51;
  t161_n40: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t161_n42;
  t161_n41: return 0.06703561544418335f;
  t161_n42: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t161_n46;
  t161_n43: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t161_n45;
  t161_n44: return 0.1304980218410492f;
  t161_n45: return -0.045586906373500824f;
  t161_n46: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t161_n50;
  t161_n47: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t161_n49;
  t161_n48: return 0.07365286350250244f;
  t161_n49: return 0.09798556566238403f;
  t161_n50: return 0.017948836088180542f;
  t161_n51: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t161_n53;
  t161_n52: return 0.12399797141551971f;
  t161_n53: return 0.08107002079486847f;
  t161_n54: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t161_n60;
  t161_n55: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t161_n57;
  t161_n56: return 0.10333004593849182f;
  t161_n57: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t161_n59;
  t161_n58: return 0.09960895031690598f;
  t161_n59: return 0.13100561499595642f;
  t161_n60: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t161_n62;
  t161_n61: return 0.020503757521510124f;
  t161_n62: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t161_n68;
  t161_n63: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t161_n65;
  t161_n64: return 0.014991995878517628f;
  t161_n65: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t161_n67;
  t161_n66: return 0.13082057237625122f;
  t161_n67: return 0.09040211886167526f;
  t161_n68: return -0.12795093655586243f;
  t161_n69: return 0.11118925362825394f;
  t161_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n76;
  t161_n71: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t161_n73;
  t161_n72: return 0.8949722647666931f;
  t161_n73: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t161_n75;
  t161_n74: return 0.12365969270467758f;
  t161_n75: return -0.19547727704048157f;
  t161_n76: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t161_n78;
  t161_n77: return -0.017833227291703224f;
  t161_n78: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t161_n82;
  t161_n79: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t161_n81;
  t161_n80: return 0.10477973520755768f;
  t161_n81: return 0.08016026020050049f;
  t161_n82: return -0.05174681171774864f;
  t161_n83: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t161_n85;
  t161_n84: return 0.01186918094754219f;
  t161_n85: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t161_n87;
  t161_n86: return -0.09274868667125702f;
  t161_n87: return 0.9985569715499878f;
  t161_n88: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t161_n114;
  t161_n89: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n97;
  t161_n90: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t161_n92;
  t161_n91: return -0.11745338886976242f;
  t161_n92: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t161_n96;
  t161_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t161_n95;
  t161_n94: return -0.231393963098526f;
  t161_n95: return 0.09931368380784988f;
  t161_n96: return -0.2475464940071106f;
  t161_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t161_n111;
  t161_n98: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t161_n108;
  t161_n99: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t161_n107;
  t161_n100: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t161_n106;
  t161_n101: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t161_n103;
  t161_n102: return 0.10778334736824036f;
  t161_n103: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n105;
  t161_n104: return 0.16398753225803375f;
  t161_n105: return 0.11068469285964966f;
  t161_n106: return -0.24026958644390106f;
  t161_n107: return 0.12744611501693726f;
  t161_n108: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t161_n110;
  t161_n109: return 0.09394945949316025f;
  t161_n110: return 0.06409364193677902f;
  t161_n111: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n113;
  t161_n112: return 0.1256527304649353f;
  t161_n113: return 0.13165569305419922f;
  t161_n114: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t161_n204;
  t161_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t161_n191;
  t161_n116: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t161_n156;
  t161_n117: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t161_n131;
  t161_n118: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t161_n120;
  t161_n119: return -0.05264212563633919f;
  t161_n120: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t161_n122;
  t161_n121: return -0.1818886399269104f;
  t161_n122: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t161_n124;
  t161_n123: return 0.07855578511953354f;
  t161_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n128;
  t161_n125: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t161_n127;
  t161_n126: return 0.20007559657096863f;
  t161_n127: return -0.3394598066806793f;
  t161_n128: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t161_n130;
  t161_n129: return 0.09359004348516464f;
  t161_n130: return 0.13221046328544617f;
  t161_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n139;
  t161_n132: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t161_n134;
  t161_n133: return 0.0004106148553546518f;
  t161_n134: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t161_n136;
  t161_n135: return -0.1028519943356514f;
  t161_n136: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t161_n138;
  t161_n137: return 0.13284142315387726f;
  t161_n138: return -0.13737067580223083f;
  t161_n139: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t161_n145;
  t161_n140: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t161_n144;
  t161_n141: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t161_n143;
  t161_n142: return 0.12263022363185883f;
  t161_n143: return 0.09952772408723831f;
  t161_n144: return 0.08082075417041779f;
  t161_n145: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t161_n153;
  t161_n146: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t161_n152;
  t161_n147: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t161_n151;
  t161_n148: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t161_n150;
  t161_n149: return 0.11926999688148499f;
  t161_n150: return 0.04315498098731041f;
  t161_n151: return 0.03303990513086319f;
  t161_n152: return 0.11009014397859573f;
  t161_n153: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t161_n155;
  t161_n154: return 0.1327793151140213f;
  t161_n155: return 0.10352113097906113f;
  t161_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t161_n160;
  t161_n157: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t161_n159;
  t161_n158: return -0.006185656879097223f;
  t161_n159: return 0.010719179175794125f;
  t161_n160: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t161_n162;
  t161_n161: return -0.00953273568302393f;
  t161_n162: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t161_n190;
  t161_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n183;
  t161_n164: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t161_n180;
  t161_n165: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t161_n175;
  t161_n166: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t161_n168;
  t161_n167: return 0.1270899772644043f;
  t161_n168: if (E.getNumReferences() >= 3352190016 /*105656.5*/) goto t161_n170;
  t161_n169: return -0.10393980145454407f;
  t161_n170: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t161_n172;
  t161_n171: return 0.14287471771240234f;
  t161_n172: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t161_n174;
  t161_n173: return 0.12342649698257446f;
  t161_n174: return 0.1309620440006256f;
  t161_n175: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t161_n177;
  t161_n176: return 0.23746903240680695f;
  t161_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t161_n179;
  t161_n178: return 0.09433512389659882f;
  t161_n179: return 0.0774960145354271f;
  t161_n180: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t161_n182;
  t161_n181: return -0.5121796727180481f;
  t161_n182: return 0.09069894999265671f;
  t161_n183: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t161_n187;
  t161_n184: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t161_n186;
  t161_n185: return 0.07634784281253815f;
  t161_n186: return 0.0334056131541729f;
  t161_n187: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t161_n189;
  t161_n188: return -0.3286038935184479f;
  t161_n189: return -0.029062995687127113f;
  t161_n190: return 0.01194804534316063f;
  t161_n191: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t161_n199;
  t161_n192: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t161_n194;
  t161_n193: return -0.023778943344950676f;
  t161_n194: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t161_n198;
  t161_n195: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t161_n197;
  t161_n196: return 0.10566933453083038f;
  t161_n197: return 0.12067153304815292f;
  t161_n198: return 0.03668474778532982f;
  t161_n199: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t161_n203;
  t161_n200: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t161_n202;
  t161_n201: return 0.03030567616224289f;
  t161_n202: return 0.11719610542058945f;
  t161_n203: return -0.10754139721393585f;
  t161_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t161_n206;
  t161_n205: return 0.002682497026398778f;
  t161_n206: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t161_n222;
  t161_n207: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t161_n213;
  t161_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t161_n210;
  t161_n209: return -0.012827778235077858f;
  t161_n210: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t161_n212;
  t161_n211: return -0.16220255196094513f;
  t161_n212: return 0.13115251064300537f;
  t161_n213: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n215;
  t161_n214: return -0.017816107720136642f;
  t161_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n217;
  t161_n216: return 0.06263185292482376f;
  t161_n217: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t161_n221;
  t161_n218: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t161_n220;
  t161_n219: return 0.10769906640052795f;
  t161_n220: return 0.08135147392749786f;
  t161_n221: return 0.04400691017508507f;
  t161_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n248;
  t161_n223: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t161_n245;
  t161_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t161_n226;
  t161_n225: return -0.11102160066366196f;
  t161_n226: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t161_n244;
  t161_n227: if (E.getNumReferences() >= 3344186496 /*54332.5*/) goto t161_n233;
  t161_n228: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n232;
  t161_n229: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t161_n231;
  t161_n230: return 2.5033936500549316f;
  t161_n231: return -0.20228897035121918f;
  t161_n232: return -0.11448933184146881f;
  t161_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n237;
  t161_n234: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t161_n236;
  t161_n235: return 0.12378638982772827f;
  t161_n236: return -0.22798466682434082f;
  t161_n237: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t161_n239;
  t161_n238: return -0.10998150706291199f;
  t161_n239: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t161_n241;
  t161_n240: return 0.13977912068367004f;
  t161_n241: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t161_n243;
  t161_n242: return -0.10043317079544067f;
  t161_n243: return 0.15447892248630524f;
  t161_n244: return 0.03284170851111412f;
  t161_n245: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t161_n247;
  t161_n246: return -0.2142113447189331f;
  t161_n247: return 0.12884235382080078f;
  t161_n248: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t161_n254;
  t161_n249: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t161_n251;
  t161_n250: return 0.2515125572681427f;
  t161_n251: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t161_n253;
  t161_n252: return 0.10208284109830856f;
  t161_n253: return 0.09044199436903f;
  t161_n254: return -0.1508825719356537f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree162(const Example& E) {
  t162_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t162_n134;
  t162_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t162_n3;
  t162_n2: return -0.0006945895729586482f;
  t162_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t162_n19;
  t162_n4: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t162_n10;
  t162_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t162_n9;
  t162_n6: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t162_n8;
  t162_n7: return -0.1429622620344162f;
  t162_n8: return -0.2219202220439911f;
  t162_n9: return -0.020459463819861412f;
  t162_n10: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t162_n18;
  t162_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t162_n17;
  t162_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t162_n16;
  t162_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t162_n15;
  t162_n14: return -0.18732307851314545f;
  t162_n15: return -0.007285905536264181f;
  t162_n16: return 0.011974379420280457f;
  t162_n17: return -0.0015944025944918394f;
  t162_n18: return -0.015897653996944427f;
  t162_n19: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t162_n121;
  t162_n20: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t162_n52;
  t162_n21: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t162_n23;
  t162_n22: return 0.006776755675673485f;
  t162_n23: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t162_n45;
  t162_n24: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t162_n32;
  t162_n25: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t162_n27;
  t162_n26: return -4.340443047112785e-05f;
  t162_n27: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t162_n29;
  t162_n28: return -0.09465615451335907f;
  t162_n29: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t162_n31;
  t162_n30: return -0.06499207764863968f;
  t162_n31: return 0.05142935737967491f;
  t162_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t162_n40;
  t162_n33: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n39;
  t162_n34: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t162_n38;
  t162_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t162_n37;
  t162_n36: return -0.14770376682281494f;
  t162_n37: return 0.28213658928871155f;
  t162_n38: return -0.14040258526802063f;
  t162_n39: return -0.01655616983771324f;
  t162_n40: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t162_n42;
  t162_n41: return -0.12990885972976685f;
  t162_n42: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t162_n44;
  t162_n43: return -0.10193604230880737f;
  t162_n44: return -0.1866438090801239f;
  t162_n45: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t162_n51;
  t162_n46: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t162_n48;
  t162_n47: return -0.18437212705612183f;
  t162_n48: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t162_n50;
  t162_n49: return 0.0992405116558075f;
  t162_n50: return -0.14455963671207428f;
  t162_n51: return 0.024259373545646667f;
  t162_n52: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t162_n90;
  t162_n53: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t162_n59;
  t162_n54: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t162_n56;
  t162_n55: return -0.029235245659947395f;
  t162_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n58;
  t162_n57: return -0.17041528224945068f;
  t162_n58: return -0.32207271456718445f;
  t162_n59: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t162_n65;
  t162_n60: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t162_n62;
  t162_n61: return 0.032445866614580154f;
  t162_n62: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t162_n64;
  t162_n63: return 0.10654263198375702f;
  t162_n64: return -0.1237628310918808f;
  t162_n65: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t162_n81;
  t162_n66: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t162_n70;
  t162_n67: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n69;
  t162_n68: return -0.09978090971708298f;
  t162_n69: return -0.25326457619667053f;
  t162_n70: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t162_n72;
  t162_n71: return -0.012812281027436256f;
  t162_n72: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t162_n80;
  t162_n73: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t162_n75;
  t162_n74: return 0.0f;
  t162_n75: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t162_n77;
  t162_n76: return -0.12101536244153976f;
  t162_n77: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n79;
  t162_n78: return 0.34839242696762085f;
  t162_n79: return 0.12620045244693756f;
  t162_n80: return 0.24955326318740845f;
  t162_n81: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t162_n83;
  t162_n82: return 0.027580074965953827f;
  t162_n83: if (E.getNumReferences() >= 3333245184 /*22180.5*/) goto t162_n89;
  t162_n84: if (E.getNumReferences() >= 3324139520 /*10390.0*/) goto t162_n86;
  t162_n85: return -0.0020370245911180973f;
  t162_n86: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t162_n88;
  t162_n87: return 0.06091473251581192f;
  t162_n88: return -0.24189405143260956f;
  t162_n89: return -0.044921230524778366f;
  t162_n90: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t162_n114;
  t162_n91: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t162_n101;
  t162_n92: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t162_n100;
  t162_n93: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t162_n95;
  t162_n94: return -0.05315345525741577f;
  t162_n95: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t162_n99;
  t162_n96: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n98;
  t162_n97: return 0.0857173278927803f;
  t162_n98: return 0.14032702147960663f;
  t162_n99: return -0.06745105236768723f;
  t162_n100: return 0.1206170991063118f;
  t162_n101: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t162_n103;
  t162_n102: return -0.066182941198349f;
  t162_n103: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t162_n113;
  t162_n104: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t162_n112;
  t162_n105: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t162_n107;
  t162_n106: return 0.09276270866394043f;
  t162_n107: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t162_n111;
  t162_n108: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t162_n110;
  t162_n109: return 0.04366994649171829f;
  t162_n110: return 0.13288861513137817f;
  t162_n111: return 0.12805835902690887f;
  t162_n112: return 0.013092193752527237f;
  t162_n113: return 0.025660112500190735f;
  t162_n114: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n120;
  t162_n115: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t162_n117;
  t162_n116: return 0.12805384397506714f;
  t162_n117: if (E.getNumReferences() >= 3254255616 /*31.0*/) goto t162_n119;
  t162_n118: return -2.6478335857391357f;
  t162_n119: return 0.20651844143867493f;
  t162_n120: return 0.03288702294230461f;
  t162_n121: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t162_n133;
  t162_n122: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t162_n124;
  t162_n123: return -3.719814048963599e-05f;
  t162_n124: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t162_n132;
  t162_n125: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t162_n131;
  t162_n126: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t162_n130;
  t162_n127: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t162_n129;
  t162_n128: return 0.05314498022198677f;
  t162_n129: return 0.08794562518596649f;
  t162_n130: return 0.008580495603382587f;
  t162_n131: return -0.03940891847014427f;
  t162_n132: return 0.005647244863212109f;
  t162_n133: return -0.07974942028522491f;
  t162_n134: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t162_n208;
  t162_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t162_n195;
  t162_n136: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t162_n170;
  t162_n137: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t162_n147;
  t162_n138: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t162_n144;
  t162_n139: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t162_n141;
  t162_n140: return -0.20463190972805023f;
  t162_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t162_n143;
  t162_n142: return 0.12433496862649918f;
  t162_n143: return 0.12795376777648926f;
  t162_n144: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t162_n146;
  t162_n145: return -0.046126969158649445f;
  t162_n146: return 0.06015588715672493f;
  t162_n147: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t162_n155;
  t162_n148: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t162_n150;
  t162_n149: return -0.00040324649307876825f;
  t162_n150: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t162_n152;
  t162_n151: return -0.10254976898431778f;
  t162_n152: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t162_n154;
  t162_n153: return 0.12415961921215057f;
  t162_n154: return -0.13883115351200104f;
  t162_n155: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t162_n159;
  t162_n156: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t162_n158;
  t162_n157: return 0.10103418678045273f;
  t162_n158: return 0.07723810523748398f;
  t162_n159: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t162_n167;
  t162_n160: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n166;
  t162_n161: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t162_n165;
  t162_n162: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t162_n164;
  t162_n163: return 0.11150822043418884f;
  t162_n164: return 0.040051091462373734f;
  t162_n165: return 0.025314325466752052f;
  t162_n166: return 0.10946178436279297f;
  t162_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t162_n169;
  t162_n168: return 0.12894058227539062f;
  t162_n169: return 0.10037990659475327f;
  t162_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t162_n172;
  t162_n171: return 0.0033234297297894955f;
  t162_n172: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t162_n174;
  t162_n173: return -0.005128685384988785f;
  t162_n174: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t162_n194;
  t162_n175: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t162_n193;
  t162_n176: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t162_n190;
  t162_n177: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t162_n185;
  t162_n178: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t162_n180;
  t162_n179: return 0.10135680437088013f;
  t162_n180: if (E.getNumReferences() >= 3352190016 /*105656.5*/) goto t162_n182;
  t162_n181: return 0.0f;
  t162_n182: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t162_n184;
  t162_n183: return 0.13912397623062134f;
  t162_n184: return 0.12349649518728256f;
  t162_n185: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t162_n189;
  t162_n186: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t162_n188;
  t162_n187: return 0.0f;
  t162_n188: return 0.09577043354511261f;
  t162_n189: return 0.07940539717674255f;
  t162_n190: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t162_n192;
  t162_n191: return -0.5008249878883362f;
  t162_n192: return 0.07351379841566086f;
  t162_n193: return 0.033390503376722336f;
  t162_n194: return 0.011314528062939644f;
  t162_n195: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t162_n203;
  t162_n196: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t162_n198;
  t162_n197: return -0.018964994698762894f;
  t162_n198: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t162_n202;
  t162_n199: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t162_n201;
  t162_n200: return 0.1041397824883461f;
  t162_n201: return 0.1189790740609169f;
  t162_n202: return 0.0332503616809845f;
  t162_n203: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t162_n207;
  t162_n204: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t162_n206;
  t162_n205: return 0.035698052495718f;
  t162_n206: return 0.11751198768615723f;
  t162_n207: return -0.10628875344991684f;
  t162_n208: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t162_n224;
  t162_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t162_n215;
  t162_n210: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t162_n212;
  t162_n211: return -0.09419550746679306f;
  t162_n212: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t162_n214;
  t162_n213: return 0.10499145835638046f;
  t162_n214: return 0.12320201098918915f;
  t162_n215: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n223;
  t162_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t162_n218;
  t162_n217: return -0.17303258180618286f;
  t162_n218: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t162_n222;
  t162_n219: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t162_n221;
  t162_n220: return 0.10732952505350113f;
  t162_n221: return 0.09092066437005997f;
  t162_n222: return 0.019058074802160263f;
  t162_n223: return -0.20168662071228027f;
  t162_n224: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t162_n226;
  t162_n225: return 0.0023343288339674473f;
  t162_n226: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t162_n228;
  t162_n227: return 0.018844373524188995f;
  t162_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t162_n248;
  t162_n229: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t162_n245;
  t162_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t162_n232;
  t162_n231: return -0.10940603911876678f;
  t162_n232: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t162_n244;
  t162_n233: if (E.getNumReferences() >= 3344186496 /*54332.5*/) goto t162_n235;
  t162_n234: return 0.2430451214313507f;
  t162_n235: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t162_n243;
  t162_n236: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t162_n240;
  t162_n237: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t162_n239;
  t162_n238: return 0.1223011389374733f;
  t162_n239: return -0.1187557652592659f;
  t162_n240: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t162_n242;
  t162_n241: return -0.23891080915927887f;
  t162_n242: return 0.1336168497800827f;
  t162_n243: return -0.49783021211624146f;
  t162_n244: return 0.016164101660251617f;
  t162_n245: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t162_n247;
  t162_n246: return -0.20928296446800232f;
  t162_n247: return 0.1274159699678421f;
  t162_n248: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t162_n254;
  t162_n249: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t162_n251;
  t162_n250: return 0.14312121272087097f;
  t162_n251: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t162_n253;
  t162_n252: return 0.10042594373226166f;
  t162_n253: return 0.0881325826048851f;
  t162_n254: return -0.16274045407772064f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree163(const Example& E) {
  t163_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t163_n174;
  t163_n1: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t163_n15;
  t163_n2: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t163_n4;
  t163_n3: return 0.0004899885389022529f;
  t163_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n12;
  t163_n5: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t163_n7;
  t163_n6: return 0.0009624084923416376f;
  t163_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t163_n9;
  t163_n8: return -0.1012587621808052f;
  t163_n9: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t163_n11;
  t163_n10: return 0.0970035046339035f;
  t163_n11: return 0.09386338293552399f;
  t163_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t163_n14;
  t163_n13: return -0.1015002653002739f;
  t163_n14: return 0.017189793288707733f;
  t163_n15: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t163_n57;
  t163_n16: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t163_n18;
  t163_n17: return 2.6935053028864786e-05f;
  t163_n18: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t163_n34;
  t163_n19: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t163_n21;
  t163_n20: return -0.030044658109545708f;
  t163_n21: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t163_n33;
  t163_n22: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t163_n32;
  t163_n23: if (E.getNumReferences() >= 3326722048 /*12912.0*/) goto t163_n31;
  t163_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t163_n26;
  t163_n25: return -0.1342582106590271f;
  t163_n26: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t163_n28;
  t163_n27: return -0.053300607949495316f;
  t163_n28: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t163_n30;
  t163_n29: return 0.03318982198834419f;
  t163_n30: return 0.11080969870090485f;
  t163_n31: return 0.12177389860153198f;
  t163_n32: return -0.014677859842777252f;
  t163_n33: return -0.06275386363267899f;
  t163_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n36;
  t163_n35: return 0.04360082000494003f;
  t163_n36: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t163_n56;
  t163_n37: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t163_n43;
  t163_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t163_n40;
  t163_n39: return 0.03344998136162758f;
  t163_n40: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t163_n42;
  t163_n41: return 0.1146981343626976f;
  t163_n42: return 0.02954774908721447f;
  t163_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t163_n51;
  t163_n44: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t163_n46;
  t163_n45: return -0.05269352346658707f;
  t163_n46: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t163_n50;
  t163_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t163_n49;
  t163_n48: return 0.14995095133781433f;
  t163_n49: return 0.09173114597797394f;
  t163_n50: return 0.09602970629930496f;
  t163_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t163_n53;
  t163_n52: return -0.11123666912317276f;
  t163_n53: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t163_n55;
  t163_n54: return 0.10958313941955566f;
  t163_n55: return 0.1112457886338234f;
  t163_n56: return -0.0436239130795002f;
  t163_n57: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t163_n81;
  t163_n58: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t163_n66;
  t163_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t163_n61;
  t163_n60: return 0.004474981222301722f;
  t163_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n63;
  t163_n62: return 0.11716597527265549f;
  t163_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t163_n65;
  t163_n64: return 0.04224833846092224f;
  t163_n65: return 0.08370360732078552f;
  t163_n66: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n70;
  t163_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t163_n69;
  t163_n68: return 0.06655792146921158f;
  t163_n69: return 0.11560963839292526f;
  t163_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t163_n72;
  t163_n71: return 0.10298063606023788f;
  t163_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t163_n74;
  t163_n73: return 0.030460132285952568f;
  t163_n74: if (E.getNumReferences() >= 3286040576 /*442.0*/) goto t163_n80;
  t163_n75: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t163_n77;
  t163_n76: return 0.12936969101428986f;
  t163_n77: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t163_n79;
  t163_n78: return -0.3013767600059509f;
  t163_n79: return 0.141237273812294f;
  t163_n80: return 0.10870172083377838f;
  t163_n81: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t163_n173;
  t163_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t163_n130;
  t163_n83: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t163_n85;
  t163_n84: return -0.009565899148583412f;
  t163_n85: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t163_n87;
  t163_n86: return -0.0030357306823134422f;
  t163_n87: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t163_n97;
  t163_n88: if (E.getNumReferences() >= 3290931200 /*670.5*/) goto t163_n90;
  t163_n89: return -0.021221095696091652f;
  t163_n90: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t163_n92;
  t163_n91: return -0.016708068549633026f;
  t163_n92: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t163_n96;
  t163_n93: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t163_n95;
  t163_n94: return 0.11560119688510895f;
  t163_n95: return 0.10107562690973282f;
  t163_n96: return 0.05267363041639328f;
  t163_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t163_n103;
  t163_n98: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t163_n100;
  t163_n99: return 0.026075201109051704f;
  t163_n100: if (E.getFileProximityDistance() >= 3249537024 /*22.0*/) goto t163_n102;
  t163_n101: return 0.05697586387395859f;
  t163_n102: return 0.10107731074094772f;
  t163_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t163_n105;
  t163_n104: return -0.03326351195573807f;
  t163_n105: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t163_n127;
  t163_n106: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t163_n108;
  t163_n107: return 0.04126027598977089f;
  t163_n108: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t163_n126;
  t163_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t163_n125;
  t163_n110: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t163_n118;
  t163_n111: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t163_n113;
  t163_n112: return 0.07035236805677414f;
  t163_n113: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t163_n115;
  t163_n114: return -0.00638721976429224f;
  t163_n115: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t163_n117;
  t163_n116: return 0.07334938645362854f;
  t163_n117: return 0.013410795480012894f;
  t163_n118: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t163_n124;
  t163_n119: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t163_n123;
  t163_n120: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t163_n122;
  t163_n121: return 0.09300994873046875f;
  t163_n122: return -0.05894811823964119f;
  t163_n123: return 0.11719324439764023f;
  t163_n124: return 0.047766342759132385f;
  t163_n125: return 0.03209768235683441f;
  t163_n126: return -0.10252390801906586f;
  t163_n127: if (E.getNumReferences() >= 3316683776 /*5650.5*/) goto t163_n129;
  t163_n128: return -0.0006327289738692343f;
  t163_n129: return 0.07026783376932144f;
  t163_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t163_n138;
  t163_n131: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t163_n137;
  t163_n132: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t163_n134;
  t163_n133: return 0.006134744267910719f;
  t163_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t163_n136;
  t163_n135: return 0.010488833300769329f;
  t163_n136: return 0.02725367806851864f;
  t163_n137: return -0.10945279896259308f;
  t163_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t163_n160;
  t163_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t163_n149;
  t163_n140: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t163_n146;
  t163_n141: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t163_n143;
  t163_n142: return 0.048613373190164566f;
  t163_n143: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t163_n145;
  t163_n144: return 0.15374144911766052f;
  t163_n145: return 0.5809617638587952f;
  t163_n146: if (E.getNumReferences() >= 3332987392 /*21677.0*/) goto t163_n148;
  t163_n147: return -0.05543459951877594f;
  t163_n148: return 0.10355474054813385f;
  t163_n149: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t163_n159;
  t163_n150: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t163_n156;
  t163_n151: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t163_n155;
  t163_n152: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t163_n154;
  t163_n153: return 0.0011765464441850781f;
  t163_n154: return 0.10703639686107635f;
  t163_n155: return 0.0025968982372432947f;
  t163_n156: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t163_n158;
  t163_n157: return 0.07586495578289032f;
  t163_n158: return 0.03198496252298355f;
  t163_n159: return 0.006310765631496906f;
  t163_n160: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t163_n164;
  t163_n161: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t163_n163;
  t163_n162: return 0.03977745771408081f;
  t163_n163: return 0.0944921225309372f;
  t163_n164: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t163_n170;
  t163_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t163_n169;
  t163_n166: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t163_n168;
  t163_n167: return 0.12206026911735535f;
  t163_n168: return 0.038342319428920746f;
  t163_n169: return 0.0829552710056305f;
  t163_n170: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t163_n172;
  t163_n171: return 0.12249360233545303f;
  t163_n172: return 0.03234643489122391f;
  t163_n173: return -0.047135915607213974f;
  t163_n174: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t163_n244;
  t163_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t163_n231;
  t163_n176: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t163_n208;
  t163_n177: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t163_n185;
  t163_n178: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t163_n184;
  t163_n179: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t163_n181;
  t163_n180: return -0.19531100988388062f;
  t163_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t163_n183;
  t163_n182: return 0.12306822836399078f;
  t163_n183: return 0.12473953515291214f;
  t163_n184: return 0.017159435898065567f;
  t163_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t163_n193;
  t163_n186: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t163_n188;
  t163_n187: return -0.001663518138229847f;
  t163_n188: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t163_n190;
  t163_n189: return -0.1022966131567955f;
  t163_n190: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t163_n192;
  t163_n191: return 0.1205088347196579f;
  t163_n192: return -0.13113902509212494f;
  t163_n193: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t163_n197;
  t163_n194: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n196;
  t163_n195: return 0.09756768494844437f;
  t163_n196: return 0.07297434657812119f;
  t163_n197: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t163_n207;
  t163_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t163_n206;
  t163_n199: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t163_n203;
  t163_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n202;
  t163_n201: return 0.10372310876846313f;
  t163_n202: return 0.037279192358255386f;
  t163_n203: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n205;
  t163_n204: return -0.19561852514743805f;
  t163_n205: return 0.08374955505132675f;
  t163_n206: return 0.108881376683712f;
  t163_n207: return 0.12022096663713455f;
  t163_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t163_n210;
  t163_n209: return 0.0029008383862674236f;
  t163_n210: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t163_n212;
  t163_n211: return -0.005359471309930086f;
  t163_n212: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t163_n230;
  t163_n213: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t163_n229;
  t163_n214: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t163_n228;
  t163_n215: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t163_n223;
  t163_n216: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t163_n218;
  t163_n217: return 0.10318757593631744f;
  t163_n218: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t163_n220;
  t163_n219: return 0.125162273645401f;
  t163_n220: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t163_n222;
  t163_n221: return 0.0f;
  t163_n222: return 0.12170030921697617f;
  t163_n223: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t163_n227;
  t163_n224: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t163_n226;
  t163_n225: return 0.0f;
  t163_n226: return 0.09342297166585922f;
  t163_n227: return 0.07513988018035889f;
  t163_n228: return 0.01555407140403986f;
  t163_n229: return 0.03104354627430439f;
  t163_n230: return 0.011289107613265514f;
  t163_n231: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t163_n239;
  t163_n232: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t163_n234;
  t163_n233: return -0.01442734058946371f;
  t163_n234: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t163_n238;
  t163_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n237;
  t163_n236: return 0.10274885594844818f;
  t163_n237: return 0.1174221932888031f;
  t163_n238: return 0.033897727727890015f;
  t163_n239: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t163_n243;
  t163_n240: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t163_n242;
  t163_n241: return 0.03226948529481888f;
  t163_n242: return 0.1159091591835022f;
  t163_n243: return -0.10531175881624222f;
  t163_n244: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t163_n254;
  t163_n245: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t163_n253;
  t163_n246: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t163_n248;
  t163_n247: return -0.08964891731739044f;
  t163_n248: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t163_n252;
  t163_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t163_n251;
  t163_n250: return -0.1883617341518402f;
  t163_n251: return 0.09503157436847687f;
  t163_n252: return -0.22293923795223236f;
  t163_n253: return 0.09454914927482605f;
  t163_n254: return 0.0031545383390039206f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree164(const Example& E) {
  t164_n0: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t164_n78;
  t164_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t164_n3;
  t164_n2: return 0.00047555204946547747f;
  t164_n3: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t164_n5;
  t164_n4: return 0.0037867631763219833f;
  t164_n5: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t164_n13;
  t164_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t164_n12;
  t164_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t164_n9;
  t164_n8: return -0.0932597815990448f;
  t164_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t164_n11;
  t164_n10: return 0.10261143743991852f;
  t164_n11: return -0.006226572673767805f;
  t164_n12: return -0.04287434369325638f;
  t164_n13: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t164_n53;
  t164_n14: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t164_n52;
  t164_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t164_n17;
  t164_n16: return -0.004953397437930107f;
  t164_n17: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t164_n27;
  t164_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t164_n20;
  t164_n19: return -0.15345723927021027f;
  t164_n20: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t164_n22;
  t164_n21: return -0.04227060452103615f;
  t164_n22: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t164_n26;
  t164_n23: if (E.getNumReferences() >= 3240099840 /*10.0*/) goto t164_n25;
  t164_n24: return -0.03769074007868767f;
  t164_n25: return 0.18540753424167633f;
  t164_n26: return 0.0653560608625412f;
  t164_n27: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t164_n31;
  t164_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t164_n30;
  t164_n29: return -0.0818609818816185f;
  t164_n30: return -0.0022426170762628317f;
  t164_n31: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t164_n39;
  t164_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t164_n34;
  t164_n33: return 0.02136388048529625f;
  t164_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t164_n36;
  t164_n35: return -0.04393041878938675f;
  t164_n36: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t164_n38;
  t164_n37: return 0.03123265691101551f;
  t164_n38: return 0.12550877034664154f;
  t164_n39: if (E.getFileProximityDistance() >= 3254517760 /*31.5*/) goto t164_n51;
  t164_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t164_n50;
  t164_n41: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t164_n43;
  t164_n42: return 0.031708624213933945f;
  t164_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t164_n49;
  t164_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t164_n46;
  t164_n45: return 0.08317208290100098f;
  t164_n46: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t164_n48;
  t164_n47: return 0.13380439579486847f;
  t164_n48: return 0.1508534699678421f;
  t164_n49: return -0.026018263772130013f;
  t164_n50: return 0.02087215706706047f;
  t164_n51: return 0.21365796029567719f;
  t164_n52: return -0.016344716772437096f;
  t164_n53: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t164_n67;
  t164_n54: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t164_n64;
  t164_n55: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t164_n61;
  t164_n56: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t164_n58;
  t164_n57: return -0.13747380673885345f;
  t164_n58: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t164_n60;
  t164_n59: return 0.12235703319311142f;
  t164_n60: return -0.09153880923986435f;
  t164_n61: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t164_n63;
  t164_n62: return 0.12054448574781418f;
  t164_n63: return -0.13825032114982605f;
  t164_n64: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t164_n66;
  t164_n65: return 0.07838335633277893f;
  t164_n66: return -0.08561631292104721f;
  t164_n67: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t164_n73;
  t164_n68: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t164_n72;
  t164_n69: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t164_n71;
  t164_n70: return -0.11474771797657013f;
  t164_n71: return 0.11660466343164444f;
  t164_n72: return 0.10136471688747406f;
  t164_n73: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t164_n77;
  t164_n74: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t164_n76;
  t164_n75: return -0.26631736755371094f;
  t164_n76: return 0.1339673101902008f;
  t164_n77: return -0.031344082206487656f;
  t164_n78: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t164_n252;
  t164_n79: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t164_n107;
  t164_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t164_n102;
  t164_n81: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t164_n83;
  t164_n82: return -0.004487832076847553f;
  t164_n83: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t164_n93;
  t164_n84: if (E.getNumReferences() >= 3325242368 /*11467.0*/) goto t164_n92;
  t164_n85: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t164_n87;
  t164_n86: return 0.08798421919345856f;
  t164_n87: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t164_n89;
  t164_n88: return -0.007905972190201283f;
  t164_n89: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t164_n91;
  t164_n90: return 0.1151450127363205f;
  t164_n91: return 0.1268569678068161f;
  t164_n92: return 0.018748272210359573f;
  t164_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t164_n101;
  t164_n94: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t164_n96;
  t164_n95: return -0.005477665923535824f;
  t164_n96: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t164_n100;
  t164_n97: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t164_n99;
  t164_n98: return 0.09138374030590057f;
  t164_n99: return -0.11262167990207672f;
  t164_n100: return 0.02389921434223652f;
  t164_n101: return -0.06851910054683685f;
  t164_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t164_n106;
  t164_n103: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t164_n105;
  t164_n104: return -0.0387607105076313f;
  t164_n105: return -0.17789560556411743f;
  t164_n106: return 0.018694691359996796f;
  t164_n107: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t164_n205;
  t164_n108: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t164_n204;
  t164_n109: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t164_n135;
  t164_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t164_n130;
  t164_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t164_n113;
  t164_n112: return 0.0008465859573334455f;
  t164_n113: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t164_n121;
  t164_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t164_n116;
  t164_n115: return -0.10962218046188354f;
  t164_n116: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t164_n120;
  t164_n117: if (E.getNumReferences() >= 3281960960 /*317.5*/) goto t164_n119;
  t164_n118: return 0.0f;
  t164_n119: return 0.11111635714769363f;
  t164_n120: return 0.04206680878996849f;
  t164_n121: if (E.getNumReferences() >= 3292168192 /*746.0*/) goto t164_n127;
  t164_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t164_n124;
  t164_n123: return 0.044127609580755234f;
  t164_n124: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t164_n126;
  t164_n125: return 0.11584790796041489f;
  t164_n126: return 0.0440109483897686f;
  t164_n127: if (E.getNumReferences() >= 3293167616 /*807.0*/) goto t164_n129;
  t164_n128: return 0.14461776614189148f;
  t164_n129: return 0.045937616378068924f;
  t164_n130: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t164_n132;
  t164_n131: return 0.012793325819075108f;
  t164_n132: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t164_n134;
  t164_n133: return 0.11045747250318527f;
  t164_n134: return -0.10914666950702667f;
  t164_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t164_n151;
  t164_n136: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t164_n138;
  t164_n137: return -0.034014992415905f;
  t164_n138: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t164_n142;
  t164_n139: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t164_n141;
  t164_n140: return 0.07459478825330734f;
  t164_n141: return 0.0963473841547966f;
  t164_n142: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t164_n144;
  t164_n143: return -0.13663209974765778f;
  t164_n144: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t164_n148;
  t164_n145: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t164_n147;
  t164_n146: return 0.1202511414885521f;
  t164_n147: return 0.06697114557027817f;
  t164_n148: if (E.getNumReferences() >= 3272179712 /*137.5*/) goto t164_n150;
  t164_n149: return -0.00693654827773571f;
  t164_n150: return 0.1157338097691536f;
  t164_n151: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t164_n173;
  t164_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t164_n166;
  t164_n153: if (E.getNumReferences() >= 3317816320 /*6203.5*/) goto t164_n165;
  t164_n154: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t164_n156;
  t164_n155: return -0.07398267835378647f;
  t164_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t164_n162;
  t164_n157: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t164_n161;
  t164_n158: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t164_n160;
  t164_n159: return 0.12052817642688751f;
  t164_n160: return -0.10349442064762115f;
  t164_n161: return 0.07510969042778015f;
  t164_n162: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t164_n164;
  t164_n163: return -0.10312850028276443f;
  t164_n164: return 0.18628893792629242f;
  t164_n165: return 0.1824316680431366f;
  t164_n166: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t164_n168;
  t164_n167: return -0.045248109847307205f;
  t164_n168: if (E.getNumReferences() >= 3290480640 /*643.0*/) goto t164_n172;
  t164_n169: if (E.getNumReferences() >= 3280977920 /*287.5*/) goto t164_n171;
  t164_n170: return 0.09165851771831512f;
  t164_n171: return 0.11810969561338425f;
  t164_n172: return 0.08207377046346664f;
  t164_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t164_n185;
  t164_n174: if (E.getNumReferences() >= 3274080256 /*166.5*/) goto t164_n176;
  t164_n175: return 0.04656168445944786f;
  t164_n176: if (E.getNumReferences() >= 3275194368 /*183.5*/) goto t164_n178;
  t164_n177: return 0.12749414145946503f;
  t164_n178: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t164_n180;
  t164_n179: return -0.11278913915157318f;
  t164_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t164_n182;
  t164_n181: return 0.07612936943769455f;
  t164_n182: if (E.getNumReferences() >= 3292618752 /*773.5*/) goto t164_n184;
  t164_n183: return 0.15669429302215576f;
  t164_n184: return 0.020068015903234482f;
  t164_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t164_n187;
  t164_n186: return 0.028565144166350365f;
  t164_n187: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t164_n191;
  t164_n188: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t164_n190;
  t164_n189: return 0.11741072684526443f;
  t164_n190: return -0.23411202430725098f;
  t164_n191: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t164_n197;
  t164_n192: if (E.getNumReferences() >= 3264020480 /*70.5*/) goto t164_n196;
  t164_n193: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t164_n195;
  t164_n194: return 0.11843745410442352f;
  t164_n195: return -0.007218184880912304f;
  t164_n196: return 0.11959139257669449f;
  t164_n197: if (E.getNumReferences() >= 3275816960 /*193.0*/) goto t164_n199;
  t164_n198: return 0.026400092989206314f;
  t164_n199: if (E.getNumReferences() >= 3279323136 /*246.5*/) goto t164_n201;
  t164_n200: return 0.10432508587837219f;
  t164_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t164_n203;
  t164_n202: return -0.1327662318944931f;
  t164_n203: return 0.12469317018985748f;
  t164_n204: return -0.005817900877445936f;
  t164_n205: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t164_n211;
  t164_n206: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t164_n208;
  t164_n207: return -0.08325809985399246f;
  t164_n208: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t164_n210;
  t164_n209: return -0.15709291398525238f;
  t164_n210: return 0.10964876413345337f;
  t164_n211: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t164_n215;
  t164_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t164_n214;
  t164_n213: return -0.06639596074819565f;
  t164_n214: return 0.037090964615345f;
  t164_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t164_n217;
  t164_n216: return 0.002676212228834629f;
  t164_n217: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t164_n251;
  t164_n218: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t164_n222;
  t164_n219: if (E.getNumReferences() >= 3268214784 /*102.5*/) goto t164_n221;
  t164_n220: return 0.08794429153203964f;
  t164_n221: return -0.035972390323877335f;
  t164_n222: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t164_n250;
  t164_n223: if (E.getNumReferences() >= 3351111424 /*97230.0*/) goto t164_n245;
  t164_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t164_n226;
  t164_n225: return -0.08135027438402176f;
  t164_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t164_n228;
  t164_n227: return -0.004566966090351343f;
  t164_n228: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t164_n230;
  t164_n229: return 0.10942614823579788f;
  t164_n230: if (E.getNumReferences() >= 3291865088 /*727.5*/) goto t164_n232;
  t164_n231: return -0.004090880509465933f;
  t164_n232: if (E.getNumReferences() >= 3314309120 /*4491.0*/) goto t164_n238;
  t164_n233: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t164_n235;
  t164_n234: return 0.1093001589179039f;
  t164_n235: if (E.getNumReferences() >= 3309062144 /*3012.5*/) goto t164_n237;
  t164_n236: return 0.005793809425085783f;
  t164_n237: return 0.11960732936859131f;
  t164_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t164_n240;
  t164_n239: return -0.08520496636629105f;
  t164_n240: if (E.getNumReferences() >= 3322163200 /*8460.0*/) goto t164_n242;
  t164_n241: return -0.22857792675495148f;
  t164_n242: if (E.getNumReferences() >= 3327389696 /*13564.0*/) goto t164_n244;
  t164_n243: return 0.11143941432237625f;
  t164_n244: return 0.045656781643629074f;
  t164_n245: if (E.getNumReferences() >= 3363327264 /*254260.5*/) goto t164_n249;
  t164_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t164_n248;
  t164_n247: return -0.044647835195064545f;
  t164_n248: return 0.11428780108690262f;
  t164_n249: return 0.01080297864973545f;
  t164_n250: return 0.01902351714670658f;
  t164_n251: return 0.10972835123538971f;
  t164_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t164_n254;
  t164_n253: return 0.02327170968055725f;
  t164_n254: return 0.03970065712928772f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree165(const Example& E) {
  t165_n0: if (E.getNumReferences() >= 3309340672 /*3080.5*/) goto t165_n2;
  t165_n1: return -0.0004028862458653748f;
  t165_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t165_n52;
  t165_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t165_n5;
  t165_n4: return 0.010801627300679684f;
  t165_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t165_n43;
  t165_n6: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t165_n36;
  t165_n7: if (E.getNumReferences() >= 3344355328 /*54992.0*/) goto t165_n27;
  t165_n8: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t165_n24;
  t165_n9: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t165_n19;
  t165_n10: if (E.getNumReferences() >= 3315905536 /*5270.5*/) goto t165_n12;
  t165_n11: return 0.009025966748595238f;
  t165_n12: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t165_n14;
  t165_n13: return 0.05992607772350311f;
  t165_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t165_n16;
  t165_n15: return 0.029332172125577927f;
  t165_n16: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t165_n18;
  t165_n17: return 0.10314308851957321f;
  t165_n18: return 0.05838044360280037f;
  t165_n19: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t165_n23;
  t165_n20: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t165_n22;
  t165_n21: return -0.11254341900348663f;
  t165_n22: return -1.0256515741348267f;
  t165_n23: return -0.006457197014242411f;
  t165_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t165_n26;
  t165_n25: return 0.10048037022352219f;
  t165_n26: return 0.024316290393471718f;
  t165_n27: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t165_n35;
  t165_n28: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t165_n30;
  t165_n29: return 0.5705655217170715f;
  t165_n30: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t165_n32;
  t165_n31: return 0.2735494077205658f;
  t165_n32: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t165_n34;
  t165_n33: return 0.1425503045320511f;
  t165_n34: return 0.1121358573436737f;
  t165_n35: return 0.00334366993047297f;
  t165_n36: if (E.getNumReferences() >= 3344974336 /*57410.0*/) goto t165_n38;
  t165_n37: return -0.09486235678195953f;
  t165_n38: if (E.getNumReferences() >= 3345444992 /*59248.5*/) goto t165_n42;
  t165_n39: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t165_n41;
  t165_n40: return 0.1370670199394226f;
  t165_n41: return 0.1359836906194687f;
  t165_n42: return 0.005842081271111965f;
  t165_n43: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t165_n51;
  t165_n44: if (E.getNumReferences() >= 3314761728 /*4712.0*/) goto t165_n46;
  t165_n45: return -0.17279638350009918f;
  t165_n46: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t165_n48;
  t165_n47: return 0.1052354946732521f;
  t165_n48: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t165_n50;
  t165_n49: return 0.14039257168769836f;
  t165_n50: return 0.14039760828018188f;
  t165_n51: return -0.034495119005441666f;
  t165_n52: if (E.getNumReferences() >= 3309346816 /*3082.0*/) goto t165_n56;
  t165_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t165_n55;
  t165_n54: return -0.22765815258026123f;
  t165_n55: return 0.11891598999500275f;
  t165_n56: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t165_n58;
  t165_n57: return -0.00041993072954937816f;
  t165_n58: if (E.getNumReferences() >= 3325491712 /*11710.5*/) goto t165_n192;
  t165_n59: if (E.getNumReferences() >= 3325364224 /*11586.0*/) goto t165_n187;
  t165_n60: if (E.getNumReferences() >= 3320644608 /*7584.5*/) goto t165_n78;
  t165_n61: if (E.getNumReferences() >= 3320582144 /*7554.0*/) goto t165_n77;
  t165_n62: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t165_n76;
  t165_n63: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t165_n71;
  t165_n64: if (E.getNumReferences() >= 3309570048 /*3136.5*/) goto t165_n68;
  t165_n65: if (E.getNumReferences() >= 3309533184 /*3127.5*/) goto t165_n67;
  t165_n66: return 0.030377784743905067f;
  t165_n67: return 0.10433100163936615f;
  t165_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t165_n70;
  t165_n69: return -0.11323612183332443f;
  t165_n70: return 0.05722620338201523f;
  t165_n71: if (E.getNumReferences() >= 3309365248 /*3086.5*/) goto t165_n75;
  t165_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t165_n74;
  t165_n73: return -0.10212747752666473f;
  t165_n74: return 0.10543319582939148f;
  t165_n75: return 0.013854891993105412f;
  t165_n76: return 0.11174500733613968f;
  t165_n77: return -0.6866514086723328f;
  t165_n78: if (E.getNumReferences() >= 3321948672 /*8250.5*/) goto t165_n110;
  t165_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t165_n103;
  t165_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t165_n94;
  t165_n81: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t165_n83;
  t165_n82: return -0.017806779593229294f;
  t165_n83: if (E.getNumReferences() >= 3321384960 /*7946.0*/) goto t165_n89;
  t165_n84: if (E.getNumReferences() >= 3320866816 /*7693.0*/) goto t165_n88;
  t165_n85: if (E.getNumReferences() >= 3320749056 /*7635.5*/) goto t165_n87;
  t165_n86: return 0.022330328822135925f;
  t165_n87: return 0.11966170370578766f;
  t165_n88: return 0.001941765658557415f;
  t165_n89: if (E.getNumReferences() >= 3321413632 /*7960.0*/) goto t165_n93;
  t165_n90: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n92;
  t165_n91: return 0.1311112940311432f;
  t165_n92: return 0.11827903240919113f;
  t165_n93: return 0.056425873190164566f;
  t165_n94: if (E.getNumReferences() >= 3321060352 /*7787.5*/) goto t165_n100;
  t165_n95: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t165_n99;
  t165_n96: if (E.getNumReferences() >= 3320947712 /*7732.5*/) goto t165_n98;
  t165_n97: return 0.04716522619128227f;
  t165_n98: return 0.09963924437761307f;
  t165_n99: return 0.11496860533952713f;
  t165_n100: if (E.getNumReferences() >= 3321886720 /*8191.0*/) goto t165_n102;
  t165_n101: return 0.06379008293151855f;
  t165_n102: return 0.10546834766864777f;
  t165_n103: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n105;
  t165_n104: return 0.11506211012601852f;
  t165_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t165_n107;
  t165_n106: return -0.10444121062755585f;
  t165_n107: if (E.getNumReferences() >= 3321802752 /*8150.0*/) goto t165_n109;
  t165_n108: return 0.11426880210638046f;
  t165_n109: return 0.11981803178787231f;
  t165_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t165_n134;
  t165_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t165_n113;
  t165_n112: return -0.14319537580013275f;
  t165_n113: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t165_n115;
  t165_n114: return -0.0609855093061924f;
  t165_n115: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n127;
  t165_n116: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t165_n126;
  t165_n117: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t165_n119;
  t165_n118: return -0.071821428835392f;
  t165_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t165_n121;
  t165_n120: return -0.3284303843975067f;
  t165_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t165_n123;
  t165_n122: return -0.8354986310005188f;
  t165_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t165_n125;
  t165_n124: return 0.11360827088356018f;
  t165_n125: return -0.10886365920305252f;
  t165_n126: return -0.14196394383907318f;
  t165_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t165_n131;
  t165_n128: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t165_n130;
  t165_n129: return 0.06565193831920624f;
  t165_n130: return 0.09551139920949936f;
  t165_n131: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t165_n133;
  t165_n132: return 0.10098154097795486f;
  t165_n133: return -1.4897332191467285f;
  t165_n134: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t165_n182;
  t165_n135: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t165_n177;
  t165_n136: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t165_n156;
  t165_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t165_n149;
  t165_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t165_n140;
  t165_n139: return -0.12606512010097504f;
  t165_n140: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t165_n142;
  t165_n141: return -0.10182911157608032f;
  t165_n142: if (E.getNumReferences() >= 3323492352 /*9758.0*/) goto t165_n144;
  t165_n143: return 0.09903501719236374f;
  t165_n144: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t165_n148;
  t165_n145: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t165_n147;
  t165_n146: return 0.12062319368124008f;
  t165_n147: return -0.10855866223573685f;
  t165_n148: return -0.08861561864614487f;
  t165_n149: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t165_n151;
  t165_n150: return -0.005525455344468355f;
  t165_n151: if (E.getNumReferences() >= 3323013120 /*9290.0*/) goto t165_n155;
  t165_n152: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t165_n154;
  t165_n153: return 0.11509793251752853f;
  t165_n154: return 0.11199122667312622f;
  t165_n155: return -0.037801165133714676f;
  t165_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t165_n168;
  t165_n157: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t165_n159;
  t165_n158: return 0.12357891350984573f;
  t165_n159: if (E.getNumReferences() >= 3322167808 /*8464.5*/) goto t165_n163;
  t165_n160: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t165_n162;
  t165_n161: return -0.07569428533315659f;
  t165_n162: return 0.12121927738189697f;
  t165_n163: if (E.getNumReferences() >= 3324302336 /*10549.0*/) goto t165_n165;
  t165_n164: return -0.060341715812683105f;
  t165_n165: if (E.getNumReferences() >= 3324882944 /*11116.0*/) goto t165_n167;
  t165_n166: return 0.10120561718940735f;
  t165_n167: return -0.12831668555736542f;
  t165_n168: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t165_n170;
  t165_n169: return 0.028363768011331558f;
  t165_n170: if (E.getNumReferences() >= 3324087808 /*10339.5*/) goto t165_n176;
  t165_n171: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t165_n175;
  t165_n172: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t165_n174;
  t165_n173: return 0.09079837054014206f;
  t165_n174: return 0.23696346580982208f;
  t165_n175: return -0.02252291329205036f;
  t165_n176: return 0.10603144764900208f;
  t165_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t165_n179;
  t165_n178: return -0.2985196113586426f;
  t165_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t165_n181;
  t165_n180: return 0.09908277541399002f;
  t165_n181: return 0.10266083478927612f;
  t165_n182: if (E.getNumReferences() >= 3323669504 /*9931.0*/) goto t165_n186;
  t165_n183: if (E.getNumReferences() >= 3322761216 /*9044.0*/) goto t165_n185;
  t165_n184: return 0.025299636647105217f;
  t165_n185: return 0.10756243020296097f;
  t165_n186: return 0.0036094726528972387f;
  t165_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t165_n191;
  t165_n188: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t165_n190;
  t165_n189: return 0.10840442776679993f;
  t165_n190: return 0.08436774462461472f;
  t165_n191: return 0.11814957857131958f;
  t165_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t165_n210;
  t165_n193: if (E.getNumReferences() >= 3325559808 /*11777.0*/) goto t165_n195;
  t165_n194: return -0.25367799401283264f;
  t165_n195: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t165_n201;
  t165_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t165_n200;
  t165_n197: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t165_n199;
  t165_n198: return -0.3082372844219208f;
  t165_n199: return -0.22847041487693787f;
  t165_n200: return -0.04509396106004715f;
  t165_n201: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t165_n203;
  t165_n202: return -0.010238808579742908f;
  t165_n203: if (E.getNumReferences() >= 3325698048 /*11912.0*/) goto t165_n209;
  t165_n204: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t165_n206;
  t165_n205: return 0.4666461646556854f;
  t165_n206: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t165_n208;
  t165_n207: return 0.18352870643138885f;
  t165_n208: return -0.09341245144605637f;
  t165_n209: return 0.018004335463047028f;
  t165_n210: if (E.getNumReferences() >= 3367651744 /*381517.0*/) goto t165_n244;
  t165_n211: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t165_n231;
  t165_n212: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t165_n216;
  t165_n213: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n215;
  t165_n214: return -0.06497051566839218f;
  t165_n215: return 0.03238943591713905f;
  t165_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t165_n218;
  t165_n217: return 0.023860769346356392f;
  t165_n218: if (E.getNumReferences() >= 3344570752 /*55833.5*/) goto t165_n230;
  t165_n219: if (E.getNumReferences() >= 3335207936 /*26014.0*/) goto t165_n225;
  t165_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t165_n222;
  t165_n221: return 0.011700427159667015f;
  t165_n222: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n224;
  t165_n223: return 0.11387111991643906f;
  t165_n224: return -0.11144348233938217f;
  t165_n225: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n229;
  t165_n226: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t165_n228;
  t165_n227: return 0.06858273595571518f;
  t165_n228: return 0.11570139974355698f;
  t165_n229: return 0.11966991424560547f;
  t165_n230: return 0.02067425660789013f;
  t165_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t165_n241;
  t165_n232: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n236;
  t165_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t165_n235;
  t165_n234: return -0.31321507692337036f;
  t165_n235: return -0.11088378727436066f;
  t165_n236: if (E.getNumReferences() >= 3338822144 /*33378.0*/) goto t165_n238;
  t165_n237: return -0.13375689089298248f;
  t165_n238: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t165_n240;
  t165_n239: return 0.062263067811727524f;
  t165_n240: return 0.10258661955595016f;
  t165_n241: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t165_n243;
  t165_n242: return 0.09664493799209595f;
  t165_n243: return 0.026620112359523773f;
  t165_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t165_n246;
  t165_n245: return 0.05532413348555565f;
  t165_n246: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t165_n248;
  t165_n247: return 0.02750077284872532f;
  t165_n248: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t165_n250;
  t165_n249: return 0.11028121411800385f;
  t165_n250: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t165_n254;
  t165_n251: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t165_n253;
  t165_n252: return 0.10360893607139587f;
  t165_n253: return 0.09512107074260712f;
  t165_n254: return 0.06934218853712082f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree166(const Example& E) {
  t166_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t166_n2;
  t166_n1: return -0.0013024130603298545f;
  t166_n2: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t166_n84;
  t166_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t166_n81;
  t166_n4: if (E.getNumReferences() >= 3329800192 /*15918.0*/) goto t166_n64;
  t166_n5: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t166_n61;
  t166_n6: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t166_n44;
  t166_n7: if (E.getNumReferences() >= 3295674368 /*960.0*/) goto t166_n41;
  t166_n8: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t166_n14;
  t166_n9: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t166_n13;
  t166_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t166_n12;
  t166_n11: return -0.1203548014163971f;
  t166_n12: return -0.0047096204943954945f;
  t166_n13: return 0.004620173014700413f;
  t166_n14: if (E.getNumReferences() >= 3267952640 /*100.5*/) goto t166_n40;
  t166_n15: if (E.getNumReferences() >= 3266969600 /*93.0*/) goto t166_n39;
  t166_n16: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t166_n38;
  t166_n17: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t166_n31;
  t166_n18: if (E.getNumReferences() >= 3263561728 /*67.0*/) goto t166_n28;
  t166_n19: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t166_n27;
  t166_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t166_n24;
  t166_n21: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t166_n23;
  t166_n22: return 0.017433451488614082f;
  t166_n23: return 0.09231309592723846f;
  t166_n24: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t166_n26;
  t166_n25: return 0.11225274205207825f;
  t166_n26: return 0.09744738042354584f;
  t166_n27: return -0.24266070127487183f;
  t166_n28: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t166_n30;
  t166_n29: return 0.1316603124141693f;
  t166_n30: return 0.07556340098381042f;
  t166_n31: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t166_n35;
  t166_n32: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t166_n34;
  t166_n33: return -0.03228405863046646f;
  t166_n34: return 0.10245022177696228f;
  t166_n35: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t166_n37;
  t166_n36: return 0.0973496064543724f;
  t166_n37: return 0.12241137772798538f;
  t166_n38: return -0.0662304237484932f;
  t166_n39: return 0.10160166770219803f;
  t166_n40: return -0.07822781056165695f;
  t166_n41: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t166_n43;
  t166_n42: return 0.102906234562397f;
  t166_n43: return -0.03826082870364189f;
  t166_n44: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t166_n56;
  t166_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t166_n47;
  t166_n46: return -0.09193561971187592f;
  t166_n47: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t166_n51;
  t166_n48: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t166_n50;
  t166_n49: return -0.09826099127531052f;
  t166_n50: return -0.012689637020230293f;
  t166_n51: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t166_n53;
  t166_n52: return -0.05631566420197487f;
  t166_n53: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t166_n55;
  t166_n54: return 0.10512089729309082f;
  t166_n55: return -0.16302412748336792f;
  t166_n56: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t166_n60;
  t166_n57: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t166_n59;
  t166_n58: return -0.1423855870962143f;
  t166_n59: return 0.0868086889386177f;
  t166_n60: return 0.12792527675628662f;
  t166_n61: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t166_n63;
  t166_n62: return -0.004984728526324034f;
  t166_n63: return 0.0023051206953823566f;
  t166_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t166_n78;
  t166_n65: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t166_n77;
  t166_n66: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t166_n70;
  t166_n67: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t166_n69;
  t166_n68: return 0.11061973869800568f;
  t166_n69: return 0.12728118896484375f;
  t166_n70: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t166_n76;
  t166_n71: if (E.getNumReferences() >= 3336411136 /*28364.0*/) goto t166_n73;
  t166_n72: return 0.11994786560535431f;
  t166_n73: if (E.getNumReferences() >= 3343861504 /*53063.0*/) goto t166_n75;
  t166_n74: return -0.3567308485507965f;
  t166_n75: return 0.10179830342531204f;
  t166_n76: return 0.038064323365688324f;
  t166_n77: return 0.009553967043757439f;
  t166_n78: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t166_n80;
  t166_n79: return -0.036171600222587585f;
  t166_n80: return 0.10576992481946945f;
  t166_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t166_n83;
  t166_n82: return -9.390151535626501e-05f;
  t166_n83: return 0.0451197475194931f;
  t166_n84: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t166_n250;
  t166_n85: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t166_n209;
  t166_n86: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t166_n188;
  t166_n87: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t166_n133;
  t166_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t166_n90;
  t166_n89: return 0.0020941407419741154f;
  t166_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t166_n116;
  t166_n91: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t166_n111;
  t166_n92: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t166_n102;
  t166_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t166_n95;
  t166_n94: return 0.009713796898722649f;
  t166_n95: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t166_n97;
  t166_n96: return 0.00614231638610363f;
  t166_n97: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t166_n101;
  t166_n98: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t166_n100;
  t166_n99: return 0.07721754908561707f;
  t166_n100: return 0.131268709897995f;
  t166_n101: return 0.019251078367233276f;
  t166_n102: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t166_n104;
  t166_n103: return 0.06289055943489075f;
  t166_n104: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t166_n106;
  t166_n105: return 0.10657040774822235f;
  t166_n106: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t166_n108;
  t166_n107: return 0.02226862497627735f;
  t166_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t166_n110;
  t166_n109: return -0.254813015460968f;
  t166_n110: return 0.1828266680240631f;
  t166_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t166_n113;
  t166_n112: return -0.02251775749027729f;
  t166_n113: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t166_n115;
  t166_n114: return 0.01433639321476221f;
  t166_n115: return 0.125406414270401f;
  t166_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t166_n122;
  t166_n117: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t166_n119;
  t166_n118: return -0.1570449322462082f;
  t166_n119: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t166_n121;
  t166_n120: return 0.022328443825244904f;
  t166_n121: return 0.13047382235527039f;
  t166_n122: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t166_n130;
  t166_n123: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t166_n129;
  t166_n124: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t166_n126;
  t166_n125: return 0.0706963911652565f;
  t166_n126: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t166_n128;
  t166_n127: return 0.11085617542266846f;
  t166_n128: return 0.06085053086280823f;
  t166_n129: return -0.0813262015581131f;
  t166_n130: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t166_n132;
  t166_n131: return 0.10631050914525986f;
  t166_n132: return -0.02597920410335064f;
  t166_n133: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t166_n183;
  t166_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t166_n142;
  t166_n135: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t166_n141;
  t166_n136: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t166_n138;
  t166_n137: return -0.06358297169208527f;
  t166_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t166_n140;
  t166_n139: return -0.21512427926063538f;
  t166_n140: return 0.03930584713816643f;
  t166_n141: return -0.020858002826571465f;
  t166_n142: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t166_n164;
  t166_n143: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t166_n145;
  t166_n144: return -0.021289797499775887f;
  t166_n145: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t166_n153;
  t166_n146: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t166_n148;
  t166_n147: return -0.008002053014934063f;
  t166_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t166_n150;
  t166_n149: return 0.04679303616285324f;
  t166_n150: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t166_n152;
  t166_n151: return 0.09751445800065994f;
  t166_n152: return 0.10637523978948593f;
  t166_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t166_n157;
  t166_n154: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t166_n156;
  t166_n155: return -0.08107952028512955f;
  t166_n156: return 0.18743331730365753f;
  t166_n157: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t166_n161;
  t166_n158: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t166_n160;
  t166_n159: return 0.2148398756980896f;
  t166_n160: return -0.21557702124118805f;
  t166_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t166_n163;
  t166_n162: return 0.37430113554000854f;
  t166_n163: return 0.1210348904132843f;
  t166_n164: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t166_n182;
  t166_n165: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t166_n169;
  t166_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t166_n168;
  t166_n167: return 0.005261542741209269f;
  t166_n168: return 0.04157360643148422f;
  t166_n169: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t166_n171;
  t166_n170: return 0.022649414837360382f;
  t166_n171: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t166_n179;
  t166_n172: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t166_n174;
  t166_n173: return 0.10754420608282089f;
  t166_n174: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t166_n176;
  t166_n175: return 0.05319057032465935f;
  t166_n176: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t166_n178;
  t166_n177: return 0.11412031203508377f;
  t166_n178: return 0.10717040300369263f;
  t166_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t166_n181;
  t166_n180: return -0.055511459708213806f;
  t166_n181: return 0.1371784508228302f;
  t166_n182: return -0.021754663437604904f;
  t166_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t166_n185;
  t166_n184: return -0.0588979534804821f;
  t166_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t166_n187;
  t166_n186: return -0.032113172113895416f;
  t166_n187: return 0.01437383983284235f;
  t166_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t166_n204;
  t166_n189: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t166_n191;
  t166_n190: return -0.09906313568353653f;
  t166_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t166_n197;
  t166_n192: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t166_n194;
  t166_n193: return 0.07459750026464462f;
  t166_n194: if (E.getNumReferences() >= 3279159296 /*244.0*/) goto t166_n196;
  t166_n195: return 0.4332926273345947f;
  t166_n196: return 0.11216230690479279f;
  t166_n197: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t166_n199;
  t166_n198: return 0.008094200864434242f;
  t166_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t166_n203;
  t166_n200: if (E.getNumReferences() >= 3275423744 /*187.0*/) goto t166_n202;
  t166_n201: return 0.10119996964931488f;
  t166_n202: return 0.030258744955062866f;
  t166_n203: return 0.10822523385286331f;
  t166_n204: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t166_n208;
  t166_n205: if (E.getNumReferences() >= 3279519744 /*249.5*/) goto t166_n207;
  t166_n206: return 0.08520627021789551f;
  t166_n207: return -0.355392187833786f;
  t166_n208: return 0.11209701746702194f;
  t166_n209: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t166_n249;
  t166_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t166_n214;
  t166_n211: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t166_n213;
  t166_n212: return -0.06858737021684647f;
  t166_n213: return -0.021851185709238052f;
  t166_n214: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t166_n220;
  t166_n215: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t166_n217;
  t166_n216: return -0.026937320828437805f;
  t166_n217: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t166_n219;
  t166_n218: return -0.01580287143588066f;
  t166_n219: return 0.0278032124042511f;
  t166_n220: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t166_n242;
  t166_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t166_n241;
  t166_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t166_n226;
  t166_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t166_n225;
  t166_n224: return -0.09521282464265823f;
  t166_n225: return -0.24198418855667114f;
  t166_n226: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t166_n236;
  t166_n227: if (E.getNumReferences() >= 3257008128 /*40.5*/) goto t166_n235;
  t166_n228: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t166_n230;
  t166_n229: return -0.028844423592090607f;
  t166_n230: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t166_n234;
  t166_n231: if (E.getNumReferences() >= 3256090624 /*37.0*/) goto t166_n233;
  t166_n232: return 0.12220916897058487f;
  t166_n233: return 0.09175761044025421f;
  t166_n234: return -0.2142580896615982f;
  t166_n235: return -0.17651353776454926f;
  t166_n236: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t166_n238;
  t166_n237: return -0.00044208765029907227f;
  t166_n238: if (E.getNumReferences() >= 3265658880 /*83.0*/) goto t166_n240;
  t166_n239: return 0.10696009546518326f;
  t166_n240: return -0.037118688225746155f;
  t166_n241: return -0.019200734794139862f;
  t166_n242: if (E.getNumReferences() >= 3251634176 /*26.0*/) goto t166_n244;
  t166_n243: return -0.19925455749034882f;
  t166_n244: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t166_n248;
  t166_n245: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t166_n247;
  t166_n246: return 0.05786784365773201f;
  t166_n247: return 0.09871626645326614f;
  t166_n248: return -0.19606713950634003f;
  t166_n249: return 0.01232688594609499f;
  t166_n250: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t166_n252;
  t166_n251: return 0.007620596326887608f;
  t166_n252: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t166_n254;
  t166_n253: return 0.0005229103844612837f;
  t166_n254: return 0.01492831390351057f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree167(const Example& E) {
  t167_n0: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t167_n140;
  t167_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t167_n3;
  t167_n2: return -0.01731361821293831f;
  t167_n3: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t167_n139;
  t167_n4: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t167_n6;
  t167_n5: return -0.004017665516585112f;
  t167_n6: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t167_n72;
  t167_n7: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t167_n23;
  t167_n8: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t167_n22;
  t167_n9: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t167_n21;
  t167_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t167_n12;
  t167_n11: return -0.11495233327150345f;
  t167_n12: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t167_n14;
  t167_n13: return -0.03477218374609947f;
  t167_n14: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t167_n20;
  t167_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t167_n17;
  t167_n16: return 0.03045211173593998f;
  t167_n17: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t167_n19;
  t167_n18: return 0.15161176025867462f;
  t167_n19: return -0.16400612890720367f;
  t167_n20: return -0.11571458727121353f;
  t167_n21: return 0.09827826917171478f;
  t167_n22: return 0.03179502859711647f;
  t167_n23: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t167_n25;
  t167_n24: return 0.009754561819136143f;
  t167_n25: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t167_n43;
  t167_n26: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t167_n36;
  t167_n27: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t167_n35;
  t167_n28: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t167_n30;
  t167_n29: return 0.024232368916273117f;
  t167_n30: if (E.getNumReferences() >= 3271753728 /*131.0*/) goto t167_n32;
  t167_n31: return 0.08316969126462936f;
  t167_n32: if (E.getNumReferences() >= 3278766080 /*238.0*/) goto t167_n34;
  t167_n33: return 0.12243986129760742f;
  t167_n34: return 0.11380459368228912f;
  t167_n35: return -0.015327430330216885f;
  t167_n36: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t167_n42;
  t167_n37: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t167_n39;
  t167_n38: return 0.14212682843208313f;
  t167_n39: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t167_n41;
  t167_n40: return 0.036518123000860214f;
  t167_n41: return 0.10510057955980301f;
  t167_n42: return -0.1449078619480133f;
  t167_n43: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t167_n45;
  t167_n44: return 0.0006411854410544038f;
  t167_n45: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t167_n59;
  t167_n46: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t167_n56;
  t167_n47: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t167_n55;
  t167_n48: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t167_n54;
  t167_n49: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t167_n51;
  t167_n50: return 0.07861961424350739f;
  t167_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t167_n53;
  t167_n52: return 0.1107986643910408f;
  t167_n53: return 0.11630908399820328f;
  t167_n54: return -0.20949016511440277f;
  t167_n55: return 0.12156553566455841f;
  t167_n56: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t167_n58;
  t167_n57: return -0.13156843185424805f;
  t167_n58: return 0.14542941749095917f;
  t167_n59: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t167_n65;
  t167_n60: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t167_n62;
  t167_n61: return 0.12719812989234924f;
  t167_n62: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t167_n64;
  t167_n63: return -0.0017786158714443445f;
  t167_n64: return 0.09535789489746094f;
  t167_n65: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t167_n69;
  t167_n66: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t167_n68;
  t167_n67: return 0.16434264183044434f;
  t167_n68: return -0.08763578534126282f;
  t167_n69: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t167_n71;
  t167_n70: return 0.10250526666641235f;
  t167_n71: return 0.044459372758865356f;
  t167_n72: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t167_n136;
  t167_n73: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t167_n75;
  t167_n74: return 0.011665952391922474f;
  t167_n75: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t167_n123;
  t167_n76: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t167_n118;
  t167_n77: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t167_n111;
  t167_n78: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t167_n102;
  t167_n79: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t167_n101;
  t167_n80: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t167_n94;
  t167_n81: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t167_n87;
  t167_n82: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t167_n86;
  t167_n83: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t167_n85;
  t167_n84: return 0.06519754976034164f;
  t167_n85: return 0.056503135710954666f;
  t167_n86: return -0.0775432363152504f;
  t167_n87: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t167_n93;
  t167_n88: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t167_n92;
  t167_n89: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t167_n91;
  t167_n90: return 0.0014120611594989896f;
  t167_n91: return 0.12104490399360657f;
  t167_n92: return 0.11413145810365677f;
  t167_n93: return 0.26475438475608826f;
  t167_n94: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t167_n100;
  t167_n95: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t167_n99;
  t167_n96: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t167_n98;
  t167_n97: return -0.12278396636247635f;
  t167_n98: return 0.1135520190000534f;
  t167_n99: return 0.05093660578131676f;
  t167_n100: return -0.2167055755853653f;
  t167_n101: return 0.12269947677850723f;
  t167_n102: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t167_n104;
  t167_n103: return -0.005643406882882118f;
  t167_n104: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t167_n110;
  t167_n105: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t167_n107;
  t167_n106: return -0.07795283943414688f;
  t167_n107: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t167_n109;
  t167_n108: return 0.07377547770738602f;
  t167_n109: return 0.13399021327495575f;
  t167_n110: return 0.05953291431069374f;
  t167_n111: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t167_n113;
  t167_n112: return 0.1241844892501831f;
  t167_n113: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t167_n117;
  t167_n114: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t167_n116;
  t167_n115: return 0.14473801851272583f;
  t167_n116: return 0.04182086139917374f;
  t167_n117: return 0.10393523424863815f;
  t167_n118: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t167_n122;
  t167_n119: if (E.getNumReferences() >= 3324914176 /*11146.5*/) goto t167_n121;
  t167_n120: return -0.452038437128067f;
  t167_n121: return 0.10636299848556519f;
  t167_n122: return -0.01606440544128418f;
  t167_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t167_n135;
  t167_n124: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t167_n126;
  t167_n125: return 0.04912089928984642f;
  t167_n126: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t167_n130;
  t167_n127: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t167_n129;
  t167_n128: return -0.2038867324590683f;
  t167_n129: return 0.1228419616818428f;
  t167_n130: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t167_n134;
  t167_n131: if (E.getNumReferences() >= 3285483520 /*425.0*/) goto t167_n133;
  t167_n132: return 0.360183447599411f;
  t167_n133: return 0.10765651613473892f;
  t167_n134: return 0.062453627586364746f;
  t167_n135: return -0.06439634412527084f;
  t167_n136: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t167_n138;
  t167_n137: return -0.030147533863782883f;
  t167_n138: return 0.08036525547504425f;
  t167_n139: return 0.010343162342905998f;
  t167_n140: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t167_n254;
  t167_n141: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t167_n241;
  t167_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t167_n144;
  t167_n143: return 0.0012373740319162607f;
  t167_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t167_n164;
  t167_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t167_n147;
  t167_n146: return -0.10968296229839325f;
  t167_n147: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t167_n149;
  t167_n148: return 0.0034278465900570154f;
  t167_n149: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t167_n155;
  t167_n150: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t167_n154;
  t167_n151: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t167_n153;
  t167_n152: return 0.05393138900399208f;
  t167_n153: return -0.0015300634549930692f;
  t167_n154: return 0.0329853892326355f;
  t167_n155: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t167_n161;
  t167_n156: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t167_n160;
  t167_n157: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t167_n159;
  t167_n158: return -0.0559052973985672f;
  t167_n159: return 0.03819743171334267f;
  t167_n160: return 0.03884974867105484f;
  t167_n161: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t167_n163;
  t167_n162: return -0.029203834012150764f;
  t167_n163: return 0.04010125249624252f;
  t167_n164: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t167_n166;
  t167_n165: return 0.007744935341179371f;
  t167_n166: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t167_n168;
  t167_n167: return 0.008352930657565594f;
  t167_n168: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t167_n190;
  t167_n169: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t167_n189;
  t167_n170: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t167_n186;
  t167_n171: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t167_n173;
  t167_n172: return -0.062421850860118866f;
  t167_n173: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t167_n175;
  t167_n174: return -0.04491104185581207f;
  t167_n175: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t167_n185;
  t167_n176: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t167_n182;
  t167_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t167_n179;
  t167_n178: return -0.05111731216311455f;
  t167_n179: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t167_n181;
  t167_n180: return -0.3596497178077698f;
  t167_n181: return 0.10588054358959198f;
  t167_n182: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t167_n184;
  t167_n183: return 0.07548337429761887f;
  t167_n184: return 0.09466294944286346f;
  t167_n185: return -0.013570165261626244f;
  t167_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t167_n188;
  t167_n187: return -0.0336991585791111f;
  t167_n188: return 0.0291027519851923f;
  t167_n189: return 0.06961935758590698f;
  t167_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t167_n192;
  t167_n191: return -0.002079297322779894f;
  t167_n192: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t167_n240;
  t167_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t167_n239;
  t167_n194: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t167_n200;
  t167_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t167_n197;
  t167_n196: return 0.06449299305677414f;
  t167_n197: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t167_n199;
  t167_n198: return -0.12669797241687775f;
  t167_n199: return 0.0848488062620163f;
  t167_n200: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t167_n210;
  t167_n201: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t167_n209;
  t167_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t167_n204;
  t167_n203: return 0.05188394710421562f;
  t167_n204: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t167_n206;
  t167_n205: return 0.08466019481420517f;
  t167_n206: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t167_n208;
  t167_n207: return 0.09834721684455872f;
  t167_n208: return -0.1497783213853836f;
  t167_n209: return 0.0204024501144886f;
  t167_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t167_n222;
  t167_n211: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t167_n221;
  t167_n212: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t167_n216;
  t167_n213: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t167_n215;
  t167_n214: return 0.08385146409273148f;
  t167_n215: return -0.06416063010692596f;
  t167_n216: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t167_n220;
  t167_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t167_n219;
  t167_n218: return 0.1022339016199112f;
  t167_n219: return 0.10575056076049805f;
  t167_n220: return -0.05549641326069832f;
  t167_n221: return 0.07160607725381851f;
  t167_n222: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t167_n238;
  t167_n223: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t167_n233;
  t167_n224: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t167_n226;
  t167_n225: return 0.030912624672055244f;
  t167_n226: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t167_n232;
  t167_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t167_n229;
  t167_n228: return -0.11171264946460724f;
  t167_n229: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t167_n231;
  t167_n230: return 0.11457303911447525f;
  t167_n231: return -0.10007558763027191f;
  t167_n232: return 0.08946966379880905f;
  t167_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t167_n235;
  t167_n234: return -0.13837338984012604f;
  t167_n235: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t167_n237;
  t167_n236: return 0.11439261585474014f;
  t167_n237: return 0.12005655467510223f;
  t167_n238: return 0.1513637751340866f;
  t167_n239: return 0.021947365254163742f;
  t167_n240: return -0.10341797769069672f;
  t167_n241: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t167_n243;
  t167_n242: return -0.0315253846347332f;
  t167_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t167_n253;
  t167_n244: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t167_n246;
  t167_n245: return -0.0037527878303080797f;
  t167_n246: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t167_n252;
  t167_n247: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t167_n251;
  t167_n248: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t167_n250;
  t167_n249: return 0.04515055939555168f;
  t167_n250: return -0.019066888839006424f;
  t167_n251: return 0.009526156820356846f;
  t167_n252: return 0.04132305085659027f;
  t167_n253: return 0.009333179332315922f;
  t167_n254: return -0.0595644935965538f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree168(const Example& E) {
  t168_n0: if (E.getNumReferences() >= 3301019648 /*1548.5*/) goto t168_n2;
  t168_n1: return -0.00042821592069230974f;
  t168_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t168_n76;
  t168_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t168_n75;
  t168_n4: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t168_n6;
  t168_n5: return -0.008900318294763565f;
  t168_n6: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t168_n62;
  t168_n7: if (E.getNumReferences() >= 3325242368 /*11467.0*/) goto t168_n15;
  t168_n8: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t168_n10;
  t168_n9: return 0.07511236518621445f;
  t168_n10: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t168_n12;
  t168_n11: return -0.018852047622203827f;
  t168_n12: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t168_n14;
  t168_n13: return 0.11205390095710754f;
  t168_n14: return 0.12224394083023071f;
  t168_n15: if (E.getNumReferences() >= 3362860128 /*246961.5*/) goto t168_n53;
  t168_n16: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t168_n50;
  t168_n17: if (E.getNumReferences() >= 3339244032 /*35026.0*/) goto t168_n21;
  t168_n18: if (E.getNumReferences() >= 3332305408 /*20345.0*/) goto t168_n20;
  t168_n19: return 0.047662053257226944f;
  t168_n20: return -0.009794823825359344f;
  t168_n21: if (E.getNumReferences() >= 3342848512 /*49106.0*/) goto t168_n41;
  t168_n22: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t168_n32;
  t168_n23: if (E.getNumReferences() >= 3339443456 /*35805.0*/) goto t168_n29;
  t168_n24: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t168_n28;
  t168_n25: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t168_n27;
  t168_n26: return -0.1744695007801056f;
  t168_n27: return 0.10941547155380249f;
  t168_n28: return -0.4619182050228119f;
  t168_n29: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t168_n31;
  t168_n30: return -0.015808967873454094f;
  t168_n31: return 0.05410582199692726f;
  t168_n32: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t168_n36;
  t168_n33: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t168_n35;
  t168_n34: return 0.04558630287647247f;
  t168_n35: return 0.09394057840108871f;
  t168_n36: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t168_n40;
  t168_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t168_n39;
  t168_n38: return -0.13745594024658203f;
  t168_n39: return 0.1036667451262474f;
  t168_n40: return 0.060195621103048325f;
  t168_n41: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t168_n49;
  t168_n42: if (E.getNumReferences() >= 3362126976 /*235506.0*/) goto t168_n46;
  t168_n43: if (E.getNumReferences() >= 3347375936 /*68046.5*/) goto t168_n45;
  t168_n44: return 0.03089272603392601f;
  t168_n45: return -0.054993342608213425f;
  t168_n46: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t168_n48;
  t168_n47: return 0.047086089849472046f;
  t168_n48: return -0.12144618481397629f;
  t168_n49: return 0.025004493072628975f;
  t168_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t168_n52;
  t168_n51: return 0.01515953429043293f;
  t168_n52: return 0.08853618055582047f;
  t168_n53: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t168_n59;
  t168_n54: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t168_n58;
  t168_n55: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t168_n57;
  t168_n56: return 0.0f;
  t168_n57: return 0.0888710767030716f;
  t168_n58: return -0.11313435435295105f;
  t168_n59: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t168_n61;
  t168_n60: return -0.13022339344024658f;
  t168_n61: return -0.0015927581116557121f;
  t168_n62: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t168_n64;
  t168_n63: return 0.004319565370678902f;
  t168_n64: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t168_n66;
  t168_n65: return -0.03697730600833893f;
  t168_n66: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t168_n74;
  t168_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t168_n69;
  t168_n68: return -0.24613913893699646f;
  t168_n69: if (E.getNumReferences() >= 3338529536 /*32501.5*/) goto t168_n71;
  t168_n70: return -0.11830008774995804f;
  t168_n71: if (E.getNumReferences() >= 3345410816 /*59115.0*/) goto t168_n73;
  t168_n72: return 0.419765442609787f;
  t168_n73: return 0.054706476628780365f;
  t168_n74: return -0.5868790149688721f;
  t168_n75: return 0.021171920001506805f;
  t168_n76: if (E.getNumReferences() >= 3301031936 /*1550.0*/) goto t168_n82;
  t168_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t168_n79;
  t168_n78: return 0.05979115515947342f;
  t168_n79: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t168_n81;
  t168_n80: return -0.10025670379400253f;
  t168_n81: return 0.16526784002780914f;
  t168_n82: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t168_n84;
  t168_n83: return -0.0008764003869146109f;
  t168_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t168_n144;
  t168_n85: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t168_n101;
  t168_n86: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t168_n98;
  t168_n87: if (E.getNumReferences() >= 3331894528 /*19542.5*/) goto t168_n89;
  t168_n88: return -0.03630350902676582f;
  t168_n89: if (E.getNumReferences() >= 3333234688 /*22160.0*/) goto t168_n97;
  t168_n90: if (E.getNumReferences() >= 3333127936 /*21951.5*/) goto t168_n96;
  t168_n91: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t168_n95;
  t168_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t168_n94;
  t168_n93: return 0.13274185359477997f;
  t168_n94: return 0.1263469159603119f;
  t168_n95: return 0.08095669001340866f;
  t168_n96: return 0.11058309674263f;
  t168_n97: return 0.02631274238228798f;
  t168_n98: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t168_n100;
  t168_n99: return -0.1018514633178711f;
  t168_n100: return 0.01694960705935955f;
  t168_n101: if (E.getNumReferences() >= 3319645184 /*7096.5*/) goto t168_n143;
  t168_n102: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t168_n124;
  t168_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t168_n117;
  t168_n104: if (E.getNumReferences() >= 3318055936 /*6320.5*/) goto t168_n116;
  t168_n105: if (E.getNumReferences() >= 3317762048 /*6177.0*/) goto t168_n109;
  t168_n106: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t168_n108;
  t168_n107: return -0.011604161001741886f;
  t168_n108: return 0.05872621387243271f;
  t168_n109: if (E.getNumReferences() >= 3317976064 /*6281.5*/) goto t168_n113;
  t168_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t168_n112;
  t168_n111: return 0.11928705126047134f;
  t168_n112: return 0.14443339407444f;
  t168_n113: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t168_n115;
  t168_n114: return -0.2586263120174408f;
  t168_n115: return 0.12248887866735458f;
  t168_n116: return -0.17485187947750092f;
  t168_n117: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t168_n119;
  t168_n118: return -0.010136459954082966f;
  t168_n119: if (E.getNumReferences() >= 3303985152 /*1910.5*/) goto t168_n121;
  t168_n120: return 0.09178287535905838f;
  t168_n121: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t168_n123;
  t168_n122: return -0.07947573065757751f;
  t168_n123: return 0.09768825769424438f;
  t168_n124: if (E.getNumReferences() >= 3318811648 /*6689.5*/) goto t168_n132;
  t168_n125: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t168_n131;
  t168_n126: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t168_n128;
  t168_n127: return 0.0992313027381897f;
  t168_n128: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t168_n130;
  t168_n129: return 0.11417999863624573f;
  t168_n130: return 0.08836069703102112f;
  t168_n131: return -0.2537690997123718f;
  t168_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t168_n142;
  t168_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t168_n135;
  t168_n134: return -0.22629715502262115f;
  t168_n135: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t168_n137;
  t168_n136: return -0.11177241802215576f;
  t168_n137: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t168_n141;
  t168_n138: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t168_n140;
  t168_n139: return 0.156267449259758f;
  t168_n140: return 0.08189953118562698f;
  t168_n141: return 0.12381886690855026f;
  t168_n142: return -0.04141784831881523f;
  t168_n143: return 0.0075153508223593235f;
  t168_n144: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t168_n178;
  t168_n145: if (E.getNumReferences() >= 3351111424 /*97230.0*/) goto t168_n173;
  t168_n146: if (E.getNumReferences() >= 3310270464 /*3307.5*/) goto t168_n156;
  t168_n147: if (E.getNumReferences() >= 3309062144 /*3012.5*/) goto t168_n153;
  t168_n148: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t168_n150;
  t168_n149: return -0.28760671615600586f;
  t168_n150: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t168_n152;
  t168_n151: return 0.09872609376907349f;
  t168_n152: return 0.02224471978843212f;
  t168_n153: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t168_n155;
  t168_n154: return 0.11206661909818649f;
  t168_n155: return 0.10072321444749832f;
  t168_n156: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t168_n158;
  t168_n157: return -0.36273595690727234f;
  t168_n158: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t168_n172;
  t168_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t168_n161;
  t168_n160: return -0.03129902482032776f;
  t168_n161: if (E.getNumReferences() >= 3322163200 /*8460.0*/) goto t168_n163;
  t168_n162: return -0.12418938428163528f;
  t168_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t168_n167;
  t168_n164: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t168_n166;
  t168_n165: return 0.10093948245048523f;
  t168_n166: return -0.1377376914024353f;
  t168_n167: if (E.getNumReferences() >= 3328941056 /*15079.0*/) goto t168_n169;
  t168_n168: return 0.10744485259056091f;
  t168_n169: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t168_n171;
  t168_n170: return 0.10599585622549057f;
  t168_n171: return -0.08583353459835052f;
  t168_n172: return -0.22123268246650696f;
  t168_n173: if (E.getNumReferences() >= 3364974544 /*297854.5*/) goto t168_n177;
  t168_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t168_n176;
  t168_n175: return -0.003990662284195423f;
  t168_n176: return 0.11291659623384476f;
  t168_n177: return 0.009944423101842403f;
  t168_n178: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t168_n254;
  t168_n179: if (E.getNumReferences() >= 3359807328 /*199261.5*/) goto t168_n241;
  t168_n180: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t168_n182;
  t168_n181: return -0.023433450609445572f;
  t168_n182: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t168_n240;
  t168_n183: if (E.getNumReferences() >= 3309326336 /*3077.0*/) goto t168_n189;
  t168_n184: if (E.getNumReferences() >= 3304095744 /*1924.0*/) goto t168_n186;
  t168_n185: return -0.0020619460847228765f;
  t168_n186: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t168_n188;
  t168_n187: return -0.4578133225440979f;
  t168_n188: return -0.08519161492586136f;
  t168_n189: if (E.getNumReferences() >= 3310000128 /*3241.5*/) goto t168_n193;
  t168_n190: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t168_n192;
  t168_n191: return 0.110181525349617f;
  t168_n192: return -0.0005644728662446141f;
  t168_n193: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t168_n195;
  t168_n194: return -0.12173125147819519f;
  t168_n195: if (E.getNumReferences() >= 3320567808 /*7547.0*/) goto t168_n207;
  t168_n196: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t168_n204;
  t168_n197: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t168_n201;
  t168_n198: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t168_n200;
  t168_n199: return -0.32799896597862244f;
  t168_n200: return 0.0878758355975151f;
  t168_n201: if (E.getNumReferences() >= 3315718144 /*5179.0*/) goto t168_n203;
  t168_n202: return -0.0396004393696785f;
  t168_n203: return 0.10608009248971939f;
  t168_n204: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t168_n206;
  t168_n205: return 0.08858934789896011f;
  t168_n206: return -0.49200573563575745f;
  t168_n207: if (E.getNumReferences() >= 3322433024 /*8723.5*/) goto t168_n213;
  t168_n208: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t168_n212;
  t168_n209: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t168_n211;
  t168_n210: return 0.024583935737609863f;
  t168_n211: return 0.10238771885633469f;
  t168_n212: return 0.12676191329956055f;
  t168_n213: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t168_n227;
  t168_n214: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t168_n218;
  t168_n215: if (E.getNumReferences() >= 3323767808 /*10027.0*/) goto t168_n217;
  t168_n216: return 0.12608960270881653f;
  t168_n217: return -0.013140657916665077f;
  t168_n218: if (E.getNumReferences() >= 3323137024 /*9411.0*/) goto t168_n220;
  t168_n219: return 0.21156983077526093f;
  t168_n220: if (E.getNumReferences() >= 3324100096 /*10351.5*/) goto t168_n222;
  t168_n221: return -0.21692651510238647f;
  t168_n222: if (E.getNumReferences() >= 3324847616 /*11081.5*/) goto t168_n224;
  t168_n223: return 0.12419524043798447f;
  t168_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t168_n226;
  t168_n225: return 0.0365569181740284f;
  t168_n226: return 0.12315937131643295f;
  t168_n227: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t168_n237;
  t168_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t168_n230;
  t168_n229: return -0.456790030002594f;
  t168_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t168_n232;
  t168_n231: return 0.00909400638192892f;
  t168_n232: if (E.getNumReferences() >= 3326458880 /*12655.0*/) goto t168_n234;
  t168_n233: return 0.0725005716085434f;
  t168_n234: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t168_n236;
  t168_n235: return 0.11772077530622482f;
  t168_n236: return 0.09536238759756088f;
  t168_n237: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t168_n239;
  t168_n238: return 0.09837590903043747f;
  t168_n239: return 0.06744208186864853f;
  t168_n240: return 0.015186401084065437f;
  t168_n241: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t168_n253;
  t168_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t168_n244;
  t168_n243: return -0.11275064200162888f;
  t168_n244: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t168_n250;
  t168_n245: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t168_n249;
  t168_n246: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t168_n248;
  t168_n247: return -0.13504257798194885f;
  t168_n248: return 0.10021056979894638f;
  t168_n249: return 0.08625992387533188f;
  t168_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t168_n252;
  t168_n251: return 0.08278429508209229f;
  t168_n252: return 0.11248033493757248f;
  t168_n253: return 0.013491182588040829f;
  t168_n254: return -0.011744585819542408f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree169(const Example& E) {
  t169_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t169_n102;
  t169_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t169_n3;
  t169_n2: return -0.10826964676380157f;
  t169_n3: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t169_n83;
  t169_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t169_n6;
  t169_n5: return 0.0016324652824550867f;
  t169_n6: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t169_n50;
  t169_n7: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t169_n15;
  t169_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t169_n14;
  t169_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t169_n11;
  t169_n10: return 0.012342794798314571f;
  t169_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t169_n13;
  t169_n12: return -0.05109015852212906f;
  t169_n13: return -0.020928962156176567f;
  t169_n14: return 0.004695481155067682f;
  t169_n15: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t169_n17;
  t169_n16: return -0.03353520855307579f;
  t169_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n19;
  t169_n18: return 0.028499925509095192f;
  t169_n19: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t169_n29;
  t169_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t169_n26;
  t169_n21: if (E.getNumReferences() >= 3288825856 /*542.0*/) goto t169_n23;
  t169_n22: return -0.02724814973771572f;
  t169_n23: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t169_n25;
  t169_n24: return 0.036706626415252686f;
  t169_n25: return 0.09602746367454529f;
  t169_n26: if (E.getNumReferences() >= 3281731584 /*310.5*/) goto t169_n28;
  t169_n27: return 0.09848051518201828f;
  t169_n28: return -0.353045254945755f;
  t169_n29: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t169_n49;
  t169_n30: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t169_n36;
  t169_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t169_n33;
  t169_n32: return 0.03850877657532692f;
  t169_n33: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t169_n35;
  t169_n34: return 0.11596714705228806f;
  t169_n35: return -0.0388321653008461f;
  t169_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t169_n44;
  t169_n37: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t169_n39;
  t169_n38: return -0.051740024238824844f;
  t169_n39: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t169_n43;
  t169_n40: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t169_n42;
  t169_n41: return 0.1412803828716278f;
  t169_n42: return -0.28366467356681824f;
  t169_n43: return -0.5043507218360901f;
  t169_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t169_n46;
  t169_n45: return -0.11412868648767471f;
  t169_n46: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t169_n48;
  t169_n47: return 0.10858672857284546f;
  t169_n48: return 0.11061164736747742f;
  t169_n49: return -0.03216706961393356f;
  t169_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t169_n58;
  t169_n51: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t169_n53;
  t169_n52: return -0.007189216557890177f;
  t169_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t169_n55;
  t169_n54: return -0.006059628911316395f;
  t169_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t169_n57;
  t169_n56: return 0.01648963987827301f;
  t169_n57: return 0.036748722195625305f;
  t169_n58: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t169_n66;
  t169_n59: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t169_n65;
  t169_n60: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t169_n62;
  t169_n61: return 0.0393209308385849f;
  t169_n62: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t169_n64;
  t169_n63: return -0.10210158675909042f;
  t169_n64: return 0.10687302052974701f;
  t169_n65: return 0.010637683793902397f;
  t169_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t169_n72;
  t169_n67: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t169_n69;
  t169_n68: return 0.029916971921920776f;
  t169_n69: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n71;
  t169_n70: return 0.0669500082731247f;
  t169_n71: return 0.005395282059907913f;
  t169_n72: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t169_n76;
  t169_n73: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t169_n75;
  t169_n74: return 0.05354776233434677f;
  t169_n75: return 0.09245216101408005f;
  t169_n76: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t169_n82;
  t169_n77: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t169_n79;
  t169_n78: return 0.11729738116264343f;
  t169_n79: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t169_n81;
  t169_n80: return 0.07112911343574524f;
  t169_n81: return 0.11679252237081528f;
  t169_n82: return 0.06758453696966171f;
  t169_n83: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t169_n89;
  t169_n84: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t169_n88;
  t169_n85: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t169_n87;
  t169_n86: return -0.11149334907531738f;
  t169_n87: return -0.20288318395614624f;
  t169_n88: return -0.08435622602701187f;
  t169_n89: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t169_n101;
  t169_n90: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t169_n98;
  t169_n91: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t169_n95;
  t169_n92: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t169_n94;
  t169_n93: return 0.015731364488601685f;
  t169_n94: return -1.6316407918930054f;
  t169_n95: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n97;
  t169_n96: return 0.0865081176161766f;
  t169_n97: return 0.011937323957681656f;
  t169_n98: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t169_n100;
  t169_n99: return 0.08924318850040436f;
  t169_n100: return 0.07870595902204514f;
  t169_n101: return -0.1044497862458229f;
  t169_n102: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t169_n240;
  t169_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t169_n227;
  t169_n104: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t169_n142;
  t169_n105: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t169_n115;
  t169_n106: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t169_n112;
  t169_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t169_n109;
  t169_n108: return -0.18622277677059174f;
  t169_n109: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t169_n111;
  t169_n110: return 0.11985214054584503f;
  t169_n111: return 0.12249067425727844f;
  t169_n112: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t169_n114;
  t169_n113: return -0.04419560357928276f;
  t169_n114: return 0.05206736922264099f;
  t169_n115: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t169_n129;
  t169_n116: if (E.getNumReferences() >= 3342417536 /*47422.5*/) goto t169_n118;
  t169_n117: return -0.08017653971910477f;
  t169_n118: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t169_n126;
  t169_n119: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t169_n125;
  t169_n120: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t169_n124;
  t169_n121: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t169_n123;
  t169_n122: return 0.037374939769506454f;
  t169_n123: return 0.11850730329751968f;
  t169_n124: return 0.09878960996866226f;
  t169_n125: return -0.1290939301252365f;
  t169_n126: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t169_n128;
  t169_n127: return 0.10345248132944107f;
  t169_n128: return -0.12724235653877258f;
  t169_n129: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t169_n141;
  t169_n130: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t169_n134;
  t169_n131: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n133;
  t169_n132: return 0.08833277225494385f;
  t169_n133: return 0.07041828334331512f;
  t169_n134: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t169_n140;
  t169_n135: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t169_n139;
  t169_n136: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n138;
  t169_n137: return 0.09311568737030029f;
  t169_n138: return 0.04234400764107704f;
  t169_n139: return 0.030671533197164536f;
  t169_n140: return 0.10824736952781677f;
  t169_n141: return 0.11703091859817505f;
  t169_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t169_n206;
  t169_n143: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t169_n145;
  t169_n144: return 0.0011298932367935777f;
  t169_n145: if (E.getNumReferences() >= 3346697088 /*64139.5*/) goto t169_n177;
  t169_n146: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t169_n162;
  t169_n147: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t169_n149;
  t169_n148: return 0.10256428271532059f;
  t169_n149: if (E.getNumReferences() >= 3344974336 /*57410.0*/) goto t169_n151;
  t169_n150: return -0.14248675107955933f;
  t169_n151: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t169_n155;
  t169_n152: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t169_n154;
  t169_n153: return 0.1108631044626236f;
  t169_n154: return 0.09085296839475632f;
  t169_n155: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t169_n157;
  t169_n156: return 0.0726114958524704f;
  t169_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n159;
  t169_n158: return -0.4123569130897522f;
  t169_n159: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t169_n161;
  t169_n160: return 0.07214666903018951f;
  t169_n161: return -0.5373157858848572f;
  t169_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t169_n170;
  t169_n163: if (E.getNumReferences() >= 3344562560 /*55801.5*/) goto t169_n167;
  t169_n164: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t169_n166;
  t169_n165: return 0.0f;
  t169_n166: return 0.1161576509475708f;
  t169_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t169_n169;
  t169_n168: return -1.0026590824127197f;
  t169_n169: return -0.03007247857749462f;
  t169_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t169_n176;
  t169_n171: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t169_n175;
  t169_n172: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n174;
  t169_n173: return 0.09354698657989502f;
  t169_n174: return 0.12917102873325348f;
  t169_n175: return 0.10793226957321167f;
  t169_n176: return 0.13961675763130188f;
  t169_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t169_n199;
  t169_n178: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n198;
  t169_n179: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t169_n191;
  t169_n180: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t169_n190;
  t169_n181: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t169_n183;
  t169_n182: return 0.08706644177436829f;
  t169_n183: if (E.getNumReferences() >= 3350349056 /*91274.0*/) goto t169_n189;
  t169_n184: if (E.getNumReferences() >= 3350097472 /*89308.5*/) goto t169_n186;
  t169_n185: return -0.15928514301776886f;
  t169_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t169_n188;
  t169_n187: return -1.339017629623413f;
  t169_n188: return -0.19773127138614655f;
  t169_n189: return -0.06207078695297241f;
  t169_n190: return 0.0994798019528389f;
  t169_n191: if (E.getNumReferences() >= 3350460992 /*92148.5*/) goto t169_n197;
  t169_n192: if (E.getNumReferences() >= 3349481088 /*84493.0*/) goto t169_n194;
  t169_n193: return -0.33176189661026f;
  t169_n194: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t169_n196;
  t169_n195: return 0.10573632270097733f;
  t169_n196: return 0.09958138316869736f;
  t169_n197: return -0.0025724219158291817f;
  t169_n198: return 0.021760890260338783f;
  t169_n199: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t169_n201;
  t169_n200: return -0.5708135366439819f;
  t169_n201: if (E.getNumReferences() >= 3366869888 /*357084.0*/) goto t169_n203;
  t169_n202: return 0.05674722418189049f;
  t169_n203: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t169_n205;
  t169_n204: return 0.12890005111694336f;
  t169_n205: return -0.026201358065009117f;
  t169_n206: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t169_n208;
  t169_n207: return -0.005846128799021244f;
  t169_n208: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t169_n226;
  t169_n209: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t169_n225;
  t169_n210: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t169_n224;
  t169_n211: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t169_n221;
  t169_n212: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t169_n214;
  t169_n213: return 0.10252529382705688f;
  t169_n214: if (E.getNumReferences() >= 3352190016 /*105656.5*/) goto t169_n216;
  t169_n215: return 0.0f;
  t169_n216: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t169_n218;
  t169_n217: return 0.12185724079608917f;
  t169_n218: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t169_n220;
  t169_n219: return 0.11813091486692429f;
  t169_n220: return 0.11586550623178482f;
  t169_n221: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n223;
  t169_n222: return 0.0882735624909401f;
  t169_n223: return 0.07635706663131714f;
  t169_n224: return 0.012672771699726582f;
  t169_n225: return 0.02870822139084339f;
  t169_n226: return 0.006998536642640829f;
  t169_n227: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t169_n235;
  t169_n228: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t169_n230;
  t169_n229: return -0.011194456368684769f;
  t169_n230: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t169_n234;
  t169_n231: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n233;
  t169_n232: return 0.10153960436582565f;
  t169_n233: return 0.11582732945680618f;
  t169_n234: return 0.029148252680897713f;
  t169_n235: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t169_n239;
  t169_n236: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t169_n238;
  t169_n237: return 0.03660909831523895f;
  t169_n238: return 0.11172571778297424f;
  t169_n239: return -0.10430265963077545f;
  t169_n240: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t169_n254;
  t169_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t169_n243;
  t169_n242: return -0.0031387328635901213f;
  t169_n243: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t169_n253;
  t169_n244: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t169_n252;
  t169_n245: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t169_n251;
  t169_n246: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t169_n248;
  t169_n247: return 0.07927939295768738f;
  t169_n248: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t169_n250;
  t169_n249: return 0.09105941653251648f;
  t169_n250: return 0.06189655140042305f;
  t169_n251: return 0.11682170629501343f;
  t169_n252: return -0.23750607669353485f;
  t169_n253: return 0.11576737463474274f;
  t169_n254: return 0.0031968236435204744f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree170(const Example& E) {
  t170_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t170_n2;
  t170_n1: return -0.00042195606511086226f;
  t170_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t170_n48;
  t170_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t170_n7;
  t170_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t170_n6;
  t170_n5: return -0.03851437568664551f;
  t170_n6: return -0.27344807982444763f;
  t170_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t170_n47;
  t170_n8: if (E.getNumReferences() >= 3298402304 /*1229.0*/) goto t170_n14;
  t170_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t170_n11;
  t170_n10: return -0.006162066012620926f;
  t170_n11: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t170_n13;
  t170_n12: return 0.11860248446464539f;
  t170_n13: return 0.2691657841205597f;
  t170_n14: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t170_n18;
  t170_n15: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t170_n17;
  t170_n16: return -0.007081388961523771f;
  t170_n17: return 0.0640927329659462f;
  t170_n18: if (E.getNumReferences() >= 3325406720 /*11627.5*/) goto t170_n36;
  t170_n19: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t170_n21;
  t170_n20: return 0.059664372354745865f;
  t170_n21: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t170_n27;
  t170_n22: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t170_n26;
  t170_n23: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t170_n25;
  t170_n24: return -0.10242967307567596f;
  t170_n25: return 0.125668004155159f;
  t170_n26: return 0.054407548159360886f;
  t170_n27: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t170_n35;
  t170_n28: if (E.getNumReferences() >= 3325212160 /*11437.5*/) goto t170_n32;
  t170_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t170_n31;
  t170_n30: return 0.11942022293806076f;
  t170_n31: return 0.07201504707336426f;
  t170_n32: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t170_n34;
  t170_n33: return 0.11547777056694031f;
  t170_n34: return -0.14027822017669678f;
  t170_n35: return -0.1428690403699875f;
  t170_n36: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t170_n38;
  t170_n37: return 0.014748482033610344f;
  t170_n38: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t170_n40;
  t170_n39: return -0.008167708292603493f;
  t170_n40: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t170_n46;
  t170_n41: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t170_n43;
  t170_n42: return 0.08766001462936401f;
  t170_n43: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t170_n45;
  t170_n44: return 0.017192553728818893f;
  t170_n45: return 0.0629882737994194f;
  t170_n46: return -0.03218185901641846f;
  t170_n47: return 0.020519327372312546f;
  t170_n48: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t170_n50;
  t170_n49: return -0.0008257136796601117f;
  t170_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t170_n130;
  t170_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t170_n59;
  t170_n52: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t170_n54;
  t170_n53: return 0.0055969152599573135f;
  t170_n54: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t170_n58;
  t170_n55: if (E.getNumReferences() >= 3300810752 /*1523.0*/) goto t170_n57;
  t170_n56: return 0.4993419945240021f;
  t170_n57: return -0.08928769081830978f;
  t170_n58: return 0.015766194090247154f;
  t170_n59: if (E.getNumReferences() >= 3329258496 /*15389.0*/) goto t170_n125;
  t170_n60: if (E.getNumReferences() >= 3329011200 /*15147.5*/) goto t170_n122;
  t170_n61: if (E.getNumReferences() >= 3316514816 /*5568.0*/) goto t170_n69;
  t170_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t170_n64;
  t170_n63: return 0.004004596266895533f;
  t170_n64: if (E.getNumReferences() >= 3308197888 /*2801.5*/) goto t170_n68;
  t170_n65: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t170_n67;
  t170_n66: return 0.08242220431566238f;
  t170_n67: return 0.027173152193427086f;
  t170_n68: return -0.10161072760820389f;
  t170_n69: if (E.getNumReferences() >= 3319526400 /*7038.5*/) goto t170_n99;
  t170_n70: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t170_n88;
  t170_n71: if (E.getNumReferences() >= 3318019072 /*6302.5*/) goto t170_n87;
  t170_n72: if (E.getNumReferences() >= 3317762048 /*6177.0*/) goto t170_n82;
  t170_n73: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t170_n75;
  t170_n74: return -0.3841574788093567f;
  t170_n75: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t170_n81;
  t170_n76: if (E.getNumReferences() >= 3316544512 /*5582.5*/) goto t170_n78;
  t170_n77: return 0.12342137843370438f;
  t170_n78: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t170_n80;
  t170_n79: return 0.09860433638095856f;
  t170_n80: return -0.02970573492348194f;
  t170_n81: return 0.027932848781347275f;
  t170_n82: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t170_n86;
  t170_n83: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t170_n85;
  t170_n84: return 0.1278751939535141f;
  t170_n85: return 0.1379217803478241f;
  t170_n86: return 0.09374995529651642f;
  t170_n87: return -0.09849909693002701f;
  t170_n88: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t170_n96;
  t170_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t170_n91;
  t170_n90: return 0.0926036536693573f;
  t170_n91: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t170_n93;
  t170_n92: return 0.11108825355768204f;
  t170_n93: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t170_n95;
  t170_n94: return 0.12863479554653168f;
  t170_n95: return -0.3721252679824829f;
  t170_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t170_n98;
  t170_n97: return 0.01408098079264164f;
  t170_n98: return 0.1207791268825531f;
  t170_n99: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t170_n109;
  t170_n100: if (E.getNumReferences() >= 3324609024 /*10848.5*/) goto t170_n102;
  t170_n101: return -0.10813019424676895f;
  t170_n102: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t170_n108;
  t170_n103: if (E.getNumReferences() >= 3325290496 /*11514.0*/) goto t170_n107;
  t170_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t170_n106;
  t170_n105: return 0.0534478984773159f;
  t170_n106: return 0.11661145091056824f;
  t170_n107: return 0.02796105109155178f;
  t170_n108: return -0.06191421300172806f;
  t170_n109: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t170_n111;
  t170_n110: return 0.1343103051185608f;
  t170_n111: if (E.getNumReferences() >= 3323105792 /*9380.5*/) goto t170_n119;
  t170_n112: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t170_n114;
  t170_n113: return 0.008043241687119007f;
  t170_n114: if (E.getNumReferences() >= 3322166272 /*8463.0*/) goto t170_n116;
  t170_n115: return 0.12284234166145325f;
  t170_n116: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t170_n118;
  t170_n117: return 0.04608540236949921f;
  t170_n118: return 0.11061551421880722f;
  t170_n119: if (E.getNumReferences() >= 3328340480 /*14492.5*/) goto t170_n121;
  t170_n120: return -0.0109843909740448f;
  t170_n121: return 0.2626827359199524f;
  t170_n122: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t170_n124;
  t170_n123: return -0.47266438603401184f;
  t170_n124: return 0.10875902324914932f;
  t170_n125: if (E.getNumReferences() >= 3330075136 /*16186.5*/) goto t170_n129;
  t170_n126: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t170_n128;
  t170_n127: return -0.17053577303886414f;
  t170_n128: return 0.11422690749168396f;
  t170_n129: return 0.007990623824298382f;
  t170_n130: if (E.getNumReferences() >= 3298828288 /*1281.0*/) goto t170_n134;
  t170_n131: if (E.getNumReferences() >= 3298672640 /*1262.0*/) goto t170_n133;
  t170_n132: return -0.007321703247725964f;
  t170_n133: return 0.11337955296039581f;
  t170_n134: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t170_n254;
  t170_n135: if (E.getNumReferences() >= 3359807328 /*199261.5*/) goto t170_n237;
  t170_n136: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t170_n148;
  t170_n137: if (E.getNumReferences() >= 3335927040 /*27418.5*/) goto t170_n145;
  t170_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t170_n144;
  t170_n139: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t170_n141;
  t170_n140: return -0.10918290913105011f;
  t170_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t170_n143;
  t170_n142: return 0.06978033483028412f;
  t170_n143: return -0.1828291118144989f;
  t170_n144: return -0.5915963053703308f;
  t170_n145: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t170_n147;
  t170_n146: return -0.006122308317571878f;
  t170_n147: return 0.09775163233280182f;
  t170_n148: if (E.getNumReferences() >= 3310143488 /*3276.5*/) goto t170_n170;
  t170_n149: if (E.getNumReferences() >= 3309791232 /*3190.5*/) goto t170_n169;
  t170_n150: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t170_n166;
  t170_n151: if (E.getNumReferences() >= 3299901440 /*1412.0*/) goto t170_n155;
  t170_n152: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t170_n154;
  t170_n153: return 0.13165409862995148f;
  t170_n154: return 0.013968360610306263f;
  t170_n155: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t170_n157;
  t170_n156: return -0.14003242552280426f;
  t170_n157: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t170_n165;
  t170_n158: if (E.getNumReferences() >= 3307579392 /*2650.5*/) goto t170_n164;
  t170_n159: if (E.getNumReferences() >= 3301048320 /*1552.0*/) goto t170_n161;
  t170_n160: return 0.08948439359664917f;
  t170_n161: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t170_n163;
  t170_n162: return -0.4852878749370575f;
  t170_n163: return 0.09222908318042755f;
  t170_n164: return 0.09080558270215988f;
  t170_n165: return -0.10070933401584625f;
  t170_n166: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t170_n168;
  t170_n167: return 0.10734126716852188f;
  t170_n168: return 0.054252319037914276f;
  t170_n169: return 0.11573760211467743f;
  t170_n170: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t170_n182;
  t170_n171: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t170_n175;
  t170_n172: if (E.getNumReferences() >= 3318062080 /*6323.5*/) goto t170_n174;
  t170_n173: return 0.11701828241348267f;
  t170_n174: return -0.045857418328523636f;
  t170_n175: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t170_n177;
  t170_n176: return 0.016751401126384735f;
  t170_n177: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t170_n179;
  t170_n178: return 0.10423695296049118f;
  t170_n179: if (E.getNumReferences() >= 3353810176 /*118314.0*/) goto t170_n181;
  t170_n180: return 0.09298044443130493f;
  t170_n181: return -0.3870544731616974f;
  t170_n182: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t170_n236;
  t170_n183: if (E.getNumReferences() >= 3320567808 /*7547.0*/) goto t170_n199;
  t170_n184: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t170_n192;
  t170_n185: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t170_n191;
  t170_n186: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t170_n190;
  t170_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t170_n189;
  t170_n188: return -0.2293570637702942f;
  t170_n189: return 0.13132257759571075f;
  t170_n190: return 0.07646144926548004f;
  t170_n191: return 0.08768144994974136f;
  t170_n192: if (E.getNumReferences() >= 3315718144 /*5179.0*/) goto t170_n196;
  t170_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t170_n195;
  t170_n194: return -0.34772634506225586f;
  t170_n195: return 0.07057030498981476f;
  t170_n196: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t170_n198;
  t170_n197: return -0.33211246132850647f;
  t170_n198: return 0.11690125614404678f;
  t170_n199: if (E.getNumReferences() >= 3322577408 /*8864.5*/) goto t170_n209;
  t170_n200: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t170_n208;
  t170_n201: if (E.getNumReferences() >= 3322246144 /*8541.0*/) goto t170_n205;
  t170_n202: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t170_n204;
  t170_n203: return -0.10463829338550568f;
  t170_n204: return 0.10545933246612549f;
  t170_n205: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t170_n207;
  t170_n206: return 0.11930481344461441f;
  t170_n207: return 0.19068880379199982f;
  t170_n208: return 0.04892431199550629f;
  t170_n209: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t170_n231;
  t170_n210: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t170_n222;
  t170_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t170_n219;
  t170_n212: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t170_n214;
  t170_n213: return -0.1986933946609497f;
  t170_n214: if (E.getNumReferences() >= 3324083200 /*10335.0*/) goto t170_n216;
  t170_n215: return -0.13755103945732117f;
  t170_n216: if (E.getNumReferences() >= 3324847616 /*11081.5*/) goto t170_n218;
  t170_n217: return 0.11455902457237244f;
  t170_n218: return 0.07960418611764908f;
  t170_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t170_n221;
  t170_n220: return 0.11762493848800659f;
  t170_n221: return 0.06665255129337311f;
  t170_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t170_n224;
  t170_n223: return -0.32626086473464966f;
  t170_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t170_n226;
  t170_n225: return 0.017655562609434128f;
  t170_n226: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t170_n228;
  t170_n227: return 0.10972487926483154f;
  t170_n228: if (E.getNumReferences() >= 3328272384 /*14426.0*/) goto t170_n230;
  t170_n229: return -0.09741710871458054f;
  t170_n230: return 0.10967276990413666f;
  t170_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t170_n233;
  t170_n232: return 0.1492459923028946f;
  t170_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t170_n235;
  t170_n234: return -0.04582453891634941f;
  t170_n235: return 0.09323175996541977f;
  t170_n236: return 0.016122203320264816f;
  t170_n237: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t170_n241;
  t170_n238: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t170_n240;
  t170_n239: return -0.4644733667373657f;
  t170_n240: return 0.10989998281002045f;
  t170_n241: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t170_n253;
  t170_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t170_n244;
  t170_n243: return -0.11168895661830902f;
  t170_n244: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t170_n250;
  t170_n245: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t170_n249;
  t170_n246: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t170_n248;
  t170_n247: return -0.10935313999652863f;
  t170_n248: return 0.08857351541519165f;
  t170_n249: return 0.01177476067095995f;
  t170_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t170_n252;
  t170_n251: return 0.07602708786725998f;
  t170_n252: return 0.11028194427490234f;
  t170_n253: return 0.011301929131150246f;
  t170_n254: return -0.008704951964318752f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree171(const Example& E) {
  t171_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t171_n2;
  t171_n1: return -0.0004324068140704185f;
  t171_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t171_n44;
  t171_n3: if (E.getNumReferences() >= 3298328576 /*1220.0*/) goto t171_n7;
  t171_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t171_n6;
  t171_n5: return 0.010432755574584007f;
  t171_n6: return 0.13788878917694092f;
  t171_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t171_n15;
  t171_n8: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t171_n12;
  t171_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t171_n11;
  t171_n10: return -0.044229377061128616f;
  t171_n11: return -0.15687480568885803f;
  t171_n12: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t171_n14;
  t171_n13: return 0.10977301001548767f;
  t171_n14: return -0.28740614652633667f;
  t171_n15: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t171_n17;
  t171_n16: return 0.00865729060024023f;
  t171_n17: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t171_n43;
  t171_n18: if (E.getNumReferences() >= 3318441984 /*6509.0*/) goto t171_n20;
  t171_n19: return 0.0155702019110322f;
  t171_n20: if (E.getNumReferences() >= 3323142656 /*9416.5*/) goto t171_n42;
  t171_n21: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t171_n27;
  t171_n22: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t171_n26;
  t171_n23: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t171_n25;
  t171_n24: return 0.10661926865577698f;
  t171_n25: return 0.21894051134586334f;
  t171_n26: return 0.06546502560377121f;
  t171_n27: if (E.getNumReferences() >= 3319041024 /*6801.5*/) goto t171_n29;
  t171_n28: return -0.07669851928949356f;
  t171_n29: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t171_n31;
  t171_n30: return 0.10202479362487793f;
  t171_n31: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n37;
  t171_n32: if (E.getNumReferences() >= 3319356416 /*6955.5*/) goto t171_n34;
  t171_n33: return -0.13919131457805634f;
  t171_n34: if (E.getNumReferences() >= 3320364032 /*7447.5*/) goto t171_n36;
  t171_n35: return 0.14488574862480164f;
  t171_n36: return 0.12353023141622543f;
  t171_n37: if (E.getNumReferences() >= 3322502656 /*8791.5*/) goto t171_n41;
  t171_n38: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t171_n40;
  t171_n39: return 0.053836554288864136f;
  t171_n40: return 0.11348212510347366f;
  t171_n41: return 0.1142587810754776f;
  t171_n42: return 0.030808184295892715f;
  t171_n43: return 0.0182010717689991f;
  t171_n44: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t171_n46;
  t171_n45: return -0.0004321168817114085f;
  t171_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t171_n152;
  t171_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t171_n57;
  t171_n48: if (E.getNumReferences() >= 3331681536 /*19126.5*/) goto t171_n50;
  t171_n49: return -0.03098749928176403f;
  t171_n50: if (E.getNumReferences() >= 3332416512 /*20562.0*/) goto t171_n56;
  t171_n51: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t171_n55;
  t171_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t171_n54;
  t171_n53: return 0.22298505902290344f;
  t171_n54: return 0.12623336911201477f;
  t171_n55: return 0.05572693794965744f;
  t171_n56: return 0.01754256710410118f;
  t171_n57: if (E.getNumReferences() >= 3329258496 /*15389.0*/) goto t171_n143;
  t171_n58: if (E.getNumReferences() >= 3329011200 /*15147.5*/) goto t171_n134;
  t171_n59: if (E.getNumReferences() >= 3316514816 /*5568.0*/) goto t171_n69;
  t171_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t171_n62;
  t171_n61: return 0.0035999994724988937f;
  t171_n62: if (E.getNumReferences() >= 3308197888 /*2801.5*/) goto t171_n68;
  t171_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t171_n67;
  t171_n64: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t171_n66;
  t171_n65: return -0.15359866619110107f;
  t171_n66: return 0.06437664479017258f;
  t171_n67: return 0.10431721806526184f;
  t171_n68: return -0.06340841948986053f;
  t171_n69: if (E.getNumReferences() >= 3319526400 /*7038.5*/) goto t171_n97;
  t171_n70: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t171_n86;
  t171_n71: if (E.getNumReferences() >= 3318019072 /*6302.5*/) goto t171_n85;
  t171_n72: if (E.getNumReferences() >= 3317762048 /*6177.0*/) goto t171_n80;
  t171_n73: if (E.getNumReferences() >= 3317071872 /*5840.0*/) goto t171_n79;
  t171_n74: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t171_n78;
  t171_n75: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t171_n77;
  t171_n76: return -0.017926031723618507f;
  t171_n77: return 0.11415122449398041f;
  t171_n78: return 0.07736137509346008f;
  t171_n79: return -0.12434811145067215f;
  t171_n80: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t171_n84;
  t171_n81: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t171_n83;
  t171_n82: return 0.1212383508682251f;
  t171_n83: return 0.13722360134124756f;
  t171_n84: return 0.09033427387475967f;
  t171_n85: return -0.07761339098215103f;
  t171_n86: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t171_n94;
  t171_n87: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t171_n89;
  t171_n88: return 0.08991661667823792f;
  t171_n89: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t171_n91;
  t171_n90: return 0.11044429987668991f;
  t171_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t171_n93;
  t171_n92: return 0.12789957225322723f;
  t171_n93: return -0.23517397046089172f;
  t171_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t171_n96;
  t171_n95: return 0.012713182717561722f;
  t171_n96: return 0.11828591674566269f;
  t171_n97: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t171_n111;
  t171_n98: if (E.getNumReferences() >= 3324609024 /*10848.5*/) goto t171_n100;
  t171_n99: return -0.08801257610321045f;
  t171_n100: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t171_n106;
  t171_n101: if (E.getNumReferences() >= 3325290496 /*11514.0*/) goto t171_n105;
  t171_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t171_n104;
  t171_n103: return 0.07089252024888992f;
  t171_n104: return 0.11591194570064545f;
  t171_n105: return 0.028243685141205788f;
  t171_n106: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t171_n108;
  t171_n107: return -0.1275799721479416f;
  t171_n108: if (E.getNumReferences() >= 3326428672 /*12625.5*/) goto t171_n110;
  t171_n109: return 0.1317007690668106f;
  t171_n110: return -0.15186850726604462f;
  t171_n111: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t171_n113;
  t171_n112: return -0.051854945719242096f;
  t171_n113: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t171_n119;
  t171_n114: if (E.getNumReferences() >= 3326753280 /*12942.5*/) goto t171_n116;
  t171_n115: return -0.0849306508898735f;
  t171_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n118;
  t171_n117: return 0.15868628025054932f;
  t171_n118: return 0.09332545846700668f;
  t171_n119: if (E.getNumReferences() >= 3323087360 /*9362.5*/) goto t171_n127;
  t171_n120: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t171_n122;
  t171_n121: return 0.036398403346538544f;
  t171_n122: if (E.getNumReferences() >= 3322166272 /*8463.0*/) goto t171_n124;
  t171_n123: return 0.12007655948400497f;
  t171_n124: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t171_n126;
  t171_n125: return 0.1130535900592804f;
  t171_n126: return 0.10750889778137207f;
  t171_n127: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t171_n133;
  t171_n128: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t171_n130;
  t171_n129: return -0.2381414771080017f;
  t171_n130: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t171_n132;
  t171_n131: return 0.11420410871505737f;
  t171_n132: return -0.13663876056671143f;
  t171_n133: return 0.0805388018488884f;
  t171_n134: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t171_n136;
  t171_n135: return -0.42250627279281616f;
  t171_n136: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t171_n142;
  t171_n137: if (E.getNumReferences() >= 3329118720 /*15252.5*/) goto t171_n139;
  t171_n138: return 0.0552336685359478f;
  t171_n139: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n141;
  t171_n140: return 0.10243038088083267f;
  t171_n141: return 0.13531288504600525f;
  t171_n142: return 0.11995341628789902f;
  t171_n143: if (E.getNumReferences() >= 3329553408 /*15677.0*/) goto t171_n145;
  t171_n144: return -0.12980377674102783f;
  t171_n145: if (E.getNumReferences() >= 3329933824 /*16048.5*/) goto t171_n149;
  t171_n146: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t171_n148;
  t171_n147: return 0.10530756413936615f;
  t171_n148: return 0.14526315033435822f;
  t171_n149: if (E.getNumReferences() >= 3330075136 /*16186.5*/) goto t171_n151;
  t171_n150: return -0.5501658320426941f;
  t171_n151: return 0.0067606340162456036f;
  t171_n152: if (E.getNumReferences() >= 3299901440 /*1412.0*/) goto t171_n162;
  t171_n153: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t171_n161;
  t171_n154: if (E.getNumReferences() >= 3298500608 /*1241.0*/) goto t171_n156;
  t171_n155: return -0.5676220655441284f;
  t171_n156: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t171_n160;
  t171_n157: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t171_n159;
  t171_n158: return 0.05986804515123367f;
  t171_n159: return 0.13199765980243683f;
  t171_n160: return 0.04386083409190178f;
  t171_n161: return 0.10087142884731293f;
  t171_n162: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t171_n188;
  t171_n163: if (E.getNumReferences() >= 3351111424 /*97230.0*/) goto t171_n183;
  t171_n164: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t171_n166;
  t171_n165: return -0.09845943003892899f;
  t171_n166: if (E.getNumReferences() >= 3310399488 /*3339.0*/) goto t171_n170;
  t171_n167: if (E.getNumReferences() >= 3309062144 /*3012.5*/) goto t171_n169;
  t171_n168: return -0.051036734133958817f;
  t171_n169: return 0.11164921522140503f;
  t171_n170: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n172;
  t171_n171: return -0.044675879180431366f;
  t171_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t171_n176;
  t171_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t171_n175;
  t171_n174: return -0.3764229118824005f;
  t171_n175: return 0.03489059954881668f;
  t171_n176: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t171_n182;
  t171_n177: if (E.getNumReferences() >= 3336411136 /*28364.0*/) goto t171_n181;
  t171_n178: if (E.getNumReferences() >= 3327422976 /*13596.5*/) goto t171_n180;
  t171_n179: return 0.0924210399389267f;
  t171_n180: return -0.08245706558227539f;
  t171_n181: return 0.11385613679885864f;
  t171_n182: return 0.04006079211831093f;
  t171_n183: if (E.getNumReferences() >= 3364974544 /*297854.5*/) goto t171_n187;
  t171_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t171_n186;
  t171_n185: return 0.015091688372194767f;
  t171_n186: return 0.10966179519891739f;
  t171_n187: return 0.009290046989917755f;
  t171_n188: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t171_n254;
  t171_n189: if (E.getNumReferences() >= 3359807328 /*199261.5*/) goto t171_n245;
  t171_n190: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t171_n192;
  t171_n191: return -0.0178214143961668f;
  t171_n192: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t171_n244;
  t171_n193: if (E.getNumReferences() >= 3309326336 /*3077.0*/) goto t171_n195;
  t171_n194: return -0.05693595111370087f;
  t171_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t171_n217;
  t171_n196: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n198;
  t171_n197: return -0.26939353346824646f;
  t171_n198: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t171_n202;
  t171_n199: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t171_n201;
  t171_n200: return -0.5527371764183044f;
  t171_n201: return 0.09038937091827393f;
  t171_n202: if (E.getNumReferences() >= 3315718144 /*5179.0*/) goto t171_n208;
  t171_n203: if (E.getNumReferences() >= 3314667520 /*4666.0*/) goto t171_n207;
  t171_n204: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t171_n206;
  t171_n205: return 0.10225287824869156f;
  t171_n206: return -0.2758767902851105f;
  t171_n207: return -0.18155404925346375f;
  t171_n208: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t171_n214;
  t171_n209: if (E.getNumReferences() >= 3324847616 /*11081.5*/) goto t171_n213;
  t171_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t171_n212;
  t171_n211: return 0.11084918677806854f;
  t171_n212: return 0.11368335038423538f;
  t171_n213: return 0.07388412952423096f;
  t171_n214: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t171_n216;
  t171_n215: return 0.03660636022686958f;
  t171_n216: return 0.09016694128513336f;
  t171_n217: if (E.getNumReferences() >= 3310016512 /*3245.5*/) goto t171_n219;
  t171_n218: return 0.10839946568012238f;
  t171_n219: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t171_n223;
  t171_n220: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t171_n222;
  t171_n221: return -0.023540180176496506f;
  t171_n222: return 0.08747586607933044f;
  t171_n223: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t171_n225;
  t171_n224: return 0.12076948583126068f;
  t171_n225: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t171_n241;
  t171_n226: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t171_n240;
  t171_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t171_n229;
  t171_n228: return 0.003369174199178815f;
  t171_n229: if (E.getNumReferences() >= 3323780096 /*10039.0*/) goto t171_n231;
  t171_n230: return 0.15832959115505219f;
  t171_n231: if (E.getNumReferences() >= 3324083200 /*10335.0*/) goto t171_n233;
  t171_n232: return 0.03591826558113098f;
  t171_n233: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t171_n235;
  t171_n234: return -0.015171959064900875f;
  t171_n235: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n237;
  t171_n236: return 0.1667923629283905f;
  t171_n237: if (E.getNumReferences() >= 3327807488 /*13972.0*/) goto t171_n239;
  t171_n238: return 0.11273717880249023f;
  t171_n239: return 0.09913081675767899f;
  t171_n240: return 0.018619831651449203f;
  t171_n241: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n243;
  t171_n242: return -0.6365578174591064f;
  t171_n243: return 0.067222461104393f;
  t171_n244: return 0.014122436754405499f;
  t171_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t171_n253;
  t171_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t171_n248;
  t171_n247: return -0.10998524725437164f;
  t171_n248: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t171_n250;
  t171_n249: return 0.07081490755081177f;
  t171_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t171_n252;
  t171_n251: return 0.06999590247869492f;
  t171_n252: return 0.10320820659399033f;
  t171_n253: return 0.010368632152676582f;
  t171_n254: return -0.010568870231509209f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree172(const Example& E) {
  t172_n0: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t172_n218;
  t172_n1: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t172_n163;
  t172_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t172_n16;
  t172_n3: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t172_n5;
  t172_n4: return -0.004192250315099955f;
  t172_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t172_n9;
  t172_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t172_n8;
  t172_n7: return -0.04370567202568054f;
  t172_n8: return -0.020790396258234978f;
  t172_n9: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t172_n11;
  t172_n10: return 0.008942605927586555f;
  t172_n11: if (E.getNumReferences() >= 3282354176 /*329.5*/) goto t172_n13;
  t172_n12: return -0.03760452941060066f;
  t172_n13: if (E.getNumReferences() >= 3290128384 /*621.5*/) goto t172_n15;
  t172_n14: return 0.12190929055213928f;
  t172_n15: return 0.03895523026585579f;
  t172_n16: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t172_n162;
  t172_n17: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t172_n113;
  t172_n18: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n76;
  t172_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t172_n21;
  t172_n20: return 0.0023666981142014265f;
  t172_n21: if (E.getNumReferences() >= 3283779584 /*373.0*/) goto t172_n73;
  t172_n22: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t172_n56;
  t172_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t172_n51;
  t172_n24: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t172_n50;
  t172_n25: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t172_n31;
  t172_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t172_n28;
  t172_n27: return 0.0023724378552287817f;
  t172_n28: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t172_n30;
  t172_n29: return 0.00424455339089036f;
  t172_n30: return 0.06122894212603569f;
  t172_n31: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t172_n35;
  t172_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n34;
  t172_n33: return -0.058670736849308014f;
  t172_n34: return 0.06370863318443298f;
  t172_n35: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t172_n45;
  t172_n36: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t172_n38;
  t172_n37: return 0.0950574204325676f;
  t172_n38: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t172_n44;
  t172_n39: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t172_n43;
  t172_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t172_n42;
  t172_n41: return 0.06587189435958862f;
  t172_n42: return 0.14498865604400635f;
  t172_n43: return -0.1414703130722046f;
  t172_n44: return 0.12522980570793152f;
  t172_n45: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t172_n47;
  t172_n46: return 0.0245357658714056f;
  t172_n47: if (E.getNumReferences() >= 3266052096 /*86.0*/) goto t172_n49;
  t172_n48: return 0.15628010034561157f;
  t172_n49: return 0.4962131083011627f;
  t172_n50: return -0.011133690364658833f;
  t172_n51: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t172_n53;
  t172_n52: return 0.0494859404861927f;
  t172_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n55;
  t172_n54: return -0.1055285707116127f;
  t172_n55: return 0.11465109139680862f;
  t172_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t172_n58;
  t172_n57: return -0.0047311075031757355f;
  t172_n58: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t172_n70;
  t172_n59: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t172_n65;
  t172_n60: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t172_n62;
  t172_n61: return 0.06431355327367783f;
  t172_n62: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t172_n64;
  t172_n63: return 0.10121805965900421f;
  t172_n64: return 0.059216830879449844f;
  t172_n65: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t172_n67;
  t172_n66: return -0.31735458970069885f;
  t172_n67: if (E.getNumReferences() >= 3253731328 /*30.0*/) goto t172_n69;
  t172_n68: return 0.11389646679162979f;
  t172_n69: return -0.10974128544330597f;
  t172_n70: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t172_n72;
  t172_n71: return 0.1060086190700531f;
  t172_n72: return -0.0010545147815719247f;
  t172_n73: if (E.getNumReferences() >= 3289022464 /*554.0*/) goto t172_n75;
  t172_n74: return 0.11316639930009842f;
  t172_n75: return -0.005828175228089094f;
  t172_n76: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t172_n96;
  t172_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n83;
  t172_n78: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t172_n82;
  t172_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n81;
  t172_n80: return -0.11567794531583786f;
  t172_n81: return -0.030759651213884354f;
  t172_n82: return -0.02060595713555813f;
  t172_n83: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t172_n85;
  t172_n84: return -0.014969026669859886f;
  t172_n85: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t172_n87;
  t172_n86: return 0.004156079608947039f;
  t172_n87: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t172_n89;
  t172_n88: return 0.03505042940378189f;
  t172_n89: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t172_n95;
  t172_n90: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t172_n92;
  t172_n91: return -0.1256183534860611f;
  t172_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t172_n94;
  t172_n93: return -0.4140154719352722f;
  t172_n94: return 0.12735214829444885f;
  t172_n95: return 0.07779430598020554f;
  t172_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n100;
  t172_n97: if (E.getNumReferences() >= 3278536704 /*234.5*/) goto t172_n99;
  t172_n98: return -0.14270538091659546f;
  t172_n99: return 0.08027110248804092f;
  t172_n100: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t172_n112;
  t172_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t172_n107;
  t172_n102: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t172_n106;
  t172_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t172_n105;
  t172_n104: return -0.06359204649925232f;
  t172_n105: return 0.03767605498433113f;
  t172_n106: return -0.02554154023528099f;
  t172_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t172_n109;
  t172_n108: return -0.021741805598139763f;
  t172_n109: if (E.getNumReferences() >= 3256090624 /*37.0*/) goto t172_n111;
  t172_n110: return 0.05481754243373871f;
  t172_n111: return -0.28097325563430786f;
  t172_n112: return -0.009726238436996937f;
  t172_n113: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t172_n123;
  t172_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n118;
  t172_n115: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t172_n117;
  t172_n116: return -0.0961180031299591f;
  t172_n117: return 0.061624880880117416f;
  t172_n118: if (E.getNumReferences() >= 3296002048 /*980.0*/) goto t172_n120;
  t172_n119: return -0.016303544864058495f;
  t172_n120: if (E.getNumReferences() >= 3296616448 /*1017.5*/) goto t172_n122;
  t172_n121: return 0.09202103316783905f;
  t172_n122: return -0.02060674875974655f;
  t172_n123: if (E.getNumReferences() >= 3290136576 /*622.0*/) goto t172_n159;
  t172_n124: if (E.getNumReferences() >= 3271163904 /*125.0*/) goto t172_n158;
  t172_n125: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t172_n155;
  t172_n126: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t172_n154;
  t172_n127: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t172_n139;
  t172_n128: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t172_n130;
  t172_n129: return -0.04328471049666405f;
  t172_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t172_n132;
  t172_n131: return -0.03252769261598587f;
  t172_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t172_n136;
  t172_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t172_n135;
  t172_n134: return -0.03308602049946785f;
  t172_n135: return 0.08086498826742172f;
  t172_n136: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t172_n138;
  t172_n137: return 0.10486283153295517f;
  t172_n138: return 0.13079454004764557f;
  t172_n139: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t172_n143;
  t172_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t172_n142;
  t172_n141: return -0.16289936006069183f;
  t172_n142: return 0.04496808350086212f;
  t172_n143: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t172_n147;
  t172_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t172_n146;
  t172_n145: return -0.031767942011356354f;
  t172_n146: return 0.09481877833604813f;
  t172_n147: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t172_n153;
  t172_n148: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t172_n152;
  t172_n149: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n151;
  t172_n150: return 0.3180559277534485f;
  t172_n151: return 0.11639788001775742f;
  t172_n152: return -0.05306583270430565f;
  t172_n153: return -0.154471293091774f;
  t172_n154: return -0.02062896639108658f;
  t172_n155: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t172_n157;
  t172_n156: return 0.11305049806833267f;
  t172_n157: return 0.02650938555598259f;
  t172_n158: return -0.29995301365852356f;
  t172_n159: if (E.getNumReferences() >= 3292766208 /*782.5*/) goto t172_n161;
  t172_n160: return 0.12241753935813904f;
  t172_n161: return -0.06373970955610275f;
  t172_n162: return 0.004229987505823374f;
  t172_n163: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t172_n183;
  t172_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t172_n166;
  t172_n165: return 0.003925848752260208f;
  t172_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t172_n180;
  t172_n167: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t172_n179;
  t172_n168: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t172_n172;
  t172_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t172_n171;
  t172_n170: return 0.004017225932329893f;
  t172_n171: return 0.03558293730020523f;
  t172_n172: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t172_n174;
  t172_n173: return 0.012754312716424465f;
  t172_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t172_n176;
  t172_n175: return 0.037394240498542786f;
  t172_n176: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n178;
  t172_n177: return 0.06801344454288483f;
  t172_n178: return 0.05527101457118988f;
  t172_n179: return -0.09170985221862793f;
  t172_n180: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n182;
  t172_n181: return 0.038582365959882736f;
  t172_n182: return 0.09695927798748016f;
  t172_n183: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t172_n189;
  t172_n184: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t172_n186;
  t172_n185: return -0.048281989991664886f;
  t172_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t172_n188;
  t172_n187: return -0.05106306076049805f;
  t172_n188: return -0.02430972270667553f;
  t172_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t172_n193;
  t172_n190: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t172_n192;
  t172_n191: return -0.5430564880371094f;
  t172_n192: return 0.013839613646268845f;
  t172_n193: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t172_n201;
  t172_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t172_n196;
  t172_n195: return -0.0053535206243395805f;
  t172_n196: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t172_n198;
  t172_n197: return -0.1045341044664383f;
  t172_n198: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t172_n200;
  t172_n199: return -0.042126815766096115f;
  t172_n200: return 0.021712908521294594f;
  t172_n201: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t172_n203;
  t172_n202: return 0.04550231248140335f;
  t172_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t172_n205;
  t172_n204: return -0.06240458786487579f;
  t172_n205: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t172_n215;
  t172_n206: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t172_n210;
  t172_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n209;
  t172_n208: return -0.10650908946990967f;
  t172_n209: return 0.09780614078044891f;
  t172_n210: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n212;
  t172_n211: return -0.02269809879362583f;
  t172_n212: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t172_n214;
  t172_n213: return 0.14193764328956604f;
  t172_n214: return 0.14170248806476593f;
  t172_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n217;
  t172_n216: return -0.007449039723724127f;
  t172_n217: return 0.12274346500635147f;
  t172_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t172_n232;
  t172_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t172_n221;
  t172_n220: return -0.03770482540130615f;
  t172_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n223;
  t172_n222: return -0.0037373239174485207f;
  t172_n223: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t172_n225;
  t172_n224: return -0.02659694291651249f;
  t172_n225: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t172_n231;
  t172_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t172_n228;
  t172_n227: return 0.03253020718693733f;
  t172_n228: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t172_n230;
  t172_n229: return 0.03967678174376488f;
  t172_n230: return 0.0580025352537632f;
  t172_n231: return -0.0013483952498063445f;
  t172_n232: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t172_n234;
  t172_n233: return 0.033103097230196f;
  t172_n234: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t172_n246;
  t172_n235: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t172_n237;
  t172_n236: return 0.05192564055323601f;
  t172_n237: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t172_n239;
  t172_n238: return -0.1524353176355362f;
  t172_n239: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t172_n245;
  t172_n240: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t172_n244;
  t172_n241: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t172_n243;
  t172_n242: return -0.10709366202354431f;
  t172_n243: return 0.10429204255342484f;
  t172_n244: return -0.13818764686584473f;
  t172_n245: return -0.17711803317070007f;
  t172_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t172_n248;
  t172_n247: return -0.03131107985973358f;
  t172_n248: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t172_n254;
  t172_n249: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n253;
  t172_n250: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t172_n252;
  t172_n251: return 0.06210935115814209f;
  t172_n252: return 0.10187771916389465f;
  t172_n253: return 0.06199165806174278f;
  t172_n254: return -0.02714647725224495f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree173(const Example& E) {
  t173_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t173_n2;
  t173_n1: return -0.0004284012538846582f;
  t173_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t173_n16;
  t173_n3: if (E.getNumReferences() >= 3298328576 /*1220.0*/) goto t173_n7;
  t173_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t173_n6;
  t173_n5: return 0.009931406937539577f;
  t173_n6: return 0.13437886536121368f;
  t173_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t173_n13;
  t173_n8: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t173_n10;
  t173_n9: return -0.06901135295629501f;
  t173_n10: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t173_n12;
  t173_n11: return 0.10723116248846054f;
  t173_n12: return -0.27793610095977783f;
  t173_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t173_n15;
  t173_n14: return 0.008435063064098358f;
  t173_n15: return 0.01957901194691658f;
  t173_n16: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t173_n56;
  t173_n17: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t173_n19;
  t173_n18: return -0.009994464926421642f;
  t173_n19: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t173_n35;
  t173_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t173_n24;
  t173_n21: if (E.getNumReferences() >= 3298660352 /*1260.5*/) goto t173_n23;
  t173_n22: return 0.14553865790367126f;
  t173_n23: return 0.004527705255895853f;
  t173_n24: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t173_n28;
  t173_n25: if (E.getNumReferences() >= 3309955072 /*3230.5*/) goto t173_n27;
  t173_n26: return 0.154270201921463f;
  t173_n27: return 0.08509714156389236f;
  t173_n28: if (E.getNumReferences() >= 3318054912 /*6320.0*/) goto t173_n30;
  t173_n29: return -0.009103828109800816f;
  t173_n30: if (E.getNumReferences() >= 3320302592 /*7417.5*/) goto t173_n34;
  t173_n31: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n33;
  t173_n32: return 0.229728564620018f;
  t173_n33: return 0.09808985888957977f;
  t173_n34: return 0.0688985213637352f;
  t173_n35: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t173_n55;
  t173_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t173_n38;
  t173_n37: return -0.027019822970032692f;
  t173_n38: if (E.getNumReferences() >= 3298639872 /*1258.0*/) goto t173_n48;
  t173_n39: if (E.getNumReferences() >= 3298607104 /*1254.0*/) goto t173_n47;
  t173_n40: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t173_n42;
  t173_n41: return -0.04872008040547371f;
  t173_n42: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t173_n46;
  t173_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t173_n45;
  t173_n44: return 0.13513655960559845f;
  t173_n45: return -0.10016674548387527f;
  t173_n46: return 0.06929069757461548f;
  t173_n47: return 0.12059363722801208f;
  t173_n48: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t173_n52;
  t173_n49: if (E.getNumReferences() >= 3355834112 /*137180.0*/) goto t173_n51;
  t173_n50: return 0.011047939769923687f;
  t173_n51: return 0.04715603590011597f;
  t173_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t173_n54;
  t173_n53: return -0.12207383662462234f;
  t173_n54: return 0.09801582992076874f;
  t173_n55: return 0.009542862884700298f;
  t173_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t173_n158;
  t173_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t173_n63;
  t173_n58: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t173_n60;
  t173_n59: return 0.005071137100458145f;
  t173_n60: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t173_n62;
  t173_n61: return -0.07136791199445724f;
  t173_n62: return 0.015340548008680344f;
  t173_n63: if (E.getNumReferences() >= 3329258496 /*15389.0*/) goto t173_n147;
  t173_n64: if (E.getNumReferences() >= 3329011200 /*15147.5*/) goto t173_n138;
  t173_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t173_n125;
  t173_n66: if (E.getNumReferences() >= 3316514816 /*5568.0*/) goto t173_n68;
  t173_n67: return 0.0035280198790133f;
  t173_n68: if (E.getNumReferences() >= 3319526400 /*7038.5*/) goto t173_n98;
  t173_n69: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t173_n87;
  t173_n70: if (E.getNumReferences() >= 3318019072 /*6302.5*/) goto t173_n86;
  t173_n71: if (E.getNumReferences() >= 3317762048 /*6177.0*/) goto t173_n83;
  t173_n72: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t173_n74;
  t173_n73: return -0.33357948064804077f;
  t173_n74: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t173_n82;
  t173_n75: if (E.getNumReferences() >= 3316544512 /*5582.5*/) goto t173_n77;
  t173_n76: return 0.11960204690694809f;
  t173_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t173_n79;
  t173_n78: return -0.04869219660758972f;
  t173_n79: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t173_n81;
  t173_n80: return 0.1046830341219902f;
  t173_n81: return 0.02817070297896862f;
  t173_n82: return 0.016552340239286423f;
  t173_n83: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t173_n85;
  t173_n84: return 0.13193760812282562f;
  t173_n85: return 0.08348888903856277f;
  t173_n86: return -0.08466551452875137f;
  t173_n87: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t173_n95;
  t173_n88: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n90;
  t173_n89: return 0.05212504789233208f;
  t173_n90: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t173_n92;
  t173_n91: return 0.10941614210605621f;
  t173_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t173_n94;
  t173_n93: return 0.12671752274036407f;
  t173_n94: return -0.22443923354148865f;
  t173_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t173_n97;
  t173_n96: return 0.007233570329844952f;
  t173_n97: return 0.11222612857818604f;
  t173_n98: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t173_n108;
  t173_n99: if (E.getNumReferences() >= 3324609024 /*10848.5*/) goto t173_n101;
  t173_n100: return -0.08047475665807724f;
  t173_n101: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t173_n107;
  t173_n102: if (E.getNumReferences() >= 3325290496 /*11514.0*/) goto t173_n106;
  t173_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t173_n105;
  t173_n104: return 0.07100917398929596f;
  t173_n105: return 0.1136445552110672f;
  t173_n106: return 0.02014463022351265f;
  t173_n107: return -0.055442873388528824f;
  t173_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n110;
  t173_n109: return -0.07194482535123825f;
  t173_n110: if (E.getNumReferences() >= 3323109888 /*9384.5*/) goto t173_n118;
  t173_n111: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t173_n113;
  t173_n112: return 0.020895708352327347f;
  t173_n113: if (E.getNumReferences() >= 3322166272 /*8463.0*/) goto t173_n115;
  t173_n114: return 0.11733847111463547f;
  t173_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t173_n117;
  t173_n116: return 0.035338789224624634f;
  t173_n117: return 0.10961298644542694f;
  t173_n118: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t173_n124;
  t173_n119: if (E.getNumReferences() >= 3326753280 /*12942.5*/) goto t173_n121;
  t173_n120: return -0.2058699131011963f;
  t173_n121: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t173_n123;
  t173_n122: return 0.1479395180940628f;
  t173_n123: return 0.08960411697626114f;
  t173_n124: return -0.021813731640577316f;
  t173_n125: if (E.getNumReferences() >= 3321170944 /*7841.5*/) goto t173_n137;
  t173_n126: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t173_n130;
  t173_n127: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t173_n129;
  t173_n128: return 0.0766717866063118f;
  t173_n129: return -0.14186608791351318f;
  t173_n130: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t173_n134;
  t173_n131: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t173_n133;
  t173_n132: return 0.10229643434286118f;
  t173_n133: return -0.09206704795360565f;
  t173_n134: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t173_n136;
  t173_n135: return -0.18802794814109802f;
  t173_n136: return 0.08089829236268997f;
  t173_n137: return -0.5244418978691101f;
  t173_n138: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t173_n144;
  t173_n139: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t173_n141;
  t173_n140: return -0.22561956942081451f;
  t173_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t173_n143;
  t173_n142: return 0.09789305925369263f;
  t173_n143: return -0.1716519296169281f;
  t173_n144: if (E.getNumReferences() >= 3329118720 /*15252.5*/) goto t173_n146;
  t173_n145: return 0.112594373524189f;
  t173_n146: return 0.12072135508060455f;
  t173_n147: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t173_n157;
  t173_n148: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t173_n150;
  t173_n149: return 0.10260389000177383f;
  t173_n150: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t173_n154;
  t173_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t173_n153;
  t173_n152: return -0.021110879257321358f;
  t173_n153: return -0.1339297741651535f;
  t173_n154: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t173_n156;
  t173_n155: return -0.033537041395902634f;
  t173_n156: return 0.10032157599925995f;
  t173_n157: return 0.007722513750195503f;
  t173_n158: if (E.getNumReferences() >= 3299901440 /*1412.0*/) goto t173_n168;
  t173_n159: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t173_n167;
  t173_n160: if (E.getNumReferences() >= 3298500608 /*1241.0*/) goto t173_n162;
  t173_n161: return -0.3819788992404938f;
  t173_n162: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t173_n166;
  t173_n163: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n165;
  t173_n164: return -0.005565082188695669f;
  t173_n165: return 0.1260046809911728f;
  t173_n166: return 0.030823878943920135f;
  t173_n167: return 0.09807323664426804f;
  t173_n168: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t173_n254;
  t173_n169: if (E.getNumReferences() >= 3359807328 /*199261.5*/) goto t173_n241;
  t173_n170: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t173_n174;
  t173_n171: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t173_n173;
  t173_n172: return -0.305184930562973f;
  t173_n173: return -0.02147933468222618f;
  t173_n174: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t173_n178;
  t173_n175: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t173_n177;
  t173_n176: return 0.11201635003089905f;
  t173_n177: return -0.06201834976673126f;
  t173_n178: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t173_n180;
  t173_n179: return -0.0017814846942201257f;
  t173_n180: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t173_n240;
  t173_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t173_n211;
  t173_n182: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t173_n208;
  t173_n183: if (E.getNumReferences() >= 3309393920 /*3093.5*/) goto t173_n185;
  t173_n184: return -0.08379437029361725f;
  t173_n185: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t173_n187;
  t173_n186: return -0.17893622815608978f;
  t173_n187: if (E.getNumReferences() >= 3315718144 /*5179.0*/) goto t173_n193;
  t173_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t173_n190;
  t173_n189: return -0.09748886525630951f;
  t173_n190: if (E.getNumReferences() >= 3314856960 /*4758.5*/) goto t173_n192;
  t173_n191: return 0.10155452787876129f;
  t173_n192: return -0.6781949400901794f;
  t173_n193: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t173_n203;
  t173_n194: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t173_n196;
  t173_n195: return 0.04976513609290123f;
  t173_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n198;
  t173_n197: return 0.020240984857082367f;
  t173_n198: if (E.getNumReferences() >= 3324847616 /*11081.5*/) goto t173_n202;
  t173_n199: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t173_n201;
  t173_n200: return 0.1070595532655716f;
  t173_n201: return 0.11266250908374786f;
  t173_n202: return 0.08309243619441986f;
  t173_n203: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t173_n205;
  t173_n204: return -0.04919910430908203f;
  t173_n205: if (E.getNumReferences() >= 3323238400 /*9510.0*/) goto t173_n207;
  t173_n206: return 0.09773404151201248f;
  t173_n207: return 0.04041055589914322f;
  t173_n208: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t173_n210;
  t173_n209: return 0.08982706069946289f;
  t173_n210: return -0.009838038124144077f;
  t173_n211: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n215;
  t173_n212: if (E.getNumReferences() >= 3308220416 /*2807.0*/) goto t173_n214;
  t173_n213: return -0.38486552238464355f;
  t173_n214: return 0.1095999926328659f;
  t173_n215: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t173_n227;
  t173_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t173_n224;
  t173_n217: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t173_n221;
  t173_n218: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t173_n220;
  t173_n219: return -0.5198633670806885f;
  t173_n220: return 0.01829935796558857f;
  t173_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t173_n223;
  t173_n222: return 0.1310722529888153f;
  t173_n223: return 0.07768522202968597f;
  t173_n224: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t173_n226;
  t173_n225: return -0.028418220579624176f;
  t173_n226: return 0.0945972353219986f;
  t173_n227: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t173_n229;
  t173_n228: return 0.11876238137483597f;
  t173_n229: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t173_n239;
  t173_n230: if (E.getNumReferences() >= 3323780096 /*10039.0*/) goto t173_n232;
  t173_n231: return 0.1517568677663803f;
  t173_n232: if (E.getNumReferences() >= 3325920768 /*12129.5*/) goto t173_n234;
  t173_n233: return 0.05524455010890961f;
  t173_n234: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t173_n236;
  t173_n235: return -0.0027218740433454514f;
  t173_n236: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t173_n238;
  t173_n237: return 0.1281440705060959f;
  t173_n238: return 0.04592811316251755f;
  t173_n239: return -0.07387468218803406f;
  t173_n240: return 0.012018291279673576f;
  t173_n241: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n245;
  t173_n242: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t173_n244;
  t173_n243: return -0.3479765057563782f;
  t173_n244: return 0.10557828843593597f;
  t173_n245: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t173_n247;
  t173_n246: return 0.0529196672141552f;
  t173_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t173_n251;
  t173_n248: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t173_n250;
  t173_n249: return -0.14250092208385468f;
  t173_n250: return 0.08725111931562424f;
  t173_n251: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t173_n253;
  t173_n252: return 0.10702486336231232f;
  t173_n253: return -0.25610747933387756f;
  t173_n254: return -0.006528749596327543f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree174(const Example& E) {
  t174_n0: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t174_n232;
  t174_n1: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t174_n139;
  t174_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n34;
  t174_n3: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t174_n5;
  t174_n4: return -0.00421095872297883f;
  t174_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t174_n9;
  t174_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t174_n8;
  t174_n7: return -0.037307288497686386f;
  t174_n8: return -0.018890736624598503f;
  t174_n9: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t174_n29;
  t174_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t174_n12;
  t174_n11: return -0.04477576166391373f;
  t174_n12: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t174_n16;
  t174_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t174_n15;
  t174_n14: return -0.03079165890812874f;
  t174_n15: return 0.004629898350685835f;
  t174_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t174_n28;
  t174_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t174_n21;
  t174_n18: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t174_n20;
  t174_n19: return -0.04832429811358452f;
  t174_n20: return 0.031813330948352814f;
  t174_n21: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t174_n27;
  t174_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n24;
  t174_n23: return 0.08640828728675842f;
  t174_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n26;
  t174_n25: return 0.054307710379362106f;
  t174_n26: return 0.01885141059756279f;
  t174_n27: return 0.0028163925744593143f;
  t174_n28: return 0.0024684264790266752f;
  t174_n29: if (E.getNumReferences() >= 3282354176 /*329.5*/) goto t174_n31;
  t174_n30: return -0.03419913351535797f;
  t174_n31: if (E.getNumReferences() >= 3290128384 /*621.5*/) goto t174_n33;
  t174_n32: return 0.11973924189805984f;
  t174_n33: return 0.04391603171825409f;
  t174_n34: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t174_n138;
  t174_n35: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t174_n97;
  t174_n36: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t174_n94;
  t174_n37: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t174_n59;
  t174_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n56;
  t174_n39: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n41;
  t174_n40: return 0.008544860407710075f;
  t174_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t174_n51;
  t174_n42: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t174_n44;
  t174_n43: return 0.031046289950609207f;
  t174_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t174_n46;
  t174_n45: return 0.05957324057817459f;
  t174_n46: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t174_n50;
  t174_n47: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t174_n49;
  t174_n48: return 0.10980275273323059f;
  t174_n49: return -0.3075336217880249f;
  t174_n50: return 0.12393631786108017f;
  t174_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t174_n53;
  t174_n52: return 0.018521863967180252f;
  t174_n53: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t174_n55;
  t174_n54: return 0.06602504849433899f;
  t174_n55: return 0.09872197359800339f;
  t174_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t174_n58;
  t174_n57: return -0.04775255545973778f;
  t174_n58: return -0.006021272391080856f;
  t174_n59: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t174_n63;
  t174_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t174_n62;
  t174_n61: return -0.04801463708281517f;
  t174_n62: return -0.01714707724750042f;
  t174_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t174_n77;
  t174_n64: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t174_n66;
  t174_n65: return -0.015104933641850948f;
  t174_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t174_n68;
  t174_n67: return 0.010263306088745594f;
  t174_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n70;
  t174_n69: return 0.09238564223051071f;
  t174_n70: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t174_n72;
  t174_n71: return -0.1653822362422943f;
  t174_n72: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t174_n76;
  t174_n73: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t174_n75;
  t174_n74: return 0.04924427345395088f;
  t174_n75: return 0.12594284117221832f;
  t174_n76: return -0.14417725801467896f;
  t174_n77: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t174_n81;
  t174_n78: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n80;
  t174_n79: return 0.12383829802274704f;
  t174_n80: return 0.05721529573202133f;
  t174_n81: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t174_n85;
  t174_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n84;
  t174_n83: return -0.3884260952472687f;
  t174_n84: return 0.042391013354063034f;
  t174_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n93;
  t174_n86: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t174_n92;
  t174_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t174_n89;
  t174_n88: return 0.031456876546144485f;
  t174_n89: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t174_n91;
  t174_n90: return 0.09396517276763916f;
  t174_n91: return 0.07777409255504608f;
  t174_n92: return -1.0379657745361328f;
  t174_n93: return 0.018942512571811676f;
  t174_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t174_n96;
  t174_n95: return -0.10101044923067093f;
  t174_n96: return -0.017583953216671944f;
  t174_n97: if (E.getNumReferences() >= 3273424896 /*156.5*/) goto t174_n99;
  t174_n98: return 0.10720726102590561f;
  t174_n99: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t174_n135;
  t174_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n102;
  t174_n101: return -0.13706214725971222f;
  t174_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t174_n108;
  t174_n103: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t174_n105;
  t174_n104: return -0.026180844753980637f;
  t174_n105: if (E.getNumReferences() >= 3275522048 /*188.5*/) goto t174_n107;
  t174_n106: return 0.10250142961740494f;
  t174_n107: return 0.058130908757448196f;
  t174_n108: if (E.getNumReferences() >= 3287351296 /*482.0*/) goto t174_n128;
  t174_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t174_n111;
  t174_n110: return -0.03774216026067734f;
  t174_n111: if (E.getNumReferences() >= 3278798848 /*238.5*/) goto t174_n121;
  t174_n112: if (E.getNumReferences() >= 3275849728 /*193.5*/) goto t174_n120;
  t174_n113: if (E.getNumReferences() >= 3275194368 /*183.5*/) goto t174_n117;
  t174_n114: if (E.getNumReferences() >= 3274244096 /*169.0*/) goto t174_n116;
  t174_n115: return 0.08933373540639877f;
  t174_n116: return -0.38010719418525696f;
  t174_n117: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t174_n119;
  t174_n118: return 0.11177628487348557f;
  t174_n119: return 0.0626181960105896f;
  t174_n120: return -0.08890291303396225f;
  t174_n121: if (E.getNumReferences() >= 3278995456 /*241.5*/) goto t174_n123;
  t174_n122: return 0.11525218188762665f;
  t174_n123: if (E.getNumReferences() >= 3283812352 /*374.0*/) goto t174_n125;
  t174_n124: return 0.03265971317887306f;
  t174_n125: if (E.getNumReferences() >= 3284123648 /*383.5*/) goto t174_n127;
  t174_n126: return 0.11416599154472351f;
  t174_n127: return 0.02814631722867489f;
  t174_n128: if (E.getNumReferences() >= 3288137728 /*506.0*/) goto t174_n130;
  t174_n129: return 0.10271558165550232f;
  t174_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t174_n132;
  t174_n131: return 0.02181173674762249f;
  t174_n132: if (E.getNumReferences() >= 3292528640 /*768.0*/) goto t174_n134;
  t174_n133: return 0.1101708859205246f;
  t174_n134: return -0.24395059049129486f;
  t174_n135: if (E.getNumReferences() >= 3294724096 /*902.0*/) goto t174_n137;
  t174_n136: return -0.02595614828169346f;
  t174_n137: return 0.0948435366153717f;
  t174_n138: return 0.004092436749488115f;
  t174_n139: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t174_n183;
  t174_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t174_n158;
  t174_n141: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n143;
  t174_n142: return 0.009870425797998905f;
  t174_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t174_n155;
  t174_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t174_n146;
  t174_n145: return -0.00663197273388505f;
  t174_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t174_n148;
  t174_n147: return -0.02278924360871315f;
  t174_n148: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t174_n150;
  t174_n149: return 0.011318779550492764f;
  t174_n150: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n154;
  t174_n151: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t174_n153;
  t174_n152: return 0.041024889796972275f;
  t174_n153: return -0.17413829267024994f;
  t174_n154: return 0.04402310773730278f;
  t174_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Expression))) goto t174_n157;
  t174_n156: return -0.0009023207239806652f;
  t174_n157: return 0.01272203866392374f;
  t174_n158: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t174_n182;
  t174_n159: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n161;
  t174_n160: return 0.018827568739652634f;
  t174_n161: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t174_n171;
  t174_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t174_n168;
  t174_n163: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t174_n167;
  t174_n164: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n166;
  t174_n165: return 0.02590988390147686f;
  t174_n166: return -0.03148886561393738f;
  t174_n167: return 0.03112015873193741f;
  t174_n168: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n170;
  t174_n169: return 0.03406454250216484f;
  t174_n170: return 0.05639800429344177f;
  t174_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t174_n175;
  t174_n172: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t174_n174;
  t174_n173: return 0.04766146466135979f;
  t174_n174: return 0.0950751006603241f;
  t174_n175: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t174_n181;
  t174_n176: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n180;
  t174_n177: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t174_n179;
  t174_n178: return 0.23535653948783875f;
  t174_n179: return 0.18054044246673584f;
  t174_n180: return 0.2167663425207138f;
  t174_n181: return -0.2801021635532379f;
  t174_n182: return -0.09190960228443146f;
  t174_n183: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t174_n191;
  t174_n184: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n188;
  t174_n185: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t174_n187;
  t174_n186: return -0.04774585738778114f;
  t174_n187: return -0.047294218093156815f;
  t174_n188: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t174_n190;
  t174_n189: return -0.04375883564352989f;
  t174_n190: return -0.02450203150510788f;
  t174_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t174_n207;
  t174_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t174_n194;
  t174_n193: return -0.008450713939964771f;
  t174_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t174_n196;
  t174_n195: return -0.1042218953371048f;
  t174_n196: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t174_n198;
  t174_n197: return -0.044373657554388046f;
  t174_n198: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n202;
  t174_n199: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n201;
  t174_n200: return 0.05321327596902847f;
  t174_n201: return -0.0008748568361625075f;
  t174_n202: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n204;
  t174_n203: return -0.015231399796903133f;
  t174_n204: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n206;
  t174_n205: return -0.0013940136414021254f;
  t174_n206: return 0.039726730436086655f;
  t174_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t174_n215;
  t174_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t174_n214;
  t174_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n213;
  t174_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n212;
  t174_n211: return -1.2744790315628052f;
  t174_n212: return -0.12342067807912827f;
  t174_n213: return 0.016191918402910233f;
  t174_n214: return -0.07013558596372604f;
  t174_n215: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t174_n231;
  t174_n216: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t174_n230;
  t174_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n219;
  t174_n218: return 0.07554734498262405f;
  t174_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t174_n223;
  t174_n220: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t174_n222;
  t174_n221: return -0.25926846265792847f;
  t174_n222: return 0.10083439201116562f;
  t174_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n225;
  t174_n224: return 0.0926205962896347f;
  t174_n225: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n227;
  t174_n226: return -0.057509586215019226f;
  t174_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t174_n229;
  t174_n228: return 0.13713344931602478f;
  t174_n229: return 0.12757360935211182f;
  t174_n230: return 1.7750731706619263f;
  t174_n231: return 0.17864735424518585f;
  t174_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t174_n234;
  t174_n233: return -0.03579888865351677f;
  t174_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n236;
  t174_n235: return 0.00044729726505465806f;
  t174_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t174_n252;
  t174_n237: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t174_n241;
  t174_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t174_n240;
  t174_n239: return -0.026930220425128937f;
  t174_n240: return 0.04902089387178421f;
  t174_n241: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t174_n249;
  t174_n242: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t174_n246;
  t174_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t174_n245;
  t174_n244: return 0.03092808648943901f;
  t174_n245: return 0.03701213374733925f;
  t174_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t174_n248;
  t174_n247: return 0.03834790736436844f;
  t174_n248: return 0.067581407725811f;
  t174_n249: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t174_n251;
  t174_n250: return -0.005377460271120071f;
  t174_n251: return 0.05261502042412758f;
  t174_n252: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t174_n254;
  t174_n253: return 0.11400895565748215f;
  t174_n254: return 0.06676482409238815f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree175(const Example& E) {
  t175_n0: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t175_n250;
  t175_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t175_n81;
  t175_n2: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t175_n6;
  t175_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t175_n5;
  t175_n4: return -0.06578267365694046f;
  t175_n5: return -0.020321380347013474f;
  t175_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t175_n8;
  t175_n7: return -0.09694590419530869f;
  t175_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t175_n36;
  t175_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t175_n13;
  t175_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t175_n12;
  t175_n11: return -0.024450181052088737f;
  t175_n12: return 0.035437434911727905f;
  t175_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t175_n21;
  t175_n14: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t175_n18;
  t175_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n17;
  t175_n16: return -0.041089240461587906f;
  t175_n17: return -0.004529738798737526f;
  t175_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t175_n20;
  t175_n19: return 0.04383694380521774f;
  t175_n20: return 0.005093058105558157f;
  t175_n21: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t175_n35;
  t175_n22: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t175_n30;
  t175_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n29;
  t175_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t175_n28;
  t175_n25: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t175_n27;
  t175_n26: return 0.038002338260412216f;
  t175_n27: return -0.7032470107078552f;
  t175_n28: return 0.057635802775621414f;
  t175_n29: return 0.058778636157512665f;
  t175_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t175_n32;
  t175_n31: return -0.04975855350494385f;
  t175_n32: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n34;
  t175_n33: return 0.025386113673448563f;
  t175_n34: return 0.08193009346723557f;
  t175_n35: return 0.036701951175928116f;
  t175_n36: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t175_n56;
  t175_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t175_n45;
  t175_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t175_n40;
  t175_n39: return 0.04153118655085564f;
  t175_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t175_n42;
  t175_n41: return 0.047527652233839035f;
  t175_n42: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t175_n44;
  t175_n43: return 0.0033310274593532085f;
  t175_n44: return -0.47281041741371155f;
  t175_n45: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t175_n53;
  t175_n46: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t175_n52;
  t175_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t175_n49;
  t175_n48: return -0.14808255434036255f;
  t175_n49: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t175_n51;
  t175_n50: return -0.018689608201384544f;
  t175_n51: return 0.0093385623767972f;
  t175_n52: return 0.045209772884845734f;
  t175_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t175_n55;
  t175_n54: return -0.025657465681433678f;
  t175_n55: return 0.031207239255309105f;
  t175_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t175_n66;
  t175_n57: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t175_n61;
  t175_n58: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n60;
  t175_n59: return 0.018593937158584595f;
  t175_n60: return 0.04959861934185028f;
  t175_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t175_n63;
  t175_n62: return -0.0672571137547493f;
  t175_n63: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t175_n65;
  t175_n64: return -0.15333999693393707f;
  t175_n65: return -0.010270551778376102f;
  t175_n66: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t175_n70;
  t175_n67: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t175_n69;
  t175_n68: return -0.05097483471035957f;
  t175_n69: return 0.07848037779331207f;
  t175_n70: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t175_n72;
  t175_n71: return -0.035121552646160126f;
  t175_n72: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t175_n76;
  t175_n73: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n75;
  t175_n74: return 0.10681959986686707f;
  t175_n75: return 0.07760409265756607f;
  t175_n76: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t175_n78;
  t175_n77: return -0.11355426907539368f;
  t175_n78: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t175_n80;
  t175_n79: return 0.09119097143411636f;
  t175_n80: return -0.11630687862634659f;
  t175_n81: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t175_n249;
  t175_n82: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t175_n84;
  t175_n83: return -0.0038831315468996763f;
  t175_n84: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t175_n100;
  t175_n85: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t175_n99;
  t175_n86: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t175_n98;
  t175_n87: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t175_n91;
  t175_n88: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t175_n90;
  t175_n89: return -0.05889086797833443f;
  t175_n90: return -0.13340355455875397f;
  t175_n91: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t175_n93;
  t175_n92: return -0.027732787653803825f;
  t175_n93: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t175_n97;
  t175_n94: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t175_n96;
  t175_n95: return 0.13901783525943756f;
  t175_n96: return -0.12647703289985657f;
  t175_n97: return -0.06805355101823807f;
  t175_n98: return 0.09727713465690613f;
  t175_n99: return 0.02831890434026718f;
  t175_n100: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t175_n166;
  t175_n101: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t175_n127;
  t175_n102: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t175_n110;
  t175_n103: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t175_n105;
  t175_n104: return 0.03921220451593399f;
  t175_n105: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t175_n107;
  t175_n106: return 0.10188861936330795f;
  t175_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t175_n109;
  t175_n108: return 0.11872754991054535f;
  t175_n109: return -0.10052713751792908f;
  t175_n110: if (E.getNumReferences() >= 3341265408 /*42922.0*/) goto t175_n112;
  t175_n111: return -0.017303353175520897f;
  t175_n112: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t175_n114;
  t175_n113: return 0.0012922517489641905f;
  t175_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n118;
  t175_n115: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t175_n117;
  t175_n116: return 0.11284949630498886f;
  t175_n117: return 0.12595131993293762f;
  t175_n118: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t175_n126;
  t175_n119: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t175_n121;
  t175_n120: return 0.08791298419237137f;
  t175_n121: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t175_n125;
  t175_n122: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t175_n124;
  t175_n123: return 0.10884398967027664f;
  t175_n124: return 0.10145341604948044f;
  t175_n125: return 0.08821801096200943f;
  t175_n126: return -0.18932202458381653f;
  t175_n127: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t175_n131;
  t175_n128: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t175_n130;
  t175_n129: return 0.005340032745152712f;
  t175_n130: return -0.6019424200057983f;
  t175_n131: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t175_n155;
  t175_n132: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t175_n148;
  t175_n133: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t175_n141;
  t175_n134: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t175_n140;
  t175_n135: if (E.getNumReferences() >= 3275390976 /*186.5*/) goto t175_n137;
  t175_n136: return 0.03156457841396332f;
  t175_n137: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t175_n139;
  t175_n138: return 0.11412452906370163f;
  t175_n139: return -5.476819038391113f;
  t175_n140: return -0.13658881187438965f;
  t175_n141: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t175_n145;
  t175_n142: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t175_n144;
  t175_n143: return 0.11146789789199829f;
  t175_n144: return -0.03138618916273117f;
  t175_n145: if (E.getNumReferences() >= 3252158464 /*27.0*/) goto t175_n147;
  t175_n146: return 0.1255498081445694f;
  t175_n147: return 0.08119107782840729f;
  t175_n148: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t175_n152;
  t175_n149: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t175_n151;
  t175_n150: return 0.08209671080112457f;
  t175_n151: return 0.13789300620555878f;
  t175_n152: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t175_n154;
  t175_n153: return 0.05657481402158737f;
  t175_n154: return 0.10277747362852097f;
  t175_n155: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t175_n165;
  t175_n156: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t175_n164;
  t175_n157: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t175_n161;
  t175_n158: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t175_n160;
  t175_n159: return 0.024394726380705833f;
  t175_n160: return 0.11732762306928635f;
  t175_n161: if (E.getNumReferences() >= 3304701952 /*1998.0*/) goto t175_n163;
  t175_n162: return 0.015663666650652885f;
  t175_n163: return 0.10908263921737671f;
  t175_n164: return 0.023908937349915504f;
  t175_n165: return -0.07761967182159424f;
  t175_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t175_n246;
  t175_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t175_n169;
  t175_n168: return -0.023003194481134415f;
  t175_n169: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t175_n233;
  t175_n170: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t175_n214;
  t175_n171: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t175_n209;
  t175_n172: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t175_n202;
  t175_n173: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t175_n199;
  t175_n174: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t175_n196;
  t175_n175: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n177;
  t175_n176: return 0.039020851254463196f;
  t175_n177: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t175_n183;
  t175_n178: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t175_n182;
  t175_n179: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t175_n181;
  t175_n180: return 0.11123771965503693f;
  t175_n181: return -0.9190685153007507f;
  t175_n182: return 0.050565607845783234f;
  t175_n183: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t175_n185;
  t175_n184: return -0.02177560329437256f;
  t175_n185: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t175_n193;
  t175_n186: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t175_n192;
  t175_n187: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t175_n191;
  t175_n188: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t175_n190;
  t175_n189: return -0.10079415887594223f;
  t175_n190: return 0.13827726244926453f;
  t175_n191: return 0.10900766402482986f;
  t175_n192: return -0.1118987575173378f;
  t175_n193: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t175_n195;
  t175_n194: return 0.06280030310153961f;
  t175_n195: return 0.01118916179984808f;
  t175_n196: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t175_n198;
  t175_n197: return 0.13431096076965332f;
  t175_n198: return 0.04754271358251572f;
  t175_n199: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t175_n201;
  t175_n200: return 0.03708985075354576f;
  t175_n201: return -0.1909184753894806f;
  t175_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t175_n204;
  t175_n203: return 0.1319207400083542f;
  t175_n204: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t175_n206;
  t175_n205: return -0.10265633463859558f;
  t175_n206: if (E.getNumReferences() >= 3246391296 /*16.0*/) goto t175_n208;
  t175_n207: return 0.0008461074903607368f;
  t175_n208: return 0.12961634993553162f;
  t175_n209: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t175_n213;
  t175_n210: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t175_n212;
  t175_n211: return 0.1378301978111267f;
  t175_n212: return 0.12648224830627441f;
  t175_n213: return 0.007313184905797243f;
  t175_n214: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n218;
  t175_n215: if (E.getNumReferences() >= 3324914176 /*11146.5*/) goto t175_n217;
  t175_n216: return -0.23640279471874237f;
  t175_n217: return 0.09022556990385056f;
  t175_n218: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t175_n224;
  t175_n219: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t175_n221;
  t175_n220: return 0.03735090792179108f;
  t175_n221: if (E.getNumReferences() >= 3271491584 /*127.5*/) goto t175_n223;
  t175_n222: return 0.18528850376605988f;
  t175_n223: return 0.07770758867263794f;
  t175_n224: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t175_n230;
  t175_n225: if (E.getNumReferences() >= 3289579520 /*588.0*/) goto t175_n227;
  t175_n226: return -0.08763673156499863f;
  t175_n227: if (E.getNumReferences() >= 3291111424 /*681.5*/) goto t175_n229;
  t175_n228: return 0.10109417885541916f;
  t175_n229: return -0.036379918456077576f;
  t175_n230: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t175_n232;
  t175_n231: return -0.1305377036333084f;
  t175_n232: return 0.07888396084308624f;
  t175_n233: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t175_n245;
  t175_n234: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t175_n236;
  t175_n235: return 0.035212427377700806f;
  t175_n236: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t175_n240;
  t175_n237: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t175_n239;
  t175_n238: return -0.20034876465797424f;
  t175_n239: return 0.12012509256601334f;
  t175_n240: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t175_n244;
  t175_n241: if (E.getNumReferences() >= 3285483520 /*425.0*/) goto t175_n243;
  t175_n242: return 0.2618654668331146f;
  t175_n243: return 0.10629928857088089f;
  t175_n244: return 0.05909845232963562f;
  t175_n245: return -0.0606222003698349f;
  t175_n246: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t175_n248;
  t175_n247: return -0.022991620004177094f;
  t175_n248: return 0.07231548428535461f;
  t175_n249: return 0.009947014041244984f;
  t175_n250: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t175_n254;
  t175_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t175_n253;
  t175_n252: return -0.06162610277533531f;
  t175_n253: return 0.05350995808839798f;
  t175_n254: return 0.0012686201371252537f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree176(const Example& E) {
  t176_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t176_n2;
  t176_n1: return -0.0004264278686605394f;
  t176_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t176_n24;
  t176_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t176_n23;
  t176_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n6;
  t176_n5: return -0.11174436658620834f;
  t176_n6: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t176_n16;
  t176_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t176_n11;
  t176_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t176_n10;
  t176_n9: return -0.39417341351509094f;
  t176_n10: return 0.02475498616695404f;
  t176_n11: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t176_n15;
  t176_n12: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t176_n14;
  t176_n13: return 0.08919243514537811f;
  t176_n14: return -0.11129515618085861f;
  t176_n15: return -2.25527286529541f;
  t176_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t176_n18;
  t176_n17: return 0.0062956134788692f;
  t176_n18: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t176_n22;
  t176_n19: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t176_n21;
  t176_n20: return 0.0921962633728981f;
  t176_n21: return 0.051324497908353806f;
  t176_n22: return 0.07733341306447983f;
  t176_n23: return -0.01951495371758938f;
  t176_n24: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t176_n236;
  t176_n25: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t176_n39;
  t176_n26: if (E.getNumReferences() >= 3283320832 /*359.0*/) goto t176_n32;
  t176_n27: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t176_n31;
  t176_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t176_n30;
  t176_n29: return -0.1764257252216339f;
  t176_n30: return -0.025263819843530655f;
  t176_n31: return -0.17712457478046417f;
  t176_n32: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t176_n38;
  t176_n33: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t176_n35;
  t176_n34: return -0.03177884221076965f;
  t176_n35: if (E.getNumReferences() >= 3293888512 /*851.0*/) goto t176_n37;
  t176_n36: return 0.0714932307600975f;
  t176_n37: return 0.04426773637533188f;
  t176_n38: return 0.09918895363807678f;
  t176_n39: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t176_n81;
  t176_n40: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t176_n42;
  t176_n41: return 0.011549800634384155f;
  t176_n42: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t176_n80;
  t176_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t176_n55;
  t176_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t176_n48;
  t176_n45: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t176_n47;
  t176_n46: return -0.09019868820905685f;
  t176_n47: return 0.029462816193699837f;
  t176_n48: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t176_n50;
  t176_n49: return 0.03983277082443237f;
  t176_n50: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t176_n52;
  t176_n51: return -0.05149456858634949f;
  t176_n52: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t176_n54;
  t176_n53: return 0.13816651701927185f;
  t176_n54: return -0.035262394696474075f;
  t176_n55: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t176_n65;
  t176_n56: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t176_n58;
  t176_n57: return -0.19641530513763428f;
  t176_n58: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t176_n64;
  t176_n59: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t176_n63;
  t176_n60: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t176_n62;
  t176_n61: return 0.12909498810768127f;
  t176_n62: return 0.09047278016805649f;
  t176_n63: return -0.1561691164970398f;
  t176_n64: return 0.14759968221187592f;
  t176_n65: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t176_n77;
  t176_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t176_n68;
  t176_n67: return -0.023763328790664673f;
  t176_n68: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t176_n70;
  t176_n69: return 0.033195942640304565f;
  t176_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t176_n72;
  t176_n71: return 0.10088367015123367f;
  t176_n72: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t176_n74;
  t176_n73: return -0.08969245105981827f;
  t176_n74: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t176_n76;
  t176_n75: return 0.13116107881069183f;
  t176_n76: return 0.047506291419267654f;
  t176_n77: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t176_n79;
  t176_n78: return -0.14709466695785522f;
  t176_n79: return 0.10412479192018509f;
  t176_n80: return 0.013668385334312916f;
  t176_n81: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t176_n161;
  t176_n82: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t176_n100;
  t176_n83: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t176_n99;
  t176_n84: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t176_n98;
  t176_n85: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t176_n91;
  t176_n86: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n88;
  t176_n87: return -0.10924886912107468f;
  t176_n88: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t176_n90;
  t176_n89: return 0.1096864640712738f;
  t176_n90: return -0.008549611084163189f;
  t176_n91: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t176_n93;
  t176_n92: return 0.10895030945539474f;
  t176_n93: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t176_n97;
  t176_n94: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t176_n96;
  t176_n95: return -0.15364687144756317f;
  t176_n96: return 0.1705411672592163f;
  t176_n97: return 0.11187689751386642f;
  t176_n98: return 0.02276303619146347f;
  t176_n99: return -0.08234378695487976f;
  t176_n100: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t176_n118;
  t176_n101: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t176_n103;
  t176_n102: return 0.00896972231566906f;
  t176_n103: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t176_n105;
  t176_n104: return 0.06319660693407059f;
  t176_n105: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t176_n117;
  t176_n106: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t176_n108;
  t176_n107: return 0.15848729014396667f;
  t176_n108: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t176_n114;
  t176_n109: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t176_n113;
  t176_n110: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t176_n112;
  t176_n111: return 0.8624885082244873f;
  t176_n112: return 0.11060649156570435f;
  t176_n113: return 0.03834899142384529f;
  t176_n114: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n116;
  t176_n115: return 0.11250381171703339f;
  t176_n116: return 0.12692837417125702f;
  t176_n117: return -0.1339406669139862f;
  t176_n118: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t176_n120;
  t176_n119: return 0.0009153832797892392f;
  t176_n120: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t176_n148;
  t176_n121: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t176_n123;
  t176_n122: return 0.0021150424145162106f;
  t176_n123: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t176_n125;
  t176_n124: return -0.010180666111409664f;
  t176_n125: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t176_n127;
  t176_n126: return 0.030076628550887108f;
  t176_n127: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n143;
  t176_n128: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t176_n142;
  t176_n129: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t176_n131;
  t176_n130: return 0.08295987546443939f;
  t176_n131: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t176_n133;
  t176_n132: return 0.03238701820373535f;
  t176_n133: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t176_n135;
  t176_n134: return 0.0814627856016159f;
  t176_n135: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t176_n137;
  t176_n136: return 0.0294413510710001f;
  t176_n137: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t176_n139;
  t176_n138: return 0.014656325802206993f;
  t176_n139: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t176_n141;
  t176_n140: return 0.09154242277145386f;
  t176_n141: return -0.13474580645561218f;
  t176_n142: return 0.02033083513379097f;
  t176_n143: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t176_n147;
  t176_n144: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t176_n146;
  t176_n145: return -0.017653517425060272f;
  t176_n146: return 0.06114513799548149f;
  t176_n147: return 0.11822322010993958f;
  t176_n148: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t176_n150;
  t176_n149: return -0.06873512268066406f;
  t176_n150: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t176_n160;
  t176_n151: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t176_n159;
  t176_n152: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t176_n158;
  t176_n153: if (E.getNumReferences() >= 3260153856 /*52.5*/) goto t176_n155;
  t176_n154: return 0.13330884277820587f;
  t176_n155: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n157;
  t176_n156: return -0.11203644424676895f;
  t176_n157: return 0.10776790976524353f;
  t176_n158: return 0.02282494306564331f;
  t176_n159: return -0.02200036309659481f;
  t176_n160: return 0.05121050029993057f;
  t176_n161: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t176_n219;
  t176_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t176_n166;
  t176_n163: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t176_n165;
  t176_n164: return -0.05594972148537636f;
  t176_n165: return 0.19143299758434296f;
  t176_n166: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t176_n172;
  t176_n167: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t176_n169;
  t176_n168: return 0.024157943204045296f;
  t176_n169: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t176_n171;
  t176_n170: return -0.1710437536239624f;
  t176_n171: return -0.03474530950188637f;
  t176_n172: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t176_n192;
  t176_n173: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t176_n187;
  t176_n174: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t176_n176;
  t176_n175: return -0.07007706165313721f;
  t176_n176: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t176_n184;
  t176_n177: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t176_n179;
  t176_n178: return -0.0812382772564888f;
  t176_n179: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t176_n183;
  t176_n180: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t176_n182;
  t176_n181: return 0.10722175985574722f;
  t176_n182: return -0.03881087154150009f;
  t176_n183: return 0.10776451230049133f;
  t176_n184: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t176_n186;
  t176_n185: return 0.1293865144252777f;
  t176_n186: return -0.14699813723564148f;
  t176_n187: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t176_n189;
  t176_n188: return 0.11760580539703369f;
  t176_n189: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t176_n191;
  t176_n190: return -0.11810611933469772f;
  t176_n191: return 0.11571376770734787f;
  t176_n192: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t176_n194;
  t176_n193: return -0.09014682471752167f;
  t176_n194: if (E.getNumReferences() >= 3279814656 /*254.0*/) goto t176_n208;
  t176_n195: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t176_n205;
  t176_n196: if (E.getNumReferences() >= 3278962688 /*241.0*/) goto t176_n204;
  t176_n197: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t176_n201;
  t176_n198: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t176_n200;
  t176_n199: return 0.08830820024013519f;
  t176_n200: return 0.005206044297665358f;
  t176_n201: if (E.getNumReferences() >= 3272736768 /*146.0*/) goto t176_n203;
  t176_n202: return 0.11969684809446335f;
  t176_n203: return 0.06653214246034622f;
  t176_n204: return 0.15008200705051422f;
  t176_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n207;
  t176_n206: return 0.09195809066295624f;
  t176_n207: return 0.1393737494945526f;
  t176_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t176_n216;
  t176_n209: if (E.getNumReferences() >= 3296608256 /*1017.0*/) goto t176_n213;
  t176_n210: if (E.getNumReferences() >= 3291398144 /*699.0*/) goto t176_n212;
  t176_n211: return -0.04336072877049446f;
  t176_n212: return -0.3797342777252197f;
  t176_n213: if (E.getNumReferences() >= 3297202176 /*1082.5*/) goto t176_n215;
  t176_n214: return 0.1266629546880722f;
  t176_n215: return -0.07761402428150177f;
  t176_n216: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t176_n218;
  t176_n217: return -0.06630448251962662f;
  t176_n218: return 0.11551117897033691f;
  t176_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t176_n233;
  t176_n220: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t176_n228;
  t176_n221: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t176_n223;
  t176_n222: return 0.045424070209264755f;
  t176_n223: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t176_n225;
  t176_n224: return 0.6037192940711975f;
  t176_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n227;
  t176_n226: return 0.13685989379882812f;
  t176_n227: return 0.051933448761701584f;
  t176_n228: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n232;
  t176_n229: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t176_n231;
  t176_n230: return -0.020969880744814873f;
  t176_n231: return 0.08756247907876968f;
  t176_n232: return 0.10586483031511307f;
  t176_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n235;
  t176_n234: return -0.06419984251260757f;
  t176_n235: return 0.05875939875841141f;
  t176_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t176_n240;
  t176_n237: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t176_n239;
  t176_n238: return -0.006439375691115856f;
  t176_n239: return 0.0037990580312907696f;
  t176_n240: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t176_n252;
  t176_n241: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t176_n243;
  t176_n242: return 0.02264370210468769f;
  t176_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n245;
  t176_n244: return 0.0800895020365715f;
  t176_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t176_n251;
  t176_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t176_n248;
  t176_n247: return 0.013807513751089573f;
  t176_n248: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t176_n250;
  t176_n249: return 0.10974359512329102f;
  t176_n250: return 0.13233643770217896f;
  t176_n251: return -0.08885827660560608f;
  t176_n252: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t176_n254;
  t176_n253: return 0.007429932709783316f;
  t176_n254: return -0.07878474146127701f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree177(const Example& E) {
  t177_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t177_n2;
  t177_n1: return -0.000390149507438764f;
  t177_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t177_n10;
  t177_n3: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t177_n9;
  t177_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t177_n8;
  t177_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t177_n7;
  t177_n6: return -0.14077432453632355f;
  t177_n7: return -0.21501679718494415f;
  t177_n8: return -0.019651515409350395f;
  t177_n9: return 0.00017687772924546152f;
  t177_n10: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t177_n188;
  t177_n11: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t177_n27;
  t177_n12: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t177_n14;
  t177_n13: return 0.006539792753756046f;
  t177_n14: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t177_n22;
  t177_n15: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t177_n17;
  t177_n16: return -0.00989763718098402f;
  t177_n17: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t177_n19;
  t177_n18: return -0.0700974240899086f;
  t177_n19: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t177_n21;
  t177_n20: return -0.15801195800304413f;
  t177_n21: return -0.15861250460147858f;
  t177_n22: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t177_n26;
  t177_n23: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t177_n25;
  t177_n24: return -0.1639707088470459f;
  t177_n25: return 0.029470127075910568f;
  t177_n26: return 0.11708724498748779f;
  t177_n27: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t177_n109;
  t177_n28: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t177_n50;
  t177_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t177_n37;
  t177_n30: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t177_n36;
  t177_n31: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t177_n35;
  t177_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t177_n34;
  t177_n33: return 0.18690137565135956f;
  t177_n34: return 0.11692226678133011f;
  t177_n35: return 0.05051310360431671f;
  t177_n36: return -0.07452430576086044f;
  t177_n37: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t177_n49;
  t177_n38: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t177_n40;
  t177_n39: return -0.1365058273077011f;
  t177_n40: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t177_n48;
  t177_n41: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t177_n43;
  t177_n42: return 0.06289684772491455f;
  t177_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n47;
  t177_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t177_n46;
  t177_n45: return -0.12275335937738419f;
  t177_n46: return 0.0812181755900383f;
  t177_n47: return 0.08612003922462463f;
  t177_n48: return -0.07802195101976395f;
  t177_n49: return -0.24325628578662872f;
  t177_n50: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t177_n64;
  t177_n51: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t177_n63;
  t177_n52: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t177_n60;
  t177_n53: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t177_n57;
  t177_n54: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t177_n56;
  t177_n55: return 0.09995579719543457f;
  t177_n56: return -0.03133971989154816f;
  t177_n57: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t177_n59;
  t177_n58: return -0.14541399478912354f;
  t177_n59: return 0.1305980086326599f;
  t177_n60: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n62;
  t177_n61: return -0.045735254883766174f;
  t177_n62: return 0.12231747061014175f;
  t177_n63: return -0.09389390796422958f;
  t177_n64: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t177_n100;
  t177_n65: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t177_n87;
  t177_n66: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t177_n68;
  t177_n67: return -0.00902304146438837f;
  t177_n68: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t177_n86;
  t177_n69: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t177_n85;
  t177_n70: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t177_n72;
  t177_n71: return -0.15808500349521637f;
  t177_n72: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t177_n76;
  t177_n73: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t177_n75;
  t177_n74: return 0.11249828338623047f;
  t177_n75: return -0.13762669265270233f;
  t177_n76: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t177_n84;
  t177_n77: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t177_n83;
  t177_n78: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t177_n80;
  t177_n79: return -0.1524084061384201f;
  t177_n80: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t177_n82;
  t177_n81: return 0.10685862600803375f;
  t177_n82: return 0.01476842351257801f;
  t177_n83: return 0.16761745512485504f;
  t177_n84: return -0.4336182177066803f;
  t177_n85: return 0.09253909438848495f;
  t177_n86: return 0.10606599599123001f;
  t177_n87: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t177_n95;
  t177_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t177_n90;
  t177_n89: return -0.38739094138145447f;
  t177_n90: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t177_n94;
  t177_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t177_n93;
  t177_n92: return -0.10733252018690109f;
  t177_n93: return 0.11192444711923599f;
  t177_n94: return 0.12160857766866684f;
  t177_n95: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t177_n97;
  t177_n96: return 0.04012085869908333f;
  t177_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n99;
  t177_n98: return 0.008728859946131706f;
  t177_n99: return 0.11178336292505264f;
  t177_n100: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t177_n102;
  t177_n101: return -0.004364111460745335f;
  t177_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t177_n104;
  t177_n103: return -0.10436521470546722f;
  t177_n104: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t177_n108;
  t177_n105: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t177_n107;
  t177_n106: return 0.1312233805656433f;
  t177_n107: return 0.011721893213689327f;
  t177_n108: return 0.04396749287843704f;
  t177_n109: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t177_n147;
  t177_n110: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n116;
  t177_n111: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t177_n113;
  t177_n112: return -0.030824050307273865f;
  t177_n113: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t177_n115;
  t177_n114: return 0.11378654837608337f;
  t177_n115: return 0.0376536063849926f;
  t177_n116: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t177_n122;
  t177_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t177_n119;
  t177_n118: return -0.23374895751476288f;
  t177_n119: if (E.getNumReferences() >= 3257401344 /*42.0*/) goto t177_n121;
  t177_n120: return -0.137730211019516f;
  t177_n121: return 0.09471195936203003f;
  t177_n122: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t177_n124;
  t177_n123: return -0.14751887321472168f;
  t177_n124: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t177_n130;
  t177_n125: if (E.getNumReferences() >= 3273129984 /*152.0*/) goto t177_n127;
  t177_n126: return -0.11126815527677536f;
  t177_n127: if (E.getNumReferences() >= 3277127680 /*213.0*/) goto t177_n129;
  t177_n128: return 0.12106175720691681f;
  t177_n129: return 0.004712610971182585f;
  t177_n130: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t177_n136;
  t177_n131: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t177_n133;
  t177_n132: return 0.09109578281641006f;
  t177_n133: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t177_n135;
  t177_n134: return 0.10168681293725967f;
  t177_n135: return -0.18267704546451569f;
  t177_n136: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t177_n140;
  t177_n137: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t177_n139;
  t177_n138: return -0.25942549109458923f;
  t177_n139: return 0.06281420588493347f;
  t177_n140: if (E.getNumReferences() >= 3256352768 /*38.0*/) goto t177_n142;
  t177_n141: return 0.10020679980516434f;
  t177_n142: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t177_n144;
  t177_n143: return -0.24271777272224426f;
  t177_n144: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t177_n146;
  t177_n145: return 0.11707417666912079f;
  t177_n146: return 0.0744423121213913f;
  t177_n147: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t177_n187;
  t177_n148: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t177_n174;
  t177_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t177_n161;
  t177_n150: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t177_n152;
  t177_n151: return -0.09687678515911102f;
  t177_n152: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n154;
  t177_n153: return 0.03401947021484375f;
  t177_n154: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t177_n156;
  t177_n155: return -0.22381173074245453f;
  t177_n156: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t177_n158;
  t177_n157: return 0.09793730080127716f;
  t177_n158: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t177_n160;
  t177_n159: return 0.119362473487854f;
  t177_n160: return 0.10084366053342819f;
  t177_n161: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t177_n173;
  t177_n162: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t177_n168;
  t177_n163: if (E.getNumReferences() >= 3256090624 /*37.0*/) goto t177_n167;
  t177_n164: if (E.getNumReferences() >= 3250061312 /*23.0*/) goto t177_n166;
  t177_n165: return 0.090629942715168f;
  t177_n166: return -0.06629298627376556f;
  t177_n167: return 0.11528375744819641f;
  t177_n168: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t177_n170;
  t177_n169: return -0.2501525282859802f;
  t177_n170: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t177_n172;
  t177_n171: return 0.10646555572748184f;
  t177_n172: return -0.0559065006673336f;
  t177_n173: return 0.031517427414655685f;
  t177_n174: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t177_n184;
  t177_n175: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t177_n177;
  t177_n176: return -0.06926585733890533f;
  t177_n177: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t177_n181;
  t177_n178: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t177_n180;
  t177_n179: return 0.1133953407406807f;
  t177_n180: return 0.039298128336668015f;
  t177_n181: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n183;
  t177_n182: return 0.1147204115986824f;
  t177_n183: return -0.05735696479678154f;
  t177_n184: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t177_n186;
  t177_n185: return 0.1147015169262886f;
  t177_n186: return 0.03304498642683029f;
  t177_n187: return 0.013656419701874256f;
  t177_n188: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t177_n212;
  t177_n189: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t177_n191;
  t177_n190: return -0.04378262162208557f;
  t177_n191: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t177_n193;
  t177_n192: return -0.04374217614531517f;
  t177_n193: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t177_n195;
  t177_n194: return -0.022285766899585724f;
  t177_n195: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t177_n201;
  t177_n196: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t177_n200;
  t177_n197: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t177_n199;
  t177_n198: return 0.1570809930562973f;
  t177_n199: return 0.10877250880002975f;
  t177_n200: return 0.05333009734749794f;
  t177_n201: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t177_n211;
  t177_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t177_n204;
  t177_n203: return 0.023562509566545486f;
  t177_n204: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n210;
  t177_n205: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t177_n209;
  t177_n206: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t177_n208;
  t177_n207: return 0.024177711457014084f;
  t177_n208: return 0.0594371072947979f;
  t177_n209: return -0.029574759304523468f;
  t177_n210: return 0.009104850701987743f;
  t177_n211: return -0.003025685204192996f;
  t177_n212: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t177_n254;
  t177_n213: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t177_n237;
  t177_n214: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n222;
  t177_n215: if (E.getNumReferences() >= 3322721280 /*9005.0*/) goto t177_n219;
  t177_n216: if (E.getFileProximityDistance() >= 3251109888 /*25.0*/) goto t177_n218;
  t177_n217: return 0.03170266002416611f;
  t177_n218: return 1.007369875907898f;
  t177_n219: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t177_n221;
  t177_n220: return 0.09120277315378189f;
  t177_n221: return -0.04685872048139572f;
  t177_n222: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t177_n236;
  t177_n223: if (E.getNumReferences() >= 3334587392 /*24802.0*/) goto t177_n235;
  t177_n224: if (E.getNumReferences() >= 3290071040 /*618.0*/) goto t177_n234;
  t177_n225: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t177_n231;
  t177_n226: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t177_n228;
  t177_n227: return 0.04099518060684204f;
  t177_n228: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t177_n230;
  t177_n229: return 0.10634998977184296f;
  t177_n230: return 0.08317594975233078f;
  t177_n231: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t177_n233;
  t177_n232: return 0.04653552547097206f;
  t177_n233: return -0.15003082156181335f;
  t177_n234: return 0.09326910972595215f;
  t177_n235: return -0.6865056753158569f;
  t177_n236: return 0.13838237524032593f;
  t177_n237: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t177_n239;
  t177_n238: return 0.0027840412221848965f;
  t177_n239: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t177_n253;
  t177_n240: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t177_n242;
  t177_n241: return -0.03804606571793556f;
  t177_n242: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t177_n248;
  t177_n243: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t177_n247;
  t177_n244: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t177_n246;
  t177_n245: return 0.11219148337841034f;
  t177_n246: return -0.1117468997836113f;
  t177_n247: return 0.10669496655464172f;
  t177_n248: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t177_n252;
  t177_n249: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t177_n251;
  t177_n250: return 0.06165629252791405f;
  t177_n251: return 0.1110730841755867f;
  t177_n252: return -0.13619622588157654f;
  t177_n253: return 0.006763484328985214f;
  t177_n254: return 0.002987643238157034f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree178(const Example& E) {
  t178_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t178_n230;
  t178_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t178_n3;
  t178_n2: return -0.00020145418238826096f;
  t178_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t178_n165;
  t178_n4: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t178_n164;
  t178_n5: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t178_n25;
  t178_n6: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t178_n10;
  t178_n7: if (E.getNumReferences() >= 3280207872 /*264.0*/) goto t178_n9;
  t178_n8: return 0.02225569635629654f;
  t178_n9: return -0.4386032521724701f;
  t178_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t178_n12;
  t178_n11: return -0.026421571150422096f;
  t178_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t178_n14;
  t178_n13: return 0.00583090353757143f;
  t178_n14: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t178_n16;
  t178_n15: return 0.01864231377840042f;
  t178_n16: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t178_n18;
  t178_n17: return -0.03270494565367699f;
  t178_n18: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t178_n20;
  t178_n19: return 0.023247646167874336f;
  t178_n20: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t178_n22;
  t178_n21: return -0.012974857352674007f;
  t178_n22: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t178_n24;
  t178_n23: return -0.1157151609659195f;
  t178_n24: return 0.11162222921848297f;
  t178_n25: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t178_n129;
  t178_n26: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t178_n28;
  t178_n27: return 0.02660672925412655f;
  t178_n28: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t178_n62;
  t178_n29: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t178_n61;
  t178_n30: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t178_n34;
  t178_n31: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t178_n33;
  t178_n32: return -0.037410952150821686f;
  t178_n33: return -0.22737224400043488f;
  t178_n34: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t178_n60;
  t178_n35: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t178_n39;
  t178_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t178_n38;
  t178_n37: return 0.028122689574956894f;
  t178_n38: return 0.1001436784863472f;
  t178_n39: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t178_n55;
  t178_n40: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t178_n42;
  t178_n41: return -0.07286402583122253f;
  t178_n42: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t178_n50;
  t178_n43: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t178_n49;
  t178_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t178_n46;
  t178_n45: return -0.1349981725215912f;
  t178_n46: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t178_n48;
  t178_n47: return 0.09154918789863586f;
  t178_n48: return 0.13500787317752838f;
  t178_n49: return -0.027534935623407364f;
  t178_n50: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t178_n52;
  t178_n51: return -0.09464459121227264f;
  t178_n52: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t178_n54;
  t178_n53: return 0.02532198466360569f;
  t178_n54: return 0.13900305330753326f;
  t178_n55: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t178_n57;
  t178_n56: return 0.020892083644866943f;
  t178_n57: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t178_n59;
  t178_n58: return 0.12279364466667175f;
  t178_n59: return -0.11412575095891953f;
  t178_n60: return 0.10405834019184113f;
  t178_n61: return -0.0009496358688920736f;
  t178_n62: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t178_n64;
  t178_n63: return -0.049769822508096695f;
  t178_n64: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t178_n74;
  t178_n65: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t178_n69;
  t178_n66: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t178_n68;
  t178_n67: return -0.4498443007469177f;
  t178_n68: return 0.08675692975521088f;
  t178_n69: if (E.getNumReferences() >= 3269459968 /*112.0*/) goto t178_n71;
  t178_n70: return -0.03050893358886242f;
  t178_n71: if (E.getNumReferences() >= 3274899456 /*179.0*/) goto t178_n73;
  t178_n72: return 0.12125296145677567f;
  t178_n73: return 0.0410318523645401f;
  t178_n74: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t178_n96;
  t178_n75: if (E.getNumReferences() >= 3278503936 /*234.0*/) goto t178_n95;
  t178_n76: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t178_n94;
  t178_n77: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t178_n91;
  t178_n78: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t178_n90;
  t178_n79: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t178_n81;
  t178_n80: return -0.6921550631523132f;
  t178_n81: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t178_n83;
  t178_n82: return -0.07243554294109344f;
  t178_n83: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t178_n85;
  t178_n84: return 0.09583292156457901f;
  t178_n85: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t178_n89;
  t178_n86: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t178_n88;
  t178_n87: return -0.0015079390723258257f;
  t178_n88: return 0.11832374334335327f;
  t178_n89: return -0.33082446455955505f;
  t178_n90: return 0.10098050534725189f;
  t178_n91: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t178_n93;
  t178_n92: return 0.10483294725418091f;
  t178_n93: return 0.02193715237081051f;
  t178_n94: return -0.10469905287027359f;
  t178_n95: return 0.07874462008476257f;
  t178_n96: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t178_n114;
  t178_n97: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t178_n101;
  t178_n98: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t178_n100;
  t178_n99: return 0.11487466841936111f;
  t178_n100: return 0.056790150701999664f;
  t178_n101: if (E.getSymbolScopeDistance() >= 3240099840 /*10.0*/) goto t178_n109;
  t178_n102: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t178_n108;
  t178_n103: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t178_n105;
  t178_n104: return -0.07018359750509262f;
  t178_n105: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t178_n107;
  t178_n106: return 0.11969397962093353f;
  t178_n107: return 0.04435697942972183f;
  t178_n108: return 0.09233160316944122f;
  t178_n109: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t178_n111;
  t178_n110: return 0.11442156136035919f;
  t178_n111: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t178_n113;
  t178_n112: return -0.14979925751686096f;
  t178_n113: return 0.1118730753660202f;
  t178_n114: if (E.getNumReferences() >= 3269066752 /*109.0*/) goto t178_n120;
  t178_n115: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t178_n119;
  t178_n116: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t178_n118;
  t178_n117: return 0.12633544206619263f;
  t178_n118: return 0.06396222114562988f;
  t178_n119: return -0.014791748486459255f;
  t178_n120: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t178_n128;
  t178_n121: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t178_n125;
  t178_n122: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t178_n124;
  t178_n123: return -0.14140069484710693f;
  t178_n124: return 0.12176613509654999f;
  t178_n125: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n127;
  t178_n126: return -0.23153725266456604f;
  t178_n127: return 0.11796277016401291f;
  t178_n128: return 0.021743157878518105f;
  t178_n129: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t178_n159;
  t178_n130: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t178_n152;
  t178_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n149;
  t178_n132: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t178_n134;
  t178_n133: return 0.10427269339561462f;
  t178_n134: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t178_n142;
  t178_n135: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t178_n137;
  t178_n136: return 0.06543313711881638f;
  t178_n137: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t178_n139;
  t178_n138: return 0.21429535746574402f;
  t178_n139: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t178_n141;
  t178_n140: return 0.13480810821056366f;
  t178_n141: return 0.04959540814161301f;
  t178_n142: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t178_n148;
  t178_n143: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t178_n145;
  t178_n144: return -0.19346283376216888f;
  t178_n145: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t178_n147;
  t178_n146: return 0.08898285031318665f;
  t178_n147: return 0.10962776839733124f;
  t178_n148: return -0.012936791405081749f;
  t178_n149: if (E.getNumReferences() >= 3247439872 /*18.0*/) goto t178_n151;
  t178_n150: return 0.017175450921058655f;
  t178_n151: return -0.6122277975082397f;
  t178_n152: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n154;
  t178_n153: return -0.01205557119101286f;
  t178_n154: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t178_n156;
  t178_n155: return -0.002586424583569169f;
  t178_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t178_n158;
  t178_n157: return 0.10199514776468277f;
  t178_n158: return 0.1137448102235794f;
  t178_n159: if (E.getNumReferences() >= 3303403520 /*1839.5*/) goto t178_n163;
  t178_n160: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t178_n162;
  t178_n161: return 0.006636401172727346f;
  t178_n162: return -0.22753921151161194f;
  t178_n163: return 0.09561043977737427f;
  t178_n164: return -0.0019318696577101946f;
  t178_n165: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t178_n167;
  t178_n166: return 0.0064772069454193115f;
  t178_n167: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t178_n181;
  t178_n168: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t178_n180;
  t178_n169: if (E.getNumReferences() >= 3305879552 /*2235.5*/) goto t178_n179;
  t178_n170: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t178_n178;
  t178_n171: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n175;
  t178_n172: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t178_n174;
  t178_n173: return 0.10374537110328674f;
  t178_n174: return 0.11584331095218658f;
  t178_n175: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t178_n177;
  t178_n176: return 0.09150953590869904f;
  t178_n177: return -0.34021905064582825f;
  t178_n178: return 0.053244698792696f;
  t178_n179: return 0.10874247550964355f;
  t178_n180: return 0.008969453163444996f;
  t178_n181: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t178_n223;
  t178_n182: if (E.getNumReferences() >= 3324623872 /*10863.0*/) goto t178_n220;
  t178_n183: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t178_n209;
  t178_n184: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t178_n204;
  t178_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n195;
  t178_n186: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t178_n194;
  t178_n187: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t178_n189;
  t178_n188: return 0.08025682717561722f;
  t178_n189: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t178_n193;
  t178_n190: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t178_n192;
  t178_n191: return -0.15171626210212708f;
  t178_n192: return 0.13465553522109985f;
  t178_n193: return 0.10371610522270203f;
  t178_n194: return -0.023629801347851753f;
  t178_n195: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t178_n203;
  t178_n196: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t178_n198;
  t178_n197: return -0.012766093946993351f;
  t178_n198: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t178_n202;
  t178_n199: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t178_n201;
  t178_n200: return 0.09511766582727432f;
  t178_n201: return 0.09000690281391144f;
  t178_n202: return -0.4988269507884979f;
  t178_n203: return -0.039677694439888f;
  t178_n204: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t178_n208;
  t178_n205: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t178_n207;
  t178_n206: return 0.10456015169620514f;
  t178_n207: return 0.11504139006137848f;
  t178_n208: return 0.004218322690576315f;
  t178_n209: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t178_n211;
  t178_n210: return 0.02802639827132225f;
  t178_n211: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n213;
  t178_n212: return 0.03291323035955429f;
  t178_n213: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t178_n215;
  t178_n214: return 0.12438186258077621f;
  t178_n215: if (E.getNumReferences() >= 3282731008 /*341.0*/) goto t178_n217;
  t178_n216: return 0.11971411854028702f;
  t178_n217: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t178_n219;
  t178_n218: return 0.1301061064004898f;
  t178_n219: return -0.0279241930693388f;
  t178_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t178_n222;
  t178_n221: return 0.1009020060300827f;
  t178_n222: return 0.006687514949589968f;
  t178_n223: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t178_n227;
  t178_n224: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t178_n226;
  t178_n225: return -0.19174383580684662f;
  t178_n226: return 0.10750926285982132f;
  t178_n227: if (E.getNumReferences() >= 3269132288 /*109.5*/) goto t178_n229;
  t178_n228: return -0.6217468976974487f;
  t178_n229: return -0.30951523780822754f;
  t178_n230: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t178_n246;
  t178_n231: if (E.getNumReferences() >= 3284877312 /*406.5*/) goto t178_n233;
  t178_n232: return -0.038484279066324234f;
  t178_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t178_n245;
  t178_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n244;
  t178_n235: if (E.getNumReferences() >= 3298754560 /*1272.0*/) goto t178_n241;
  t178_n236: if (E.getNumReferences() >= 3294642176 /*897.0*/) goto t178_n240;
  t178_n237: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t178_n239;
  t178_n238: return -0.13799281418323517f;
  t178_n239: return 0.883996307849884f;
  t178_n240: return 0.19915200769901276f;
  t178_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t178_n243;
  t178_n242: return -0.11338190734386444f;
  t178_n243: return 0.3873768448829651f;
  t178_n244: return 0.07181569188833237f;
  t178_n245: return -0.10227082669734955f;
  t178_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t178_n254;
  t178_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n249;
  t178_n248: return -0.07719717174768448f;
  t178_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t178_n253;
  t178_n250: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t178_n252;
  t178_n251: return -0.14223049581050873f;
  t178_n252: return -0.2879208028316498f;
  t178_n253: return -0.12408822029829025f;
  t178_n254: return -0.01726151444017887f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree179(const Example& E) {
  t179_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t179_n2;
  t179_n1: return -0.00039998465217649937f;
  t179_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t179_n168;
  t179_n3: if (E.getNumReferences() >= 3298328576 /*1220.0*/) goto t179_n7;
  t179_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t179_n6;
  t179_n5: return -0.0028190561570227146f;
  t179_n6: return 0.13108253479003906f;
  t179_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t179_n167;
  t179_n8: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t179_n12;
  t179_n9: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t179_n11;
  t179_n10: return -0.008237339556217194f;
  t179_n11: return 0.0616728700697422f;
  t179_n12: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t179_n156;
  t179_n13: if (E.getNumReferences() >= 3325242368 /*11467.0*/) goto t179_n21;
  t179_n14: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t179_n16;
  t179_n15: return 0.05982687696814537f;
  t179_n16: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t179_n18;
  t179_n17: return -0.010620025917887688f;
  t179_n18: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t179_n20;
  t179_n19: return 0.10692249983549118f;
  t179_n20: return 0.11250372976064682f;
  t179_n21: if (E.getNumReferences() >= 3361098688 /*219439.0*/) goto t179_n155;
  t179_n22: if (E.getNumReferences() >= 3339244032 /*35026.0*/) goto t179_n80;
  t179_n23: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t179_n77;
  t179_n24: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t179_n66;
  t179_n25: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t179_n49;
  t179_n26: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t179_n48;
  t179_n27: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t179_n37;
  t179_n28: if (E.getNumReferences() >= 3330330368 /*16487.5*/) goto t179_n36;
  t179_n29: if (E.getNumReferences() >= 3330192896 /*16301.5*/) goto t179_n35;
  t179_n30: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t179_n34;
  t179_n31: if (E.getNumReferences() >= 3325383680 /*11605.0*/) goto t179_n33;
  t179_n32: return 0.1212223470211029f;
  t179_n33: return 0.03221386298537254f;
  t179_n34: return -0.07725005596876144f;
  t179_n35: return 0.1320531964302063f;
  t179_n36: return -0.017849059775471687f;
  t179_n37: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t179_n43;
  t179_n38: if (E.getNumReferences() >= 3337965568 /*31400.0*/) goto t179_n40;
  t179_n39: return 0.009879023768007755f;
  t179_n40: if (E.getNumReferences() >= 3338812928 /*33342.0*/) goto t179_n42;
  t179_n41: return 0.15554344654083252f;
  t179_n42: return -0.10554318875074387f;
  t179_n43: if (E.getNumReferences() >= 3332038144 /*19823.0*/) goto t179_n47;
  t179_n44: if (E.getNumReferences() >= 3331079424 /*17950.5*/) goto t179_n46;
  t179_n45: return 0.5013631582260132f;
  t179_n46: return 0.12705029547214508f;
  t179_n47: return -0.2357441931962967f;
  t179_n48: return 0.004418500699102879f;
  t179_n49: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t179_n55;
  t179_n50: if (E.getNumReferences() >= 3331347712 /*18474.5*/) goto t179_n54;
  t179_n51: if (E.getNumReferences() >= 3331214848 /*18215.0*/) goto t179_n53;
  t179_n52: return 0.021192342042922974f;
  t179_n53: return 0.11307284235954285f;
  t179_n54: return -0.15522004663944244f;
  t179_n55: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t179_n59;
  t179_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type))) goto t179_n58;
  t179_n57: return -0.1429699808359146f;
  t179_n58: return 0.09141042828559875f;
  t179_n59: if (E.getNumReferences() >= 3335568384 /*26718.0*/) goto t179_n65;
  t179_n60: if (E.getNumReferences() >= 3334574080 /*24776.0*/) goto t179_n64;
  t179_n61: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t179_n63;
  t179_n62: return 0.012183521874248981f;
  t179_n63: return 0.13219834864139557f;
  t179_n64: return 0.10008124262094498f;
  t179_n65: return -0.059245895594358444f;
  t179_n66: if (E.getNumReferences() >= 3330499328 /*16817.5*/) goto t179_n70;
  t179_n67: if (E.getNumReferences() >= 3325739520 /*11952.5*/) goto t179_n69;
  t179_n68: return 0.025176016613841057f;
  t179_n69: return -0.32512107491493225f;
  t179_n70: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t179_n76;
  t179_n71: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t179_n75;
  t179_n72: if (E.getNumReferences() >= 3331408640 /*18593.5*/) goto t179_n74;
  t179_n73: return 0.10072766244411469f;
  t179_n74: return 0.10414355993270874f;
  t179_n75: return -0.02561655268073082f;
  t179_n76: return -0.040144845843315125f;
  t179_n77: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t179_n79;
  t179_n78: return -0.23080971837043762f;
  t179_n79: return 0.10454107075929642f;
  t179_n80: if (E.getNumReferences() >= 3342848512 /*49106.0*/) goto t179_n100;
  t179_n81: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t179_n91;
  t179_n82: if (E.getNumReferences() >= 3339443456 /*35805.0*/) goto t179_n88;
  t179_n83: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t179_n87;
  t179_n84: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t179_n86;
  t179_n85: return -0.1857873946428299f;
  t179_n86: return 0.10567515343427658f;
  t179_n87: return -0.3736220598220825f;
  t179_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t179_n90;
  t179_n89: return -0.01702474057674408f;
  t179_n90: return 0.05043250694870949f;
  t179_n91: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t179_n95;
  t179_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t179_n94;
  t179_n93: return 0.034261107444763184f;
  t179_n94: return 0.08730768412351608f;
  t179_n95: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t179_n99;
  t179_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t179_n98;
  t179_n97: return -0.13243485987186432f;
  t179_n98: return 0.08891291171312332f;
  t179_n99: return 0.0560181550681591f;
  t179_n100: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t179_n102;
  t179_n101: return -0.020639510825276375f;
  t179_n102: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t179_n146;
  t179_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t179_n105;
  t179_n104: return -0.0003562315250746906f;
  t179_n105: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t179_n123;
  t179_n106: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t179_n116;
  t179_n107: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t179_n115;
  t179_n108: if (E.getNumReferences() >= 3349883520 /*87637.0*/) goto t179_n110;
  t179_n109: return 0.0323173888027668f;
  t179_n110: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t179_n114;
  t179_n111: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t179_n113;
  t179_n112: return 0.102862149477005f;
  t179_n113: return 0.06170634552836418f;
  t179_n114: return -0.2331061065196991f;
  t179_n115: return -0.10174140334129333f;
  t179_n116: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t179_n118;
  t179_n117: return -0.013782525435090065f;
  t179_n118: if (E.getNumReferences() >= 3348072384 /*73487.5*/) goto t179_n120;
  t179_n119: return 0.09841644018888474f;
  t179_n120: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t179_n122;
  t179_n121: return -0.5529049038887024f;
  t179_n122: return 0.1053927093744278f;
  t179_n123: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t179_n133;
  t179_n124: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t179_n130;
  t179_n125: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t179_n127;
  t179_n126: return 0.10909270495176315f;
  t179_n127: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t179_n129;
  t179_n128: return 0.09218146651983261f;
  t179_n129: return -0.19299833476543427f;
  t179_n130: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t179_n132;
  t179_n131: return 0.053278449922800064f;
  t179_n132: return -0.455231249332428f;
  t179_n133: if (E.getNumReferences() >= 3351834112 /*102876.0*/) goto t179_n135;
  t179_n134: return -0.019955020397901535f;
  t179_n135: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t179_n145;
  t179_n136: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t179_n138;
  t179_n137: return 0.03960325941443443f;
  t179_n138: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t179_n140;
  t179_n139: return 0.02078094333410263f;
  t179_n140: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t179_n142;
  t179_n141: return 0.12079114466905594f;
  t179_n142: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t179_n144;
  t179_n143: return -0.2784310281276703f;
  t179_n144: return 0.153601735830307f;
  t179_n145: return -0.10640688985586166f;
  t179_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t179_n148;
  t179_n147: return -0.09700322896242142f;
  t179_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t179_n152;
  t179_n149: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t179_n151;
  t179_n150: return 0.047057077288627625f;
  t179_n151: return 0.09797867387533188f;
  t179_n152: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t179_n154;
  t179_n153: return 0.08389124274253845f;
  t179_n154: return 0.11027498543262482f;
  t179_n155: return -0.00776694668456912f;
  t179_n156: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t179_n158;
  t179_n157: return -0.0057794805616140366f;
  t179_n158: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t179_n166;
  t179_n159: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t179_n161;
  t179_n160: return 0.08495788276195526f;
  t179_n161: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t179_n165;
  t179_n162: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t179_n164;
  t179_n163: return -0.028445135802030563f;
  t179_n164: return 0.029858944937586784f;
  t179_n165: return 0.06024080887436867f;
  t179_n166: return -0.02447957918047905f;
  t179_n167: return 0.018547028303146362f;
  t179_n168: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t179_n170;
  t179_n169: return -0.0004777481372002512f;
  t179_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t179_n172;
  t179_n171: return 0.005694905761629343f;
  t179_n172: if (E.getNumReferences() >= 3299901440 /*1412.0*/) goto t179_n180;
  t179_n173: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t179_n179;
  t179_n174: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t179_n178;
  t179_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t179_n177;
  t179_n176: return -0.026724830269813538f;
  t179_n177: return 0.08762840181589127f;
  t179_n178: return 0.11988922208547592f;
  t179_n179: return 0.02347046323120594f;
  t179_n180: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t179_n206;
  t179_n181: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t179_n205;
  t179_n182: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t179_n190;
  t179_n183: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t179_n185;
  t179_n184: return -0.039432596415281296f;
  t179_n185: if (E.getNumReferences() >= 3310399488 /*3339.0*/) goto t179_n189;
  t179_n186: if (E.getNumReferences() >= 3309062144 /*3012.5*/) goto t179_n188;
  t179_n187: return -0.13639555871486664f;
  t179_n188: return 0.10995916277170181f;
  t179_n189: return 0.0296745877712965f;
  t179_n190: if (E.getNumReferences() >= 3351111424 /*97230.0*/) goto t179_n200;
  t179_n191: if (E.getNumReferences() >= 3338323200 /*32098.5*/) goto t179_n195;
  t179_n192: if (E.getNumReferences() >= 3316014080 /*5323.5*/) goto t179_n194;
  t179_n193: return 0.10443536937236786f;
  t179_n194: return -0.12158460170030594f;
  t179_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t179_n197;
  t179_n196: return -0.14795707166194916f;
  t179_n197: if (E.getNumReferences() >= 3339744256 /*36980.0*/) goto t179_n199;
  t179_n198: return 0.1292692869901657f;
  t179_n199: return 0.1221500113606453f;
  t179_n200: if (E.getNumReferences() >= 3363327264 /*254260.5*/) goto t179_n204;
  t179_n201: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t179_n203;
  t179_n202: return 0.10688687115907669f;
  t179_n203: return 0.10759350657463074f;
  t179_n204: return -0.052828311920166016f;
  t179_n205: return -0.06512115895748138f;
  t179_n206: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t179_n254;
  t179_n207: if (E.getNumReferences() >= 3359807328 /*199261.5*/) goto t179_n245;
  t179_n208: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t179_n210;
  t179_n209: return -0.018409358337521553f;
  t179_n210: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t179_n244;
  t179_n211: if (E.getNumReferences() >= 3309326336 /*3077.0*/) goto t179_n213;
  t179_n212: return -0.04012124612927437f;
  t179_n213: if (E.getNumReferences() >= 3310000128 /*3241.5*/) goto t179_n217;
  t179_n214: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t179_n216;
  t179_n215: return 0.1044839397072792f;
  t179_n216: return 0.011139802634716034f;
  t179_n217: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t179_n219;
  t179_n218: return -0.03212020918726921f;
  t179_n219: if (E.getNumReferences() >= 3320567808 /*7547.0*/) goto t179_n221;
  t179_n220: return 0.035415634512901306f;
  t179_n221: if (E.getNumReferences() >= 3322433024 /*8723.5*/) goto t179_n227;
  t179_n222: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t179_n226;
  t179_n223: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t179_n225;
  t179_n224: return 0.008431429974734783f;
  t179_n225: return 0.09738503396511078f;
  t179_n226: return 0.11776309460401535f;
  t179_n227: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t179_n241;
  t179_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t179_n238;
  t179_n229: if (E.getNumReferences() >= 3324083200 /*10335.0*/) goto t179_n231;
  t179_n230: return -0.14199551939964294f;
  t179_n231: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t179_n233;
  t179_n232: return -0.417422354221344f;
  t179_n233: if (E.getNumReferences() >= 3324847616 /*11081.5*/) goto t179_n235;
  t179_n234: return 0.10542873293161392f;
  t179_n235: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t179_n237;
  t179_n236: return 0.050343070179224014f;
  t179_n237: return 0.0803866758942604f;
  t179_n238: if (E.getNumReferences() >= 3323780096 /*10039.0*/) goto t179_n240;
  t179_n239: return 0.1467849314212799f;
  t179_n240: return 0.08054427057504654f;
  t179_n241: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t179_n243;
  t179_n242: return -0.5370262265205383f;
  t179_n243: return 0.07232190668582916f;
  t179_n244: return 0.010128199122846127f;
  t179_n245: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t179_n247;
  t179_n246: return 0.045570265501737595f;
  t179_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t179_n251;
  t179_n248: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t179_n250;
  t179_n249: return -0.09828488528728485f;
  t179_n250: return 0.08403901010751724f;
  t179_n251: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t179_n253;
  t179_n252: return 0.1050480306148529f;
  t179_n253: return -0.18777012825012207f;
  t179_n254: return -0.008209028281271458f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree180(const Example& E) {
  t180_n0: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t180_n236;
  t180_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t180_n127;
  t180_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t180_n100;
  t180_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t180_n5;
  t180_n4: return -0.04628494381904602f;
  t180_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t180_n7;
  t180_n6: return -0.06266451627016068f;
  t180_n7: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t180_n73;
  t180_n8: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t180_n30;
  t180_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t180_n11;
  t180_n10: return -0.10859336704015732f;
  t180_n11: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t180_n29;
  t180_n12: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n22;
  t180_n13: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t180_n21;
  t180_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t180_n20;
  t180_n15: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n19;
  t180_n16: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t180_n18;
  t180_n17: return 0.0028684765566140413f;
  t180_n18: return -0.01504200417548418f;
  t180_n19: return -0.008707613684237003f;
  t180_n20: return 0.004041273146867752f;
  t180_n21: return 0.007334784604609013f;
  t180_n22: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t180_n24;
  t180_n23: return -0.0016596510540693998f;
  t180_n24: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t180_n26;
  t180_n25: return 0.014299564994871616f;
  t180_n26: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t180_n28;
  t180_n27: return 0.08836674690246582f;
  t180_n28: return -0.020458223298192024f;
  t180_n29: return -0.051813311874866486f;
  t180_n30: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t180_n38;
  t180_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t180_n33;
  t180_n32: return 0.0009673252352513373f;
  t180_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t180_n37;
  t180_n34: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n36;
  t180_n35: return 0.08369125425815582f;
  t180_n36: return 0.09777361154556274f;
  t180_n37: return 0.017545174807310104f;
  t180_n38: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t180_n68;
  t180_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t180_n45;
  t180_n40: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t180_n44;
  t180_n41: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t180_n43;
  t180_n42: return -0.24257464706897736f;
  t180_n43: return -0.07501308619976044f;
  t180_n44: return -0.18927811086177826f;
  t180_n45: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n47;
  t180_n46: return 0.042406268417835236f;
  t180_n47: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t180_n63;
  t180_n48: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t180_n52;
  t180_n49: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t180_n51;
  t180_n50: return -0.0665026530623436f;
  t180_n51: return -0.0005112877697683871f;
  t180_n52: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t180_n54;
  t180_n53: return -0.030497577041387558f;
  t180_n54: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t180_n58;
  t180_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n57;
  t180_n56: return 0.10465893894433975f;
  t180_n57: return 0.10476826876401901f;
  t180_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n62;
  t180_n59: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t180_n61;
  t180_n60: return 0.10131648182868958f;
  t180_n61: return 0.10639595240354538f;
  t180_n62: return 0.00627591647207737f;
  t180_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n67;
  t180_n64: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t180_n66;
  t180_n65: return 0.20060837268829346f;
  t180_n66: return 0.020408527925610542f;
  t180_n67: return 0.08133211731910706f;
  t180_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t180_n72;
  t180_n69: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t180_n71;
  t180_n70: return 0.1763128936290741f;
  t180_n71: return -0.03034706600010395f;
  t180_n72: return -0.028944911435246468f;
  t180_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t180_n91;
  t180_n74: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t180_n80;
  t180_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t180_n77;
  t180_n76: return 0.005347174126654863f;
  t180_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t180_n79;
  t180_n78: return 0.024953462183475494f;
  t180_n79: return 0.02280914969742298f;
  t180_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n86;
  t180_n81: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t180_n85;
  t180_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t180_n84;
  t180_n83: return 0.014004012569785118f;
  t180_n84: return 0.0609004870057106f;
  t180_n85: return -0.011491521261632442f;
  t180_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t180_n90;
  t180_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t180_n89;
  t180_n88: return -0.02493251860141754f;
  t180_n89: return 0.041232138872146606f;
  t180_n90: return -0.0010058965999633074f;
  t180_n91: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t180_n99;
  t180_n92: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n98;
  t180_n93: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t180_n97;
  t180_n94: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t180_n96;
  t180_n95: return 0.09799212217330933f;
  t180_n96: return 0.09633806347846985f;
  t180_n97: return 0.059776827692985535f;
  t180_n98: return 0.06533707678318024f;
  t180_n99: return -0.043587297201156616f;
  t180_n100: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t180_n126;
  t180_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t180_n103;
  t180_n102: return 0.0011095565278083086f;
  t180_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t180_n105;
  t180_n104: return -0.0008377032936550677f;
  t180_n105: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n107;
  t180_n106: return 0.005925206001847982f;
  t180_n107: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t180_n109;
  t180_n108: return 0.007452378980815411f;
  t180_n109: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t180_n113;
  t180_n110: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t180_n112;
  t180_n111: return -0.015247092582285404f;
  t180_n112: return 0.06039436534047127f;
  t180_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t180_n115;
  t180_n114: return -0.0009428478660993278f;
  t180_n115: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t180_n125;
  t180_n116: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n124;
  t180_n117: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t180_n119;
  t180_n118: return 0.06565598398447037f;
  t180_n119: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t180_n123;
  t180_n120: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t180_n122;
  t180_n121: return 0.06581185013055801f;
  t180_n122: return 0.08878441154956818f;
  t180_n123: return 0.019449152052402496f;
  t180_n124: return 0.024144019931554794f;
  t180_n125: return -0.10264390707015991f;
  t180_n126: return -0.05783015489578247f;
  t180_n127: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t180_n129;
  t180_n128: return 0.0044548227451741695f;
  t180_n129: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t180_n131;
  t180_n130: return -0.050505734980106354f;
  t180_n131: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t180_n235;
  t180_n132: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t180_n134;
  t180_n133: return -0.004130261018872261f;
  t180_n134: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t180_n186;
  t180_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t180_n137;
  t180_n136: return -0.04380081221461296f;
  t180_n137: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n173;
  t180_n138: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t180_n140;
  t180_n139: return 0.014409860596060753f;
  t180_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t180_n168;
  t180_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t180_n143;
  t180_n142: return 0.03318597003817558f;
  t180_n143: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t180_n167;
  t180_n144: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t180_n166;
  t180_n145: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t180_n161;
  t180_n146: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t180_n160;
  t180_n147: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t180_n157;
  t180_n148: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t180_n150;
  t180_n149: return 0.11178689450025558f;
  t180_n150: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t180_n156;
  t180_n151: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n153;
  t180_n152: return 0.1177116259932518f;
  t180_n153: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t180_n155;
  t180_n154: return -0.2485622763633728f;
  t180_n155: return 0.10443127900362015f;
  t180_n156: return -0.2500877380371094f;
  t180_n157: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t180_n159;
  t180_n158: return -0.2342892587184906f;
  t180_n159: return 0.15031364560127258f;
  t180_n160: return 0.06375293433666229f;
  t180_n161: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t180_n165;
  t180_n162: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t180_n164;
  t180_n163: return 0.12458450347185135f;
  t180_n164: return -0.17558403313159943f;
  t180_n165: return 0.16345159709453583f;
  t180_n166: return 0.10328947752714157f;
  t180_n167: return -0.00032025668770074844f;
  t180_n168: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t180_n172;
  t180_n169: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t180_n171;
  t180_n170: return -0.11110451072454453f;
  t180_n171: return 0.1272381991147995f;
  t180_n172: return -0.12043686211109161f;
  t180_n173: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t180_n175;
  t180_n174: return 0.022002335637807846f;
  t180_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t180_n179;
  t180_n176: if (E.getFileProximityDistance() >= 3254517760 /*31.5*/) goto t180_n178;
  t180_n177: return 0.05861881375312805f;
  t180_n178: return 0.21046972274780273f;
  t180_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t180_n181;
  t180_n180: return -0.10102355480194092f;
  t180_n181: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t180_n183;
  t180_n182: return -0.13621680438518524f;
  t180_n183: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t180_n185;
  t180_n184: return 0.12235208600759506f;
  t180_n185: return 0.5679478049278259f;
  t180_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t180_n208;
  t180_n187: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t180_n191;
  t180_n188: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t180_n190;
  t180_n189: return -0.07362175732851028f;
  t180_n190: return 0.055941883474588394f;
  t180_n191: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t180_n205;
  t180_n192: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t180_n194;
  t180_n193: return -0.14833028614521027f;
  t180_n194: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t180_n204;
  t180_n195: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t180_n197;
  t180_n196: return -0.004078893922269344f;
  t180_n197: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t180_n203;
  t180_n198: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n200;
  t180_n199: return 0.11060479283332825f;
  t180_n200: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t180_n202;
  t180_n201: return -0.20037873089313507f;
  t180_n202: return 0.10849402844905853f;
  t180_n203: return 0.11371657252311707f;
  t180_n204: return -0.0529976412653923f;
  t180_n205: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n207;
  t180_n206: return 0.1349056363105774f;
  t180_n207: return 0.048008110374212265f;
  t180_n208: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t180_n234;
  t180_n209: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t180_n223;
  t180_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n216;
  t180_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t180_n213;
  t180_n212: return 0.00940269511193037f;
  t180_n213: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t180_n215;
  t180_n214: return 0.04624434933066368f;
  t180_n215: return 0.10308396071195602f;
  t180_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t180_n222;
  t180_n217: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t180_n219;
  t180_n218: return -0.5428057909011841f;
  t180_n219: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t180_n221;
  t180_n220: return 0.0342194028198719f;
  t180_n221: return -1.0538171529769897f;
  t180_n222: return -0.012540485709905624f;
  t180_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t180_n229;
  t180_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n228;
  t180_n225: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t180_n227;
  t180_n226: return 0.020914411172270775f;
  t180_n227: return -0.2714061439037323f;
  t180_n228: return 0.045181840658187866f;
  t180_n229: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t180_n233;
  t180_n230: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t180_n232;
  t180_n231: return 0.053795382380485535f;
  t180_n232: return 0.1475246548652649f;
  t180_n233: return 0.07672049105167389f;
  t180_n234: return -0.10397972911596298f;
  t180_n235: return -0.01755037158727646f;
  t180_n236: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t180_n252;
  t180_n237: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t180_n251;
  t180_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t180_n246;
  t180_n239: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t180_n241;
  t180_n240: return -0.0044383700005710125f;
  t180_n241: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t180_n245;
  t180_n242: if (E.getNumReferences() >= 3358908544 /*185218.0*/) goto t180_n244;
  t180_n243: return 0.028660131618380547f;
  t180_n244: return -0.005997000727802515f;
  t180_n245: return 0.00042260007467120886f;
  t180_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t180_n250;
  t180_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n249;
  t180_n248: return -0.018887480720877647f;
  t180_n249: return -0.1127694621682167f;
  t180_n250: return 0.01758459024131298f;
  t180_n251: return -0.0016231245826929808f;
  t180_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t180_n254;
  t180_n253: return 0.021323716267943382f;
  t180_n254: return 0.03588753566145897f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree181(const Example& E) {
  t181_n0: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t181_n254;
  t181_n1: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t181_n3;
  t181_n2: return -0.005014815367758274f;
  t181_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t181_n65;
  t181_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t181_n64;
  t181_n5: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t181_n57;
  t181_n6: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t181_n54;
  t181_n7: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n23;
  t181_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol))) goto t181_n14;
  t181_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t181_n11;
  t181_n10: return 0.01824582740664482f;
  t181_n11: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n13;
  t181_n12: return 0.08091114461421967f;
  t181_n13: return 0.06706328690052032f;
  t181_n14: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n16;
  t181_n15: return 0.0029984943103045225f;
  t181_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t181_n18;
  t181_n17: return 0.019338048994541168f;
  t181_n18: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t181_n22;
  t181_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t181_n21;
  t181_n20: return -0.1441810429096222f;
  t181_n21: return 0.11825219541788101f;
  t181_n22: return -0.09603410214185715f;
  t181_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t181_n45;
  t181_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t181_n26;
  t181_n25: return 0.020336216315627098f;
  t181_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t181_n28;
  t181_n27: return -0.03628062829375267f;
  t181_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n42;
  t181_n29: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t181_n31;
  t181_n30: return 0.025435779243707657f;
  t181_n31: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t181_n41;
  t181_n32: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t181_n40;
  t181_n33: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t181_n35;
  t181_n34: return 0.13369332253932953f;
  t181_n35: if (E.getNumReferences() >= 3243245568 /*13.0*/) goto t181_n39;
  t181_n36: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t181_n38;
  t181_n37: return 0.09395311027765274f;
  t181_n38: return 0.0019443468190729618f;
  t181_n39: return 0.10967651754617691f;
  t181_n40: return 0.17824716866016388f;
  t181_n41: return -0.05946781486272812f;
  t181_n42: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t181_n44;
  t181_n43: return 0.07265793532133102f;
  t181_n44: return -0.03676087409257889f;
  t181_n45: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t181_n49;
  t181_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t181_n48;
  t181_n47: return -0.13142244517803192f;
  t181_n48: return -0.004774325992912054f;
  t181_n49: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Namespace))) goto t181_n51;
  t181_n50: return -0.05111478269100189f;
  t181_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n53;
  t181_n52: return -0.05995502322912216f;
  t181_n53: return 0.12792706489562988f;
  t181_n54: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t181_n56;
  t181_n55: return 0.014970039017498493f;
  t181_n56: return 0.10949261486530304f;
  t181_n57: if (E.getNumReferences() >= 3287318528 /*481.0*/) goto t181_n59;
  t181_n58: return 0.002046664012596011f;
  t181_n59: if (E.getNumReferences() >= 3288530944 /*524.0*/) goto t181_n63;
  t181_n60: if (E.getNumReferences() >= 3288072192 /*504.0*/) goto t181_n62;
  t181_n61: return 0.09825824946165085f;
  t181_n62: return 0.11528678238391876f;
  t181_n63: return -0.06324490159749985f;
  t181_n64: return 0.007984789088368416f;
  t181_n65: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t181_n157;
  t181_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t181_n68;
  t181_n67: return -0.004529192578047514f;
  t181_n68: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t181_n122;
  t181_n69: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t181_n111;
  t181_n70: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t181_n106;
  t181_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t181_n93;
  t181_n72: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t181_n90;
  t181_n73: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t181_n83;
  t181_n74: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t181_n76;
  t181_n75: return -0.10086347907781601f;
  t181_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t181_n78;
  t181_n77: return 0.010873881168663502f;
  t181_n78: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t181_n82;
  t181_n79: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t181_n81;
  t181_n80: return 0.09851019829511642f;
  t181_n81: return -0.04367154464125633f;
  t181_n82: return 0.1110948771238327f;
  t181_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t181_n85;
  t181_n84: return 0.017524270340800285f;
  t181_n85: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t181_n87;
  t181_n86: return -0.395682692527771f;
  t181_n87: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n89;
  t181_n88: return 0.11166781187057495f;
  t181_n89: return -0.1351151466369629f;
  t181_n90: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t181_n92;
  t181_n91: return 0.07223940640687943f;
  t181_n92: return 0.02896467037498951f;
  t181_n93: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t181_n105;
  t181_n94: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t181_n104;
  t181_n95: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t181_n97;
  t181_n96: return 0.04696177691221237f;
  t181_n97: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n103;
  t181_n98: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t181_n102;
  t181_n99: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n101;
  t181_n100: return 0.10248609632253647f;
  t181_n101: return 0.07947064191102982f;
  t181_n102: return 0.10111589729785919f;
  t181_n103: return -0.3169642686843872f;
  t181_n104: return 0.1071612536907196f;
  t181_n105: return -0.34004315733909607f;
  t181_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t181_n108;
  t181_n107: return 0.05068778991699219f;
  t181_n108: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n110;
  t181_n109: return 0.11447665840387344f;
  t181_n110: return 0.11374961584806442f;
  t181_n111: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t181_n113;
  t181_n112: return -0.050461702048778534f;
  t181_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t181_n115;
  t181_n114: return 0.00903636496514082f;
  t181_n115: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t181_n117;
  t181_n116: return 0.09747406095266342f;
  t181_n117: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t181_n119;
  t181_n118: return -0.1421816200017929f;
  t181_n119: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n121;
  t181_n120: return 0.11708196997642517f;
  t181_n121: return -0.10557655245065689f;
  t181_n122: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t181_n138;
  t181_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t181_n137;
  t181_n124: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t181_n136;
  t181_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t181_n127;
  t181_n126: return 0.031950101256370544f;
  t181_n127: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n129;
  t181_n128: return 0.03383219614624977f;
  t181_n129: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t181_n131;
  t181_n130: return -0.2285328060388565f;
  t181_n131: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n135;
  t181_n132: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t181_n134;
  t181_n133: return 0.143879234790802f;
  t181_n134: return 0.35313645005226135f;
  t181_n135: return 0.39475440979003906f;
  t181_n136: return 0.020744547247886658f;
  t181_n137: return 0.08884534239768982f;
  t181_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t181_n156;
  t181_n139: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t181_n155;
  t181_n140: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t181_n154;
  t181_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t181_n151;
  t181_n142: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t181_n150;
  t181_n143: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n149;
  t181_n144: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n146;
  t181_n145: return 0.09650279581546783f;
  t181_n146: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t181_n148;
  t181_n147: return 0.4997074007987976f;
  t181_n148: return 0.10952669382095337f;
  t181_n149: return 0.08602803945541382f;
  t181_n150: return -0.7188640832901001f;
  t181_n151: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t181_n153;
  t181_n152: return -0.3063431680202484f;
  t181_n153: return 0.12432903051376343f;
  t181_n154: return 0.04672197625041008f;
  t181_n155: return 0.10911185294389725f;
  t181_n156: return 0.1090698167681694f;
  t181_n157: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t181_n179;
  t181_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t181_n166;
  t181_n159: if (E.getNumReferences() >= 3266772992 /*91.5*/) goto t181_n163;
  t181_n160: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t181_n162;
  t181_n161: return -0.0580422468483448f;
  t181_n162: return -0.016505656763911247f;
  t181_n163: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t181_n165;
  t181_n164: return -0.12848542630672455f;
  t181_n165: return -0.013868873938918114f;
  t181_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t181_n178;
  t181_n167: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t181_n175;
  t181_n168: if (E.getNumReferences() >= 3301953536 /*1662.5*/) goto t181_n174;
  t181_n169: if (E.getNumReferences() >= 3300220928 /*1451.0*/) goto t181_n171;
  t181_n170: return -0.001935973996296525f;
  t181_n171: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t181_n173;
  t181_n172: return 0.15329720079898834f;
  t181_n173: return 0.009708196856081486f;
  t181_n174: return -0.097439706325531f;
  t181_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t181_n177;
  t181_n176: return -0.2585180401802063f;
  t181_n177: return 0.022289326414465904f;
  t181_n178: return 0.023608556017279625f;
  t181_n179: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t181_n253;
  t181_n180: if (E.getNumReferences() >= 3273293824 /*154.5*/) goto t181_n218;
  t181_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t181_n183;
  t181_n182: return 0.02726280875504017f;
  t181_n183: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t181_n213;
  t181_n184: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t181_n212;
  t181_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t181_n187;
  t181_n186: return -0.04101613909006119f;
  t181_n187: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t181_n199;
  t181_n188: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t181_n198;
  t181_n189: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t181_n197;
  t181_n190: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t181_n194;
  t181_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t181_n193;
  t181_n192: return -0.1885397881269455f;
  t181_n193: return 0.1317158043384552f;
  t181_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t181_n196;
  t181_n195: return 0.4137127697467804f;
  t181_n196: return 0.13215123116970062f;
  t181_n197: return 0.21195253729820251f;
  t181_n198: return 0.017420154064893723f;
  t181_n199: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t181_n201;
  t181_n200: return -0.17531222105026245f;
  t181_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t181_n203;
  t181_n202: return -0.10847223550081253f;
  t181_n203: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t181_n209;
  t181_n204: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t181_n208;
  t181_n205: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t181_n207;
  t181_n206: return 0.12902504205703735f;
  t181_n207: return 0.14189521968364716f;
  t181_n208: return -0.3053768277168274f;
  t181_n209: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t181_n211;
  t181_n210: return -0.1428411900997162f;
  t181_n211: return 0.1260836273431778f;
  t181_n212: return -0.003934008534997702f;
  t181_n213: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t181_n217;
  t181_n214: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t181_n216;
  t181_n215: return 0.0975392684340477f;
  t181_n216: return 0.11944660544395447f;
  t181_n217: return 0.06533866375684738f;
  t181_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t181_n232;
  t181_n219: if (E.getNumReferences() >= 3274866688 /*178.5*/) goto t181_n231;
  t181_n220: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t181_n226;
  t181_n221: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t181_n223;
  t181_n222: return 0.07817649841308594f;
  t181_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t181_n225;
  t181_n224: return 0.10140737891197205f;
  t181_n225: return 0.1150192841887474f;
  t181_n226: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t181_n228;
  t181_n227: return 0.10843773931264877f;
  t181_n228: if (E.getNumReferences() >= 3274539008 /*173.5*/) goto t181_n230;
  t181_n229: return 0.06247392296791077f;
  t181_n230: return 0.13906234502792358f;
  t181_n231: return 0.03992035612463951f;
  t181_n232: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t181_n246;
  t181_n233: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t181_n241;
  t181_n234: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t181_n236;
  t181_n235: return 0.11215230077505112f;
  t181_n236: if (E.getNumReferences() >= 3289128960 /*560.5*/) goto t181_n238;
  t181_n237: return -0.0023483445402234793f;
  t181_n238: if (E.getNumReferences() >= 3292078080 /*740.5*/) goto t181_n240;
  t181_n239: return 0.11792157590389252f;
  t181_n240: return 0.05616992712020874f;
  t181_n241: if (E.getNumReferences() >= 3317816320 /*6203.5*/) goto t181_n243;
  t181_n242: return 0.008025907911360264f;
  t181_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n245;
  t181_n244: return 0.19635146856307983f;
  t181_n245: return 1.8206694221589714e-05f;
  t181_n246: if (E.getNumReferences() >= 3276570624 /*204.5*/) goto t181_n250;
  t181_n247: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t181_n249;
  t181_n248: return 0.060268569737672806f;
  t181_n249: return 0.11857152730226517f;
  t181_n250: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t181_n252;
  t181_n251: return -0.02737201377749443f;
  t181_n252: return 0.09093685448169708f;
  t181_n253: return 0.02012431062757969f;
  t181_n254: return -0.0006794330547563732f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree182(const Example& E) {
  t182_n0: if (E.getNumReferences() >= 3300909056 /*1535.0*/) goto t182_n228;
  t182_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t182_n3;
  t182_n2: return 0.0031944899819791317f;
  t182_n3: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t182_n5;
  t182_n4: return -0.00010490298882359639f;
  t182_n5: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t182_n179;
  t182_n6: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t182_n8;
  t182_n7: return -0.04050224646925926f;
  t182_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t182_n10;
  t182_n9: return -0.004086284898221493f;
  t182_n10: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t182_n70;
  t182_n11: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t182_n13;
  t182_n12: return 0.02703881449997425f;
  t182_n13: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t182_n43;
  t182_n14: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t182_n18;
  t182_n15: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t182_n17;
  t182_n16: return -0.10627700388431549f;
  t182_n17: return -0.41894280910491943f;
  t182_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t182_n42;
  t182_n19: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t182_n21;
  t182_n20: return -0.10647132247686386f;
  t182_n21: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t182_n23;
  t182_n22: return -0.04931119084358215f;
  t182_n23: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t182_n41;
  t182_n24: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t182_n28;
  t182_n25: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t182_n27;
  t182_n26: return -0.2231960892677307f;
  t182_n27: return 0.11721235513687134f;
  t182_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t182_n40;
  t182_n29: if (E.getNumReferences() >= 3283369984 /*360.5*/) goto t182_n39;
  t182_n30: if (E.getNumReferences() >= 3281698816 /*309.5*/) goto t182_n36;
  t182_n31: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t182_n33;
  t182_n32: return 0.02743026614189148f;
  t182_n33: if (E.getNumReferences() >= 3270901760 /*123.0*/) goto t182_n35;
  t182_n34: return 0.11398747563362122f;
  t182_n35: return 0.07660534232854843f;
  t182_n36: if (E.getNumReferences() >= 3282681856 /*339.5*/) goto t182_n38;
  t182_n37: return 0.12579579651355743f;
  t182_n38: return 0.10617270320653915f;
  t182_n39: return -0.13304877281188965f;
  t182_n40: return 0.1073240414261818f;
  t182_n41: return -0.03855415806174278f;
  t182_n42: return 0.019997214898467064f;
  t182_n43: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t182_n69;
  t182_n44: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t182_n52;
  t182_n45: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t182_n47;
  t182_n46: return -0.030086059123277664f;
  t182_n47: if (E.getNumReferences() >= 3240099840 /*10.0*/) goto t182_n49;
  t182_n48: return -0.09701814502477646f;
  t182_n49: if (E.getNumReferences() >= 3246915584 /*17.0*/) goto t182_n51;
  t182_n50: return 0.16744780540466309f;
  t182_n51: return 0.038889214396476746f;
  t182_n52: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t182_n54;
  t182_n53: return 0.03050844371318817f;
  t182_n54: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t182_n58;
  t182_n55: if (E.getNumReferences() >= 3257008128 /*40.5*/) goto t182_n57;
  t182_n56: return 0.06250199675559998f;
  t182_n57: return 0.12080085277557373f;
  t182_n58: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t182_n60;
  t182_n59: return 0.007534489035606384f;
  t182_n60: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t182_n68;
  t182_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t182_n63;
  t182_n62: return -0.012850450351834297f;
  t182_n63: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t182_n67;
  t182_n64: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t182_n66;
  t182_n65: return 0.05615997686982155f;
  t182_n66: return 0.134567990899086f;
  t182_n67: return 0.10754141211509705f;
  t182_n68: return 0.006179125979542732f;
  t182_n69: return -0.07371591031551361f;
  t182_n70: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t182_n114;
  t182_n71: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t182_n113;
  t182_n72: if (E.getNumReferences() >= 3299135488 /*1318.5*/) goto t182_n100;
  t182_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t182_n75;
  t182_n74: return 0.03923127055168152f;
  t182_n75: if (E.getNumReferences() >= 3288391680 /*515.5*/) goto t182_n95;
  t182_n76: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t182_n78;
  t182_n77: return 0.07254110276699066f;
  t182_n78: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t182_n82;
  t182_n79: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t182_n81;
  t182_n80: return 0.13175716996192932f;
  t182_n81: return -0.13511952757835388f;
  t182_n82: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t182_n92;
  t182_n83: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t182_n85;
  t182_n84: return 0.0693102702498436f;
  t182_n85: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t182_n91;
  t182_n86: if (E.getNumReferences() >= 3268673536 /*106.0*/) goto t182_n90;
  t182_n87: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t182_n89;
  t182_n88: return 0.1423364132642746f;
  t182_n89: return 0.5394939184188843f;
  t182_n90: return 0.12584084272384644f;
  t182_n91: return 0.008575604297220707f;
  t182_n92: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t182_n94;
  t182_n93: return 0.06491739302873611f;
  t182_n94: return 0.13696950674057007f;
  t182_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t182_n99;
  t182_n96: if (E.getNumReferences() >= 3288924160 /*548.0*/) goto t182_n98;
  t182_n97: return 0.12676286697387695f;
  t182_n98: return 0.11441385000944138f;
  t182_n99: return 0.1245310828089714f;
  t182_n100: if (E.getNumReferences() >= 3299160064 /*1321.5*/) goto t182_n104;
  t182_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t182_n103;
  t182_n102: return -0.1008075475692749f;
  t182_n103: return 0.12455190718173981f;
  t182_n104: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t182_n108;
  t182_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t182_n107;
  t182_n106: return -0.4544238746166229f;
  t182_n107: return 0.12347500026226044f;
  t182_n108: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t182_n110;
  t182_n109: return -0.06653737276792526f;
  t182_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t182_n112;
  t182_n111: return 0.03308621421456337f;
  t182_n112: return 0.11546028405427933f;
  t182_n113: return -0.025287173688411713f;
  t182_n114: if (E.getNumReferences() >= 3291545600 /*708.0*/) goto t182_n174;
  t182_n115: if (E.getNumReferences() >= 3282927616 /*347.0*/) goto t182_n173;
  t182_n116: if (E.getNumReferences() >= 3282518016 /*334.5*/) goto t182_n170;
  t182_n117: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t182_n155;
  t182_n118: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t182_n134;
  t182_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t182_n121;
  t182_n120: return -0.44628235697746277f;
  t182_n121: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t182_n123;
  t182_n122: return -0.0381096713244915f;
  t182_n123: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t182_n133;
  t182_n124: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t182_n132;
  t182_n125: if (E.getNumReferences() >= 3271557120 /*128.0*/) goto t182_n131;
  t182_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t182_n128;
  t182_n127: return -0.46585893630981445f;
  t182_n128: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t182_n130;
  t182_n129: return 0.16153451800346375f;
  t182_n130: return 0.10067593306303024f;
  t182_n131: return -0.1760074645280838f;
  t182_n132: return 0.12796247005462646f;
  t182_n133: return -0.2521098554134369f;
  t182_n134: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t182_n142;
  t182_n135: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t182_n137;
  t182_n136: return -0.008798763155937195f;
  t182_n137: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t182_n141;
  t182_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t182_n140;
  t182_n139: return 0.03943028673529625f;
  t182_n140: return 0.10792442411184311f;
  t182_n141: return 0.053572241216897964f;
  t182_n142: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t182_n150;
  t182_n143: if (E.getNumReferences() >= 3274964992 /*180.0*/) goto t182_n149;
  t182_n144: if (E.getNumReferences() >= 3272540160 /*143.0*/) goto t182_n148;
  t182_n145: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t182_n147;
  t182_n146: return -0.07855000346899033f;
  t182_n147: return 0.1177186518907547f;
  t182_n148: return 0.1030270904302597f;
  t182_n149: return -0.00044780559255741537f;
  t182_n150: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t182_n154;
  t182_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t182_n153;
  t182_n152: return -0.24956922233104706f;
  t182_n153: return 0.11513686180114746f;
  t182_n154: return 0.04054916277527809f;
  t182_n155: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t182_n159;
  t182_n156: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t182_n158;
  t182_n157: return -0.1117861196398735f;
  t182_n158: return 0.13502250611782074f;
  t182_n159: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t182_n167;
  t182_n160: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t182_n164;
  t182_n161: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t182_n163;
  t182_n162: return -0.02469170093536377f;
  t182_n163: return 0.11490143835544586f;
  t182_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t182_n166;
  t182_n165: return 0.04611942917108536f;
  t182_n166: return 0.11583967506885529f;
  t182_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t182_n169;
  t182_n168: return -0.02846226841211319f;
  t182_n169: return 0.11328056454658508f;
  t182_n170: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t182_n172;
  t182_n171: return -0.05326344445347786f;
  t182_n172: return 0.19001387059688568f;
  t182_n173: return -0.08526018261909485f;
  t182_n174: if (E.getNumReferences() >= 3292733440 /*780.5*/) goto t182_n178;
  t182_n175: if (E.getNumReferences() >= 3292413952 /*761.0*/) goto t182_n177;
  t182_n176: return 0.07833552360534668f;
  t182_n177: return 0.1033463329076767f;
  t182_n178: return 0.00430723512545228f;
  t182_n179: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t182_n207;
  t182_n180: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t182_n182;
  t182_n181: return -0.041745152324438095f;
  t182_n182: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t182_n206;
  t182_n183: if (E.getNumReferences() >= 3272540160 /*143.0*/) goto t182_n203;
  t182_n184: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t182_n186;
  t182_n185: return 0.033778201788663864f;
  t182_n186: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t182_n192;
  t182_n187: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t182_n191;
  t182_n188: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t182_n190;
  t182_n189: return 11.944103240966797f;
  t182_n190: return 0.11474881321191788f;
  t182_n191: return 0.08901528269052505f;
  t182_n192: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t182_n198;
  t182_n193: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t182_n195;
  t182_n194: return 0.03734009712934494f;
  t182_n195: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t182_n197;
  t182_n196: return 0.13123618066310883f;
  t182_n197: return -0.10222800076007843f;
  t182_n198: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t182_n200;
  t182_n199: return 0.14175692200660706f;
  t182_n200: if (E.getNumReferences() >= 3259498496 /*50.0*/) goto t182_n202;
  t182_n201: return -0.10081258416175842f;
  t182_n202: return 0.1138281300663948f;
  t182_n203: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t182_n205;
  t182_n204: return 0.1114489808678627f;
  t182_n205: return -0.10159128159284592f;
  t182_n206: return 0.026133034378290176f;
  t182_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t182_n215;
  t182_n208: if (E.getNumReferences() >= 3274211328 /*168.5*/) goto t182_n214;
  t182_n209: if (E.getNumReferences() >= 3274145792 /*167.5*/) goto t182_n213;
  t182_n210: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t182_n212;
  t182_n211: return 0.04397662729024887f;
  t182_n212: return -0.0011606179177761078f;
  t182_n213: return 0.11485189199447632f;
  t182_n214: return -0.005784195382148027f;
  t182_n215: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t182_n217;
  t182_n216: return 0.10536504536867142f;
  t182_n217: if (E.getNumReferences() >= 3257401344 /*42.0*/) goto t182_n225;
  t182_n218: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t182_n224;
  t182_n219: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t182_n223;
  t182_n220: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t182_n222;
  t182_n221: return 0.09052539616823196f;
  t182_n222: return -0.03186918795108795f;
  t182_n223: return -0.2716638445854187f;
  t182_n224: return 0.16276830434799194f;
  t182_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t182_n227;
  t182_n226: return 0.06524316221475601f;
  t182_n227: return -0.024809710681438446f;
  t182_n228: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t182_n254;
  t182_n229: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t182_n249;
  t182_n230: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t182_n232;
  t182_n231: return -0.008296347223222256f;
  t182_n232: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t182_n248;
  t182_n233: if (E.getNumReferences() >= 3325242368 /*11467.0*/) goto t182_n241;
  t182_n234: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t182_n236;
  t182_n235: return 0.048261817544698715f;
  t182_n236: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t182_n238;
  t182_n237: return -0.01263643242418766f;
  t182_n238: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t182_n240;
  t182_n239: return 0.10373962670564651f;
  t182_n240: return 0.10750532895326614f;
  t182_n241: if (E.getNumReferences() >= 3368810912 /*417741.0*/) goto t182_n243;
  t182_n242: return 0.018479226157069206f;
  t182_n243: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t182_n245;
  t182_n244: return -0.023665713146328926f;
  t182_n245: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t182_n247;
  t182_n246: return -0.01213014591485262f;
  t182_n247: return 0.07144788652658463f;
  t182_n248: return 0.0012551081599667668f;
  t182_n249: if (E.getNumReferences() >= 3300937728 /*1538.5*/) goto t182_n253;
  t182_n250: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t182_n252;
  t182_n251: return -0.10916101932525635f;
  t182_n252: return 0.1259223073720932f;
  t182_n253: return 0.01856742799282074f;
  t182_n254: return 0.001451138756237924f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree183(const Example& E) {
  t183_n0: if (E.getNumReferences() >= 3325298688 /*11522.0*/) goto t183_n64;
  t183_n1: if (E.getNumReferences() >= 3325283328 /*11507.0*/) goto t183_n55;
  t183_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t183_n4;
  t183_n3: return -0.10718642175197601f;
  t183_n4: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t183_n36;
  t183_n5: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t183_n7;
  t183_n6: return 0.0010464375372976065f;
  t183_n7: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t183_n9;
  t183_n8: return -0.04779021814465523f;
  t183_n9: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t183_n11;
  t183_n10: return 0.00462611997500062f;
  t183_n11: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t183_n13;
  t183_n12: return 0.018350915983319283f;
  t183_n13: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t183_n15;
  t183_n14: return -0.0233839713037014f;
  t183_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t183_n17;
  t183_n16: return 0.01189308613538742f;
  t183_n17: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t183_n33;
  t183_n18: if (E.getNumReferences() >= 3257401344 /*42.0*/) goto t183_n28;
  t183_n19: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t183_n27;
  t183_n20: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t183_n22;
  t183_n21: return 0.032910484820604324f;
  t183_n22: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t183_n26;
  t183_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t183_n25;
  t183_n24: return 0.10393980145454407f;
  t183_n25: return 0.06873802840709686f;
  t183_n26: return 0.18206118047237396f;
  t183_n27: return 0.020134465768933296f;
  t183_n28: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t183_n30;
  t183_n29: return -0.13518324494361877f;
  t183_n30: if (E.getNumReferences() >= 3265789952 /*84.0*/) goto t183_n32;
  t183_n31: return -0.2922656536102295f;
  t183_n32: return 0.050147153437137604f;
  t183_n33: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t183_n35;
  t183_n34: return 0.11481203883886337f;
  t183_n35: return 0.10061737895011902f;
  t183_n36: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t183_n40;
  t183_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t183_n39;
  t183_n38: return -0.11716097593307495f;
  t183_n39: return -0.07686857879161835f;
  t183_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t183_n48;
  t183_n41: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n47;
  t183_n42: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t183_n44;
  t183_n43: return -0.011257611215114594f;
  t183_n44: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t183_n46;
  t183_n45: return 0.07794879376888275f;
  t183_n46: return -0.28687432408332825f;
  t183_n47: return -0.2445629984140396f;
  t183_n48: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n54;
  t183_n49: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t183_n53;
  t183_n50: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t183_n52;
  t183_n51: return -0.10008649528026581f;
  t183_n52: return 0.07146132737398148f;
  t183_n53: return -0.130430668592453f;
  t183_n54: return 0.10539832711219788f;
  t183_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n57;
  t183_n56: return -0.17097115516662598f;
  t183_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t183_n63;
  t183_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t183_n60;
  t183_n59: return -0.11529000103473663f;
  t183_n60: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t183_n62;
  t183_n61: return -1.4612258672714233f;
  t183_n62: return -0.18624594807624817f;
  t183_n63: return -0.15559250116348267f;
  t183_n64: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t183_n86;
  t183_n65: if (E.getNumReferences() >= 3325406720 /*11627.5*/) goto t183_n85;
  t183_n66: if (E.getNumReferences() >= 3325368832 /*11590.5*/) goto t183_n74;
  t183_n67: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t183_n69;
  t183_n68: return 0.06397614628076553f;
  t183_n69: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n73;
  t183_n70: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t183_n72;
  t183_n71: return 0.5477854013442993f;
  t183_n72: return -0.093460813164711f;
  t183_n73: return 0.22587457299232483f;
  t183_n74: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t183_n76;
  t183_n75: return 0.12013522535562515f;
  t183_n76: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t183_n80;
  t183_n77: if (E.getNumReferences() >= 3325383680 /*11605.0*/) goto t183_n79;
  t183_n78: return 0.10023244470357895f;
  t183_n79: return -0.1287040412425995f;
  t183_n80: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t183_n84;
  t183_n81: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t183_n83;
  t183_n82: return 0.11006079614162445f;
  t183_n83: return 0.12372563779354095f;
  t183_n84: return -0.06331092119216919f;
  t183_n85: return 0.011268979869782925f;
  t183_n86: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t183_n88;
  t183_n87: return -0.026330361142754555f;
  t183_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t183_n90;
  t183_n89: return 0.003878544317558408f;
  t183_n90: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t183_n92;
  t183_n91: return -0.04053103178739548f;
  t183_n92: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t183_n254;
  t183_n93: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t183_n243;
  t183_n94: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t183_n184;
  t183_n95: if (E.getNumReferences() >= 3342114944 /*46240.5*/) goto t183_n183;
  t183_n96: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t183_n176;
  t183_n97: if (E.getNumReferences() >= 3338881664 /*33610.5*/) goto t183_n163;
  t183_n98: if (E.getNumReferences() >= 3338855552 /*33508.5*/) goto t183_n154;
  t183_n99: if (E.getNumReferences() >= 3336705792 /*28939.5*/) goto t183_n153;
  t183_n100: if (E.getNumReferences() >= 3336160512 /*27874.5*/) goto t183_n152;
  t183_n101: if (E.getNumReferences() >= 3335010048 /*25627.5*/) goto t183_n151;
  t183_n102: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t183_n104;
  t183_n103: return 0.01931658573448658f;
  t183_n104: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n146;
  t183_n105: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n107;
  t183_n106: return 0.09987791627645493f;
  t183_n107: if (E.getNumReferences() >= 3334461184 /*24555.5*/) goto t183_n141;
  t183_n108: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t183_n140;
  t183_n109: if (E.getNumReferences() >= 3333667072 /*23004.5*/) goto t183_n139;
  t183_n110: if (E.getNumReferences() >= 3333190144 /*22073.0*/) goto t183_n138;
  t183_n111: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t183_n113;
  t183_n112: return 0.025874659419059753f;
  t183_n113: if (E.getNumReferences() >= 3327053312 /*13235.5*/) goto t183_n115;
  t183_n114: return -0.07449270784854889f;
  t183_n115: if (E.getNumReferences() >= 3327105024 /*13286.0*/) goto t183_n117;
  t183_n116: return 0.1203155517578125f;
  t183_n117: if (E.getNumReferences() >= 3327795200 /*13960.0*/) goto t183_n119;
  t183_n118: return -0.16762232780456543f;
  t183_n119: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t183_n135;
  t183_n120: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t183_n132;
  t183_n121: if (E.getNumReferences() >= 3330296064 /*16420.5*/) goto t183_n127;
  t183_n122: if (E.getNumReferences() >= 3329126400 /*15260.0*/) goto t183_n126;
  t183_n123: if (E.getNumReferences() >= 3328901632 /*15040.5*/) goto t183_n125;
  t183_n124: return 0.3076615631580353f;
  t183_n125: return -0.11574903875589371f;
  t183_n126: return 0.22394679486751556f;
  t183_n127: if (E.getNumReferences() >= 3331473408 /*18720.0*/) goto t183_n129;
  t183_n128: return -0.11240619421005249f;
  t183_n129: if (E.getNumReferences() >= 3332023808 /*19795.0*/) goto t183_n131;
  t183_n130: return 0.1227954775094986f;
  t183_n131: return -0.1467662751674652f;
  t183_n132: if (E.getNumReferences() >= 3331949568 /*19650.0*/) goto t183_n134;
  t183_n133: return -0.08170758932828903f;
  t183_n134: return -0.5698365569114685f;
  t183_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t183_n137;
  t183_n136: return -0.03975128382444382f;
  t183_n137: return 0.10275254398584366f;
  t183_n138: return 0.1108826994895935f;
  t183_n139: return -0.09641029685735703f;
  t183_n140: return 0.11500298231840134f;
  t183_n141: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t183_n145;
  t183_n142: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t183_n144;
  t183_n143: return -0.1729172021150589f;
  t183_n144: return 0.26558858156204224f;
  t183_n145: return -0.5210919380187988f;
  t183_n146: if (E.getNumReferences() >= 3334778368 /*25175.0*/) goto t183_n150;
  t183_n147: if (E.getNumReferences() >= 3326497792 /*12693.0*/) goto t183_n149;
  t183_n148: return 0.22319211065769196f;
  t183_n149: return -0.01524352841079235f;
  t183_n150: return 0.09905315190553665f;
  t183_n151: return -0.11317810416221619f;
  t183_n152: return 0.2478528618812561f;
  t183_n153: return -0.05341102555394173f;
  t183_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n162;
  t183_n155: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t183_n161;
  t183_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n160;
  t183_n157: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t183_n159;
  t183_n158: return 0.5625491142272949f;
  t183_n159: return 0.6075589656829834f;
  t183_n160: return -0.10970498621463776f;
  t183_n161: return 0.11351188272237778f;
  t183_n162: return 0.11902667582035065f;
  t183_n163: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t183_n171;
  t183_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t183_n170;
  t183_n165: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n169;
  t183_n166: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n168;
  t183_n167: return -0.1202315017580986f;
  t183_n168: return -0.6585590839385986f;
  t183_n169: return 0.013414968736469746f;
  t183_n170: return -0.05309849604964256f;
  t183_n171: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t183_n173;
  t183_n172: return -0.04095492511987686f;
  t183_n173: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t183_n175;
  t183_n174: return 0.10989005118608475f;
  t183_n175: return 0.10282562673091888f;
  t183_n176: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t183_n180;
  t183_n177: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n179;
  t183_n178: return -0.22565187513828278f;
  t183_n179: return 0.11067222058773041f;
  t183_n180: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t183_n182;
  t183_n181: return 0.14975258708000183f;
  t183_n182: return -0.21664725244045258f;
  t183_n183: return -0.19975335896015167f;
  t183_n184: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t183_n190;
  t183_n185: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n189;
  t183_n186: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t183_n188;
  t183_n187: return 0.15047436952590942f;
  t183_n188: return -0.11384521424770355f;
  t183_n189: return 0.10956577956676483f;
  t183_n190: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t183_n232;
  t183_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n231;
  t183_n192: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t183_n214;
  t183_n193: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t183_n213;
  t183_n194: if (E.getNumReferences() >= 3350105536 /*89371.5*/) goto t183_n208;
  t183_n195: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t183_n197;
  t183_n196: return -0.06489657610654831f;
  t183_n197: if (E.getNumReferences() >= 3348219712 /*74638.5*/) goto t183_n203;
  t183_n198: if (E.getNumReferences() >= 3345444992 /*59248.5*/) goto t183_n202;
  t183_n199: if (E.getNumReferences() >= 3345041664 /*57673.0*/) goto t183_n201;
  t183_n200: return 0.05136241018772125f;
  t183_n201: return 0.12654830515384674f;
  t183_n202: return -0.14319808781147003f;
  t183_n203: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t183_n207;
  t183_n204: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t183_n206;
  t183_n205: return 0.044186972081661224f;
  t183_n206: return 0.08288905024528503f;
  t183_n207: return 0.1119823157787323f;
  t183_n208: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t183_n212;
  t183_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t183_n211;
  t183_n210: return -0.10213882476091385f;
  t183_n211: return 0.09224534034729004f;
  t183_n212: return 0.054563503712415695f;
  t183_n213: return 0.010304376482963562f;
  t183_n214: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t183_n220;
  t183_n215: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t183_n217;
  t183_n216: return 0.10438898205757141f;
  t183_n217: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t183_n219;
  t183_n218: return 0.015657221898436546f;
  t183_n219: return 0.06999775767326355f;
  t183_n220: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t183_n226;
  t183_n221: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t183_n223;
  t183_n222: return -0.16514979302883148f;
  t183_n223: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t183_n225;
  t183_n224: return -0.11807815730571747f;
  t183_n225: return 0.10409494489431381f;
  t183_n226: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t183_n228;
  t183_n227: return -0.10178247094154358f;
  t183_n228: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n230;
  t183_n229: return 0.08582144230604172f;
  t183_n230: return 0.034804925322532654f;
  t183_n231: return -0.010647900402545929f;
  t183_n232: if (E.getNumReferences() >= 3348514112 /*76938.5*/) goto t183_n236;
  t183_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n235;
  t183_n234: return -0.029228227213025093f;
  t183_n235: return 0.10120672732591629f;
  t183_n236: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t183_n242;
  t183_n237: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t183_n239;
  t183_n238: return 0.0839545801281929f;
  t183_n239: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t183_n241;
  t183_n240: return -0.05222005769610405f;
  t183_n241: return 0.0735643282532692f;
  t183_n242: return 0.12887944281101227f;
  t183_n243: if (E.getNumReferences() >= 3334795520 /*25208.5*/) goto t183_n251;
  t183_n244: if (E.getNumReferences() >= 3333635072 /*22942.0*/) goto t183_n250;
  t183_n245: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n249;
  t183_n246: if (E.getNumReferences() >= 3330470656 /*16761.5*/) goto t183_n248;
  t183_n247: return -0.10312832146883011f;
  t183_n248: return 1.2999589443206787f;
  t183_n249: return -0.12630848586559296f;
  t183_n250: return 0.12072981148958206f;
  t183_n251: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t183_n253;
  t183_n252: return -0.16097374260425568f;
  t183_n253: return 0.25018569827079773f;
  t183_n254: return -0.09842358529567719f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree184(const Example& E) {
  t184_n0: if (E.getNumReferences() >= 3308861440 /*2963.5*/) goto t184_n8;
  t184_n1: if (E.getNumReferences() >= 3308840960 /*2958.5*/) goto t184_n3;
  t184_n2: return -0.00035733680124394596f;
  t184_n3: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n5;
  t184_n4: return -0.14209286868572235f;
  t184_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t184_n7;
  t184_n6: return -0.6634206175804138f;
  t184_n7: return -0.5386044383049011f;
  t184_n8: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t184_n66;
  t184_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t184_n51;
  t184_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t184_n50;
  t184_n11: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t184_n43;
  t184_n12: if (E.getNumReferences() >= 3339317120 /*35311.5*/) goto t184_n36;
  t184_n13: if (E.getNumReferences() >= 3313035264 /*3982.5*/) goto t184_n23;
  t184_n14: if (E.getNumReferences() >= 3313004544 /*3975.0*/) goto t184_n22;
  t184_n15: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t184_n17;
  t184_n16: return -0.21708306670188904f;
  t184_n17: if (E.getNumReferences() >= 3311329280 /*3566.0*/) goto t184_n19;
  t184_n18: return -0.44697993993759155f;
  t184_n19: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t184_n21;
  t184_n20: return 0.12766851484775543f;
  t184_n21: return 0.037015728652477264f;
  t184_n22: return 0.1200091689825058f;
  t184_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n35;
  t184_n24: if (E.getNumReferences() >= 3323488768 /*9754.5*/) goto t184_n30;
  t184_n25: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t184_n27;
  t184_n26: return -0.15369239449501038f;
  t184_n27: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t184_n29;
  t184_n28: return -0.33862340450286865f;
  t184_n29: return -1.6902390718460083f;
  t184_n30: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t184_n32;
  t184_n31: return -0.041336990892887115f;
  t184_n32: if (E.getNumReferences() >= 3331854592 /*19464.5*/) goto t184_n34;
  t184_n33: return 0.07964643836021423f;
  t184_n34: return -0.4437645375728607f;
  t184_n35: return 0.04505482688546181f;
  t184_n36: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t184_n38;
  t184_n37: return -0.3739854693412781f;
  t184_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n40;
  t184_n39: return 0.05490680783987045f;
  t184_n40: if (E.getNumReferences() >= 3344898560 /*57114.0*/) goto t184_n42;
  t184_n41: return 0.10785537213087082f;
  t184_n42: return 0.047585126012563705f;
  t184_n43: if (E.getNumReferences() >= 3349315712 /*83201.0*/) goto t184_n45;
  t184_n44: return -0.17148029804229736f;
  t184_n45: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t184_n49;
  t184_n46: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n48;
  t184_n47: return 0.04762778431177139f;
  t184_n48: return -0.34687182307243347f;
  t184_n49: return -0.19983072578907013f;
  t184_n50: return 0.011243102140724659f;
  t184_n51: if (E.getNumReferences() >= 3308972032 /*2990.5*/) goto t184_n57;
  t184_n52: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t184_n56;
  t184_n53: if (E.getNumReferences() >= 3308906496 /*2974.5*/) goto t184_n55;
  t184_n54: return 0.13686998188495636f;
  t184_n55: return 0.031132705509662628f;
  t184_n56: return 0.11149261146783829f;
  t184_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t184_n59;
  t184_n58: return 0.017102396115660667f;
  t184_n59: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t184_n65;
  t184_n60: if (E.getNumReferences() >= 3317001216 /*5805.5*/) goto t184_n64;
  t184_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t184_n63;
  t184_n62: return -0.13404347002506256f;
  t184_n63: return 0.16423480212688446f;
  t184_n64: return 0.1175604984164238f;
  t184_n65: return -0.03587713837623596f;
  t184_n66: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t184_n68;
  t184_n67: return -0.0015003113076090813f;
  t184_n68: if (E.getNumReferences() >= 3333341184 /*22368.0*/) goto t184_n234;
  t184_n69: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t184_n165;
  t184_n70: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t184_n120;
  t184_n71: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t184_n81;
  t184_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t184_n80;
  t184_n73: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t184_n75;
  t184_n74: return 0.009781773202121258f;
  t184_n75: if (E.getNumReferences() >= 3320302592 /*7417.5*/) goto t184_n79;
  t184_n76: if (E.getNumReferences() >= 3319290880 /*6923.5*/) goto t184_n78;
  t184_n77: return 0.10721231251955032f;
  t184_n78: return 0.1074562668800354f;
  t184_n79: return 0.04416098818182945f;
  t184_n80: return -0.0937422662973404f;
  t184_n81: if (E.getNumReferences() >= 3318226944 /*6404.0*/) goto t184_n89;
  t184_n82: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t184_n88;
  t184_n83: if (E.getNumReferences() >= 3309780992 /*3188.0*/) goto t184_n87;
  t184_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t184_n86;
  t184_n85: return 0.06300542503595352f;
  t184_n86: return 0.11774332821369171f;
  t184_n87: return 0.028402650728821754f;
  t184_n88: return 0.0024592955596745014f;
  t184_n89: if (E.getNumReferences() >= 3318784000 /*6676.0*/) goto t184_n119;
  t184_n90: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n96;
  t184_n91: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t184_n95;
  t184_n92: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t184_n94;
  t184_n93: return 0.10940928757190704f;
  t184_n94: return -0.04119542986154556f;
  t184_n95: return 0.01350487396121025f;
  t184_n96: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t184_n106;
  t184_n97: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t184_n99;
  t184_n98: return 0.27667200565338135f;
  t184_n99: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t184_n105;
  t184_n100: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t184_n102;
  t184_n101: return -0.11945128440856934f;
  t184_n102: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t184_n104;
  t184_n103: return 0.12514232099056244f;
  t184_n104: return 0.08991323411464691f;
  t184_n105: return 0.08378748595714569f;
  t184_n106: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t184_n112;
  t184_n107: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t184_n109;
  t184_n108: return 0.08279432356357574f;
  t184_n109: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t184_n111;
  t184_n110: return 0.11387267708778381f;
  t184_n111: return 0.06559960544109344f;
  t184_n112: if (E.getNumReferences() >= 3318714368 /*6642.0*/) goto t184_n118;
  t184_n113: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t184_n115;
  t184_n114: return -0.11348031461238861f;
  t184_n115: if (E.getNumReferences() >= 3318256640 /*6418.5*/) goto t184_n117;
  t184_n116: return 0.1324397176504135f;
  t184_n117: return 0.11333335936069489f;
  t184_n118: return 0.13806840777397156f;
  t184_n119: return 0.017334921285510063f;
  t184_n120: if (E.getNumReferences() >= 3309760512 /*3183.0*/) goto t184_n122;
  t184_n121: return -0.10116156935691833f;
  t184_n122: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t184_n160;
  t184_n123: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t184_n157;
  t184_n124: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t184_n132;
  t184_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t184_n129;
  t184_n126: if (E.getNumReferences() >= 3311990784 /*3727.5*/) goto t184_n128;
  t184_n127: return 0.0795750692486763f;
  t184_n128: return -0.05654770880937576f;
  t184_n129: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t184_n131;
  t184_n130: return 0.10840052366256714f;
  t184_n131: return -0.14450420439243317f;
  t184_n132: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t184_n138;
  t184_n133: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t184_n135;
  t184_n134: return 0.04652930051088333f;
  t184_n135: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n137;
  t184_n136: return 0.1049511656165123f;
  t184_n137: return 0.11525100469589233f;
  t184_n138: if (E.getNumReferences() >= 3321964544 /*8266.0*/) goto t184_n140;
  t184_n139: return -0.027642134577035904f;
  t184_n140: if (E.getNumReferences() >= 3322966016 /*9244.0*/) goto t184_n146;
  t184_n141: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n143;
  t184_n142: return 0.10460109263658524f;
  t184_n143: if (E.getNumReferences() >= 3322208768 /*8504.5*/) goto t184_n145;
  t184_n144: return 0.11253786087036133f;
  t184_n145: return 0.09855704009532928f;
  t184_n146: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t184_n154;
  t184_n147: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t184_n153;
  t184_n148: if (E.getNumReferences() >= 3324703232 /*10940.5*/) goto t184_n152;
  t184_n149: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n151;
  t184_n150: return 0.13788558542728424f;
  t184_n151: return 0.11153776198625565f;
  t184_n152: return 0.06134341284632683f;
  t184_n153: return 0.014302845112979412f;
  t184_n154: if (E.getNumReferences() >= 3327475712 /*13648.0*/) goto t184_n156;
  t184_n155: return -0.046510327607393265f;
  t184_n156: return 0.08708252012729645f;
  t184_n157: if (E.getNumReferences() >= 3314504704 /*4586.5*/) goto t184_n159;
  t184_n158: return 0.10108499228954315f;
  t184_n159: return 0.03521665185689926f;
  t184_n160: if (E.getNumReferences() >= 3315111936 /*4883.0*/) goto t184_n164;
  t184_n161: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t184_n163;
  t184_n162: return 0.12324710190296173f;
  t184_n163: return -0.3767958879470825f;
  t184_n164: return 0.06965842097997665f;
  t184_n165: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t184_n175;
  t184_n166: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t184_n174;
  t184_n167: if (E.getNumReferences() >= 3331489536 /*18751.5*/) goto t184_n173;
  t184_n168: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t184_n172;
  t184_n169: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t184_n171;
  t184_n170: return 0.15003293752670288f;
  t184_n171: return 0.11796627193689346f;
  t184_n172: return 0.00013063081132713705f;
  t184_n173: return 0.027439303696155548f;
  t184_n174: return 0.12649011611938477f;
  t184_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace))) goto t184_n225;
  t184_n176: if (E.getNumReferences() >= 3333150720 /*21996.0*/) goto t184_n214;
  t184_n177: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t184_n179;
  t184_n178: return -0.08294659107923508f;
  t184_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t184_n183;
  t184_n180: if (E.getNumReferences() >= 3333062144 /*21823.0*/) goto t184_n182;
  t184_n181: return 0.0034780350979417562f;
  t184_n182: return -0.7859443426132202f;
  t184_n183: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t184_n197;
  t184_n184: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t184_n186;
  t184_n185: return -0.07194910943508148f;
  t184_n186: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t184_n194;
  t184_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t184_n189;
  t184_n188: return 0.038890253752470016f;
  t184_n189: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n191;
  t184_n190: return -0.23271845281124115f;
  t184_n191: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t184_n193;
  t184_n192: return 0.1254224330186844f;
  t184_n193: return -0.5227401852607727f;
  t184_n194: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n196;
  t184_n195: return -0.014535917900502682f;
  t184_n196: return 0.12458661198616028f;
  t184_n197: if (E.getNumReferences() >= 3332022528 /*19792.5*/) goto t184_n203;
  t184_n198: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n202;
  t184_n199: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n201;
  t184_n200: return 0.11025134474039078f;
  t184_n201: return 0.10182156413793564f;
  t184_n202: return -0.10175175964832306f;
  t184_n203: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t184_n205;
  t184_n204: return 0.03057844564318657f;
  t184_n205: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n213;
  t184_n206: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t184_n212;
  t184_n207: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t184_n211;
  t184_n208: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t184_n210;
  t184_n209: return -0.12753723561763763f;
  t184_n210: return 0.14823468029499054f;
  t184_n211: return 0.10585367679595947f;
  t184_n212: return -0.5997214317321777f;
  t184_n213: return -0.11409372836351395f;
  t184_n214: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t184_n218;
  t184_n215: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t184_n217;
  t184_n216: return 0.20092681050300598f;
  t184_n217: return 0.04896285757422447f;
  t184_n218: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t184_n224;
  t184_n219: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t184_n221;
  t184_n220: return -1.0578292608261108f;
  t184_n221: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n223;
  t184_n222: return 0.11427240818738937f;
  t184_n223: return -0.0015535200946033f;
  t184_n224: return -0.008649052120745182f;
  t184_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t184_n227;
  t184_n226: return -0.10179968923330307f;
  t184_n227: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t184_n233;
  t184_n228: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t184_n230;
  t184_n229: return 0.042522333562374115f;
  t184_n230: if (E.getNumReferences() >= 3332491264 /*20708.0*/) goto t184_n232;
  t184_n231: return 0.11916402727365494f;
  t184_n232: return 0.043660640716552734f;
  t184_n233: return 0.09605246037244797f;
  t184_n234: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t184_n254;
  t184_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t184_n253;
  t184_n236: if (E.getNumReferences() >= 3339403904 /*35650.5*/) goto t184_n248;
  t184_n237: if (E.getNumReferences() >= 3339210368 /*34894.5*/) goto t184_n247;
  t184_n238: if (E.getNumReferences() >= 3336494336 /*28526.5*/) goto t184_n240;
  t184_n239: return -0.19575124979019165f;
  t184_n240: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t184_n242;
  t184_n241: return -0.12098034471273422f;
  t184_n242: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t184_n244;
  t184_n243: return -0.4348093271255493f;
  t184_n244: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t184_n246;
  t184_n245: return 0.10420862585306168f;
  t184_n246: return 0.058329880237579346f;
  t184_n247: return 0.10999801754951477f;
  t184_n248: if (E.getNumReferences() >= 3341955584 /*45618.0*/) goto t184_n252;
  t184_n249: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t184_n251;
  t184_n250: return -0.52498859167099f;
  t184_n251: return 0.09745971858501434f;
  t184_n252: return -0.04009340703487396f;
  t184_n253: return -0.009367668069899082f;
  t184_n254: return 0.03377360850572586f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree185(const Example& E) {
  t185_n0: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t185_n112;
  t185_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t185_n93;
  t185_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t185_n4;
  t185_n3: return -0.004016815684735775f;
  t185_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t185_n90;
  t185_n5: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t185_n89;
  t185_n6: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t185_n88;
  t185_n7: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t185_n79;
  t185_n8: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t185_n10;
  t185_n9: return -0.0031859613955020905f;
  t185_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t185_n34;
  t185_n11: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t185_n29;
  t185_n12: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t185_n26;
  t185_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t185_n19;
  t185_n14: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t185_n16;
  t185_n15: return -0.05873775854706764f;
  t185_n16: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t185_n18;
  t185_n17: return -0.45403987169265747f;
  t185_n18: return -0.13427257537841797f;
  t185_n19: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t185_n25;
  t185_n20: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t185_n24;
  t185_n21: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t185_n23;
  t185_n22: return -0.21170924603939056f;
  t185_n23: return 0.010239040479063988f;
  t185_n24: return -0.011342586949467659f;
  t185_n25: return 0.03236059099435806f;
  t185_n26: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t185_n28;
  t185_n27: return 0.04074576497077942f;
  t185_n28: return 0.13768692314624786f;
  t185_n29: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t185_n33;
  t185_n30: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t185_n32;
  t185_n31: return -0.088398277759552f;
  t185_n32: return 0.04782962426543236f;
  t185_n33: return -0.16532225906848907f;
  t185_n34: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t185_n36;
  t185_n35: return -0.17863978445529938f;
  t185_n36: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t185_n66;
  t185_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t185_n39;
  t185_n38: return -0.18029943108558655f;
  t185_n39: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t185_n45;
  t185_n40: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t185_n44;
  t185_n41: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t185_n43;
  t185_n42: return -0.0965985357761383f;
  t185_n43: return 0.08581145852804184f;
  t185_n44: return 0.14101749658584595f;
  t185_n45: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t185_n47;
  t185_n46: return -0.47410646080970764f;
  t185_n47: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t185_n49;
  t185_n48: return 0.1600121557712555f;
  t185_n49: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t185_n57;
  t185_n50: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t185_n52;
  t185_n51: return 0.02053808607161045f;
  t185_n52: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t185_n54;
  t185_n53: return 0.11102624982595444f;
  t185_n54: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t185_n56;
  t185_n55: return 0.004039584193378687f;
  t185_n56: return 0.11031181365251541f;
  t185_n57: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t185_n65;
  t185_n58: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t185_n64;
  t185_n59: if (E.getFileProximityDistance() >= 3249537024 /*22.0*/) goto t185_n63;
  t185_n60: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t185_n62;
  t185_n61: return 0.11276090145111084f;
  t185_n62: return 0.08380714058876038f;
  t185_n63: return -0.00529521657153964f;
  t185_n64: return -0.03591466322541237f;
  t185_n65: return -0.04949536919593811f;
  t185_n66: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t185_n78;
  t185_n67: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t185_n77;
  t185_n68: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t185_n70;
  t185_n69: return 0.029401006177067757f;
  t185_n70: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t185_n72;
  t185_n71: return -0.22320832312107086f;
  t185_n72: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t185_n74;
  t185_n73: return 0.0926232635974884f;
  t185_n74: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t185_n76;
  t185_n75: return 0.022803036496043205f;
  t185_n76: return 0.08137644827365875f;
  t185_n77: return -0.007287429179996252f;
  t185_n78: return -0.1268504410982132f;
  t185_n79: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t185_n87;
  t185_n80: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t185_n86;
  t185_n81: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t185_n83;
  t185_n82: return 0.032995663583278656f;
  t185_n83: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t185_n85;
  t185_n84: return 0.11253079026937485f;
  t185_n85: return 0.11886242777109146f;
  t185_n86: return -0.05167246237397194f;
  t185_n87: return -0.08878498524427414f;
  t185_n88: return -0.07325030118227005f;
  t185_n89: return -0.011448615230619907f;
  t185_n90: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t185_n92;
  t185_n91: return 0.0037470299284905195f;
  t185_n92: return -0.05907553434371948f;
  t185_n93: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t185_n99;
  t185_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t185_n96;
  t185_n95: return 0.0019797824788838625f;
  t185_n96: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t185_n98;
  t185_n97: return 0.027848904952406883f;
  t185_n98: return -0.02428283728659153f;
  t185_n99: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t185_n101;
  t185_n100: return -0.037006743252277374f;
  t185_n101: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t185_n111;
  t185_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t185_n104;
  t185_n103: return -0.004103535320609808f;
  t185_n104: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t185_n108;
  t185_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t185_n107;
  t185_n106: return -0.07147955894470215f;
  t185_n107: return -0.011094900779426098f;
  t185_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t185_n110;
  t185_n109: return -0.08093655109405518f;
  t185_n110: return 0.0178377702832222f;
  t185_n111: return -0.01283916924148798f;
  t185_n112: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t185_n228;
  t185_n113: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t185_n211;
  t185_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t185_n162;
  t185_n115: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t185_n147;
  t185_n116: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t185_n118;
  t185_n117: return 0.0008782442309893668f;
  t185_n118: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t185_n140;
  t185_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t185_n121;
  t185_n120: return -0.5403375625610352f;
  t185_n121: if (E.getNumReferences() >= 3284008960 /*380.0*/) goto t185_n123;
  t185_n122: return -0.0635373517870903f;
  t185_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t185_n125;
  t185_n124: return -0.17504698038101196f;
  t185_n125: if (E.getNumReferences() >= 3296239616 /*994.5*/) goto t185_n137;
  t185_n126: if (E.getNumReferences() >= 3290546176 /*647.0*/) goto t185_n134;
  t185_n127: if (E.getNumReferences() >= 3287941120 /*500.0*/) goto t185_n133;
  t185_n128: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t185_n130;
  t185_n129: return -0.12066898494958878f;
  t185_n130: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t185_n132;
  t185_n131: return 0.15082749724388123f;
  t185_n132: return 0.036299291998147964f;
  t185_n133: return -0.2975493371486664f;
  t185_n134: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t185_n136;
  t185_n135: return 0.10179834812879562f;
  t185_n136: return 0.03954039141535759f;
  t185_n137: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t185_n139;
  t185_n138: return -0.3653782606124878f;
  t185_n139: return 0.10516504943370819f;
  t185_n140: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t185_n142;
  t185_n141: return -0.21587005257606506f;
  t185_n142: if (E.getNumReferences() >= 3266904064 /*92.5*/) goto t185_n144;
  t185_n143: return 0.22151681780815125f;
  t185_n144: if (E.getNumReferences() >= 3280568320 /*275.0*/) goto t185_n146;
  t185_n145: return 0.12520642578601837f;
  t185_n146: return 0.011862309649586678f;
  t185_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t185_n149;
  t185_n148: return -0.010942126624286175f;
  t185_n149: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t185_n151;
  t185_n150: return -0.12960213422775269f;
  t185_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t185_n157;
  t185_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t185_n154;
  t185_n153: return -0.06444675475358963f;
  t185_n154: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t185_n156;
  t185_n155: return -0.014983626082539558f;
  t185_n156: return 0.12196018546819687f;
  t185_n157: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t185_n159;
  t185_n158: return -0.3218836188316345f;
  t185_n159: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t185_n161;
  t185_n160: return 0.0974937155842781f;
  t185_n161: return 0.06167072057723999f;
  t185_n162: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t185_n206;
  t185_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t185_n205;
  t185_n164: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t185_n202;
  t185_n165: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t185_n177;
  t185_n166: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t185_n172;
  t185_n167: if (E.getNumReferences() >= 3339097344 /*34453.0*/) goto t185_n169;
  t185_n168: return -0.04889669269323349f;
  t185_n169: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t185_n171;
  t185_n170: return -0.009274343959987164f;
  t185_n171: return 0.0773976594209671f;
  t185_n172: if (E.getNumReferences() >= 3349315712 /*83201.0*/) goto t185_n174;
  t185_n173: return -0.11769062280654907f;
  t185_n174: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t185_n176;
  t185_n175: return 0.03311305120587349f;
  t185_n176: return -0.21407131850719452f;
  t185_n177: if (E.getNumReferences() >= 3279962112 /*256.5*/) goto t185_n179;
  t185_n178: return -0.10284741222858429f;
  t185_n179: if (E.getNumReferences() >= 3281666048 /*308.5*/) goto t185_n181;
  t185_n180: return 0.11759629845619202f;
  t185_n181: if (E.getNumReferences() >= 3332163840 /*20068.5*/) goto t185_n201;
  t185_n182: if (E.getNumReferences() >= 3305103360 /*2047.0*/) goto t185_n194;
  t185_n183: if (E.getNumReferences() >= 3292487680 /*765.5*/) goto t185_n189;
  t185_n184: if (E.getNumReferences() >= 3290152960 /*623.0*/) goto t185_n188;
  t185_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t185_n187;
  t185_n186: return -0.2297629565000534f;
  t185_n187: return 0.10057603567838669f;
  t185_n188: return 0.12241652607917786f;
  t185_n189: if (E.getNumReferences() >= 3294076928 /*862.5*/) goto t185_n191;
  t185_n190: return -0.9793858528137207f;
  t185_n191: if (E.getNumReferences() >= 3296215040 /*993.0*/) goto t185_n193;
  t185_n192: return 0.08399108797311783f;
  t185_n193: return -0.0581575445830822f;
  t185_n194: if (E.getNumReferences() >= 3306749952 /*2448.0*/) goto t185_n196;
  t185_n195: return 0.11330646276473999f;
  t185_n196: if (E.getNumReferences() >= 3323779072 /*10038.0*/) goto t185_n200;
  t185_n197: if (E.getNumReferences() >= 3311661056 /*3647.0*/) goto t185_n199;
  t185_n198: return 0.1096503958106041f;
  t185_n199: return -0.12145514041185379f;
  t185_n200: return 0.08673889189958572f;
  t185_n201: return -0.03000660240650177f;
  t185_n202: if (E.getNumReferences() >= 3275325440 /*185.5*/) goto t185_n204;
  t185_n203: return 0.16898581385612488f;
  t185_n204: return -0.31136807799339294f;
  t185_n205: return 0.00770686287432909f;
  t185_n206: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t185_n210;
  t185_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t185_n209;
  t185_n208: return 0.017184173688292503f;
  t185_n209: return 0.03335610032081604f;
  t185_n210: return -0.12328598648309708f;
  t185_n211: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t185_n213;
  t185_n212: return -0.0013622869737446308f;
  t185_n213: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t185_n227;
  t185_n214: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t185_n224;
  t185_n215: if (E.getNumReferences() >= 3264872448 /*77.0*/) goto t185_n217;
  t185_n216: return -0.11561789363622665f;
  t185_n217: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t185_n219;
  t185_n218: return 0.14069314301013947f;
  t185_n219: if (E.getNumReferences() >= 3272998912 /*150.0*/) goto t185_n221;
  t185_n220: return -0.024184560403227806f;
  t185_n221: if (E.getNumReferences() >= 3273490432 /*157.5*/) goto t185_n223;
  t185_n222: return 0.10726751387119293f;
  t185_n223: return 0.06846949458122253f;
  t185_n224: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t185_n226;
  t185_n225: return 0.12714138627052307f;
  t185_n226: return 0.05462047830224037f;
  t185_n227: return 0.021590258926153183f;
  t185_n228: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t185_n238;
  t185_n229: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t185_n237;
  t185_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t185_n232;
  t185_n231: return -0.12710942327976227f;
  t185_n232: if (E.getNumReferences() >= 3269132288 /*109.5*/) goto t185_n234;
  t185_n233: return 0.01003093458712101f;
  t185_n234: if (E.getNumReferences() >= 3272212480 /*138.0*/) goto t185_n236;
  t185_n235: return 0.12515433132648468f;
  t185_n236: return -0.03431535139679909f;
  t185_n237: return -0.1883072853088379f;
  t185_n238: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t185_n240;
  t185_n239: return 0.0404503159224987f;
  t185_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t185_n242;
  t185_n241: return 0.006417338270694017f;
  t185_n242: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t185_n252;
  t185_n243: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t185_n251;
  t185_n244: if (E.getNumReferences() >= 3283353600 /*360.0*/) goto t185_n248;
  t185_n245: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t185_n247;
  t185_n246: return 0.5685080885887146f;
  t185_n247: return -0.14451369643211365f;
  t185_n248: if (E.getNumReferences() >= 3286253568 /*448.5*/) goto t185_n250;
  t185_n249: return 0.12063411623239517f;
  t185_n250: return 0.08298827707767487f;
  t185_n251: return 0.03867156058549881f;
  t185_n252: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t185_n254;
  t185_n253: return 0.1521046906709671f;
  t185_n254: return 0.07335355132818222f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree186(const Example& E) {
  t186_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t186_n230;
  t186_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t186_n229;
  t186_n2: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t186_n4;
  t186_n3: return 0.001782266073860228f;
  t186_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t186_n214;
  t186_n5: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t186_n61;
  t186_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t186_n8;
  t186_n7: return -0.00733170798048377f;
  t186_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t186_n46;
  t186_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t186_n31;
  t186_n10: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t186_n20;
  t186_n11: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t186_n13;
  t186_n12: return 0.013160674832761288f;
  t186_n13: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t186_n15;
  t186_n14: return -0.32299068570137024f;
  t186_n15: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t186_n17;
  t186_n16: return 0.11757487803697586f;
  t186_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t186_n19;
  t186_n18: return -0.11551551520824432f;
  t186_n19: return 0.12586894631385803f;
  t186_n20: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t186_n30;
  t186_n21: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t186_n25;
  t186_n22: if (E.getNumReferences() >= 3330598400 /*17011.0*/) goto t186_n24;
  t186_n23: return -0.06310763955116272f;
  t186_n24: return 0.10377486795186996f;
  t186_n25: if (E.getNumReferences() >= 3275456512 /*187.5*/) goto t186_n27;
  t186_n26: return 0.10698983073234558f;
  t186_n27: if (E.getNumReferences() >= 3310170112 /*3283.0*/) goto t186_n29;
  t186_n28: return -0.37118855118751526f;
  t186_n29: return 0.12138301134109497f;
  t186_n30: return 0.1287004053592682f;
  t186_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t186_n35;
  t186_n32: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t186_n34;
  t186_n33: return -0.059170231223106384f;
  t186_n34: return -0.2592608630657196f;
  t186_n35: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t186_n39;
  t186_n36: if (E.getNumReferences() >= 3304484864 /*1971.5*/) goto t186_n38;
  t186_n37: return -0.025981983169913292f;
  t186_n38: return -0.27973952889442444f;
  t186_n39: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t186_n41;
  t186_n40: return 0.11256241053342819f;
  t186_n41: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t186_n45;
  t186_n42: if (E.getNumReferences() >= 3283976192 /*379.0*/) goto t186_n44;
  t186_n43: return 0.018280113115906715f;
  t186_n44: return 0.09944209456443787f;
  t186_n45: return -0.3632505536079407f;
  t186_n46: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t186_n48;
  t186_n47: return -0.018899334594607353f;
  t186_n48: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t186_n58;
  t186_n49: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t186_n51;
  t186_n50: return 0.12553058564662933f;
  t186_n51: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t186_n57;
  t186_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t186_n54;
  t186_n53: return -0.1741359680891037f;
  t186_n54: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t186_n56;
  t186_n55: return 0.10074833035469055f;
  t186_n56: return -0.0029818692710250616f;
  t186_n57: return 0.11419955641031265f;
  t186_n58: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t186_n60;
  t186_n59: return -0.04087809845805168f;
  t186_n60: return 0.12197928875684738f;
  t186_n61: if (E.getNumReferences() >= 3280584704 /*275.5*/) goto t186_n213;
  t186_n62: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t186_n170;
  t186_n63: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t186_n65;
  t186_n64: return -0.013857617974281311f;
  t186_n65: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t186_n167;
  t186_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t186_n68;
  t186_n67: return 0.04664923995733261f;
  t186_n68: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t186_n98;
  t186_n69: if (E.getNumReferences() >= 3273687040 /*160.5*/) goto t186_n97;
  t186_n70: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t186_n86;
  t186_n71: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t186_n73;
  t186_n72: return 0.13674421608448029f;
  t186_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t186_n81;
  t186_n74: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t186_n80;
  t186_n75: if (E.getNumReferences() >= 3271622656 /*129.0*/) goto t186_n79;
  t186_n76: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t186_n78;
  t186_n77: return 0.19830982387065887f;
  t186_n78: return 0.138961523771286f;
  t186_n79: return -0.11495674401521683f;
  t186_n80: return 0.1041034460067749f;
  t186_n81: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t186_n85;
  t186_n82: if (E.getNumReferences() >= 3266510848 /*89.5*/) goto t186_n84;
  t186_n83: return 0.11878706514835358f;
  t186_n84: return 0.09462732821702957f;
  t186_n85: return 0.030402828007936478f;
  t186_n86: if (E.getNumReferences() >= 3267297280 /*95.5*/) goto t186_n94;
  t186_n87: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t186_n91;
  t186_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t186_n90;
  t186_n89: return 0.0994776040315628f;
  t186_n90: return 0.10850613564252853f;
  t186_n91: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t186_n93;
  t186_n92: return -0.33802154660224915f;
  t186_n93: return 0.07548215985298157f;
  t186_n94: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t186_n96;
  t186_n95: return -0.2506146728992462f;
  t186_n96: return 0.09739760309457779f;
  t186_n97: return -0.1419524848461151f;
  t186_n98: if (E.getNumReferences() >= 3279912960 /*255.5*/) goto t186_n164;
  t186_n99: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t186_n103;
  t186_n100: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t186_n102;
  t186_n101: return -0.30726513266563416f;
  t186_n102: return 0.031221652403473854f;
  t186_n103: if (E.getNumReferences() >= 3271098368 /*124.5*/) goto t186_n125;
  t186_n104: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t186_n118;
  t186_n105: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t186_n109;
  t186_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t186_n108;
  t186_n107: return -0.13786262273788452f;
  t186_n108: return 0.13386638462543488f;
  t186_n109: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t186_n117;
  t186_n110: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t186_n114;
  t186_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Function))) goto t186_n113;
  t186_n112: return -0.16444429755210876f;
  t186_n113: return 0.13538114726543427f;
  t186_n114: if (E.getNumReferences() >= 3270574080 /*120.5*/) goto t186_n116;
  t186_n115: return 0.28623124957084656f;
  t186_n116: return -0.15610714256763458f;
  t186_n117: return -0.013294008560478687f;
  t186_n118: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t186_n120;
  t186_n119: return -0.017660239711403847f;
  t186_n120: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t186_n122;
  t186_n121: return 0.12669984996318817f;
  t186_n122: if (E.getNumReferences() >= 3270836224 /*122.5*/) goto t186_n124;
  t186_n123: return 0.7876565456390381f;
  t186_n124: return 0.0515180379152298f;
  t186_n125: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t186_n127;
  t186_n126: return 0.006396535784006119f;
  t186_n127: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t186_n145;
  t186_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t186_n142;
  t186_n129: if (E.getNumReferences() >= 3279028224 /*242.0*/) goto t186_n139;
  t186_n130: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t186_n132;
  t186_n131: return -0.12734171748161316f;
  t186_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t186_n134;
  t186_n133: return 0.026240075007081032f;
  t186_n134: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t186_n136;
  t186_n135: return -0.2620522081851959f;
  t186_n136: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t186_n138;
  t186_n137: return 0.19157004356384277f;
  t186_n138: return 0.019441738724708557f;
  t186_n139: if (E.getNumReferences() >= 3279388672 /*247.5*/) goto t186_n141;
  t186_n140: return 0.10572632402181625f;
  t186_n141: return 0.056882359087467194f;
  t186_n142: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t186_n144;
  t186_n143: return 0.6092644333839417f;
  t186_n144: return 0.11990684270858765f;
  t186_n145: if (E.getNumReferences() >= 3275194368 /*183.5*/) goto t186_n163;
  t186_n146: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t186_n162;
  t186_n147: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t186_n161;
  t186_n148: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t186_n150;
  t186_n149: return 0.0942394956946373f;
  t186_n150: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t186_n156;
  t186_n151: if (E.getNumReferences() >= 3272343552 /*140.0*/) goto t186_n155;
  t186_n152: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t186_n154;
  t186_n153: return -0.10995908081531525f;
  t186_n154: return 0.4610445201396942f;
  t186_n155: return 0.12380397319793701f;
  t186_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t186_n158;
  t186_n157: return -0.10785214602947235f;
  t186_n158: if (E.getNumReferences() >= 3273818112 /*162.5*/) goto t186_n160;
  t186_n159: return 0.09923693537712097f;
  t186_n160: return 0.44949325919151306f;
  t186_n161: return -0.09038351476192474f;
  t186_n162: return 0.13851827383041382f;
  t186_n163: return -0.049582939594984055f;
  t186_n164: if (E.getNumReferences() >= 3279962112 /*256.5*/) goto t186_n166;
  t186_n165: return 0.115471251308918f;
  t186_n166: return -0.22281737625598907f;
  t186_n167: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t186_n169;
  t186_n168: return 0.0616641491651535f;
  t186_n169: return 0.02075006440281868f;
  t186_n170: if (E.getNumReferences() >= 3280076800 /*260.0*/) goto t186_n208;
  t186_n171: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t186_n173;
  t186_n172: return -0.1153697595000267f;
  t186_n173: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t186_n207;
  t186_n174: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t186_n202;
  t186_n175: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t186_n197;
  t186_n176: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t186_n178;
  t186_n177: return -0.029317311942577362f;
  t186_n178: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t186_n186;
  t186_n179: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t186_n183;
  t186_n180: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t186_n182;
  t186_n181: return 0.21149827539920807f;
  t186_n182: return -0.33405712246894836f;
  t186_n183: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t186_n185;
  t186_n184: return 0.10654521733522415f;
  t186_n185: return 0.11411833018064499f;
  t186_n186: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t186_n190;
  t186_n187: if (E.getNumReferences() >= 3278471168 /*233.5*/) goto t186_n189;
  t186_n188: return 0.049746401607990265f;
  t186_n189: return 0.28384751081466675f;
  t186_n190: if (E.getNumReferences() >= 3269984256 /*116.0*/) goto t186_n192;
  t186_n191: return -0.08636771887540817f;
  t186_n192: if (E.getNumReferences() >= 3275128832 /*182.5*/) goto t186_n196;
  t186_n193: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t186_n195;
  t186_n194: return 0.13682201504707336f;
  t186_n195: return -0.19927294552326202f;
  t186_n196: return -0.06312176585197449f;
  t186_n197: if (E.getNumReferences() >= 3265134592 /*79.0*/) goto t186_n199;
  t186_n198: return -0.10229342430830002f;
  t186_n199: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t186_n201;
  t186_n200: return 0.12380918115377426f;
  t186_n201: return 0.05492518097162247f;
  t186_n202: if (E.getNumReferences() >= 3277422592 /*217.5*/) goto t186_n204;
  t186_n203: return -0.03974096104502678f;
  t186_n204: if (E.getNumReferences() >= 3278209024 /*229.5*/) goto t186_n206;
  t186_n205: return 0.2296922206878662f;
  t186_n206: return -0.03587697446346283f;
  t186_n207: return 0.02966712974011898f;
  t186_n208: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t186_n212;
  t186_n209: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t186_n211;
  t186_n210: return 0.11925139278173447f;
  t186_n211: return 0.11314435303211212f;
  t186_n212: return -0.2752797603607178f;
  t186_n213: return 0.0015567935770377517f;
  t186_n214: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t186_n224;
  t186_n215: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t186_n223;
  t186_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t186_n218;
  t186_n217: return 0.027155403047800064f;
  t186_n218: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t186_n222;
  t186_n219: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t186_n221;
  t186_n220: return -0.020017031580209732f;
  t186_n221: return 0.10577955842018127f;
  t186_n222: return 0.0028596408665180206f;
  t186_n223: return 0.014259175397455692f;
  t186_n224: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t186_n228;
  t186_n225: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t186_n227;
  t186_n226: return -0.029691819101572037f;
  t186_n227: return 3.9555389881134033f;
  t186_n228: return 0.09576333314180374f;
  t186_n229: return -0.0012177583994343877f;
  t186_n230: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t186_n254;
  t186_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t186_n233;
  t186_n232: return 0.004391705617308617f;
  t186_n233: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t186_n247;
  t186_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t186_n244;
  t186_n235: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t186_n237;
  t186_n236: return 0.08534576743841171f;
  t186_n237: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t186_n241;
  t186_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t186_n240;
  t186_n239: return -0.17852656543254852f;
  t186_n240: return 0.09263347834348679f;
  t186_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t186_n243;
  t186_n242: return 0.12073776870965958f;
  t186_n243: return 0.11587531119585037f;
  t186_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t186_n246;
  t186_n245: return 0.0958481952548027f;
  t186_n246: return 0.05771293863654137f;
  t186_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t186_n253;
  t186_n248: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t186_n250;
  t186_n249: return -0.47185882925987244f;
  t186_n250: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t186_n252;
  t186_n251: return 0.11993293464183807f;
  t186_n252: return 0.12502843141555786f;
  t186_n253: return -0.010683135129511356f;
  t186_n254: return 0.004165726248174906f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree187(const Example& E) {
  t187_n0: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t187_n2;
  t187_n1: return -0.00046644240501336753f;
  t187_n2: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t187_n236;
  t187_n3: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t187_n153;
  t187_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t187_n6;
  t187_n5: return 0.0012657862389460206f;
  t187_n6: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t187_n8;
  t187_n7: return 0.10118541121482849f;
  t187_n8: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t187_n152;
  t187_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t187_n131;
  t187_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t187_n12;
  t187_n11: return -0.06318040192127228f;
  t187_n12: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t187_n18;
  t187_n13: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t187_n15;
  t187_n14: return 0.017295213416218758f;
  t187_n15: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t187_n17;
  t187_n16: return -0.3241463899612427f;
  t187_n17: return 0.1340644806623459f;
  t187_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t187_n54;
  t187_n19: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t187_n35;
  t187_n20: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t187_n34;
  t187_n21: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t187_n33;
  t187_n22: if (E.getNumReferences() >= 3286056960 /*442.5*/) goto t187_n24;
  t187_n23: return 0.022375693544745445f;
  t187_n24: if (E.getNumReferences() >= 3288694784 /*534.0*/) goto t187_n32;
  t187_n25: if (E.getNumReferences() >= 3288088576 /*504.5*/) goto t187_n29;
  t187_n26: if (E.getNumReferences() >= 3286335488 /*451.0*/) goto t187_n28;
  t187_n27: return 0.1480315625667572f;
  t187_n28: return 0.03618667647242546f;
  t187_n29: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t187_n31;
  t187_n30: return -0.10055456310510635f;
  t187_n31: return 0.11230430752038956f;
  t187_n32: return 0.028902409598231316f;
  t187_n33: return 0.0032243062742054462f;
  t187_n34: return -0.04500287026166916f;
  t187_n35: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t187_n53;
  t187_n36: if (E.getNumReferences() >= 3275358208 /*186.0*/) goto t187_n38;
  t187_n37: return -0.18517068028450012f;
  t187_n38: if (E.getNumReferences() >= 3279716352 /*252.5*/) goto t187_n44;
  t187_n39: if (E.getNumReferences() >= 3278569472 /*235.0*/) goto t187_n43;
  t187_n40: if (E.getNumReferences() >= 3275653120 /*190.5*/) goto t187_n42;
  t187_n41: return 0.10820043087005615f;
  t187_n42: return -0.18806852400302887f;
  t187_n43: return 0.11209414154291153f;
  t187_n44: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t187_n48;
  t187_n45: if (E.getNumReferences() >= 3292758016 /*782.0*/) goto t187_n47;
  t187_n46: return 0.14496196806430817f;
  t187_n47: return 0.12555967271327972f;
  t187_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t187_n50;
  t187_n49: return -0.15912799537181854f;
  t187_n50: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t187_n52;
  t187_n51: return 0.10735123604536057f;
  t187_n52: return -0.16102057695388794f;
  t187_n53: return -0.0546259768307209f;
  t187_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t187_n56;
  t187_n55: return -0.01594160683453083f;
  t187_n56: if (E.getNumReferences() >= 3271098368 /*124.5*/) goto t187_n72;
  t187_n57: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t187_n63;
  t187_n58: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t187_n62;
  t187_n59: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t187_n61;
  t187_n60: return 0.15791106224060059f;
  t187_n61: return 0.055173568427562714f;
  t187_n62: return -0.0086901243776083f;
  t187_n63: if (E.getNumReferences() >= 3270836224 /*122.5*/) goto t187_n69;
  t187_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t187_n68;
  t187_n65: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t187_n67;
  t187_n66: return -0.1261642873287201f;
  t187_n67: return 0.11696066707372665f;
  t187_n68: return 0.12329985201358795f;
  t187_n69: if (E.getNumReferences() >= 3270967296 /*123.5*/) goto t187_n71;
  t187_n70: return 0.12019441276788712f;
  t187_n71: return -0.11677715927362442f;
  t187_n72: if (E.getNumReferences() >= 3278602240 /*235.5*/) goto t187_n76;
  t187_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t187_n75;
  t187_n74: return -0.0006026948685757816f;
  t187_n75: return 0.07171722501516342f;
  t187_n76: if (E.getNumReferences() >= 3279994880 /*257.5*/) goto t187_n92;
  t187_n77: if (E.getNumReferences() >= 3279912960 /*255.5*/) goto t187_n87;
  t187_n78: if (E.getNumReferences() >= 3279126528 /*243.5*/) goto t187_n86;
  t187_n79: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t187_n81;
  t187_n80: return -0.1452096402645111f;
  t187_n81: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t187_n85;
  t187_n82: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t187_n84;
  t187_n83: return 0.32909661531448364f;
  t187_n84: return -0.23409052193164825f;
  t187_n85: return 0.12200077623128891f;
  t187_n86: return -0.11569412797689438f;
  t187_n87: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t187_n91;
  t187_n88: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t187_n90;
  t187_n89: return -0.2875572741031647f;
  t187_n90: return 0.13582485914230347f;
  t187_n91: return 0.12010299414396286f;
  t187_n92: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t187_n118;
  t187_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t187_n95;
  t187_n94: return 0.04429960250854492f;
  t187_n95: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t187_n97;
  t187_n96: return -0.06302307546138763f;
  t187_n97: if (E.getNumReferences() >= 3281502208 /*303.5*/) goto t187_n99;
  t187_n98: return -0.08518396317958832f;
  t187_n99: if (E.getNumReferences() >= 3281682432 /*309.0*/) goto t187_n101;
  t187_n100: return 0.12111898511648178f;
  t187_n101: if (E.getNumReferences() >= 3284418560 /*392.5*/) goto t187_n103;
  t187_n102: return -0.03373561054468155f;
  t187_n103: if (E.getNumReferences() >= 3302064128 /*1676.0*/) goto t187_n117;
  t187_n104: if (E.getNumReferences() >= 3292233728 /*750.0*/) goto t187_n112;
  t187_n105: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t187_n111;
  t187_n106: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t187_n110;
  t187_n107: if (E.getNumReferences() >= 3286089728 /*443.5*/) goto t187_n109;
  t187_n108: return 0.03520903363823891f;
  t187_n109: return 0.11713691800832748f;
  t187_n110: return 0.06254663318395615f;
  t187_n111: return 0.0108256246894598f;
  t187_n112: if (E.getNumReferences() >= 3297796096 /*1155.0*/) goto t187_n116;
  t187_n113: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t187_n115;
  t187_n114: return 0.1323985457420349f;
  t187_n115: return 0.08842974156141281f;
  t187_n116: return 0.10030961781740189f;
  t187_n117: return 0.04846611246466637f;
  t187_n118: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t187_n128;
  t187_n119: if (E.getNumReferences() >= 3281944576 /*317.0*/) goto t187_n121;
  t187_n120: return 0.0821327194571495f;
  t187_n121: if (E.getNumReferences() >= 3283599360 /*367.5*/) goto t187_n123;
  t187_n122: return 0.17609848082065582f;
  t187_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t187_n127;
  t187_n124: if (E.getNumReferences() >= 3288760320 /*538.0*/) goto t187_n126;
  t187_n125: return 0.13119637966156006f;
  t187_n126: return -0.10970784723758698f;
  t187_n127: return 0.15386700630187988f;
  t187_n128: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t187_n130;
  t187_n129: return 0.03668753430247307f;
  t187_n130: return -0.22638100385665894f;
  t187_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t187_n143;
  t187_n132: if (E.getNumReferences() >= 3330029056 /*16141.5*/) goto t187_n140;
  t187_n133: if (E.getNumReferences() >= 3293192192 /*808.5*/) goto t187_n137;
  t187_n134: if (E.getNumReferences() >= 3293093888 /*802.5*/) goto t187_n136;
  t187_n135: return -0.016972294077277184f;
  t187_n136: return 0.11778029054403305f;
  t187_n137: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t187_n139;
  t187_n138: return -0.10883177071809769f;
  t187_n139: return 0.09914248436689377f;
  t187_n140: if (E.getNumReferences() >= 3331594240 /*18956.0*/) goto t187_n142;
  t187_n141: return 0.11738230288028717f;
  t187_n142: return 0.007805028464645147f;
  t187_n143: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t187_n147;
  t187_n144: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t187_n146;
  t187_n145: return -0.05921526625752449f;
  t187_n146: return 0.05628411844372749f;
  t187_n147: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t187_n151;
  t187_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t187_n150;
  t187_n149: return 0.11087051779031754f;
  t187_n150: return 0.09944386035203934f;
  t187_n151: return 0.036515973508358f;
  t187_n152: return 0.014135024510324001f;
  t187_n153: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t187_n189;
  t187_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t187_n172;
  t187_n155: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t187_n157;
  t187_n156: return -0.04159403219819069f;
  t187_n157: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t187_n161;
  t187_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t187_n160;
  t187_n159: return 0.10995606333017349f;
  t187_n160: return 0.109839528799057f;
  t187_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t187_n163;
  t187_n162: return 0.032277293503284454f;
  t187_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t187_n165;
  t187_n164: return 0.045380253344774246f;
  t187_n165: if (E.getNumReferences() >= 3289800704 /*601.5*/) goto t187_n167;
  t187_n166: return 0.06772036105394363f;
  t187_n167: if (E.getNumReferences() >= 3291504640 /*705.5*/) goto t187_n171;
  t187_n168: if (E.getNumReferences() >= 3290923008 /*670.0*/) goto t187_n170;
  t187_n169: return 0.10267538577318192f;
  t187_n170: return 0.12561668455600739f;
  t187_n171: return 0.06710595637559891f;
  t187_n172: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t187_n180;
  t187_n173: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t187_n179;
  t187_n174: if (E.getNumReferences() >= 3288891392 /*546.0*/) goto t187_n176;
  t187_n175: return -0.04131636023521423f;
  t187_n176: if (E.getNumReferences() >= 3291193344 /*686.5*/) goto t187_n178;
  t187_n177: return 0.12901362776756287f;
  t187_n178: return 0.008170148357748985f;
  t187_n179: return 0.1025586873292923f;
  t187_n180: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t187_n182;
  t187_n181: return 0.10126198083162308f;
  t187_n182: if (E.getNumReferences() >= 3313785856 /*4235.5*/) goto t187_n188;
  t187_n183: if (E.getNumReferences() >= 3276242944 /*199.5*/) goto t187_n185;
  t187_n184: return 0.03827086091041565f;
  t187_n185: if (E.getNumReferences() >= 3278143488 /*228.5*/) goto t187_n187;
  t187_n186: return 0.1064048483967781f;
  t187_n187: return 0.07681070268154144f;
  t187_n188: return -0.3052935302257538f;
  t187_n189: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t187_n191;
  t187_n190: return -0.019254563376307487f;
  t187_n191: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t187_n201;
  t187_n192: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t187_n194;
  t187_n193: return 0.00013674930960405618f;
  t187_n194: if (E.getNumReferences() >= 3273261056 /*154.0*/) goto t187_n198;
  t187_n195: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t187_n197;
  t187_n196: return -0.163194939494133f;
  t187_n197: return 0.14690986275672913f;
  t187_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t187_n200;
  t187_n199: return -0.16437067091464996f;
  t187_n200: return 0.05920817330479622f;
  t187_n201: if (E.getSymbolScopeDistance() >= 3246915584 /*17.0*/) goto t187_n223;
  t187_n202: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t187_n222;
  t187_n203: if (E.getNumReferences() >= 3287072768 /*473.5*/) goto t187_n209;
  t187_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t187_n206;
  t187_n205: return 0.09243077039718628f;
  t187_n206: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t187_n208;
  t187_n207: return 2.8538811206817627f;
  t187_n208: return 0.18577782809734344f;
  t187_n209: if (E.getNumReferences() >= 3288285184 /*510.5*/) goto t187_n211;
  t187_n210: return 0.13383227586746216f;
  t187_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace))) goto t187_n221;
  t187_n212: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t187_n218;
  t187_n213: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t187_n217;
  t187_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t187_n216;
  t187_n215: return 0.03210006654262543f;
  t187_n216: return 0.23591859638690948f;
  t187_n217: return -0.21356800198554993f;
  t187_n218: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t187_n220;
  t187_n219: return 0.13062086701393127f;
  t187_n220: return -0.23896293342113495f;
  t187_n221: return 0.12838420271873474f;
  t187_n222: return 0.13729743659496307f;
  t187_n223: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t187_n235;
  t187_n224: if (E.getNumReferences() >= 3355687776 /*134893.5*/) goto t187_n232;
  t187_n225: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t187_n227;
  t187_n226: return 0.013761309906840324f;
  t187_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t187_n231;
  t187_n228: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t187_n230;
  t187_n229: return -0.22428201138973236f;
  t187_n230: return 0.07697849720716476f;
  t187_n231: return 0.07056015729904175f;
  t187_n232: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t187_n234;
  t187_n233: return -0.006593940779566765f;
  t187_n234: return -0.07739370316267014f;
  t187_n235: return 0.0489828921854496f;
  t187_n236: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t187_n254;
  t187_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t187_n239;
  t187_n238: return 0.05171804130077362f;
  t187_n239: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t187_n241;
  t187_n240: return 0.10709478706121445f;
  t187_n241: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t187_n243;
  t187_n242: return 0.04971366748213768f;
  t187_n243: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t187_n249;
  t187_n244: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t187_n246;
  t187_n245: return 0.04157460108399391f;
  t187_n246: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t187_n248;
  t187_n247: return -0.0852891355752945f;
  t187_n248: return 0.126091867685318f;
  t187_n249: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t187_n251;
  t187_n250: return -0.015507016330957413f;
  t187_n251: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t187_n253;
  t187_n252: return 0.13047629594802856f;
  t187_n253: return 0.11732589453458786f;
  t187_n254: return 0.02319086529314518f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree188(const Example& E) {
  t188_n0: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t188_n214;
  t188_n1: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t188_n129;
  t188_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t188_n26;
  t188_n3: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t188_n5;
  t188_n4: return -0.003730676369741559f;
  t188_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t188_n7;
  t188_n6: return -0.01363696251064539f;
  t188_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t188_n9;
  t188_n8: return -0.021774772554636f;
  t188_n9: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t188_n25;
  t188_n10: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t188_n12;
  t188_n11: return 0.003206630004569888f;
  t188_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n24;
  t188_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t188_n21;
  t188_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t188_n16;
  t188_n15: return -0.04140862077474594f;
  t188_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n18;
  t188_n17: return 0.08019185811281204f;
  t188_n18: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t188_n20;
  t188_n19: return 0.04598677530884743f;
  t188_n20: return -0.019499029964208603f;
  t188_n21: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t188_n23;
  t188_n22: return -0.005107576958835125f;
  t188_n23: return 0.06105893850326538f;
  t188_n24: return 0.00556687219068408f;
  t188_n25: return -0.02351885847747326f;
  t188_n26: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t188_n128;
  t188_n27: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t188_n115;
  t188_n28: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t188_n110;
  t188_n29: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t188_n87;
  t188_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n32;
  t188_n31: return -0.0021983699407428503f;
  t188_n32: if (E.getNumReferences() >= 3281485824 /*303.0*/) goto t188_n82;
  t188_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t188_n75;
  t188_n34: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t188_n38;
  t188_n35: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t188_n37;
  t188_n36: return 0.022569280117750168f;
  t188_n37: return -0.06807295978069305f;
  t188_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t188_n58;
  t188_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t188_n41;
  t188_n40: return -0.015460309572517872f;
  t188_n41: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t188_n57;
  t188_n42: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t188_n52;
  t188_n43: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t188_n45;
  t188_n44: return 0.0385725162923336f;
  t188_n45: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n51;
  t188_n46: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t188_n48;
  t188_n47: return 0.09625967592000961f;
  t188_n48: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t188_n50;
  t188_n49: return -0.1526423841714859f;
  t188_n50: return 0.09579643607139587f;
  t188_n51: return 0.15484118461608887f;
  t188_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t188_n56;
  t188_n53: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t188_n55;
  t188_n54: return 0.13447563350200653f;
  t188_n55: return -0.3821552097797394f;
  t188_n56: return 0.10030467063188553f;
  t188_n57: return -0.030632706359028816f;
  t188_n58: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t188_n70;
  t188_n59: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t188_n65;
  t188_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t188_n62;
  t188_n61: return 0.012601097114384174f;
  t188_n62: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t188_n64;
  t188_n63: return 0.10092172771692276f;
  t188_n64: return -0.0825372189283371f;
  t188_n65: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t188_n69;
  t188_n66: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t188_n68;
  t188_n67: return 0.08593389391899109f;
  t188_n68: return 0.00592559389770031f;
  t188_n69: return -0.06818782538175583f;
  t188_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t188_n72;
  t188_n71: return 0.15315662324428558f;
  t188_n72: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t188_n74;
  t188_n73: return 0.14154185354709625f;
  t188_n74: return 0.1627807319164276f;
  t188_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t188_n77;
  t188_n76: return -0.13869816064834595f;
  t188_n77: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t188_n79;
  t188_n78: return 0.0519988089799881f;
  t188_n79: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t188_n81;
  t188_n80: return 0.132859468460083f;
  t188_n81: return 0.09848211705684662f;
  t188_n82: if (E.getNumReferences() >= 3289022464 /*554.0*/) goto t188_n86;
  t188_n83: if (E.getNumReferences() >= 3284107264 /*383.0*/) goto t188_n85;
  t188_n84: return 0.11830876022577286f;
  t188_n85: return 0.10425155609846115f;
  t188_n86: return 0.014110476709902287f;
  t188_n87: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t188_n91;
  t188_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t188_n90;
  t188_n89: return -0.07893817126750946f;
  t188_n90: return -0.008412557654082775f;
  t188_n91: if (E.getNumReferences() >= 3278241792 /*230.0*/) goto t188_n99;
  t188_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t188_n94;
  t188_n93: return -0.042971715331077576f;
  t188_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t188_n96;
  t188_n95: return -0.022789757698774338f;
  t188_n96: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n98;
  t188_n97: return 0.022854413837194443f;
  t188_n98: return 0.13955479860305786f;
  t188_n99: if (E.getNumReferences() >= 3278962688 /*241.0*/) goto t188_n101;
  t188_n100: return 0.11040925979614258f;
  t188_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t188_n103;
  t188_n102: return -0.10765905678272247f;
  t188_n103: if (E.getNumReferences() >= 3290464256 /*642.0*/) goto t188_n107;
  t188_n104: if (E.getNumReferences() >= 3280748544 /*280.5*/) goto t188_n106;
  t188_n105: return 0.10531022399663925f;
  t188_n106: return 0.010758694261312485f;
  t188_n107: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t188_n109;
  t188_n108: return -0.04956215247511864f;
  t188_n109: return 0.10105735063552856f;
  t188_n110: if (E.getNumReferences() >= 3296002048 /*980.0*/) goto t188_n112;
  t188_n111: return -0.01481482945382595f;
  t188_n112: if (E.getNumReferences() >= 3296616448 /*1017.5*/) goto t188_n114;
  t188_n113: return 0.09542827308177948f;
  t188_n114: return -0.022482577711343765f;
  t188_n115: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t188_n117;
  t188_n116: return 0.013513841666281223f;
  t188_n117: if (E.getNumReferences() >= 3273654272 /*160.0*/) goto t188_n119;
  t188_n118: return 0.10794440656900406f;
  t188_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t188_n121;
  t188_n120: return -0.006621612701565027f;
  t188_n121: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t188_n123;
  t188_n122: return 0.02713610604405403f;
  t188_n123: if (E.getNumReferences() >= 3292078080 /*740.5*/) goto t188_n127;
  t188_n124: if (E.getNumReferences() >= 3286990848 /*471.0*/) goto t188_n126;
  t188_n125: return 0.04365888237953186f;
  t188_n126: return 0.10243414342403412f;
  t188_n127: return 0.04073135927319527f;
  t188_n128: return 0.004023120738565922f;
  t188_n129: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t188_n181;
  t188_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t188_n176;
  t188_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t188_n167;
  t188_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t188_n154;
  t188_n133: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t188_n143;
  t188_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t188_n140;
  t188_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t188_n139;
  t188_n136: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t188_n138;
  t188_n137: return -0.11565063148736954f;
  t188_n138: return -0.16018174588680267f;
  t188_n139: return -0.1078789085149765f;
  t188_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t188_n142;
  t188_n141: return 0.01991686038672924f;
  t188_n142: return 0.033885736018419266f;
  t188_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t188_n153;
  t188_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t188_n146;
  t188_n145: return -0.06646876782178879f;
  t188_n146: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t188_n152;
  t188_n147: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t188_n149;
  t188_n148: return 0.09277335554361343f;
  t188_n149: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t188_n151;
  t188_n150: return 0.10190832614898682f;
  t188_n151: return 0.06894893199205399f;
  t188_n152: return -0.002001996384933591f;
  t188_n153: return 0.013510113582015038f;
  t188_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t188_n158;
  t188_n155: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n157;
  t188_n156: return 0.011347639374434948f;
  t188_n157: return 0.04179825261235237f;
  t188_n158: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n160;
  t188_n159: return 0.07711243629455566f;
  t188_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t188_n162;
  t188_n161: return 0.061718057841062546f;
  t188_n162: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n166;
  t188_n163: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t188_n165;
  t188_n164: return 0.24483467638492584f;
  t188_n165: return 0.12971976399421692f;
  t188_n166: return -0.10150572657585144f;
  t188_n167: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n173;
  t188_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t188_n172;
  t188_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n171;
  t188_n170: return -0.16467812657356262f;
  t188_n171: return 0.02127045765519142f;
  t188_n172: return -0.004476966802030802f;
  t188_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t188_n175;
  t188_n174: return -0.0006162780337035656f;
  t188_n175: return 0.01166662760078907f;
  t188_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n180;
  t188_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t188_n179;
  t188_n178: return 0.11374019086360931f;
  t188_n179: return 0.011291583068668842f;
  t188_n180: return -0.01970345713198185f;
  t188_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t188_n191;
  t188_n182: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t188_n188;
  t188_n183: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n185;
  t188_n184: return -0.03246455639600754f;
  t188_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n187;
  t188_n186: return -0.038152504712343216f;
  t188_n187: return -0.023191427811980247f;
  t188_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t188_n190;
  t188_n189: return -0.010672398842871189f;
  t188_n190: return 0.014813595451414585f;
  t188_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t188_n197;
  t188_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t188_n194;
  t188_n193: return -0.13235528767108917f;
  t188_n194: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n196;
  t188_n195: return 0.07279699295759201f;
  t188_n196: return -0.046470966190099716f;
  t188_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t188_n201;
  t188_n198: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n200;
  t188_n199: return -0.13096649944782257f;
  t188_n200: return 0.04827476292848587f;
  t188_n201: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n213;
  t188_n202: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n206;
  t188_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t188_n205;
  t188_n204: return -0.10467900335788727f;
  t188_n205: return 0.0884697213768959f;
  t188_n206: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t188_n208;
  t188_n207: return -0.01250266470015049f;
  t188_n208: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t188_n212;
  t188_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t188_n211;
  t188_n210: return 0.10629641264677048f;
  t188_n211: return 0.1588486284017563f;
  t188_n212: return 0.12714970111846924f;
  t188_n213: return 0.08122647553682327f;
  t188_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t188_n216;
  t188_n215: return -0.032140329480171204f;
  t188_n216: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t188_n218;
  t188_n217: return -0.002363086212426424f;
  t188_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t188_n252;
  t188_n219: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t188_n225;
  t188_n220: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t188_n224;
  t188_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t188_n223;
  t188_n222: return -0.04150150343775749f;
  t188_n223: return 0.04409562796354294f;
  t188_n224: return 0.05881880968809128f;
  t188_n225: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t188_n249;
  t188_n226: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t188_n232;
  t188_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t188_n229;
  t188_n228: return 0.025212114676833153f;
  t188_n229: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t188_n231;
  t188_n230: return 0.0631205290555954f;
  t188_n231: return 0.015936115756630898f;
  t188_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t188_n238;
  t188_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t188_n237;
  t188_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t188_n236;
  t188_n235: return 0.05063987895846367f;
  t188_n236: return 0.08162672817707062f;
  t188_n237: return -0.0011963858269155025f;
  t188_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t188_n242;
  t188_n239: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t188_n241;
  t188_n240: return 0.03354136273264885f;
  t188_n241: return 0.07495719939470291f;
  t188_n242: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t188_n246;
  t188_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t188_n245;
  t188_n244: return -0.1361045241355896f;
  t188_n245: return 0.09360917657613754f;
  t188_n246: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t188_n248;
  t188_n247: return -0.00015991665713954717f;
  t188_n248: return 0.08770252019166946f;
  t188_n249: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t188_n251;
  t188_n250: return -0.004273523576557636f;
  t188_n251: return 0.04794163256883621f;
  t188_n252: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t188_n254;
  t188_n253: return 0.11048618704080582f;
  t188_n254: return 0.05551352724432945f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree189(const Example& E) {
  t189_n0: if (E.getNumReferences() >= 3306797056 /*2459.5*/) goto t189_n2;
  t189_n1: return -0.00036399468081071973f;
  t189_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t189_n4;
  t189_n3: return 0.01172443013638258f;
  t189_n4: if (E.getNumReferences() >= 3306835968 /*2469.0*/) goto t189_n10;
  t189_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t189_n9;
  t189_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t189_n8;
  t189_n7: return -0.02863471396267414f;
  t189_n8: return 0.09105028212070465f;
  t189_n9: return 0.11522354185581207f;
  t189_n10: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t189_n12;
  t189_n11: return -0.0011811550939455628f;
  t189_n12: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t189_n228;
  t189_n13: if (E.getNumReferences() >= 3315681280 /*5161.0*/) goto t189_n27;
  t189_n14: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t189_n18;
  t189_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t189_n17;
  t189_n16: return -0.10667984932661057f;
  t189_n17: return 0.008383634500205517f;
  t189_n18: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n22;
  t189_n19: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t189_n21;
  t189_n20: return 0.10191347450017929f;
  t189_n21: return -0.09957420080900192f;
  t189_n22: if (E.getNumReferences() >= 3312386048 /*3824.0*/) goto t189_n26;
  t189_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t189_n25;
  t189_n24: return 0.12393452972173691f;
  t189_n25: return -0.09096372872591019f;
  t189_n26: return -1.1102079153060913f;
  t189_n27: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t189_n37;
  t189_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t189_n34;
  t189_n29: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t189_n31;
  t189_n30: return -0.005309075582772493f;
  t189_n31: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t189_n33;
  t189_n32: return 0.09922939538955688f;
  t189_n33: return -0.1198887974023819f;
  t189_n34: if (E.getNumReferences() >= 3315727360 /*5183.5*/) goto t189_n36;
  t189_n35: return 0.09655473381280899f;
  t189_n36: return 0.12537682056427002f;
  t189_n37: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t189_n227;
  t189_n38: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t189_n204;
  t189_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t189_n41;
  t189_n40: return 0.014804106205701828f;
  t189_n41: if (E.getNumReferences() >= 3334023936 /*23701.5*/) goto t189_n187;
  t189_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t189_n134;
  t189_n43: if (E.getNumReferences() >= 3321819136 /*8158.0*/) goto t189_n97;
  t189_n44: if (E.getNumReferences() >= 3321606144 /*8054.0*/) goto t189_n94;
  t189_n45: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t189_n57;
  t189_n46: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t189_n48;
  t189_n47: return -0.03868400678038597f;
  t189_n48: if (E.getNumReferences() >= 3319636992 /*7092.5*/) goto t189_n54;
  t189_n49: if (E.getNumReferences() >= 3317832704 /*6211.5*/) goto t189_n53;
  t189_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t189_n52;
  t189_n51: return 0.1560359001159668f;
  t189_n52: return 0.11370043456554413f;
  t189_n53: return -0.252521812915802f;
  t189_n54: if (E.getNumReferences() >= 3320252416 /*7393.0*/) goto t189_n56;
  t189_n55: return 0.12955592572689056f;
  t189_n56: return 0.07883001863956451f;
  t189_n57: if (E.getNumReferences() >= 3320574976 /*7550.5*/) goto t189_n79;
  t189_n58: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t189_n78;
  t189_n59: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t189_n75;
  t189_n60: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t189_n74;
  t189_n61: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t189_n63;
  t189_n62: return -0.1370147317647934f;
  t189_n63: if (E.getNumReferences() >= 3317490688 /*6044.5*/) goto t189_n65;
  t189_n64: return -0.35051703453063965f;
  t189_n65: if (E.getNumReferences() >= 3317757952 /*6175.0*/) goto t189_n67;
  t189_n66: return 0.1179148256778717f;
  t189_n67: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t189_n73;
  t189_n68: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t189_n72;
  t189_n69: if (E.getNumReferences() >= 3319047168 /*6804.5*/) goto t189_n71;
  t189_n70: return 0.1090007945895195f;
  t189_n71: return -0.1470809280872345f;
  t189_n72: return -0.13006068766117096f;
  t189_n73: return 0.09224629402160645f;
  t189_n74: return -0.06258303672075272f;
  t189_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t189_n77;
  t189_n76: return -0.02796366810798645f;
  t189_n77: return 0.15607984364032745f;
  t189_n78: return -0.03636224567890167f;
  t189_n79: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t189_n85;
  t189_n80: if (E.getNumReferences() >= 3320749056 /*7635.5*/) goto t189_n84;
  t189_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t189_n83;
  t189_n82: return 0.00827658362686634f;
  t189_n83: return 0.14403650164604187f;
  t189_n84: return -0.0670345351099968f;
  t189_n85: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t189_n91;
  t189_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t189_n90;
  t189_n87: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t189_n89;
  t189_n88: return -0.10918455570936203f;
  t189_n89: return 0.11261899024248123f;
  t189_n90: return 0.11090008914470673f;
  t189_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t189_n93;
  t189_n92: return 0.07060972601175308f;
  t189_n93: return 0.11140170693397522f;
  t189_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t189_n96;
  t189_n95: return -0.116575226187706f;
  t189_n96: return 0.11905469000339508f;
  t189_n97: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t189_n101;
  t189_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t189_n100;
  t189_n99: return -0.08645741641521454f;
  t189_n100: return 0.05079266428947449f;
  t189_n101: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t189_n109;
  t189_n102: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t189_n108;
  t189_n103: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t189_n107;
  t189_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n106;
  t189_n105: return 0.12417910993099213f;
  t189_n106: return -0.11401525139808655f;
  t189_n107: return -0.03457915410399437f;
  t189_n108: return -0.046428170055150986f;
  t189_n109: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t189_n125;
  t189_n110: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n112;
  t189_n111: return -0.09980462491512299f;
  t189_n112: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t189_n124;
  t189_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t189_n119;
  t189_n114: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t189_n116;
  t189_n115: return -0.11053500324487686f;
  t189_n116: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t189_n118;
  t189_n117: return 0.1270218789577484f;
  t189_n118: return -0.1153077483177185f;
  t189_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t189_n123;
  t189_n120: if (E.getNumReferences() >= 3329832960 /*15950.0*/) goto t189_n122;
  t189_n121: return 0.105321504175663f;
  t189_n122: return 0.10014180839061737f;
  t189_n123: return -0.06897987425327301f;
  t189_n124: return -0.0385039858520031f;
  t189_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t189_n127;
  t189_n126: return 0.018862618133425713f;
  t189_n127: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t189_n131;
  t189_n128: if (E.getNumReferences() >= 3331140096 /*18069.0*/) goto t189_n130;
  t189_n129: return 0.09831353276968002f;
  t189_n130: return -0.11444570124149323f;
  t189_n131: if (E.getNumReferences() >= 3331729664 /*19220.5*/) goto t189_n133;
  t189_n132: return 0.1161852777004242f;
  t189_n133: return 0.04678849130868912f;
  t189_n134: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t189_n152;
  t189_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t189_n137;
  t189_n136: return -0.17839248478412628f;
  t189_n137: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n145;
  t189_n138: if (E.getNumReferences() >= 3318524928 /*6549.5*/) goto t189_n140;
  t189_n139: return 0.12714987993240356f;
  t189_n140: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t189_n142;
  t189_n141: return -0.20804913341999054f;
  t189_n142: if (E.getNumReferences() >= 3323595264 /*9858.5*/) goto t189_n144;
  t189_n143: return -0.10429506748914719f;
  t189_n144: return 0.11735110729932785f;
  t189_n145: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t189_n149;
  t189_n146: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t189_n148;
  t189_n147: return 0.10906316339969635f;
  t189_n148: return 0.06052790582180023f;
  t189_n149: if (E.getNumReferences() >= 3328500736 /*14649.0*/) goto t189_n151;
  t189_n150: return 0.13677996397018433f;
  t189_n151: return 0.19664829969406128f;
  t189_n152: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t189_n154;
  t189_n153: return 0.027856241911649704f;
  t189_n154: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t189_n162;
  t189_n155: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t189_n157;
  t189_n156: return 0.021598560735583305f;
  t189_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t189_n159;
  t189_n158: return 0.030601978302001953f;
  t189_n159: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t189_n161;
  t189_n160: return 0.11619365960359573f;
  t189_n161: return 0.11088556051254272f;
  t189_n162: if (E.getNumReferences() >= 3322694144 /*8978.5*/) goto t189_n164;
  t189_n163: return 0.0019269773038104177f;
  t189_n164: if (E.getNumReferences() >= 3322934784 /*9213.5*/) goto t189_n166;
  t189_n165: return 0.11560484021902084f;
  t189_n166: if (E.getNumReferences() >= 3324730368 /*10967.0*/) goto t189_n174;
  t189_n167: if (E.getNumReferences() >= 3324197888 /*10447.0*/) goto t189_n171;
  t189_n168: if (E.getNumReferences() >= 3323776512 /*10035.5*/) goto t189_n170;
  t189_n169: return 0.2542572319507599f;
  t189_n170: return -0.2700662314891815f;
  t189_n171: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t189_n173;
  t189_n172: return 0.09065856039524078f;
  t189_n173: return 0.12726005911827087f;
  t189_n174: if (E.getNumReferences() >= 3328404480 /*14555.0*/) goto t189_n176;
  t189_n175: return -0.21839463710784912f;
  t189_n176: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t189_n186;
  t189_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t189_n183;
  t189_n178: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t189_n182;
  t189_n179: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t189_n181;
  t189_n180: return -0.4067786931991577f;
  t189_n181: return 0.0831221342086792f;
  t189_n182: return 0.11957743018865585f;
  t189_n183: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n185;
  t189_n184: return 0.10230939835309982f;
  t189_n185: return 0.08660639077425003f;
  t189_n186: return 0.038773030042648315f;
  t189_n187: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t189_n201;
  t189_n188: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t189_n198;
  t189_n189: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n191;
  t189_n190: return 0.08161254227161407f;
  t189_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t189_n197;
  t189_n192: if (E.getNumReferences() >= 3334111488 /*23872.5*/) goto t189_n196;
  t189_n193: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t189_n195;
  t189_n194: return 0.09275268763303757f;
  t189_n195: return 0.06354279816150665f;
  t189_n196: return -0.10449951142072678f;
  t189_n197: return 0.11081051081418991f;
  t189_n198: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n200;
  t189_n199: return 0.11088764667510986f;
  t189_n200: return 0.06442433595657349f;
  t189_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n203;
  t189_n202: return 0.11175227165222168f;
  t189_n203: return -0.17901504039764404f;
  t189_n204: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t189_n224;
  t189_n205: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t189_n217;
  t189_n206: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t189_n216;
  t189_n207: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t189_n209;
  t189_n208: return -0.3252536654472351f;
  t189_n209: if (E.getNumReferences() >= 3324040704 /*10293.5*/) goto t189_n215;
  t189_n210: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t189_n214;
  t189_n211: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t189_n213;
  t189_n212: return 0.0585707388818264f;
  t189_n213: return 0.09727957099676132f;
  t189_n214: return 0.09914737194776535f;
  t189_n215: return -0.006449663545936346f;
  t189_n216: return 0.05611953139305115f;
  t189_n217: if (E.getNumReferences() >= 3318883328 /*6724.5*/) goto t189_n221;
  t189_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t189_n220;
  t189_n219: return 0.05046457424759865f;
  t189_n220: return 0.10641957074403763f;
  t189_n221: if (E.getNumReferences() >= 3323495424 /*9761.0*/) goto t189_n223;
  t189_n222: return -0.1001855880022049f;
  t189_n223: return 0.04307005926966667f;
  t189_n224: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t189_n226;
  t189_n225: return -0.11796889454126358f;
  t189_n226: return 0.04190710932016373f;
  t189_n227: return 0.10086825489997864f;
  t189_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t189_n248;
  t189_n229: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t189_n243;
  t189_n230: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t189_n242;
  t189_n231: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t189_n235;
  t189_n232: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t189_n234;
  t189_n233: return -0.012809663079679012f;
  t189_n234: return 0.05331690236926079f;
  t189_n235: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t189_n237;
  t189_n236: return -0.08138769865036011f;
  t189_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t189_n239;
  t189_n238: return 0.01324445754289627f;
  t189_n239: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t189_n241;
  t189_n240: return 0.09614205360412598f;
  t189_n241: return 0.017231162637472153f;
  t189_n242: return 0.048118967562913895f;
  t189_n243: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t189_n245;
  t189_n244: return -0.33113065361976624f;
  t189_n245: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t189_n247;
  t189_n246: return 0.060348719358444214f;
  t189_n247: return 0.022848522290587425f;
  t189_n248: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t189_n254;
  t189_n249: if (E.getNumReferences() >= 3342897664 /*49298.0*/) goto t189_n251;
  t189_n250: return 0.010642926208674908f;
  t189_n251: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t189_n253;
  t189_n252: return 0.12061794847249985f;
  t189_n253: return -0.010094386525452137f;
  t189_n254: return 0.019331149756908417f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree190(const Example& E) {
  t190_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t190_n2;
  t190_n1: return -0.00037183004315011203f;
  t190_n2: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t190_n254;
  t190_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t190_n163;
  t190_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t190_n6;
  t190_n5: return 0.01802072674036026f;
  t190_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t190_n72;
  t190_n7: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t190_n59;
  t190_n8: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t190_n36;
  t190_n9: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t190_n13;
  t190_n10: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t190_n12;
  t190_n11: return 0.018861623480916023f;
  t190_n12: return -0.03989424556493759f;
  t190_n13: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t190_n29;
  t190_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n20;
  t190_n15: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t190_n19;
  t190_n16: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t190_n18;
  t190_n17: return 0.00801692996174097f;
  t190_n18: return -0.26924532651901245f;
  t190_n19: return -0.17868472635746002f;
  t190_n20: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n24;
  t190_n21: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t190_n23;
  t190_n22: return -0.21952542662620544f;
  t190_n23: return 0.0395403616130352f;
  t190_n24: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t190_n26;
  t190_n25: return -0.05981216952204704f;
  t190_n26: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t190_n28;
  t190_n27: return 0.02240973897278309f;
  t190_n28: return -1.9399462938308716f;
  t190_n29: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n35;
  t190_n30: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t190_n34;
  t190_n31: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n33;
  t190_n32: return 0.1000649705529213f;
  t190_n33: return 0.12684471905231476f;
  t190_n34: return -0.401202917098999f;
  t190_n35: return 0.021509353071451187f;
  t190_n36: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t190_n58;
  t190_n37: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t190_n53;
  t190_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t190_n50;
  t190_n39: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t190_n47;
  t190_n40: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n46;
  t190_n41: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t190_n43;
  t190_n42: return -0.14196492731571198f;
  t190_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n45;
  t190_n44: return -0.9654711484909058f;
  t190_n45: return 0.01986461877822876f;
  t190_n46: return -0.0430031418800354f;
  t190_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n49;
  t190_n48: return 0.12024897336959839f;
  t190_n49: return -0.11904450505971909f;
  t190_n50: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t190_n52;
  t190_n51: return 0.278547465801239f;
  t190_n52: return 0.020178545266389847f;
  t190_n53: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t190_n55;
  t190_n54: return 0.0036125537008047104f;
  t190_n55: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n57;
  t190_n56: return 0.10072584450244904f;
  t190_n57: return -0.16343654692173004f;
  t190_n58: return 0.13176128268241882f;
  t190_n59: if (E.getNumReferences() >= 3279994880 /*257.5*/) goto t190_n65;
  t190_n60: if (E.getNumReferences() >= 3277717504 /*222.0*/) goto t190_n62;
  t190_n61: return 0.025166720151901245f;
  t190_n62: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t190_n64;
  t190_n63: return 0.13698631525039673f;
  t190_n64: return 0.03232264518737793f;
  t190_n65: if (E.getNumReferences() >= 3339407360 /*35664.0*/) goto t190_n71;
  t190_n66: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t190_n68;
  t190_n67: return -0.019347794353961945f;
  t190_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n70;
  t190_n69: return -0.7807068228721619f;
  t190_n70: return -0.11813672631978989f;
  t190_n71: return 0.08228348940610886f;
  t190_n72: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t190_n154;
  t190_n73: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t190_n125;
  t190_n74: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t190_n84;
  t190_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t190_n79;
  t190_n76: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n78;
  t190_n77: return -0.16073328256607056f;
  t190_n78: return -0.007877168245613575f;
  t190_n79: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t190_n81;
  t190_n80: return 0.05876263976097107f;
  t190_n81: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t190_n83;
  t190_n82: return 0.8293270468711853f;
  t190_n83: return 0.18629838526248932f;
  t190_n84: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n94;
  t190_n85: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t190_n87;
  t190_n86: return -0.10302449762821198f;
  t190_n87: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t190_n89;
  t190_n88: return 0.10841555893421173f;
  t190_n89: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t190_n93;
  t190_n90: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t190_n92;
  t190_n91: return 0.07757479697465897f;
  t190_n92: return 0.11280368268489838f;
  t190_n93: return 0.014349429868161678f;
  t190_n94: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t190_n116;
  t190_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n97;
  t190_n96: return -0.03712943568825722f;
  t190_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t190_n105;
  t190_n98: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t190_n100;
  t190_n99: return -0.01157109159976244f;
  t190_n100: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t190_n102;
  t190_n101: return 0.10290662199258804f;
  t190_n102: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t190_n104;
  t190_n103: return -0.33138176798820496f;
  t190_n104: return 1.5532363653182983f;
  t190_n105: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t190_n115;
  t190_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t190_n114;
  t190_n107: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t190_n113;
  t190_n108: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t190_n112;
  t190_n109: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t190_n111;
  t190_n110: return 0.12295523285865784f;
  t190_n111: return 0.13438349962234497f;
  t190_n112: return 0.1430804431438446f;
  t190_n113: return -0.08434567600488663f;
  t190_n114: return 0.07114722579717636f;
  t190_n115: return 0.024875197559595108f;
  t190_n116: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t190_n118;
  t190_n117: return -0.04120899364352226f;
  t190_n118: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t190_n120;
  t190_n119: return 0.009797855280339718f;
  t190_n120: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t190_n122;
  t190_n121: return 0.147582545876503f;
  t190_n122: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t190_n124;
  t190_n123: return 0.02975742146372795f;
  t190_n124: return 0.11963906139135361f;
  t190_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t190_n127;
  t190_n126: return -0.16300928592681885f;
  t190_n127: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t190_n129;
  t190_n128: return -0.7329940795898438f;
  t190_n129: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t190_n135;
  t190_n130: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t190_n134;
  t190_n131: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t190_n133;
  t190_n132: return -0.04196186736226082f;
  t190_n133: return 0.05253228545188904f;
  t190_n134: return -0.34019753336906433f;
  t190_n135: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t190_n137;
  t190_n136: return 0.05246914178133011f;
  t190_n137: if (E.getNumReferences() >= 3269656576 /*113.5*/) goto t190_n153;
  t190_n138: if (E.getNumReferences() >= 3265527808 /*82.0*/) goto t190_n152;
  t190_n139: if (E.getNumReferences() >= 3263823872 /*69.0*/) goto t190_n151;
  t190_n140: if (E.getNumReferences() >= 3259760640 /*51.0*/) goto t190_n150;
  t190_n141: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t190_n143;
  t190_n142: return -0.044162798672914505f;
  t190_n143: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t190_n145;
  t190_n144: return 0.1264055371284485f;
  t190_n145: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t190_n147;
  t190_n146: return -0.11916462332010269f;
  t190_n147: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t190_n149;
  t190_n148: return -0.059382203966379166f;
  t190_n149: return 0.0860566794872284f;
  t190_n150: return -0.653089702129364f;
  t190_n151: return 0.11259346455335617f;
  t190_n152: return -0.7048563957214355f;
  t190_n153: return 0.08836523443460464f;
  t190_n154: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t190_n156;
  t190_n155: return 0.12153998762369156f;
  t190_n156: if (E.getNumReferences() >= 3282731008 /*341.0*/) goto t190_n158;
  t190_n157: return 0.11220818758010864f;
  t190_n158: if (E.getNumReferences() >= 3287007232 /*471.5*/) goto t190_n160;
  t190_n159: return -0.23284167051315308f;
  t190_n160: if (E.getNumReferences() >= 3288924160 /*548.0*/) goto t190_n162;
  t190_n161: return 0.1468205600976944f;
  t190_n162: return -0.26498255133628845f;
  t190_n163: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t190_n165;
  t190_n164: return 0.006209347862750292f;
  t190_n165: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t190_n207;
  t190_n166: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t190_n168;
  t190_n167: return -0.02060949057340622f;
  t190_n168: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t190_n188;
  t190_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t190_n171;
  t190_n170: return -0.04489394649863243f;
  t190_n171: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t190_n187;
  t190_n172: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t190_n176;
  t190_n173: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t190_n175;
  t190_n174: return 0.06991683691740036f;
  t190_n175: return -0.07849424332380295f;
  t190_n176: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t190_n180;
  t190_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t190_n179;
  t190_n178: return -0.33916619420051575f;
  t190_n179: return 0.07526851445436478f;
  t190_n180: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t190_n186;
  t190_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t190_n183;
  t190_n182: return -0.18370117247104645f;
  t190_n183: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t190_n185;
  t190_n184: return 0.08818858116865158f;
  t190_n185: return 0.13245801627635956f;
  t190_n186: return -0.06418168544769287f;
  t190_n187: return -0.11468446999788284f;
  t190_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t190_n194;
  t190_n189: if (E.getNumReferences() >= 3247964160 /*19.0*/) goto t190_n191;
  t190_n190: return -0.12503252923488617f;
  t190_n191: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t190_n193;
  t190_n192: return 0.08388757705688477f;
  t190_n193: return -0.08083996176719666f;
  t190_n194: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t190_n204;
  t190_n195: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t190_n203;
  t190_n196: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t190_n200;
  t190_n197: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t190_n199;
  t190_n198: return 0.10572981834411621f;
  t190_n199: return -0.17058111727237701f;
  t190_n200: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t190_n202;
  t190_n201: return 0.1341351568698883f;
  t190_n202: return 0.11978894472122192f;
  t190_n203: return 0.11159104108810425f;
  t190_n204: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t190_n206;
  t190_n205: return -0.1174759492278099f;
  t190_n206: return 0.10043615847826004f;
  t190_n207: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t190_n239;
  t190_n208: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t190_n238;
  t190_n209: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t190_n231;
  t190_n210: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t190_n216;
  t190_n211: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t190_n215;
  t190_n212: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t190_n214;
  t190_n213: return -0.2115284651517868f;
  t190_n214: return 0.07118396461009979f;
  t190_n215: return 0.02457071654498577f;
  t190_n216: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n222;
  t190_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t190_n219;
  t190_n218: return 0.04079410061240196f;
  t190_n219: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t190_n221;
  t190_n220: return -0.037799686193466187f;
  t190_n221: return 0.09706006199121475f;
  t190_n222: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t190_n230;
  t190_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t190_n229;
  t190_n224: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t190_n228;
  t190_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t190_n227;
  t190_n226: return -0.44468948245048523f;
  t190_n227: return 0.09835256636142731f;
  t190_n228: return 0.09205294400453568f;
  t190_n229: return 0.03947374224662781f;
  t190_n230: return 0.009860390797257423f;
  t190_n231: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t190_n233;
  t190_n232: return 0.3494124710559845f;
  t190_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t190_n237;
  t190_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n236;
  t190_n235: return 0.14737381041049957f;
  t190_n236: return 0.11857855319976807f;
  t190_n237: return 0.1537100374698639f;
  t190_n238: return -0.027745509520173073f;
  t190_n239: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t190_n241;
  t190_n240: return -0.003711710451170802f;
  t190_n241: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t190_n253;
  t190_n242: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t190_n244;
  t190_n243: return 0.1058899387717247f;
  t190_n244: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t190_n248;
  t190_n245: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t190_n247;
  t190_n246: return -0.12375029176473618f;
  t190_n247: return 0.07473351061344147f;
  t190_n248: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t190_n252;
  t190_n249: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t190_n251;
  t190_n250: return 0.10389994829893112f;
  t190_n251: return 0.06938082724809647f;
  t190_n252: return 0.03585141897201538f;
  t190_n253: return 0.011823105625808239f;
  t190_n254: return -0.0005472165648825467f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree191(const Example& E) {
  t191_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t191_n26;
  t191_n1: if (E.getNumReferences() >= 3349010432 /*80816.0*/) goto t191_n15;
  t191_n2: if (E.getNumReferences() >= 3348846016 /*79531.5*/) goto t191_n4;
  t191_n3: return -0.0001297541311942041f;
  t191_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n6;
  t191_n5: return 0.01169893704354763f;
  t191_n6: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t191_n8;
  t191_n7: return 0.0118651008233428f;
  t191_n8: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t191_n14;
  t191_n9: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t191_n13;
  t191_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n12;
  t191_n11: return 0.13053204119205475f;
  t191_n12: return 0.10332778096199036f;
  t191_n13: return -0.20143763720989227f;
  t191_n14: return 0.12505796551704407f;
  t191_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t191_n17;
  t191_n16: return -0.046733684837818146f;
  t191_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t191_n23;
  t191_n18: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t191_n22;
  t191_n19: if (E.getNumReferences() >= 3349221056 /*82461.5*/) goto t191_n21;
  t191_n20: return -0.3604876697063446f;
  t191_n21: return -0.13427108526229858f;
  t191_n22: return 0.06055426597595215f;
  t191_n23: if (E.getNumReferences() >= 3349481344 /*84495.0*/) goto t191_n25;
  t191_n24: return 0.017326723784208298f;
  t191_n25: return -0.12328728288412094f;
  t191_n26: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t191_n248;
  t191_n27: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t191_n201;
  t191_n28: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t191_n176;
  t191_n29: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t191_n145;
  t191_n30: if (E.getNumReferences() >= 3353375936 /*114921.5*/) goto t191_n126;
  t191_n31: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t191_n85;
  t191_n32: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t191_n84;
  t191_n33: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t191_n41;
  t191_n34: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t191_n40;
  t191_n35: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t191_n39;
  t191_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n38;
  t191_n37: return 0.08852383494377136f;
  t191_n38: return 0.07429914176464081f;
  t191_n39: return -0.06333870440721512f;
  t191_n40: return -0.016217947006225586f;
  t191_n41: if (E.getNumReferences() >= 3350349056 /*91274.0*/) goto t191_n47;
  t191_n42: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t191_n44;
  t191_n43: return -0.1238141879439354f;
  t191_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n46;
  t191_n45: return 0.1105690523982048f;
  t191_n46: return -0.10234072059392929f;
  t191_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n79;
  t191_n48: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t191_n64;
  t191_n49: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t191_n63;
  t191_n50: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t191_n54;
  t191_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t191_n53;
  t191_n52: return -0.14599435031414032f;
  t191_n53: return 0.04677218198776245f;
  t191_n54: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t191_n58;
  t191_n55: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t191_n57;
  t191_n56: return 0.1030626893043518f;
  t191_n57: return 0.08908560872077942f;
  t191_n58: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t191_n60;
  t191_n59: return -0.7416446208953857f;
  t191_n60: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t191_n62;
  t191_n61: return 0.07357277721166611f;
  t191_n62: return -0.11188798397779465f;
  t191_n63: return 0.020827781409025192f;
  t191_n64: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t191_n74;
  t191_n65: if (E.getNumReferences() >= 3351834112 /*102876.0*/) goto t191_n67;
  t191_n66: return -0.045493513345718384f;
  t191_n67: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t191_n73;
  t191_n68: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t191_n72;
  t191_n69: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t191_n71;
  t191_n70: return 0.06460661441087723f;
  t191_n71: return -0.23955577611923218f;
  t191_n72: return 0.08992201834917068f;
  t191_n73: return -0.1898101568222046f;
  t191_n74: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t191_n78;
  t191_n75: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t191_n77;
  t191_n76: return -0.022527674213051796f;
  t191_n77: return 0.13401171565055847f;
  t191_n78: return 0.13280701637268066f;
  t191_n79: if (E.getNumReferences() >= 3350460992 /*92148.5*/) goto t191_n83;
  t191_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n82;
  t191_n81: return 0.10422708094120026f;
  t191_n82: return -0.03633487597107887f;
  t191_n83: return -0.11027367413043976f;
  t191_n84: return 0.021519774571061134f;
  t191_n85: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t191_n87;
  t191_n86: return 0.00802328996360302f;
  t191_n87: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t191_n121;
  t191_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t191_n90;
  t191_n89: return -0.060743581503629684f;
  t191_n90: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t191_n92;
  t191_n91: return 0.09862205386161804f;
  t191_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t191_n108;
  t191_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t191_n103;
  t191_n94: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t191_n96;
  t191_n95: return 0.03679914027452469f;
  t191_n96: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n102;
  t191_n97: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t191_n101;
  t191_n98: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t191_n100;
  t191_n99: return 0.08305387198925018f;
  t191_n100: return 0.14189018309116364f;
  t191_n101: return 0.08218677341938019f;
  t191_n102: return 0.0963914766907692f;
  t191_n103: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t191_n107;
  t191_n104: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t191_n106;
  t191_n105: return 0.04687878489494324f;
  t191_n106: return 0.06841582804918289f;
  t191_n107: return -0.22154691815376282f;
  t191_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n118;
  t191_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t191_n111;
  t191_n110: return -0.04652903601527214f;
  t191_n111: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t191_n115;
  t191_n112: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t191_n114;
  t191_n113: return -2.1559653282165527f;
  t191_n114: return 0.08755278587341309f;
  t191_n115: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t191_n117;
  t191_n116: return 0.10129183530807495f;
  t191_n117: return 0.0878627747297287f;
  t191_n118: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t191_n120;
  t191_n119: return 0.05258181318640709f;
  t191_n120: return -2.9826931953430176f;
  t191_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t191_n123;
  t191_n122: return -0.05185474455356598f;
  t191_n123: if (E.getFileProximityDistance() >= 3249537024 /*22.0*/) goto t191_n125;
  t191_n124: return 0.07702705264091492f;
  t191_n125: return 0.08530953526496887f;
  t191_n126: if (E.getNumReferences() >= 3355264064 /*129672.5*/) goto t191_n134;
  t191_n127: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t191_n129;
  t191_n128: return -0.2616109251976013f;
  t191_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t191_n131;
  t191_n130: return -0.06876000016927719f;
  t191_n131: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t191_n133;
  t191_n132: return 0.08022792637348175f;
  t191_n133: return 0.03388826921582222f;
  t191_n134: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t191_n144;
  t191_n135: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t191_n141;
  t191_n136: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n138;
  t191_n137: return 0.10163265466690063f;
  t191_n138: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t191_n140;
  t191_n139: return 0.06392879039049149f;
  t191_n140: return -0.19218063354492188f;
  t191_n141: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t191_n143;
  t191_n142: return 0.04564862325787544f;
  t191_n143: return -0.1563921421766281f;
  t191_n144: return -0.03190569207072258f;
  t191_n145: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n147;
  t191_n146: return -0.019870104268193245f;
  t191_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n155;
  t191_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t191_n152;
  t191_n149: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t191_n151;
  t191_n150: return 0.004501848015934229f;
  t191_n151: return 0.0753999799489975f;
  t191_n152: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t191_n154;
  t191_n153: return -0.10279015451669693f;
  t191_n154: return 0.08321207761764526f;
  t191_n155: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t191_n159;
  t191_n156: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t191_n158;
  t191_n157: return -0.18584361672401428f;
  t191_n158: return 0.11145269125699997f;
  t191_n159: if (E.getNumReferences() >= 3359621216 /*196353.5*/) goto t191_n175;
  t191_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t191_n162;
  t191_n161: return 0.010651192627847195f;
  t191_n162: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t191_n168;
  t191_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t191_n165;
  t191_n164: return -0.21380206942558289f;
  t191_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t191_n167;
  t191_n166: return 0.10492578148841858f;
  t191_n167: return 0.008100307546555996f;
  t191_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t191_n174;
  t191_n169: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t191_n173;
  t191_n170: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t191_n172;
  t191_n171: return 0.11247123032808304f;
  t191_n172: return 0.10848066955804825f;
  t191_n173: return -0.12028038501739502f;
  t191_n174: return 0.08312270790338516f;
  t191_n175: return -0.12372381240129471f;
  t191_n176: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t191_n178;
  t191_n177: return 0.054419733583927155f;
  t191_n178: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t191_n182;
  t191_n179: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t191_n181;
  t191_n180: return -0.13208819925785065f;
  t191_n181: return -0.5768528580665588f;
  t191_n182: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t191_n198;
  t191_n183: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t191_n185;
  t191_n184: return 0.021107885986566544f;
  t191_n185: if (E.getNumReferences() >= 3354462528 /*123410.5*/) goto t191_n189;
  t191_n186: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t191_n188;
  t191_n187: return 0.07799927890300751f;
  t191_n188: return -0.15191099047660828f;
  t191_n189: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n193;
  t191_n190: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t191_n192;
  t191_n191: return 0.12747874855995178f;
  t191_n192: return 0.06448664516210556f;
  t191_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t191_n195;
  t191_n194: return 0.10095318406820297f;
  t191_n195: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t191_n197;
  t191_n196: return 0.1262647956609726f;
  t191_n197: return 0.10274937003850937f;
  t191_n198: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t191_n200;
  t191_n199: return -0.03739601746201515f;
  t191_n200: return -0.19775372743606567f;
  t191_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t191_n237;
  t191_n202: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t191_n222;
  t191_n203: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n211;
  t191_n204: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t191_n206;
  t191_n205: return 0.013070895336568356f;
  t191_n206: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t191_n210;
  t191_n207: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t191_n209;
  t191_n208: return 0.10744226723909378f;
  t191_n209: return 0.0478372685611248f;
  t191_n210: return -1.3042317628860474f;
  t191_n211: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t191_n219;
  t191_n212: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t191_n218;
  t191_n213: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t191_n217;
  t191_n214: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n216;
  t191_n215: return 0.08982595056295395f;
  t191_n216: return 0.04053816571831703f;
  t191_n217: return 0.029036905616521835f;
  t191_n218: return 0.03832484409213066f;
  t191_n219: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t191_n221;
  t191_n220: return 0.05669360235333443f;
  t191_n221: return 0.026679454371333122f;
  t191_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t191_n224;
  t191_n223: return -0.0033540658187121153f;
  t191_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n234;
  t191_n225: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t191_n227;
  t191_n226: return 0.08456474542617798f;
  t191_n227: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t191_n231;
  t191_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t191_n230;
  t191_n229: return 0.6775498986244202f;
  t191_n230: return 0.07983196526765823f;
  t191_n231: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t191_n233;
  t191_n232: return -0.17591996490955353f;
  t191_n233: return 0.12831269204616547f;
  t191_n234: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t191_n236;
  t191_n235: return 0.01603144034743309f;
  t191_n236: return 0.05436353012919426f;
  t191_n237: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t191_n239;
  t191_n238: return 0.03816407918930054f;
  t191_n239: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t191_n241;
  t191_n240: return 0.10568984597921371f;
  t191_n241: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t191_n243;
  t191_n242: return 0.050334036350250244f;
  t191_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t191_n245;
  t191_n244: return -0.10907211154699326f;
  t191_n245: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t191_n247;
  t191_n246: return 0.09463946521282196f;
  t191_n247: return -0.042006660252809525f;
  t191_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t191_n250;
  t191_n249: return -0.007834178395569324f;
  t191_n250: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t191_n254;
  t191_n251: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t191_n253;
  t191_n252: return -0.20064540207386017f;
  t191_n253: return -0.9632329940795898f;
  t191_n254: return 0.018861528486013412f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree192(const Example& E) {
  t192_n0: if (E.getNumReferences() >= 3306797056 /*2459.5*/) goto t192_n248;
  t192_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t192_n247;
  t192_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t192_n4;
  t192_n3: return -0.005058130715042353f;
  t192_n4: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t192_n94;
  t192_n5: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t192_n93;
  t192_n6: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t192_n80;
  t192_n7: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t192_n33;
  t192_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t192_n20;
  t192_n9: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t192_n13;
  t192_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t192_n12;
  t192_n11: return -0.00613399175927043f;
  t192_n12: return 0.03566127270460129f;
  t192_n13: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t192_n15;
  t192_n14: return -0.06037995219230652f;
  t192_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t192_n17;
  t192_n16: return 0.03376639261841774f;
  t192_n17: if (E.getNumReferences() >= 3267100672 /*94.0*/) goto t192_n19;
  t192_n18: return -0.0016804623883217573f;
  t192_n19: return -0.2800658941268921f;
  t192_n20: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n24;
  t192_n21: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t192_n23;
  t192_n22: return -0.12691952288150787f;
  t192_n23: return 0.004207911901175976f;
  t192_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t192_n26;
  t192_n25: return 0.009061528369784355f;
  t192_n26: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t192_n32;
  t192_n27: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t192_n29;
  t192_n28: return -0.057658858597278595f;
  t192_n29: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t192_n31;
  t192_n30: return 0.11620324105024338f;
  t192_n31: return -0.41931089758872986f;
  t192_n32: return -0.07376749813556671f;
  t192_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t192_n43;
  t192_n34: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t192_n36;
  t192_n35: return -0.009450907818973064f;
  t192_n36: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t192_n38;
  t192_n37: return 0.02606494538486004f;
  t192_n38: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t192_n42;
  t192_n39: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t192_n41;
  t192_n40: return 0.11945576965808868f;
  t192_n41: return 0.14726658165454865f;
  t192_n42: return 0.12974846363067627f;
  t192_n43: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t192_n45;
  t192_n44: return 0.028728563338518143f;
  t192_n45: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t192_n49;
  t192_n46: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n48;
  t192_n47: return 0.03649602830410004f;
  t192_n48: return -0.1056237742304802f;
  t192_n49: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t192_n75;
  t192_n50: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t192_n62;
  t192_n51: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t192_n53;
  t192_n52: return 0.030515681952238083f;
  t192_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t192_n59;
  t192_n54: if (E.getNumReferences() >= 3241148416 /*11.0*/) goto t192_n58;
  t192_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n57;
  t192_n56: return 0.09298670291900635f;
  t192_n57: return -0.04184556007385254f;
  t192_n58: return 0.12801535427570343f;
  t192_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t192_n61;
  t192_n60: return -0.7331138849258423f;
  t192_n61: return 0.12329622358083725f;
  t192_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t192_n72;
  t192_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n65;
  t192_n64: return -0.003094401676207781f;
  t192_n65: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t192_n71;
  t192_n66: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t192_n70;
  t192_n67: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t192_n69;
  t192_n68: return 0.11422167718410492f;
  t192_n69: return -0.05098200589418411f;
  t192_n70: return 0.11599211394786835f;
  t192_n71: return 0.10658109933137894f;
  t192_n72: if (E.getNumReferences() >= 3251634176 /*26.0*/) goto t192_n74;
  t192_n73: return 0.11293022334575653f;
  t192_n74: return 0.05023809149861336f;
  t192_n75: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t192_n77;
  t192_n76: return -0.08128846436738968f;
  t192_n77: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t192_n79;
  t192_n78: return 0.12907543778419495f;
  t192_n79: return -0.00042185778147540987f;
  t192_n80: if (E.getNumReferences() >= 3281272832 /*296.5*/) goto t192_n82;
  t192_n81: return 0.001643267460167408f;
  t192_n82: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t192_n90;
  t192_n83: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t192_n87;
  t192_n84: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t192_n86;
  t192_n85: return -0.22044648230075836f;
  t192_n86: return 0.11736618727445602f;
  t192_n87: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t192_n89;
  t192_n88: return 0.11813759058713913f;
  t192_n89: return 0.11328981071710587f;
  t192_n90: if (E.getNumReferences() >= 3281502208 /*303.5*/) goto t192_n92;
  t192_n91: return 0.16327694058418274f;
  t192_n92: return 0.016557427123188972f;
  t192_n93: return 0.008196642622351646f;
  t192_n94: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t192_n152;
  t192_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t192_n97;
  t192_n96: return -0.004184075631201267f;
  t192_n97: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t192_n129;
  t192_n98: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t192_n122;
  t192_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t192_n101;
  t192_n100: return 0.025623047724366188f;
  t192_n101: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t192_n103;
  t192_n102: return 0.009853770025074482f;
  t192_n103: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t192_n121;
  t192_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t192_n112;
  t192_n105: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t192_n111;
  t192_n106: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t192_n108;
  t192_n107: return 0.05036367475986481f;
  t192_n108: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t192_n110;
  t192_n109: return 0.11367261409759521f;
  t192_n110: return -0.1193108856678009f;
  t192_n111: return 0.04109983891248703f;
  t192_n112: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t192_n116;
  t192_n113: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t192_n115;
  t192_n114: return 0.08156633377075195f;
  t192_n115: return 0.01124223880469799f;
  t192_n116: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t192_n118;
  t192_n117: return 0.08242727071046829f;
  t192_n118: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t192_n120;
  t192_n119: return 0.11813835054636002f;
  t192_n120: return -0.09957332164049149f;
  t192_n121: return -0.1882905662059784f;
  t192_n122: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t192_n124;
  t192_n123: return -0.060169391334056854f;
  t192_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t192_n126;
  t192_n125: return 0.08576332032680511f;
  t192_n126: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n128;
  t192_n127: return 0.1754177063703537f;
  t192_n128: return -0.10819359123706818f;
  t192_n129: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t192_n151;
  t192_n130: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t192_n132;
  t192_n131: return -0.011524293571710587f;
  t192_n132: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t192_n150;
  t192_n133: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t192_n139;
  t192_n134: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t192_n136;
  t192_n135: return -0.41252630949020386f;
  t192_n136: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t192_n138;
  t192_n137: return 0.13301971554756165f;
  t192_n138: return -0.14530865848064423f;
  t192_n139: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t192_n149;
  t192_n140: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t192_n144;
  t192_n141: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t192_n143;
  t192_n142: return 0.08467915654182434f;
  t192_n143: return -1.2583636045455933f;
  t192_n144: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t192_n148;
  t192_n145: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t192_n147;
  t192_n146: return 0.11409997195005417f;
  t192_n147: return 0.12720003724098206f;
  t192_n148: return 0.0740944892168045f;
  t192_n149: return 0.04990680515766144f;
  t192_n150: return -0.04610450565814972f;
  t192_n151: return -0.07510194927453995f;
  t192_n152: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t192_n168;
  t192_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t192_n161;
  t192_n154: if (E.getNumReferences() >= 3274932224 /*179.5*/) goto t192_n160;
  t192_n155: if (E.getNumReferences() >= 3274473472 /*172.5*/) goto t192_n157;
  t192_n156: return -0.043129242956638336f;
  t192_n157: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t192_n159;
  t192_n158: return -0.15889328718185425f;
  t192_n159: return 0.11775092780590057f;
  t192_n160: return -0.11866634339094162f;
  t192_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t192_n165;
  t192_n162: if (E.getNumReferences() >= 3301953536 /*1662.5*/) goto t192_n164;
  t192_n163: return -0.0035083331167697906f;
  t192_n164: return -0.1678009182214737f;
  t192_n165: if (E.getNumReferences() >= 3305947136 /*2252.0*/) goto t192_n167;
  t192_n166: return 0.02170334756374359f;
  t192_n167: return 0.14553318917751312f;
  t192_n168: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t192_n246;
  t192_n169: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t192_n171;
  t192_n170: return 0.027214914560317993f;
  t192_n171: if (E.getNumReferences() >= 3275194368 /*183.5*/) goto t192_n207;
  t192_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t192_n180;
  t192_n173: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t192_n179;
  t192_n174: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t192_n176;
  t192_n175: return 0.044026292860507965f;
  t192_n176: if (E.getNumReferences() >= 3269656576 /*113.5*/) goto t192_n178;
  t192_n177: return -0.22968271374702454f;
  t192_n178: return 0.13097618520259857f;
  t192_n179: return 0.05822465941309929f;
  t192_n180: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t192_n206;
  t192_n181: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t192_n203;
  t192_n182: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t192_n186;
  t192_n183: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t192_n185;
  t192_n184: return 0.1205490455031395f;
  t192_n185: return 0.025382783263921738f;
  t192_n186: if (E.getNumReferences() >= 3274604544 /*174.5*/) goto t192_n200;
  t192_n187: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t192_n199;
  t192_n188: if (E.getNumReferences() >= 3272376320 /*140.5*/) goto t192_n196;
  t192_n189: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n191;
  t192_n190: return 0.055356092751026154f;
  t192_n191: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t192_n195;
  t192_n192: if (E.getNumReferences() >= 3271294976 /*126.0*/) goto t192_n194;
  t192_n193: return 0.15158231556415558f;
  t192_n194: return 0.130523219704628f;
  t192_n195: return -0.20072995126247406f;
  t192_n196: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t192_n198;
  t192_n197: return -0.12597578763961792f;
  t192_n198: return 0.12087619304656982f;
  t192_n199: return 0.014120208099484444f;
  t192_n200: if (E.getNumReferences() >= 3274768384 /*177.0*/) goto t192_n202;
  t192_n201: return 0.12700727581977844f;
  t192_n202: return 0.2203044295310974f;
  t192_n203: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t192_n205;
  t192_n204: return -0.24623745679855347f;
  t192_n205: return 0.13763149082660675f;
  t192_n206: return 0.103324756026268f;
  t192_n207: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t192_n245;
  t192_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t192_n236;
  t192_n209: if (E.getNumReferences() >= 3288203264 /*508.0*/) goto t192_n217;
  t192_n210: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t192_n212;
  t192_n211: return -0.05964173376560211f;
  t192_n212: if (E.getNumReferences() >= 3275390976 /*186.5*/) goto t192_n216;
  t192_n213: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t192_n215;
  t192_n214: return 0.09715889394283295f;
  t192_n215: return -0.1021253913640976f;
  t192_n216: return 0.05727195367217064f;
  t192_n217: if (E.getNumReferences() >= 3288522752 /*523.5*/) goto t192_n219;
  t192_n218: return 0.13620926439762115f;
  t192_n219: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t192_n229;
  t192_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t192_n222;
  t192_n221: return -0.07127343118190765f;
  t192_n222: if (E.getNumReferences() >= 3301138432 /*1563.0*/) goto t192_n228;
  t192_n223: if (E.getNumReferences() >= 3290349568 /*635.0*/) goto t192_n225;
  t192_n224: return 0.10288025438785553f;
  t192_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n227;
  t192_n226: return 0.21584507822990417f;
  t192_n227: return 0.10873010754585266f;
  t192_n228: return -0.45337194204330444f;
  t192_n229: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t192_n231;
  t192_n230: return 0.020763220265507698f;
  t192_n231: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n233;
  t192_n232: return 0.043851085007190704f;
  t192_n233: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t192_n235;
  t192_n234: return 0.12003874778747559f;
  t192_n235: return 0.04801009222865105f;
  t192_n236: if (E.getNumReferences() >= 3276570624 /*204.5*/) goto t192_n238;
  t192_n237: return 0.10408541560173035f;
  t192_n238: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t192_n244;
  t192_n239: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t192_n243;
  t192_n240: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t192_n242;
  t192_n241: return 0.11372073739767075f;
  t192_n242: return -0.10468878597021103f;
  t192_n243: return 0.06941788643598557f;
  t192_n244: return -0.04156972095370293f;
  t192_n245: return 0.0008257080335170031f;
  t192_n246: return 0.006880785804241896f;
  t192_n247: return -0.0011985574383288622f;
  t192_n248: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t192_n250;
  t192_n249: return 0.01133088767528534f;
  t192_n250: if (E.getNumReferences() >= 3306835968 /*2469.0*/) goto t192_n254;
  t192_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t192_n253;
  t192_n252: return 0.061664432287216187f;
  t192_n253: return 0.11273857206106186f;
  t192_n254: return 0.0015382132260128856f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree193(const Example& E) {
  t193_n0: if (E.getNumReferences() >= 3305437184 /*2127.5*/) goto t193_n94;
  t193_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t193_n93;
  t193_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t193_n4;
  t193_n3: return -0.004858333617448807f;
  t193_n4: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t193_n16;
  t193_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t193_n15;
  t193_n6: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t193_n14;
  t193_n7: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t193_n13;
  t193_n8: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t193_n12;
  t193_n9: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t193_n11;
  t193_n10: return 0.03165510296821594f;
  t193_n11: return 0.003599967574700713f;
  t193_n12: return 0.019517920911312103f;
  t193_n13: return 0.001957952743396163f;
  t193_n14: return 0.0052179801277816296f;
  t193_n15: return -0.0012109772069379687f;
  t193_n16: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t193_n90;
  t193_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t193_n85;
  t193_n18: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t193_n70;
  t193_n19: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t193_n69;
  t193_n20: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t193_n50;
  t193_n21: if (E.getNumReferences() >= 3286056960 /*442.5*/) goto t193_n23;
  t193_n22: return 0.018452517688274384f;
  t193_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t193_n37;
  t193_n24: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t193_n36;
  t193_n25: if (E.getNumReferences() >= 3288621056 /*529.5*/) goto t193_n35;
  t193_n26: if (E.getNumReferences() >= 3288506368 /*522.5*/) goto t193_n34;
  t193_n27: if (E.getNumReferences() >= 3286269952 /*449.0*/) goto t193_n29;
  t193_n28: return 0.13702835142612457f;
  t193_n29: if (E.getNumReferences() >= 3288088576 /*504.5*/) goto t193_n31;
  t193_n30: return 0.031929899007081985f;
  t193_n31: if (E.getNumReferences() >= 3288285184 /*510.5*/) goto t193_n33;
  t193_n32: return 0.10875625908374786f;
  t193_n33: return -0.1890048235654831f;
  t193_n34: return 0.11262300610542297f;
  t193_n35: return 0.051663901656866074f;
  t193_n36: return -0.011222929693758488f;
  t193_n37: if (E.getNumReferences() >= 3289546752 /*586.0*/) goto t193_n39;
  t193_n38: return -0.13718825578689575f;
  t193_n39: if (E.getNumReferences() >= 3293749248 /*842.5*/) goto t193_n47;
  t193_n40: if (E.getNumReferences() >= 3292299264 /*754.0*/) goto t193_n46;
  t193_n41: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t193_n45;
  t193_n42: if (E.getNumReferences() >= 3290275840 /*630.5*/) goto t193_n44;
  t193_n43: return 0.1652265340089798f;
  t193_n44: return 0.09564634412527084f;
  t193_n45: return -0.28643354773521423f;
  t193_n46: return 0.13100850582122803f;
  t193_n47: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t193_n49;
  t193_n48: return -0.2576806843280792f;
  t193_n49: return 0.09891107678413391f;
  t193_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t193_n54;
  t193_n51: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t193_n53;
  t193_n52: return 0.20588472485542297f;
  t193_n53: return 0.06905611604452133f;
  t193_n54: if (E.getNumReferences() >= 3289186304 /*564.0*/) goto t193_n64;
  t193_n55: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t193_n63;
  t193_n56: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t193_n62;
  t193_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t193_n59;
  t193_n58: return 0.07827695459127426f;
  t193_n59: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n61;
  t193_n60: return 0.10442449897527695f;
  t193_n61: return 0.08665504306554794f;
  t193_n62: return 0.13092373311519623f;
  t193_n63: return 0.03388834744691849f;
  t193_n64: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t193_n68;
  t193_n65: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t193_n67;
  t193_n66: return 0.13375291228294373f;
  t193_n67: return 0.13017529249191284f;
  t193_n68: return 0.04212208837270737f;
  t193_n69: return 0.02533922903239727f;
  t193_n70: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t193_n84;
  t193_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t193_n79;
  t193_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t193_n78;
  t193_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t193_n75;
  t193_n74: return -0.25310996174812317f;
  t193_n75: if (E.getNumReferences() >= 3267952640 /*100.5*/) goto t193_n77;
  t193_n76: return 0.03888333588838577f;
  t193_n77: return 0.10205201059579849f;
  t193_n78: return 0.1124652847647667f;
  t193_n79: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t193_n81;
  t193_n80: return 0.11262576282024384f;
  t193_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t193_n83;
  t193_n82: return -1.4089674949645996f;
  t193_n83: return 0.11370135843753815f;
  t193_n84: return -0.01406221091747284f;
  t193_n85: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t193_n89;
  t193_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t193_n88;
  t193_n87: return 0.024397965520620346f;
  t193_n88: return 0.11638416349887848f;
  t193_n89: return 0.04981774091720581f;
  t193_n90: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t193_n92;
  t193_n91: return -0.12322156131267548f;
  t193_n92: return 0.0036041205748915672f;
  t193_n93: return -0.0010796734131872654f;
  t193_n94: if (E.getNumReferences() >= 3305449472 /*2130.5*/) goto t193_n100;
  t193_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t193_n99;
  t193_n96: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t193_n98;
  t193_n97: return -0.06177400425076485f;
  t193_n98: return 0.10336799174547195f;
  t193_n99: return 0.18173529207706451f;
  t193_n100: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t193_n254;
  t193_n101: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t193_n103;
  t193_n102: return 0.008004298433661461f;
  t193_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t193_n245;
  t193_n104: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t193_n180;
  t193_n105: if (E.getNumReferences() >= 3344355328 /*54992.0*/) goto t193_n167;
  t193_n106: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t193_n164;
  t193_n107: if (E.getNumReferences() >= 3315905536 /*5270.5*/) goto t193_n109;
  t193_n108: return 0.008593929931521416f;
  t193_n109: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t193_n143;
  t193_n110: if (E.getNumReferences() >= 3338025472 /*31517.0*/) goto t193_n142;
  t193_n111: if (E.getNumReferences() >= 3333053952 /*21807.0*/) goto t193_n135;
  t193_n112: if (E.getNumReferences() >= 3323087872 /*9363.0*/) goto t193_n132;
  t193_n113: if (E.getNumReferences() >= 3319356416 /*6955.5*/) goto t193_n117;
  t193_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t193_n116;
  t193_n115: return 0.007101776078343391f;
  t193_n116: return 0.10593409091234207f;
  t193_n117: if (E.getNumReferences() >= 3319490560 /*7021.0*/) goto t193_n119;
  t193_n118: return 0.11515478789806366f;
  t193_n119: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t193_n129;
  t193_n120: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n122;
  t193_n121: return 0.09175771474838257f;
  t193_n122: if (E.getNumReferences() >= 3322365952 /*8658.0*/) goto t193_n128;
  t193_n123: if (E.getNumReferences() >= 3321624576 /*8063.0*/) goto t193_n127;
  t193_n124: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t193_n126;
  t193_n125: return 0.26574188470840454f;
  t193_n126: return 0.14569279551506042f;
  t193_n127: return -0.2929460108280182f;
  t193_n128: return 0.1066553145647049f;
  t193_n129: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t193_n131;
  t193_n130: return 0.0036769118160009384f;
  t193_n131: return 0.113920196890831f;
  t193_n132: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t193_n134;
  t193_n133: return 0.008368638344109058f;
  t193_n134: return 0.1072646751999855f;
  t193_n135: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n141;
  t193_n136: if (E.getNumReferences() >= 3333945600 /*23548.5*/) goto t193_n140;
  t193_n137: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t193_n139;
  t193_n138: return 0.13865351676940918f;
  t193_n139: return 0.09630802273750305f;
  t193_n140: return 0.1598517745733261f;
  t193_n141: return 0.0219232439994812f;
  t193_n142: return -0.021430589258670807f;
  t193_n143: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t193_n161;
  t193_n144: if (E.getNumReferences() >= 3316411392 /*5517.5*/) goto t193_n158;
  t193_n145: if (E.getNumReferences() >= 3316164608 /*5397.0*/) goto t193_n147;
  t193_n146: return 0.0649038553237915f;
  t193_n147: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t193_n151;
  t193_n148: if (E.getNumReferences() >= 3316251648 /*5439.5*/) goto t193_n150;
  t193_n149: return -0.35428622364997864f;
  t193_n150: return 0.17470704019069672f;
  t193_n151: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t193_n155;
  t193_n152: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n154;
  t193_n153: return 0.10384680330753326f;
  t193_n154: return 0.0044473265297710896f;
  t193_n155: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t193_n157;
  t193_n156: return -0.05688447505235672f;
  t193_n157: return 0.36475348472595215f;
  t193_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t193_n160;
  t193_n159: return 0.017685119062662125f;
  t193_n160: return 0.08197662979364395f;
  t193_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n163;
  t193_n162: return 0.06469163298606873f;
  t193_n163: return 0.024469753727316856f;
  t193_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n166;
  t193_n165: return 0.0941537544131279f;
  t193_n166: return 0.07090941816568375f;
  t193_n167: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t193_n179;
  t193_n168: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t193_n178;
  t193_n169: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n171;
  t193_n170: return 0.32559195160865784f;
  t193_n171: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t193_n173;
  t193_n172: return 0.2889363765716553f;
  t193_n173: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t193_n177;
  t193_n174: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t193_n176;
  t193_n175: return 0.08310974389314651f;
  t193_n176: return 0.17251452803611755f;
  t193_n177: return 0.10494682192802429f;
  t193_n178: return 0.12919363379478455f;
  t193_n179: return -0.0019593392498791218f;
  t193_n180: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t193_n204;
  t193_n181: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t193_n193;
  t193_n182: if (E.getNumReferences() >= 3345444992 /*59248.5*/) goto t193_n188;
  t193_n183: if (E.getNumReferences() >= 3344974336 /*57410.0*/) goto t193_n185;
  t193_n184: return -0.09529290348291397f;
  t193_n185: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t193_n187;
  t193_n186: return 0.1309811770915985f;
  t193_n187: return 0.1297673135995865f;
  t193_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t193_n192;
  t193_n189: if (E.getNumReferences() >= 3346296960 /*62576.5*/) goto t193_n191;
  t193_n190: return -0.11187467724084854f;
  t193_n191: return -0.388019323348999f;
  t193_n192: return -0.09357279539108276f;
  t193_n193: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t193_n199;
  t193_n194: if (E.getNumReferences() >= 3346400000 /*62979.0*/) goto t193_n196;
  t193_n195: return 0.054909732192754745f;
  t193_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t193_n198;
  t193_n197: return -0.5471099019050598f;
  t193_n198: return 0.06677157431840897f;
  t193_n199: if (E.getNumReferences() >= 3346792960 /*64514.0*/) goto t193_n203;
  t193_n200: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n202;
  t193_n201: return 0.11998046934604645f;
  t193_n202: return 0.13407769799232483f;
  t193_n203: return 0.052608389407396317f;
  t193_n204: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t193_n232;
  t193_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t193_n229;
  t193_n206: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t193_n210;
  t193_n207: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t193_n209;
  t193_n208: return 0.006277697626501322f;
  t193_n209: return 0.12997406721115112f;
  t193_n210: if (E.getNumReferences() >= 3350280192 /*90736.0*/) goto t193_n224;
  t193_n211: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t193_n213;
  t193_n212: return 0.0419568195939064f;
  t193_n213: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t193_n219;
  t193_n214: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t193_n218;
  t193_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n217;
  t193_n216: return 0.16471201181411743f;
  t193_n217: return 0.043301377445459366f;
  t193_n218: return 0.04496099427342415f;
  t193_n219: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t193_n223;
  t193_n220: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t193_n222;
  t193_n221: return 0.1485464721918106f;
  t193_n222: return 0.03838992491364479f;
  t193_n223: return 0.09733376652002335f;
  t193_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t193_n226;
  t193_n225: return 0.01492098905146122f;
  t193_n226: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n228;
  t193_n227: return 0.11523889005184174f;
  t193_n228: return 0.035681869834661484f;
  t193_n229: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t193_n231;
  t193_n230: return 0.12678831815719604f;
  t193_n231: return -0.4385615885257721f;
  t193_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n236;
  t193_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t193_n235;
  t193_n234: return -0.397688627243042f;
  t193_n235: return -0.016423799097537994f;
  t193_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t193_n238;
  t193_n237: return -0.6179294586181641f;
  t193_n238: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t193_n240;
  t193_n239: return 0.009598036296665668f;
  t193_n240: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t193_n242;
  t193_n241: return 0.09032092243432999f;
  t193_n242: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t193_n244;
  t193_n243: return 0.10687128454446793f;
  t193_n244: return 0.11600559204816818f;
  t193_n245: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t193_n253;
  t193_n246: if (E.getNumReferences() >= 3314761728 /*4712.0*/) goto t193_n248;
  t193_n247: return -0.2232036292552948f;
  t193_n248: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t193_n250;
  t193_n249: return 0.0880771204829216f;
  t193_n250: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t193_n252;
  t193_n251: return 0.1302260309457779f;
  t193_n252: return 0.1379508227109909f;
  t193_n253: return -0.03742384910583496f;
  t193_n254: return 0.0011737266322597861f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree194(const Example& E) {
  t194_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t194_n2;
  t194_n1: return -0.00019983640231657773f;
  t194_n2: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t194_n16;
  t194_n3: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n11;
  t194_n4: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t194_n6;
  t194_n5: return -0.08208077400922775f;
  t194_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t194_n10;
  t194_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t194_n9;
  t194_n8: return -0.1651926040649414f;
  t194_n9: return 0.09269054234027863f;
  t194_n10: return -0.22825689613819122f;
  t194_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t194_n13;
  t194_n12: return 0.08598381280899048f;
  t194_n13: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n15;
  t194_n14: return 0.11682868748903275f;
  t194_n15: return 0.12008219212293625f;
  t194_n16: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t194_n18;
  t194_n17: return -0.0033836415968835354f;
  t194_n18: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t194_n254;
  t194_n19: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t194_n253;
  t194_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t194_n224;
  t194_n21: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t194_n147;
  t194_n22: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t194_n134;
  t194_n23: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t194_n111;
  t194_n24: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t194_n28;
  t194_n25: if (E.getNumReferences() >= 3342114944 /*46240.5*/) goto t194_n27;
  t194_n26: return -0.04168703034520149f;
  t194_n27: return 0.02388695627450943f;
  t194_n28: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n30;
  t194_n29: return 0.002988257445394993f;
  t194_n30: if (E.getNumReferences() >= 3357271616 /*159641.0*/) goto t194_n110;
  t194_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t194_n35;
  t194_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t194_n34;
  t194_n33: return -0.040469054132699966f;
  t194_n34: return 0.02369603142142296f;
  t194_n35: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t194_n41;
  t194_n36: if (E.getNumReferences() >= 3342384640 /*47294.0*/) goto t194_n40;
  t194_n37: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t194_n39;
  t194_n38: return 0.05883493646979332f;
  t194_n39: return -0.05454319342970848f;
  t194_n40: return -0.15411528944969177f;
  t194_n41: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t194_n59;
  t194_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t194_n52;
  t194_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t194_n45;
  t194_n44: return -0.026482069864869118f;
  t194_n45: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t194_n51;
  t194_n46: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t194_n50;
  t194_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n49;
  t194_n48: return 0.08752357959747314f;
  t194_n49: return 0.20673176646232605f;
  t194_n50: return 0.10061877965927124f;
  t194_n51: return 0.0059186615981161594f;
  t194_n52: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n54;
  t194_n53: return -0.2313915193080902f;
  t194_n54: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t194_n58;
  t194_n55: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t194_n57;
  t194_n56: return 0.1400034874677658f;
  t194_n57: return 0.12456391006708145f;
  t194_n58: return -0.1403139978647232f;
  t194_n59: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t194_n87;
  t194_n60: if (E.getNumReferences() >= 3348072384 /*73487.5*/) goto t194_n64;
  t194_n61: if (E.getNumReferences() >= 3344816512 /*56793.5*/) goto t194_n63;
  t194_n62: return 0.06583459675312042f;
  t194_n63: return -0.043955761939287186f;
  t194_n64: if (E.getNumReferences() >= 3348327104 /*75477.5*/) goto t194_n68;
  t194_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t194_n67;
  t194_n66: return -0.08392040431499481f;
  t194_n67: return 0.09558363258838654f;
  t194_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t194_n70;
  t194_n69: return 0.024777621030807495f;
  t194_n70: if (E.getNumReferences() >= 3348704768 /*78428.0*/) goto t194_n74;
  t194_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t194_n73;
  t194_n72: return -0.24804255366325378f;
  t194_n73: return 0.12178853154182434f;
  t194_n74: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t194_n76;
  t194_n75: return -0.08498827368021011f;
  t194_n76: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t194_n86;
  t194_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t194_n85;
  t194_n78: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t194_n84;
  t194_n79: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t194_n83;
  t194_n80: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t194_n82;
  t194_n81: return 0.11728794872760773f;
  t194_n82: return 0.09277079254388809f;
  t194_n83: return -0.20901842415332794f;
  t194_n84: return 0.10076658427715302f;
  t194_n85: return -0.855132520198822f;
  t194_n86: return 0.12799373269081116f;
  t194_n87: if (E.getNumReferences() >= 3346307456 /*62617.5*/) goto t194_n101;
  t194_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t194_n90;
  t194_n89: return -0.2526993453502655f;
  t194_n90: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n100;
  t194_n91: if (E.getNumReferences() >= 3345907328 /*61054.5*/) goto t194_n93;
  t194_n92: return -0.13284660875797272f;
  t194_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t194_n95;
  t194_n94: return 0.17153699696063995f;
  t194_n95: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t194_n99;
  t194_n96: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t194_n98;
  t194_n97: return 0.18850000202655792f;
  t194_n98: return 0.1693594753742218f;
  t194_n99: return 0.07538644969463348f;
  t194_n100: return 0.05928987264633179f;
  t194_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t194_n103;
  t194_n102: return 0.014430047944188118f;
  t194_n103: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t194_n109;
  t194_n104: if (E.getNumReferences() >= 3353034176 /*112251.5*/) goto t194_n108;
  t194_n105: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t194_n107;
  t194_n106: return 0.08924288302659988f;
  t194_n107: return 0.012296284548938274f;
  t194_n108: return -0.4121106266975403f;
  t194_n109: return 0.09189702570438385f;
  t194_n110: return -0.24673616886138916f;
  t194_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t194_n121;
  t194_n112: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t194_n114;
  t194_n113: return 0.03835234045982361f;
  t194_n114: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n118;
  t194_n115: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t194_n117;
  t194_n116: return -0.17351655662059784f;
  t194_n117: return 0.12438300251960754f;
  t194_n118: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t194_n120;
  t194_n119: return 0.04568135738372803f;
  t194_n120: return 0.10678915679454803f;
  t194_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n125;
  t194_n122: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t194_n124;
  t194_n123: return 0.04456792771816254f;
  t194_n124: return 0.08565351366996765f;
  t194_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n131;
  t194_n126: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t194_n130;
  t194_n127: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t194_n129;
  t194_n128: return 0.11099665611982346f;
  t194_n129: return 0.10573211312294006f;
  t194_n130: return -0.11822674423456192f;
  t194_n131: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t194_n133;
  t194_n132: return 0.07853665947914124f;
  t194_n133: return -0.21691080927848816f;
  t194_n134: if (E.getNumReferences() >= 3344576000 /*55854.0*/) goto t194_n146;
  t194_n135: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t194_n137;
  t194_n136: return 0.015231349505484104f;
  t194_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t194_n139;
  t194_n138: return 0.08137481659650803f;
  t194_n139: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n141;
  t194_n140: return 0.3541710078716278f;
  t194_n141: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t194_n143;
  t194_n142: return 0.11716797947883606f;
  t194_n143: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t194_n145;
  t194_n144: return 0.16105054318904877f;
  t194_n145: return 0.0917062908411026f;
  t194_n146: return -0.030056888237595558f;
  t194_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t194_n191;
  t194_n148: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t194_n184;
  t194_n149: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t194_n155;
  t194_n150: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t194_n152;
  t194_n151: return -0.15346308052539825f;
  t194_n152: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t194_n154;
  t194_n153: return 0.04351089522242546f;
  t194_n154: return 0.11889557540416718f;
  t194_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n181;
  t194_n156: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t194_n176;
  t194_n157: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t194_n175;
  t194_n158: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t194_n164;
  t194_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t194_n161;
  t194_n160: return -0.030195197090506554f;
  t194_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t194_n163;
  t194_n162: return 0.04962644726037979f;
  t194_n163: return 0.09954150766134262f;
  t194_n164: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t194_n168;
  t194_n165: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t194_n167;
  t194_n166: return 0.032173383980989456f;
  t194_n167: return 0.07502651959657669f;
  t194_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t194_n170;
  t194_n169: return 0.030098095536231995f;
  t194_n170: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t194_n174;
  t194_n171: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t194_n173;
  t194_n172: return 0.1060318574309349f;
  t194_n173: return -0.047908537089824677f;
  t194_n174: return 0.022969216108322144f;
  t194_n175: return 0.017065171152353287f;
  t194_n176: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t194_n180;
  t194_n177: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n179;
  t194_n178: return -0.6762242317199707f;
  t194_n179: return -0.03980272635817528f;
  t194_n180: return 0.06229858100414276f;
  t194_n181: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t194_n183;
  t194_n182: return -0.23938989639282227f;
  t194_n183: return 0.04925679415464401f;
  t194_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t194_n186;
  t194_n185: return -0.0031563127413392067f;
  t194_n186: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t194_n188;
  t194_n187: return 1.0757086277008057f;
  t194_n188: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t194_n190;
  t194_n189: return 0.026735633611679077f;
  t194_n190: return 0.062900610268116f;
  t194_n191: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t194_n219;
  t194_n192: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t194_n218;
  t194_n193: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t194_n195;
  t194_n194: return 0.06948653608560562f;
  t194_n195: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t194_n197;
  t194_n196: return -0.10629314184188843f;
  t194_n197: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t194_n199;
  t194_n198: return -0.11296004801988602f;
  t194_n199: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n215;
  t194_n200: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t194_n204;
  t194_n201: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t194_n203;
  t194_n202: return 0.10805914551019669f;
  t194_n203: return -0.35275357961654663f;
  t194_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t194_n208;
  t194_n205: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t194_n207;
  t194_n206: return 0.013573933392763138f;
  t194_n207: return 0.10425090789794922f;
  t194_n208: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t194_n212;
  t194_n209: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t194_n211;
  t194_n210: return -0.1662767082452774f;
  t194_n211: return 0.10465323179960251f;
  t194_n212: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t194_n214;
  t194_n213: return 0.09005101025104523f;
  t194_n214: return 0.06335301697254181f;
  t194_n215: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t194_n217;
  t194_n216: return 0.05063067376613617f;
  t194_n217: return -0.051741670817136765f;
  t194_n218: return -0.06455900520086288f;
  t194_n219: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t194_n221;
  t194_n220: return 0.08961034566164017f;
  t194_n221: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t194_n223;
  t194_n222: return 0.0987483561038971f;
  t194_n223: return 0.0890997126698494f;
  t194_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t194_n226;
  t194_n225: return -0.03466985374689102f;
  t194_n226: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t194_n232;
  t194_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t194_n229;
  t194_n228: return 0.021840322762727737f;
  t194_n229: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t194_n231;
  t194_n230: return -0.1121353805065155f;
  t194_n231: return 0.11427861452102661f;
  t194_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n248;
  t194_n233: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t194_n247;
  t194_n234: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t194_n246;
  t194_n235: if (E.getNumReferences() >= 3344186496 /*54332.5*/) goto t194_n237;
  t194_n236: return 0.17520132660865784f;
  t194_n237: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t194_n245;
  t194_n238: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t194_n242;
  t194_n239: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t194_n241;
  t194_n240: return 0.10776357352733612f;
  t194_n241: return -0.11702004820108414f;
  t194_n242: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n244;
  t194_n243: return -0.22364374995231628f;
  t194_n244: return 0.13011938333511353f;
  t194_n245: return -0.2587938904762268f;
  t194_n246: return 0.003173365956172347f;
  t194_n247: return 0.1246781274676323f;
  t194_n248: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t194_n252;
  t194_n249: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n251;
  t194_n250: return 0.11432109773159027f;
  t194_n251: return 0.009755976498126984f;
  t194_n252: return -0.12152841687202454f;
  t194_n253: return -0.0025130624417215586f;
  t194_n254: return -0.024799969047307968f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree195(const Example& E) {
  t195_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t195_n134;
  t195_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t195_n3;
  t195_n2: return -0.0006172988214530051f;
  t195_n3: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t195_n133;
  t195_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t195_n54;
  t195_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t195_n13;
  t195_n6: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t195_n10;
  t195_n7: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n9;
  t195_n8: return 0.020500464364886284f;
  t195_n9: return 0.08450008928775787f;
  t195_n10: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t195_n12;
  t195_n11: return -0.056454602628946304f;
  t195_n12: return -0.24142427742481232f;
  t195_n13: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t195_n43;
  t195_n14: if (E.getNumReferences() >= 3342077440 /*46094.0*/) goto t195_n30;
  t195_n15: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t195_n17;
  t195_n16: return -0.03996129333972931f;
  t195_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t195_n19;
  t195_n18: return -0.10816345363855362f;
  t195_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t195_n29;
  t195_n20: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t195_n24;
  t195_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t195_n23;
  t195_n22: return -0.14260683953762054f;
  t195_n23: return 0.13651694357395172f;
  t195_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t195_n28;
  t195_n25: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t195_n27;
  t195_n26: return 0.03510245308279991f;
  t195_n27: return 0.10562148690223694f;
  t195_n28: return 0.12317927181720734f;
  t195_n29: return 0.09791732579469681f;
  t195_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t195_n32;
  t195_n31: return -0.19367320835590363f;
  t195_n32: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t195_n34;
  t195_n33: return 0.048885297030210495f;
  t195_n34: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t195_n42;
  t195_n35: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t195_n37;
  t195_n36: return -0.0731210708618164f;
  t195_n37: if (E.getNumReferences() >= 3342301952 /*46971.0*/) goto t195_n41;
  t195_n38: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t195_n40;
  t195_n39: return 0.1583280861377716f;
  t195_n40: return 0.05351124331355095f;
  t195_n41: return -0.03362833708524704f;
  t195_n42: return 0.10337208956480026f;
  t195_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n47;
  t195_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t195_n46;
  t195_n45: return -0.161595419049263f;
  t195_n46: return 0.13473336398601532f;
  t195_n47: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t195_n53;
  t195_n48: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t195_n50;
  t195_n49: return 0.23831889033317566f;
  t195_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n52;
  t195_n51: return 0.8290144801139832f;
  t195_n52: return 0.10079795867204666f;
  t195_n53: return 0.0917130559682846f;
  t195_n54: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t195_n72;
  t195_n55: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t195_n71;
  t195_n56: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t195_n70;
  t195_n57: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n59;
  t195_n58: return 0.009998387657105923f;
  t195_n59: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t195_n61;
  t195_n60: return 0.11208921670913696f;
  t195_n61: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t195_n67;
  t195_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t195_n66;
  t195_n63: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t195_n65;
  t195_n64: return -0.10070250183343887f;
  t195_n65: return 0.07602298259735107f;
  t195_n66: return 0.015627121552824974f;
  t195_n67: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t195_n69;
  t195_n68: return 0.0744517520070076f;
  t195_n69: return 0.08939715474843979f;
  t195_n70: return 0.02424299716949463f;
  t195_n71: return 0.031518738716840744f;
  t195_n72: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t195_n120;
  t195_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t195_n77;
  t195_n74: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n76;
  t195_n75: return -0.07079961150884628f;
  t195_n76: return 0.06084238737821579f;
  t195_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t195_n95;
  t195_n78: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n80;
  t195_n79: return 0.040485452860593796f;
  t195_n80: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t195_n94;
  t195_n81: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t195_n89;
  t195_n82: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t195_n88;
  t195_n83: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n85;
  t195_n84: return 0.25069761276245117f;
  t195_n85: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t195_n87;
  t195_n86: return -0.06424444913864136f;
  t195_n87: return 0.12861306965351105f;
  t195_n88: return 0.025115950033068657f;
  t195_n89: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n93;
  t195_n90: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t195_n92;
  t195_n91: return 0.13288313150405884f;
  t195_n92: return 0.12030206620693207f;
  t195_n93: return -0.13862648606300354f;
  t195_n94: return 0.12388943880796432f;
  t195_n95: if (E.getNumReferences() >= 3342583296 /*48070.0*/) goto t195_n119;
  t195_n96: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n112;
  t195_n97: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n105;
  t195_n98: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t195_n100;
  t195_n99: return 0.13669916987419128f;
  t195_n100: if (E.getNumReferences() >= 3342374144 /*47253.0*/) goto t195_n104;
  t195_n101: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t195_n103;
  t195_n102: return 0.38407155871391296f;
  t195_n103: return 0.13899695873260498f;
  t195_n104: return 0.11588781327009201f;
  t195_n105: if (E.getNumReferences() >= 3342374144 /*47253.0*/) goto t195_n109;
  t195_n106: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t195_n108;
  t195_n107: return 0.11786416918039322f;
  t195_n108: return 0.06763219088315964f;
  t195_n109: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t195_n111;
  t195_n110: return 0.11162998527288437f;
  t195_n111: return 0.07196138799190521f;
  t195_n112: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t195_n118;
  t195_n113: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t195_n117;
  t195_n114: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n116;
  t195_n115: return 0.11959661543369293f;
  t195_n116: return 0.055387016385793686f;
  t195_n117: return 0.13574668765068054f;
  t195_n118: return -0.054353199899196625f;
  t195_n119: return 0.0008354012970812619f;
  t195_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t195_n122;
  t195_n121: return -0.15814252197742462f;
  t195_n122: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n132;
  t195_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n131;
  t195_n124: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t195_n126;
  t195_n125: return 0.5407537221908569f;
  t195_n126: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t195_n128;
  t195_n127: return 0.1792319118976593f;
  t195_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t195_n130;
  t195_n129: return 0.15189075469970703f;
  t195_n130: return 0.14855866134166718f;
  t195_n131: return -0.12554243206977844f;
  t195_n132: return 0.0876900851726532f;
  t195_n133: return 0.002665842417627573f;
  t195_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t195_n138;
  t195_n135: if (E.getNumReferences() >= 3317625856 /*6110.5*/) goto t195_n137;
  t195_n136: return -0.0040051620453596115f;
  t195_n137: return -0.1460363268852234f;
  t195_n138: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t195_n254;
  t195_n139: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t195_n163;
  t195_n140: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t195_n142;
  t195_n141: return 0.005329661071300507f;
  t195_n142: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t195_n154;
  t195_n143: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t195_n145;
  t195_n144: return -0.008649606257677078f;
  t195_n145: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t195_n151;
  t195_n146: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t195_n150;
  t195_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t195_n149;
  t195_n148: return -0.10416405647993088f;
  t195_n149: return 0.1613553911447525f;
  t195_n150: return -0.07741770893335342f;
  t195_n151: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t195_n153;
  t195_n152: return -0.15144631266593933f;
  t195_n153: return -0.1747686117887497f;
  t195_n154: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t195_n160;
  t195_n155: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t195_n159;
  t195_n156: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t195_n158;
  t195_n157: return -0.1085275337100029f;
  t195_n158: return -0.6876611709594727f;
  t195_n159: return 0.01360538974404335f;
  t195_n160: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t195_n162;
  t195_n161: return 0.10680165886878967f;
  t195_n162: return 0.09784070402383804f;
  t195_n163: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t195_n227;
  t195_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t195_n172;
  t195_n165: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t195_n167;
  t195_n166: return 0.04722859337925911f;
  t195_n167: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t195_n169;
  t195_n168: return 0.012369712814688683f;
  t195_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t195_n171;
  t195_n170: return 0.06883733719587326f;
  t195_n171: return 0.11277304589748383f;
  t195_n172: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t195_n226;
  t195_n173: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t195_n221;
  t195_n174: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t195_n212;
  t195_n175: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t195_n211;
  t195_n176: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t195_n204;
  t195_n177: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n179;
  t195_n178: return -0.2414136826992035f;
  t195_n179: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t195_n191;
  t195_n180: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t195_n188;
  t195_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t195_n183;
  t195_n182: return -0.04471200332045555f;
  t195_n183: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t195_n185;
  t195_n184: return -0.08303086459636688f;
  t195_n185: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t195_n187;
  t195_n186: return 0.019885176792740822f;
  t195_n187: return 0.12110215425491333f;
  t195_n188: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t195_n190;
  t195_n189: return 0.11420426517724991f;
  t195_n190: return 0.14071716368198395f;
  t195_n191: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t195_n203;
  t195_n192: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t195_n202;
  t195_n193: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t195_n197;
  t195_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t195_n196;
  t195_n195: return 0.11166975647211075f;
  t195_n196: return -0.1737750619649887f;
  t195_n197: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t195_n199;
  t195_n198: return 0.11744161695241928f;
  t195_n199: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t195_n201;
  t195_n200: return 0.10708120465278625f;
  t195_n201: return -0.7864907383918762f;
  t195_n202: return -0.09842640906572342f;
  t195_n203: return -0.21680191159248352f;
  t195_n204: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t195_n206;
  t195_n205: return -0.027992350980639458f;
  t195_n206: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t195_n208;
  t195_n207: return -0.002110391156747937f;
  t195_n208: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t195_n210;
  t195_n209: return -0.0014798172051087022f;
  t195_n210: return 0.11125742644071579f;
  t195_n211: return -0.016194863244891167f;
  t195_n212: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t195_n216;
  t195_n213: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t195_n215;
  t195_n214: return -0.1061943992972374f;
  t195_n215: return 0.08826819807291031f;
  t195_n216: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t195_n220;
  t195_n217: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t195_n219;
  t195_n218: return 0.12545067071914673f;
  t195_n219: return -0.01457598339766264f;
  t195_n220: return -0.10726620256900787f;
  t195_n221: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t195_n223;
  t195_n222: return -0.15401563048362732f;
  t195_n223: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n225;
  t195_n224: return -0.27181029319763184f;
  t195_n225: return -0.00790038425475359f;
  t195_n226: return 0.10329015552997589f;
  t195_n227: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t195_n229;
  t195_n228: return -0.2453574687242508f;
  t195_n229: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t195_n251;
  t195_n230: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t195_n234;
  t195_n231: if (E.getNumReferences() >= 3361181120 /*220727.0*/) goto t195_n233;
  t195_n232: return 0.0007717356784269214f;
  t195_n233: return 0.07329950481653214f;
  t195_n234: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t195_n246;
  t195_n235: if (E.getNumReferences() >= 3264610304 /*75.0*/) goto t195_n237;
  t195_n236: return -0.5161000490188599f;
  t195_n237: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t195_n241;
  t195_n238: if (E.getNumReferences() >= 3332682752 /*21082.0*/) goto t195_n240;
  t195_n239: return -0.0774393305182457f;
  t195_n240: return 0.1185123547911644f;
  t195_n241: if (E.getNumReferences() >= 3350603008 /*93258.0*/) goto t195_n245;
  t195_n242: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t195_n244;
  t195_n243: return -2.094815492630005f;
  t195_n244: return -0.0950610339641571f;
  t195_n245: return 0.049426138401031494f;
  t195_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t195_n248;
  t195_n247: return -0.22943823039531708f;
  t195_n248: if (E.getNumReferences() >= 3270967296 /*123.5*/) goto t195_n250;
  t195_n249: return -0.1995338797569275f;
  t195_n250: return 0.12098591774702072f;
  t195_n251: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t195_n253;
  t195_n252: return 0.017757631838321686f;
  t195_n253: return -0.11667540669441223f;
  t195_n254: return 0.0032919663935899734f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree196(const Example& E) {
  t196_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t196_n2;
  t196_n1: return -0.00020302203483879566f;
  t196_n2: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t196_n106;
  t196_n3: if (E.getNumReferences() >= 3343638400 /*52191.5*/) goto t196_n75;
  t196_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t196_n38;
  t196_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t196_n23;
  t196_n6: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t196_n22;
  t196_n7: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n17;
  t196_n8: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t196_n10;
  t196_n9: return -0.06473498046398163f;
  t196_n10: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t196_n12;
  t196_n11: return 0.03773682564496994f;
  t196_n12: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t196_n14;
  t196_n13: return 0.11055511236190796f;
  t196_n14: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t196_n16;
  t196_n15: return -0.23202568292617798f;
  t196_n16: return 0.1104075014591217f;
  t196_n17: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t196_n21;
  t196_n18: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t196_n20;
  t196_n19: return 0.08998259902000427f;
  t196_n20: return -0.09911972284317017f;
  t196_n21: return -0.04168112576007843f;
  t196_n22: return -0.028846880421042442f;
  t196_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t196_n37;
  t196_n24: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n34;
  t196_n25: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t196_n27;
  t196_n26: return 0.20704972743988037f;
  t196_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t196_n29;
  t196_n28: return -0.10160165280103683f;
  t196_n29: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t196_n31;
  t196_n30: return 0.1300160139799118f;
  t196_n31: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n33;
  t196_n32: return -0.21607011556625366f;
  t196_n33: return 0.11130847036838531f;
  t196_n34: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t196_n36;
  t196_n35: return 0.10639171302318573f;
  t196_n36: return 0.06595299392938614f;
  t196_n37: return -0.14579825103282928f;
  t196_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t196_n40;
  t196_n39: return 0.017236748710274696f;
  t196_n40: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t196_n74;
  t196_n41: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t196_n65;
  t196_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t196_n48;
  t196_n43: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t196_n47;
  t196_n44: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n46;
  t196_n45: return 0.11491484194993973f;
  t196_n46: return 0.07044640183448792f;
  t196_n47: return -0.1795492023229599f;
  t196_n48: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t196_n54;
  t196_n49: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t196_n53;
  t196_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t196_n52;
  t196_n51: return 0.07789012044668198f;
  t196_n52: return 0.06807173043489456f;
  t196_n53: return -0.10378134995698929f;
  t196_n54: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t196_n60;
  t196_n55: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t196_n59;
  t196_n56: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t196_n58;
  t196_n57: return 0.07405781745910645f;
  t196_n58: return 0.035179223865270615f;
  t196_n59: return 0.015036522410809994f;
  t196_n60: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t196_n62;
  t196_n61: return -0.1857803910970688f;
  t196_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t196_n64;
  t196_n63: return 0.11549290269613266f;
  t196_n64: return 0.10346439480781555f;
  t196_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t196_n67;
  t196_n66: return -0.03981815651059151f;
  t196_n67: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t196_n73;
  t196_n68: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t196_n70;
  t196_n69: return 0.26095864176750183f;
  t196_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n72;
  t196_n71: return 0.21252192556858063f;
  t196_n72: return 0.19523859024047852f;
  t196_n73: return 0.08992475271224976f;
  t196_n74: return 0.02266082912683487f;
  t196_n75: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n81;
  t196_n76: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t196_n78;
  t196_n77: return 0.06814474612474442f;
  t196_n78: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t196_n80;
  t196_n79: return -0.39089030027389526f;
  t196_n80: return 0.11358156055212021f;
  t196_n81: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t196_n91;
  t196_n82: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n90;
  t196_n83: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t196_n85;
  t196_n84: return -0.10280397534370422f;
  t196_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t196_n87;
  t196_n86: return 0.09783078730106354f;
  t196_n87: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t196_n89;
  t196_n88: return 0.12498420476913452f;
  t196_n89: return 0.11831815540790558f;
  t196_n90: return -0.026593998074531555f;
  t196_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t196_n95;
  t196_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t196_n94;
  t196_n93: return -0.034286919981241226f;
  t196_n94: return 0.09889629483222961f;
  t196_n95: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t196_n97;
  t196_n96: return 0.00933017861098051f;
  t196_n97: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n105;
  t196_n98: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t196_n100;
  t196_n99: return 0.1787400245666504f;
  t196_n100: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t196_n102;
  t196_n101: return 0.1703227013349533f;
  t196_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t196_n104;
  t196_n103: return 0.14180463552474976f;
  t196_n104: return 0.14606937766075134f;
  t196_n105: return 0.08290208131074905f;
  t196_n106: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t196_n190;
  t196_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t196_n157;
  t196_n108: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t196_n122;
  t196_n109: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n111;
  t196_n110: return -0.02200816199183464f;
  t196_n111: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t196_n117;
  t196_n112: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t196_n116;
  t196_n113: if (E.getNumReferences() >= 3346697088 /*64139.5*/) goto t196_n115;
  t196_n114: return -0.05642814189195633f;
  t196_n115: return -0.18979796767234802f;
  t196_n116: return -0.03336590901017189f;
  t196_n117: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t196_n121;
  t196_n118: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t196_n120;
  t196_n119: return 0.11374273151159286f;
  t196_n120: return 0.1215478703379631f;
  t196_n121: return 0.007518764119595289f;
  t196_n122: if (E.getNumReferences() >= 3346171648 /*62087.0*/) goto t196_n156;
  t196_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t196_n125;
  t196_n124: return -0.03336285427212715f;
  t196_n125: if (E.getNumReferences() >= 3345144064 /*58073.0*/) goto t196_n127;
  t196_n126: return -0.09588347375392914f;
  t196_n127: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t196_n147;
  t196_n128: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n130;
  t196_n129: return 0.03555838018655777f;
  t196_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t196_n146;
  t196_n131: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t196_n133;
  t196_n132: return 0.06830720603466034f;
  t196_n133: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t196_n145;
  t196_n134: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t196_n140;
  t196_n135: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t196_n139;
  t196_n136: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t196_n138;
  t196_n137: return 0.1696188747882843f;
  t196_n138: return 0.17718909680843353f;
  t196_n139: return 0.0898512452840805f;
  t196_n140: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t196_n144;
  t196_n141: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t196_n143;
  t196_n142: return 0.12092146277427673f;
  t196_n143: return 0.10350298136472702f;
  t196_n144: return -0.10023660957813263f;
  t196_n145: return 0.06019841507077217f;
  t196_n146: return 0.11176382005214691f;
  t196_n147: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t196_n151;
  t196_n148: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n150;
  t196_n149: return 0.10146060585975647f;
  t196_n150: return 0.142096146941185f;
  t196_n151: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t196_n155;
  t196_n152: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t196_n154;
  t196_n153: return 0.12095815688371658f;
  t196_n154: return 0.10021830350160599f;
  t196_n155: return 0.009962786920368671f;
  t196_n156: return -0.025134950876235962f;
  t196_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t196_n159;
  t196_n158: return -0.04822300747036934f;
  t196_n159: if (E.getNumReferences() >= 3348219712 /*74638.5*/) goto t196_n177;
  t196_n160: if (E.getNumReferences() >= 3345444992 /*59248.5*/) goto t196_n176;
  t196_n161: if (E.getNumReferences() >= 3345041664 /*57673.0*/) goto t196_n171;
  t196_n162: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t196_n170;
  t196_n163: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t196_n169;
  t196_n164: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t196_n168;
  t196_n165: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n167;
  t196_n166: return -0.3277548551559448f;
  t196_n167: return 0.10534145683050156f;
  t196_n168: return 0.11099737137556076f;
  t196_n169: return -0.0037674515042454004f;
  t196_n170: return -0.12814205884933472f;
  t196_n171: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t196_n175;
  t196_n172: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t196_n174;
  t196_n173: return 0.15414515137672424f;
  t196_n174: return 0.1186022162437439f;
  t196_n175: return 0.18729151785373688f;
  t196_n176: return -0.08534485101699829f;
  t196_n177: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t196_n179;
  t196_n178: return -0.23456524312496185f;
  t196_n179: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n181;
  t196_n180: return 0.08234942704439163f;
  t196_n181: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t196_n183;
  t196_n182: return 0.09633205085992813f;
  t196_n183: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t196_n185;
  t196_n184: return -0.14813587069511414f;
  t196_n185: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t196_n189;
  t196_n186: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n188;
  t196_n187: return 0.09038130193948746f;
  t196_n188: return 0.05450892075896263f;
  t196_n189: return -0.09278777986764908f;
  t196_n190: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t196_n254;
  t196_n191: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t196_n215;
  t196_n192: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t196_n214;
  t196_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t196_n195;
  t196_n194: return 0.009337881579995155f;
  t196_n195: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t196_n201;
  t196_n196: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t196_n198;
  t196_n197: return 0.006364563945680857f;
  t196_n198: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n200;
  t196_n199: return 0.10915785282850266f;
  t196_n200: return 0.06120174378156662f;
  t196_n201: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t196_n213;
  t196_n202: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n212;
  t196_n203: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t196_n211;
  t196_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t196_n206;
  t196_n205: return -0.10374343395233154f;
  t196_n206: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t196_n208;
  t196_n207: return 0.09335827827453613f;
  t196_n208: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t196_n210;
  t196_n209: return 0.11306073516607285f;
  t196_n210: return 0.11449505388736725f;
  t196_n211: return -0.0484762117266655f;
  t196_n212: return 0.03834062069654465f;
  t196_n213: return -0.004780489485710859f;
  t196_n214: return 0.0048681991174817085f;
  t196_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t196_n235;
  t196_n216: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t196_n218;
  t196_n217: return 0.0310545414686203f;
  t196_n218: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t196_n234;
  t196_n219: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t196_n221;
  t196_n220: return -0.049059245735406876f;
  t196_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n231;
  t196_n222: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t196_n226;
  t196_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t196_n225;
  t196_n224: return -0.10406531393527985f;
  t196_n225: return 0.08920706063508987f;
  t196_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t196_n228;
  t196_n227: return 0.04315715655684471f;
  t196_n228: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t196_n230;
  t196_n229: return 0.0822271928191185f;
  t196_n230: return 0.10933924466371536f;
  t196_n231: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t196_n233;
  t196_n232: return -0.07320843636989594f;
  t196_n233: return 0.023902231827378273f;
  t196_n234: return -0.019600557163357735f;
  t196_n235: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t196_n237;
  t196_n236: return 0.017693467438220978f;
  t196_n237: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t196_n241;
  t196_n238: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t196_n240;
  t196_n239: return -0.2301647961139679f;
  t196_n240: return 0.10620898753404617f;
  t196_n241: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t196_n253;
  t196_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t196_n244;
  t196_n243: return -0.10901763290166855f;
  t196_n244: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t196_n246;
  t196_n245: return -0.11029323935508728f;
  t196_n246: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t196_n248;
  t196_n247: return 0.0870581641793251f;
  t196_n248: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t196_n250;
  t196_n249: return -0.013266729190945625f;
  t196_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t196_n252;
  t196_n251: return 0.034434277564287186f;
  t196_n252: return 0.08936505019664764f;
  t196_n253: return 0.006245040334761143f;
  t196_n254: return -0.002770343329757452f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree197(const Example& E) {
  t197_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t197_n2;
  t197_n1: return -0.0002049272006843239f;
  t197_n2: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t197_n12;
  t197_n3: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t197_n5;
  t197_n4: return 0.06847895681858063f;
  t197_n5: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t197_n7;
  t197_n6: return 0.12105785310268402f;
  t197_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t197_n9;
  t197_n8: return -0.11974213272333145f;
  t197_n9: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t197_n11;
  t197_n10: return 0.10690976679325104f;
  t197_n11: return 0.07930976897478104f;
  t197_n12: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t197_n50;
  t197_n13: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t197_n15;
  t197_n14: return -0.00895766168832779f;
  t197_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t197_n17;
  t197_n16: return 0.011919376440346241f;
  t197_n17: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t197_n39;
  t197_n18: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t197_n38;
  t197_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t197_n35;
  t197_n20: if (E.getNumReferences() >= 3351268608 /*98458.0*/) goto t197_n22;
  t197_n21: return 0.01727430708706379f;
  t197_n22: if (E.getNumReferences() >= 3361321216 /*222916.0*/) goto t197_n30;
  t197_n23: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t197_n29;
  t197_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n26;
  t197_n25: return 0.14421118795871735f;
  t197_n26: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t197_n28;
  t197_n27: return 0.09495095908641815f;
  t197_n28: return -0.02927744761109352f;
  t197_n29: return -0.1257515847682953f;
  t197_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t197_n32;
  t197_n31: return 0.019819283857941628f;
  t197_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n34;
  t197_n33: return -0.1107100173830986f;
  t197_n34: return 0.11898594349622726f;
  t197_n35: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t197_n37;
  t197_n36: return -0.011768262833356857f;
  t197_n37: return -0.3504181206226349f;
  t197_n38: return -0.11245030909776688f;
  t197_n39: if (E.getNumReferences() >= 3365247648 /*306389.0*/) goto t197_n47;
  t197_n40: if (E.getNumReferences() >= 3342715264 /*48585.5*/) goto t197_n42;
  t197_n41: return -0.45745617151260376f;
  t197_n42: if (E.getNumReferences() >= 3346232448 /*62324.5*/) goto t197_n46;
  t197_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t197_n45;
  t197_n44: return 0.09423363208770752f;
  t197_n45: return 0.10813306272029877f;
  t197_n46: return 0.03673981875181198f;
  t197_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t197_n49;
  t197_n48: return 0.08720039576292038f;
  t197_n49: return 0.10777366906404495f;
  t197_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t197_n240;
  t197_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t197_n53;
  t197_n52: return 0.0038233590312302113f;
  t197_n53: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t197_n239;
  t197_n54: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t197_n184;
  t197_n55: if (E.getNumReferences() >= 3360267424 /*206450.5*/) goto t197_n153;
  t197_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t197_n58;
  t197_n57: return 0.013595976866781712f;
  t197_n58: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t197_n142;
  t197_n59: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t197_n137;
  t197_n60: if (E.getNumReferences() >= 3346274176 /*62487.5*/) goto t197_n106;
  t197_n61: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t197_n93;
  t197_n62: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t197_n92;
  t197_n63: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t197_n89;
  t197_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t197_n86;
  t197_n65: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t197_n83;
  t197_n66: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t197_n76;
  t197_n67: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t197_n71;
  t197_n68: if (E.getNumReferences() >= 3342798080 /*48909.0*/) goto t197_n70;
  t197_n69: return -0.4048270583152771f;
  t197_n70: return 0.024372858926653862f;
  t197_n71: if (E.getNumReferences() >= 3344702080 /*56346.5*/) goto t197_n75;
  t197_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t197_n74;
  t197_n73: return -0.2154734581708908f;
  t197_n74: return 0.0698782280087471f;
  t197_n75: return -0.03641853854060173f;
  t197_n76: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t197_n82;
  t197_n77: if (E.getNumReferences() >= 3342798080 /*48909.0*/) goto t197_n81;
  t197_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t197_n80;
  t197_n79: return 0.111674465239048f;
  t197_n80: return 0.11461059749126434f;
  t197_n81: return 0.09402891248464584f;
  t197_n82: return -0.027931103482842445f;
  t197_n83: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t197_n85;
  t197_n84: return -0.15051954984664917f;
  t197_n85: return 0.1015748530626297f;
  t197_n86: if (E.getNumReferences() >= 3342431232 /*47476.0*/) goto t197_n88;
  t197_n87: return 0.12043626606464386f;
  t197_n88: return -0.12735632061958313f;
  t197_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t197_n91;
  t197_n90: return 0.07370457798242569f;
  t197_n91: return -0.1410348117351532f;
  t197_n92: return -0.2915423810482025f;
  t197_n93: if (E.getNumReferences() >= 3345968640 /*61294.0*/) goto t197_n103;
  t197_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t197_n96;
  t197_n95: return -0.31182119250297546f;
  t197_n96: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n98;
  t197_n97: return 0.08918303996324539f;
  t197_n98: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t197_n100;
  t197_n99: return -0.023466400802135468f;
  t197_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t197_n102;
  t197_n101: return 0.1220487654209137f;
  t197_n102: return 0.10743271559476852f;
  t197_n103: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t197_n105;
  t197_n104: return 0.07968879491090775f;
  t197_n105: return 0.10060480982065201f;
  t197_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t197_n134;
  t197_n107: if (E.getNumReferences() >= 3350955776 /*96014.0*/) goto t197_n133;
  t197_n108: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t197_n132;
  t197_n109: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t197_n119;
  t197_n110: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t197_n112;
  t197_n111: return -0.2840930223464966f;
  t197_n112: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t197_n114;
  t197_n113: return -0.24452264606952667f;
  t197_n114: if (E.getNumReferences() >= 3348960256 /*80424.0*/) goto t197_n118;
  t197_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t197_n117;
  t197_n116: return 0.08615867048501968f;
  t197_n117: return 0.10262201726436615f;
  t197_n118: return -0.2597315311431885f;
  t197_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t197_n121;
  t197_n120: return -0.06193196028470993f;
  t197_n121: if (E.getNumReferences() >= 3348072384 /*73487.5*/) goto t197_n125;
  t197_n122: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t197_n124;
  t197_n123: return 0.10708723962306976f;
  t197_n124: return -0.05078069865703583f;
  t197_n125: if (E.getNumReferences() >= 3348479616 /*76669.0*/) goto t197_n127;
  t197_n126: return -0.19756951928138733f;
  t197_n127: if (E.getNumReferences() >= 3349883520 /*87637.0*/) goto t197_n131;
  t197_n128: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t197_n130;
  t197_n129: return 0.09860913455486298f;
  t197_n130: return 0.1316646784543991f;
  t197_n131: return -0.03261396288871765f;
  t197_n132: return 0.04338795319199562f;
  t197_n133: return -0.0571746900677681f;
  t197_n134: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t197_n136;
  t197_n135: return -0.1347469836473465f;
  t197_n136: return 0.09790772944688797f;
  t197_n137: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t197_n141;
  t197_n138: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t197_n140;
  t197_n139: return -0.12051256000995636f;
  t197_n140: return 0.07356825470924377f;
  t197_n141: return 0.10277947038412094f;
  t197_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t197_n144;
  t197_n143: return -0.041766952723264694f;
  t197_n144: if (E.getNumReferences() >= 3355904736 /*138283.5*/) goto t197_n152;
  t197_n145: if (E.getNumReferences() >= 3351190528 /*97848.0*/) goto t197_n149;
  t197_n146: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t197_n148;
  t197_n147: return -0.11991716921329498f;
  t197_n148: return 0.19646286964416504f;
  t197_n149: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t197_n151;
  t197_n150: return 0.12198083102703094f;
  t197_n151: return 0.05681237205862999f;
  t197_n152: return -0.27037036418914795f;
  t197_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t197_n155;
  t197_n154: return 0.01330089196562767f;
  t197_n155: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t197_n177;
  t197_n156: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t197_n166;
  t197_n157: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t197_n165;
  t197_n158: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t197_n164;
  t197_n159: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t197_n161;
  t197_n160: return 0.014892206527292728f;
  t197_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t197_n163;
  t197_n162: return -0.11813697218894958f;
  t197_n163: return 0.09913364052772522f;
  t197_n164: return 0.09072819352149963f;
  t197_n165: return 0.11529283970594406f;
  t197_n166: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t197_n176;
  t197_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n169;
  t197_n168: return -0.10557779669761658f;
  t197_n169: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t197_n173;
  t197_n170: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t197_n172;
  t197_n171: return 0.10699617862701416f;
  t197_n172: return -0.4134959876537323f;
  t197_n173: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t197_n175;
  t197_n174: return -0.3059860169887543f;
  t197_n175: return 0.06409143656492233f;
  t197_n176: return -0.07391044497489929f;
  t197_n177: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t197_n179;
  t197_n178: return 0.07910680025815964f;
  t197_n179: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t197_n181;
  t197_n180: return 0.0943366140127182f;
  t197_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n183;
  t197_n182: return 0.09313647449016571f;
  t197_n183: return -0.12499213218688965f;
  t197_n184: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t197_n186;
  t197_n185: return -0.008707515895366669f;
  t197_n186: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t197_n208;
  t197_n187: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t197_n191;
  t197_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t197_n190;
  t197_n189: return 0.0635223537683487f;
  t197_n190: return 0.09921331703662872f;
  t197_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t197_n207;
  t197_n192: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t197_n194;
  t197_n193: return -0.14242097735404968f;
  t197_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t197_n196;
  t197_n195: return -0.13969948887825012f;
  t197_n196: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t197_n204;
  t197_n197: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t197_n201;
  t197_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t197_n200;
  t197_n199: return -0.024630796164274216f;
  t197_n200: return 0.04921211674809456f;
  t197_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t197_n203;
  t197_n202: return 0.03735116869211197f;
  t197_n203: return 0.07242735475301743f;
  t197_n204: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t197_n206;
  t197_n205: return -0.06336431950330734f;
  t197_n206: return 0.05150245130062103f;
  t197_n207: return -0.20734646916389465f;
  t197_n208: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t197_n218;
  t197_n209: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t197_n217;
  t197_n210: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t197_n212;
  t197_n211: return 0.015384248457849026f;
  t197_n212: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t197_n216;
  t197_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t197_n215;
  t197_n214: return -0.15935248136520386f;
  t197_n215: return -0.03295363858342171f;
  t197_n216: return -0.41290420293807983f;
  t197_n217: return 0.018681509420275688f;
  t197_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t197_n234;
  t197_n219: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t197_n229;
  t197_n220: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t197_n224;
  t197_n221: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n223;
  t197_n222: return 0.11692751199007034f;
  t197_n223: return -0.05864371359348297f;
  t197_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n226;
  t197_n225: return -0.02225382626056671f;
  t197_n226: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t197_n228;
  t197_n227: return 0.025000566616654396f;
  t197_n228: return 0.028817985206842422f;
  t197_n229: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t197_n231;
  t197_n230: return 0.06107282638549805f;
  t197_n231: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t197_n233;
  t197_n232: return -0.3468068242073059f;
  t197_n233: return 0.08722180128097534f;
  t197_n234: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t197_n236;
  t197_n235: return 0.10548911988735199f;
  t197_n236: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t197_n238;
  t197_n237: return -0.2747407853603363f;
  t197_n238: return 0.04191838949918747f;
  t197_n239: return -0.06224804371595383f;
  t197_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t197_n242;
  t197_n241: return -0.046064313501119614f;
  t197_n242: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t197_n254;
  t197_n243: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t197_n249;
  t197_n244: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t197_n246;
  t197_n245: return 0.03949030116200447f;
  t197_n246: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t197_n248;
  t197_n247: return 0.09705643355846405f;
  t197_n248: return -0.0014125140151008964f;
  t197_n249: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t197_n253;
  t197_n250: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t197_n252;
  t197_n251: return 0.12223724275827408f;
  t197_n252: return 0.09667182713747025f;
  t197_n253: return 0.08301389962434769f;
  t197_n254: return -0.06231631711125374f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree198(const Example& E) {
  t198_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t198_n162;
  t198_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t198_n3;
  t198_n2: return -0.0003628239210229367f;
  t198_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n5;
  t198_n4: return -0.02145686373114586f;
  t198_n5: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t198_n123;
  t198_n6: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t198_n8;
  t198_n7: return 0.008310966193675995f;
  t198_n8: if (E.getNumReferences() >= 3284484096 /*394.5*/) goto t198_n110;
  t198_n9: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t198_n49;
  t198_n10: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t198_n14;
  t198_n11: if (E.getNumReferences() >= 3283648512 /*369.0*/) goto t198_n13;
  t198_n12: return -0.019412102177739143f;
  t198_n13: return 0.10928968340158463f;
  t198_n14: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t198_n48;
  t198_n15: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t198_n45;
  t198_n16: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t198_n18;
  t198_n17: return 0.012392024509608746f;
  t198_n18: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t198_n20;
  t198_n19: return -0.031666044145822525f;
  t198_n20: if (E.getNumReferences() >= 3273031680 /*150.5*/) goto t198_n30;
  t198_n21: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t198_n29;
  t198_n22: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t198_n28;
  t198_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t198_n25;
  t198_n24: return 0.09270348399877548f;
  t198_n25: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t198_n27;
  t198_n26: return 0.34945687651634216f;
  t198_n27: return 0.11324673891067505f;
  t198_n28: return -0.10176991671323776f;
  t198_n29: return 0.04502050578594208f;
  t198_n30: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t198_n32;
  t198_n31: return 0.11719183623790741f;
  t198_n32: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t198_n44;
  t198_n33: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t198_n41;
  t198_n34: if (E.getNumReferences() >= 3278340096 /*231.5*/) goto t198_n36;
  t198_n35: return 0.021382829174399376f;
  t198_n36: if (E.getNumReferences() >= 3280420864 /*270.5*/) goto t198_n38;
  t198_n37: return 0.143484964966774f;
  t198_n38: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t198_n40;
  t198_n39: return 0.19588230550289154f;
  t198_n40: return -0.22002601623535156f;
  t198_n41: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t198_n43;
  t198_n42: return 0.13402435183525085f;
  t198_n43: return -0.10123234242200851f;
  t198_n44: return -0.04727638140320778f;
  t198_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t198_n47;
  t198_n46: return 0.11005992442369461f;
  t198_n47: return 0.10768821835517883f;
  t198_n48: return 0.0070199486799538136f;
  t198_n49: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t198_n55;
  t198_n50: if (E.getNumReferences() >= 3277750272 /*222.5*/) goto t198_n52;
  t198_n51: return -0.013584572821855545f;
  t198_n52: if (E.getNumReferences() >= 3277815808 /*223.5*/) goto t198_n54;
  t198_n53: return 0.13828901946544647f;
  t198_n54: return 0.040128193795681f;
  t198_n55: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t198_n107;
  t198_n56: if (E.getNumReferences() >= 3283943424 /*378.0*/) goto t198_n104;
  t198_n57: if (E.getNumReferences() >= 3278733312 /*237.5*/) goto t198_n101;
  t198_n58: if (E.getNumReferences() >= 3278307328 /*231.0*/) goto t198_n98;
  t198_n59: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t198_n87;
  t198_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t198_n62;
  t198_n61: return 0.012759172357618809f;
  t198_n62: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t198_n84;
  t198_n63: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t198_n69;
  t198_n64: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t198_n68;
  t198_n65: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t198_n67;
  t198_n66: return 0.12166900187730789f;
  t198_n67: return -0.3467974066734314f;
  t198_n68: return 0.12685440480709076f;
  t198_n69: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t198_n83;
  t198_n70: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t198_n78;
  t198_n71: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t198_n77;
  t198_n72: if (E.getNumReferences() >= 3268739072 /*106.5*/) goto t198_n74;
  t198_n73: return -0.23324359953403473f;
  t198_n74: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t198_n76;
  t198_n75: return 0.13212601840496063f;
  t198_n76: return -0.11202404648065567f;
  t198_n77: return 0.10718943178653717f;
  t198_n78: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t198_n82;
  t198_n79: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t198_n81;
  t198_n80: return 0.5496679544448853f;
  t198_n81: return -0.10952281951904297f;
  t198_n82: return -0.05088523030281067f;
  t198_n83: return 0.050106726586818695f;
  t198_n84: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t198_n86;
  t198_n85: return 0.004438046365976334f;
  t198_n86: return 0.12100841850042343f;
  t198_n87: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t198_n95;
  t198_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n92;
  t198_n89: if (E.getNumReferences() >= 3276603392 /*205.0*/) goto t198_n91;
  t198_n90: return -0.04431649670004845f;
  t198_n91: return 0.8104863166809082f;
  t198_n92: if (E.getNumReferences() >= 3275227136 /*184.0*/) goto t198_n94;
  t198_n93: return 0.06342873722314835f;
  t198_n94: return 0.12520131468772888f;
  t198_n95: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t198_n97;
  t198_n96: return -0.6008599400520325f;
  t198_n97: return 0.023476561531424522f;
  t198_n98: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t198_n100;
  t198_n99: return 0.11133313924074173f;
  t198_n100: return 0.09665898233652115f;
  t198_n101: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t198_n103;
  t198_n102: return -0.020755713805556297f;
  t198_n103: return 0.10191407054662704f;
  t198_n104: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t198_n106;
  t198_n105: return -0.23518557846546173f;
  t198_n106: return 0.0986367017030716f;
  t198_n107: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t198_n109;
  t198_n108: return 0.08124519139528275f;
  t198_n109: return 0.1119004413485527f;
  t198_n110: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t198_n122;
  t198_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t198_n113;
  t198_n112: return -0.017413876950740814f;
  t198_n113: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t198_n121;
  t198_n114: if (E.getNumReferences() >= 3309072384 /*3015.0*/) goto t198_n120;
  t198_n115: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t198_n119;
  t198_n116: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t198_n118;
  t198_n117: return 0.08292298018932343f;
  t198_n118: return -0.15029628574848175f;
  t198_n119: return 0.0937093049287796f;
  t198_n120: return 0.09989485889673233f;
  t198_n121: return -0.04868387058377266f;
  t198_n122: return 0.010986186563968658f;
  t198_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t198_n125;
  t198_n124: return -0.0013719334965571761f;
  t198_n125: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t198_n159;
  t198_n126: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t198_n138;
  t198_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t198_n129;
  t198_n128: return 0.009877219796180725f;
  t198_n129: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t198_n131;
  t198_n130: return 0.057723455131053925f;
  t198_n131: if (E.getNumReferences() >= 3256352768 /*38.0*/) goto t198_n137;
  t198_n132: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t198_n136;
  t198_n133: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t198_n135;
  t198_n134: return 0.07489346712827682f;
  t198_n135: return 0.09522972255945206f;
  t198_n136: return -0.11152935028076172f;
  t198_n137: return 0.11212906986474991f;
  t198_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t198_n152;
  t198_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t198_n143;
  t198_n140: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t198_n142;
  t198_n141: return -0.8440048694610596f;
  t198_n142: return -0.12423147261142731f;
  t198_n143: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t198_n147;
  t198_n144: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t198_n146;
  t198_n145: return 0.09075822681188583f;
  t198_n146: return 0.045124515891075134f;
  t198_n147: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t198_n149;
  t198_n148: return -0.5069703459739685f;
  t198_n149: if (E.getFileProximityDistance() >= 3250585600 /*24.0*/) goto t198_n151;
  t198_n150: return 0.08550652861595154f;
  t198_n151: return 0.23168085515499115f;
  t198_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t198_n158;
  t198_n153: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t198_n155;
  t198_n154: return 0.01390969380736351f;
  t198_n155: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t198_n157;
  t198_n156: return 0.1059902086853981f;
  t198_n157: return 0.1423821896314621f;
  t198_n158: return -0.07934907078742981f;
  t198_n159: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t198_n161;
  t198_n160: return 0.005585044156759977f;
  t198_n161: return -0.10647173970937729f;
  t198_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t198_n242;
  t198_n163: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t198_n235;
  t198_n164: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t198_n174;
  t198_n165: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t198_n171;
  t198_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t198_n168;
  t198_n167: return -0.02718723937869072f;
  t198_n168: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t198_n170;
  t198_n169: return 0.0906534343957901f;
  t198_n170: return -0.4569120705127716f;
  t198_n171: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t198_n173;
  t198_n172: return -0.016968337818980217f;
  t198_n173: return 0.07410212606191635f;
  t198_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t198_n208;
  t198_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n205;
  t198_n176: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t198_n200;
  t198_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n179;
  t198_n178: return -0.12864907085895538f;
  t198_n179: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t198_n197;
  t198_n180: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t198_n186;
  t198_n181: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t198_n183;
  t198_n182: return 0.07698266953229904f;
  t198_n183: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t198_n185;
  t198_n184: return 0.0023526467848569155f;
  t198_n185: return -0.09500283747911453f;
  t198_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n188;
  t198_n187: return -0.6376132965087891f;
  t198_n188: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t198_n192;
  t198_n189: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t198_n191;
  t198_n190: return 0.0014021070674061775f;
  t198_n191: return 0.05207673832774162f;
  t198_n192: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t198_n194;
  t198_n193: return 0.07654905319213867f;
  t198_n194: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t198_n196;
  t198_n195: return 0.042365662753582f;
  t198_n196: return -0.05434444546699524f;
  t198_n197: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t198_n199;
  t198_n198: return 0.006049415562301874f;
  t198_n199: return -1.1033189296722412f;
  t198_n200: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t198_n204;
  t198_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t198_n203;
  t198_n202: return -0.11390747129917145f;
  t198_n203: return 0.10764851421117783f;
  t198_n204: return 0.004679080564528704f;
  t198_n205: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t198_n207;
  t198_n206: return -0.055269233882427216f;
  t198_n207: return 0.014597010798752308f;
  t198_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t198_n230;
  t198_n209: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t198_n227;
  t198_n210: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t198_n216;
  t198_n211: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t198_n213;
  t198_n212: return -0.35560569167137146f;
  t198_n213: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t198_n215;
  t198_n214: return 0.21921047568321228f;
  t198_n215: return 0.06407880038022995f;
  t198_n216: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t198_n218;
  t198_n217: return -0.32426485419273376f;
  t198_n218: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t198_n224;
  t198_n219: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t198_n221;
  t198_n220: return -0.6152205467224121f;
  t198_n221: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t198_n223;
  t198_n222: return -0.10187657922506332f;
  t198_n223: return 0.10162670165300369f;
  t198_n224: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t198_n226;
  t198_n225: return -0.35506242513656616f;
  t198_n226: return 0.008927029557526112f;
  t198_n227: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t198_n229;
  t198_n228: return -0.08183521032333374f;
  t198_n229: return 0.06755568832159042f;
  t198_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n232;
  t198_n231: return -0.17820584774017334f;
  t198_n232: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t198_n234;
  t198_n233: return -0.16484425961971283f;
  t198_n234: return 0.21973055601119995f;
  t198_n235: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t198_n237;
  t198_n236: return 0.029859021306037903f;
  t198_n237: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t198_n239;
  t198_n238: return -0.12128010392189026f;
  t198_n239: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t198_n241;
  t198_n240: return 0.04507727548480034f;
  t198_n241: return 0.11442865431308746f;
  t198_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t198_n250;
  t198_n243: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t198_n249;
  t198_n244: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t198_n248;
  t198_n245: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t198_n247;
  t198_n246: return 0.08426224440336227f;
  t198_n247: return -0.6701565980911255f;
  t198_n248: return 0.09794019162654877f;
  t198_n249: return -0.0005998198175802827f;
  t198_n250: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t198_n254;
  t198_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n253;
  t198_n252: return -0.2464367300271988f;
  t198_n253: return -0.013008520938456059f;
  t198_n254: return 0.01578020490705967f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree199(const Example& E) {
  t199_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t199_n170;
  t199_n1: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t199_n157;
  t199_n2: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t199_n132;
  t199_n3: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t199_n131;
  t199_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t199_n90;
  t199_n5: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t199_n59;
  t199_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t199_n22;
  t199_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n9;
  t199_n8: return -0.011793685145676136f;
  t199_n9: if (E.getNumReferences() >= 3265986560 /*85.5*/) goto t199_n13;
  t199_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t199_n12;
  t199_n11: return 0.014041433110833168f;
  t199_n12: return 0.05112588778138161f;
  t199_n13: if (E.getNumReferences() >= 3266183168 /*87.0*/) goto t199_n15;
  t199_n14: return 0.1389102190732956f;
  t199_n15: if (E.getNumReferences() >= 3271491584 /*127.5*/) goto t199_n21;
  t199_n16: if (E.getNumReferences() >= 3270967296 /*123.5*/) goto t199_n20;
  t199_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n19;
  t199_n18: return 0.16111363470554352f;
  t199_n19: return 0.11454609036445618f;
  t199_n20: return 0.13016395270824432f;
  t199_n21: return 0.024733390659093857f;
  t199_n22: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t199_n36;
  t199_n23: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t199_n29;
  t199_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n28;
  t199_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n27;
  t199_n26: return -0.1265299916267395f;
  t199_n27: return -0.013662959448993206f;
  t199_n28: return 0.01695089228451252f;
  t199_n29: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t199_n31;
  t199_n30: return -0.06250794231891632f;
  t199_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t199_n33;
  t199_n32: return -0.019883016124367714f;
  t199_n33: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t199_n35;
  t199_n34: return 0.023715414106845856f;
  t199_n35: return 0.13278408348560333f;
  t199_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t199_n50;
  t199_n37: if (E.getNumReferences() >= 3275849728 /*193.5*/) goto t199_n49;
  t199_n38: if (E.getNumReferences() >= 3275620352 /*190.0*/) goto t199_n48;
  t199_n39: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t199_n43;
  t199_n40: if (E.getNumReferences() >= 3275030528 /*181.0*/) goto t199_n42;
  t199_n41: return -0.03772444650530815f;
  t199_n42: return 0.09193149954080582f;
  t199_n43: if (E.getNumReferences() >= 3274604544 /*174.5*/) goto t199_n47;
  t199_n44: if (E.getNumReferences() >= 3273916416 /*164.0*/) goto t199_n46;
  t199_n45: return 0.11597835272550583f;
  t199_n46: return -0.16925954818725586f;
  t199_n47: return 0.10257354378700256f;
  t199_n48: return 0.1100807711482048f;
  t199_n49: return -0.026708150282502174f;
  t199_n50: if (E.getNumReferences() >= 3277914112 /*225.0*/) goto t199_n52;
  t199_n51: return -0.021970104426145554f;
  t199_n52: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t199_n54;
  t199_n53: return 0.04017520323395729f;
  t199_n54: if (E.getNumReferences() >= 3284221952 /*386.5*/) goto t199_n56;
  t199_n55: return 0.13381066918373108f;
  t199_n56: if (E.getNumReferences() >= 3294429184 /*884.0*/) goto t199_n58;
  t199_n57: return 0.039308030158281326f;
  t199_n58: return 0.16570833325386047f;
  t199_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t199_n61;
  t199_n60: return -0.12365946173667908f;
  t199_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t199_n63;
  t199_n62: return 0.02118709124624729f;
  t199_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n71;
  t199_n64: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t199_n66;
  t199_n65: return 0.0036117727868258953f;
  t199_n66: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n70;
  t199_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t199_n69;
  t199_n68: return 0.00015646644169464707f;
  t199_n69: return 0.11924507468938828f;
  t199_n70: return 0.04521019384264946f;
  t199_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t199_n73;
  t199_n72: return 0.049533162266016006f;
  t199_n73: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t199_n81;
  t199_n74: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t199_n76;
  t199_n75: return 0.01333782821893692f;
  t199_n76: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n80;
  t199_n77: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t199_n79;
  t199_n78: return 0.10962851345539093f;
  t199_n79: return -0.36785173416137695f;
  t199_n80: return 0.010344229638576508f;
  t199_n81: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t199_n87;
  t199_n82: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t199_n84;
  t199_n83: return -0.03007330559194088f;
  t199_n84: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t199_n86;
  t199_n85: return 0.047079332172870636f;
  t199_n86: return -0.15868908166885376f;
  t199_n87: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t199_n89;
  t199_n88: return 0.13058796525001526f;
  t199_n89: return 0.0037932998966425657f;
  t199_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t199_n118;
  t199_n91: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t199_n93;
  t199_n92: return -0.005605393089354038f;
  t199_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n97;
  t199_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t199_n96;
  t199_n95: return 0.09498380869626999f;
  t199_n96: return 0.09157587587833405f;
  t199_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t199_n109;
  t199_n98: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n104;
  t199_n99: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t199_n101;
  t199_n100: return -0.008373819291591644f;
  t199_n101: if (E.getNumReferences() >= 3240099840 /*10.0*/) goto t199_n103;
  t199_n102: return 0.1248433068394661f;
  t199_n103: return 0.013732679188251495f;
  t199_n104: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n108;
  t199_n105: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t199_n107;
  t199_n106: return 0.11264782398939133f;
  t199_n107: return 0.07728574424982071f;
  t199_n108: return -0.09471838921308517f;
  t199_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n115;
  t199_n110: if (E.getNumReferences() >= 3272736768 /*146.0*/) goto t199_n112;
  t199_n111: return 0.053850896656513214f;
  t199_n112: if (E.getNumReferences() >= 3282026496 /*319.5*/) goto t199_n114;
  t199_n113: return 0.11240243166685104f;
  t199_n114: return 0.08654527366161346f;
  t199_n115: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t199_n117;
  t199_n116: return 0.1456594318151474f;
  t199_n117: return -0.053534962236881256f;
  t199_n118: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t199_n130;
  t199_n119: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t199_n129;
  t199_n120: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n128;
  t199_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n123;
  t199_n122: return -0.10275627672672272f;
  t199_n123: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n127;
  t199_n124: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n126;
  t199_n125: return 0.11543257534503937f;
  t199_n126: return 0.3623964190483093f;
  t199_n127: return 0.26468175649642944f;
  t199_n128: return 0.06981419771909714f;
  t199_n129: return 0.08520977199077606f;
  t199_n130: return 0.044025029987096786f;
  t199_n131: return -0.0027822493575513363f;
  t199_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t199_n136;
  t199_n133: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t199_n135;
  t199_n134: return -0.054376643151044846f;
  t199_n135: return -0.0005032608169130981f;
  t199_n136: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t199_n146;
  t199_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t199_n139;
  t199_n138: return -0.02424135059118271f;
  t199_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t199_n141;
  t199_n140: return 0.004155417438596487f;
  t199_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n145;
  t199_n142: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t199_n144;
  t199_n143: return -0.21993999183177948f;
  t199_n144: return 0.09194589406251907f;
  t199_n145: return 0.02289370819926262f;
  t199_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t199_n148;
  t199_n147: return 0.009057902731001377f;
  t199_n148: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t199_n156;
  t199_n149: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n155;
  t199_n150: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t199_n154;
  t199_n151: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t199_n153;
  t199_n152: return 0.09071037918329239f;
  t199_n153: return 0.06861001998186111f;
  t199_n154: return 0.09756626933813095f;
  t199_n155: return 0.06465838104486465f;
  t199_n156: return -0.03530872240662575f;
  t199_n157: if (E.getNumReferences() >= 3286630400 /*460.0*/) goto t199_n159;
  t199_n158: return -0.0336587056517601f;
  t199_n159: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n169;
  t199_n160: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n168;
  t199_n161: if (E.getNumReferences() >= 3298754560 /*1272.0*/) goto t199_n165;
  t199_n162: if (E.getNumReferences() >= 3294642176 /*897.0*/) goto t199_n164;
  t199_n163: return 0.6085352897644043f;
  t199_n164: return 0.20738470554351807f;
  t199_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t199_n167;
  t199_n166: return -0.11216844618320465f;
  t199_n167: return 0.3601023852825165f;
  t199_n168: return 0.04581015184521675f;
  t199_n169: return -0.06760475039482117f;
  t199_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t199_n238;
  t199_n171: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t199_n225;
  t199_n172: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t199_n182;
  t199_n173: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n179;
  t199_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t199_n176;
  t199_n175: return -0.02346820943057537f;
  t199_n176: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t199_n178;
  t199_n177: return 0.09127115458250046f;
  t199_n178: return -0.35673338174819946f;
  t199_n179: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t199_n181;
  t199_n180: return -0.018279148265719414f;
  t199_n181: return 0.07257048040628433f;
  t199_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n184;
  t199_n183: return -0.21147914230823517f;
  t199_n184: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n202;
  t199_n185: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t199_n187;
  t199_n186: return -0.019691571593284607f;
  t199_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n201;
  t199_n188: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t199_n196;
  t199_n189: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t199_n193;
  t199_n190: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t199_n192;
  t199_n191: return 0.07298140972852707f;
  t199_n192: return -0.09503155946731567f;
  t199_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n195;
  t199_n194: return 0.032951295375823975f;
  t199_n195: return -0.11154083907604218f;
  t199_n196: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t199_n200;
  t199_n197: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t199_n199;
  t199_n198: return -0.23522166907787323f;
  t199_n199: return -0.014812310226261616f;
  t199_n200: return 0.00654907152056694f;
  t199_n201: return 0.013577964156866074f;
  t199_n202: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t199_n218;
  t199_n203: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t199_n205;
  t199_n204: return -0.26095589995384216f;
  t199_n205: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t199_n217;
  t199_n206: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t199_n212;
  t199_n207: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t199_n211;
  t199_n208: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t199_n210;
  t199_n209: return -0.08908198028802872f;
  t199_n210: return 0.12453293800354004f;
  t199_n211: return -0.4939887821674347f;
  t199_n212: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n214;
  t199_n213: return -0.10097763687372208f;
  t199_n214: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t199_n216;
  t199_n215: return 0.10249397158622742f;
  t199_n216: return -0.027410227805376053f;
  t199_n217: return 0.06517916917800903f;
  t199_n218: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t199_n224;
  t199_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t199_n221;
  t199_n220: return 0.05006612464785576f;
  t199_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n223;
  t199_n222: return -0.5388970971107483f;
  t199_n223: return 0.2822599709033966f;
  t199_n224: return -0.16756296157836914f;
  t199_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n227;
  t199_n226: return 0.027782639488577843f;
  t199_n227: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t199_n237;
  t199_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t199_n236;
  t199_n229: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t199_n233;
  t199_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n232;
  t199_n231: return -0.42715194821357727f;
  t199_n232: return -0.28785890340805054f;
  t199_n233: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t199_n235;
  t199_n234: return -0.2748449742794037f;
  t199_n235: return 0.06745143234729767f;
  t199_n236: return 0.042822543531656265f;
  t199_n237: return 0.11321916431188583f;
  t199_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n246;
  t199_n239: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t199_n245;
  t199_n240: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t199_n244;
  t199_n241: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t199_n243;
  t199_n242: return 0.07983796298503876f;
  t199_n243: return -0.1606077253818512f;
  t199_n244: return 0.09997273236513138f;
  t199_n245: return 0.013445835560560226f;
  t199_n246: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t199_n248;
  t199_n247: return -0.0686192587018013f;
  t199_n248: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t199_n252;
  t199_n249: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t199_n251;
  t199_n250: return 0.09783339500427246f;
  t199_n251: return -0.01614883355796337f;
  t199_n252: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t199_n254;
  t199_n253: return -0.009878017008304596f;
  t199_n254: return 0.02853081002831459f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree200(const Example& E) {
  t200_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t200_n174;
  t200_n1: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t200_n3;
  t200_n2: return -0.00040719524258747697f;
  t200_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t200_n93;
  t200_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t200_n54;
  t200_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t200_n21;
  t200_n6: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t200_n8;
  t200_n7: return -0.009662346914410591f;
  t200_n8: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t200_n20;
  t200_n9: if (E.getNumReferences() >= 3325242368 /*11467.0*/) goto t200_n17;
  t200_n10: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t200_n12;
  t200_n11: return 0.027594076469540596f;
  t200_n12: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t200_n14;
  t200_n13: return -0.013597220182418823f;
  t200_n14: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t200_n16;
  t200_n15: return 0.10076768696308136f;
  t200_n16: return 0.10251886397600174f;
  t200_n17: if (E.getNumReferences() >= 3368810912 /*417741.0*/) goto t200_n19;
  t200_n18: return 0.015869563445448875f;
  t200_n19: return -0.02788316085934639f;
  t200_n20: return 0.001006401376798749f;
  t200_n21: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t200_n41;
  t200_n22: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t200_n32;
  t200_n23: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n25;
  t200_n24: return -0.08013244718313217f;
  t200_n25: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t200_n31;
  t200_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t200_n28;
  t200_n27: return -0.00240090093575418f;
  t200_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t200_n30;
  t200_n29: return 0.06891675293445587f;
  t200_n30: return 0.10702499747276306f;
  t200_n31: return -0.11874815076589584f;
  t200_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t200_n34;
  t200_n33: return 0.02521582692861557f;
  t200_n34: if (E.getNumReferences() >= 3288375296 /*514.5*/) goto t200_n38;
  t200_n35: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t200_n37;
  t200_n36: return -0.4578693211078644f;
  t200_n37: return 0.11089428514242172f;
  t200_n38: if (E.getNumReferences() >= 3297292288 /*1093.5*/) goto t200_n40;
  t200_n39: return 0.07160279899835587f;
  t200_n40: return 0.13958141207695007f;
  t200_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t200_n45;
  t200_n42: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t200_n44;
  t200_n43: return 0.016061749309301376f;
  t200_n44: return -0.19599084556102753f;
  t200_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t200_n51;
  t200_n46: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t200_n48;
  t200_n47: return -0.3478417992591858f;
  t200_n48: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t200_n50;
  t200_n49: return 0.03870562091469765f;
  t200_n50: return 0.08140164613723755f;
  t200_n51: if (E.getNumReferences() >= 3286646784 /*460.5*/) goto t200_n53;
  t200_n52: return 0.097058966755867f;
  t200_n53: return 0.05083946883678436f;
  t200_n54: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t200_n60;
  t200_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n59;
  t200_n56: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t200_n58;
  t200_n57: return -0.02404453046619892f;
  t200_n58: return -0.7521237134933472f;
  t200_n59: return 0.07862231135368347f;
  t200_n60: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t200_n76;
  t200_n61: if (E.getNumReferences() >= 3287891968 /*498.5*/) goto t200_n75;
  t200_n62: if (E.getNumReferences() >= 3285139456 /*414.5*/) goto t200_n66;
  t200_n63: if (E.getNumReferences() >= 3284582400 /*397.5*/) goto t200_n65;
  t200_n64: return 0.08999814838171005f;
  t200_n65: return -0.18514394760131836f;
  t200_n66: if (E.getNumReferences() >= 3285549056 /*427.0*/) goto t200_n68;
  t200_n67: return 0.12815919518470764f;
  t200_n68: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t200_n74;
  t200_n69: if (E.getNumReferences() >= 3286089728 /*443.5*/) goto t200_n71;
  t200_n70: return -0.09302203357219696f;
  t200_n71: if (E.getNumReferences() >= 3286761472 /*464.0*/) goto t200_n73;
  t200_n72: return 0.12317033857107162f;
  t200_n73: return -0.44815200567245483f;
  t200_n74: return -0.32383430004119873f;
  t200_n75: return 0.12796635925769806f;
  t200_n76: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t200_n92;
  t200_n77: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t200_n79;
  t200_n78: return -0.41919776797294617f;
  t200_n79: if (E.getNumReferences() >= 3297521664 /*1121.5*/) goto t200_n91;
  t200_n80: if (E.getNumReferences() >= 3296882688 /*1043.5*/) goto t200_n90;
  t200_n81: if (E.getNumReferences() >= 3292299264 /*754.0*/) goto t200_n83;
  t200_n82: return 0.035980224609375f;
  t200_n83: if (E.getNumReferences() >= 3292848128 /*787.5*/) goto t200_n85;
  t200_n84: return 0.11148767918348312f;
  t200_n85: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t200_n87;
  t200_n86: return -0.10457425564527512f;
  t200_n87: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t200_n89;
  t200_n88: return 0.134748175740242f;
  t200_n89: return -0.11112749576568604f;
  t200_n90: return 0.11340342462062836f;
  t200_n91: return 0.007730187848210335f;
  t200_n92: return -0.1477203667163849f;
  t200_n93: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t200_n161;
  t200_n94: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t200_n160;
  t200_n95: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t200_n145;
  t200_n96: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t200_n106;
  t200_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t200_n99;
  t200_n98: return -0.2675946056842804f;
  t200_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace))) goto t200_n101;
  t200_n100: return -0.019987337291240692f;
  t200_n101: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n105;
  t200_n102: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t200_n104;
  t200_n103: return -0.19970297813415527f;
  t200_n104: return 0.1081521138548851f;
  t200_n105: return 0.1054546982049942f;
  t200_n106: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t200_n110;
  t200_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t200_n109;
  t200_n108: return -0.10578344017267227f;
  t200_n109: return 0.09528617560863495f;
  t200_n110: if (E.getNumReferences() >= 3293175808 /*807.5*/) goto t200_n140;
  t200_n111: if (E.getNumReferences() >= 3293093888 /*802.5*/) goto t200_n137;
  t200_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t200_n130;
  t200_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t200_n115;
  t200_n114: return 0.010697031393647194f;
  t200_n115: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t200_n125;
  t200_n116: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t200_n120;
  t200_n117: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t200_n119;
  t200_n118: return -0.013346631079912186f;
  t200_n119: return 0.10330014675855637f;
  t200_n120: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t200_n122;
  t200_n121: return 0.0971500352025032f;
  t200_n122: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t200_n124;
  t200_n123: return -0.32893604040145874f;
  t200_n124: return 0.1007758378982544f;
  t200_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n127;
  t200_n126: return -0.10430184006690979f;
  t200_n127: if (E.getNumReferences() >= 3290292224 /*631.5*/) goto t200_n129;
  t200_n128: return 0.12610983848571777f;
  t200_n129: return 0.12385508418083191f;
  t200_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t200_n136;
  t200_n131: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t200_n135;
  t200_n132: if (E.getNumReferences() >= 3290480640 /*643.0*/) goto t200_n134;
  t200_n133: return 0.11687019467353821f;
  t200_n134: return 0.10352666676044464f;
  t200_n135: return -0.09769793599843979f;
  t200_n136: return 0.13024626672267914f;
  t200_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n139;
  t200_n138: return 0.12608838081359863f;
  t200_n139: return -0.2968344986438751f;
  t200_n140: if (E.getNumReferences() >= 3295215616 /*932.0*/) goto t200_n144;
  t200_n141: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t200_n143;
  t200_n142: return -0.15216290950775146f;
  t200_n143: return -0.4418107569217682f;
  t200_n144: return 0.03096916526556015f;
  t200_n145: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t200_n151;
  t200_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t200_n148;
  t200_n147: return -0.41609635949134827f;
  t200_n148: if (E.getNumReferences() >= 3293388800 /*820.5*/) goto t200_n150;
  t200_n149: return 0.10704030841588974f;
  t200_n150: return 0.09433823823928833f;
  t200_n151: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n153;
  t200_n152: return -0.017312856391072273f;
  t200_n153: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t200_n157;
  t200_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t200_n156;
  t200_n155: return -0.06997493654489517f;
  t200_n156: return 0.08372174948453903f;
  t200_n157: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t200_n159;
  t200_n158: return 0.11033417284488678f;
  t200_n159: return 0.04040052741765976f;
  t200_n160: return 0.00037145978421904147f;
  t200_n161: if (E.getNumReferences() >= 3289505792 /*583.5*/) goto t200_n173;
  t200_n162: if (E.getNumReferences() >= 3289260032 /*568.5*/) goto t200_n172;
  t200_n163: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n171;
  t200_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t200_n166;
  t200_n165: return 0.08163942396640778f;
  t200_n166: if (E.getNumReferences() >= 3285254144 /*418.0*/) goto t200_n168;
  t200_n167: return 0.10455629229545593f;
  t200_n168: if (E.getNumReferences() >= 3287810048 /*496.0*/) goto t200_n170;
  t200_n169: return -0.06424299627542496f;
  t200_n170: return 0.11506509780883789f;
  t200_n171: return -0.08444564789533615f;
  t200_n172: return 0.17366193234920502f;
  t200_n173: return 0.026978034526109695f;
  t200_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t200_n242;
  t200_n175: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t200_n241;
  t200_n176: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t200_n236;
  t200_n177: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t200_n233;
  t200_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t200_n196;
  t200_n179: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t200_n181;
  t200_n180: return -0.10844459384679794f;
  t200_n181: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t200_n191;
  t200_n182: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t200_n184;
  t200_n183: return -0.5547927618026733f;
  t200_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n190;
  t200_n185: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n187;
  t200_n186: return 0.005056262016296387f;
  t200_n187: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t200_n189;
  t200_n188: return 0.0035454982426017523f;
  t200_n189: return 0.05670947581529617f;
  t200_n190: return -0.534878134727478f;
  t200_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n195;
  t200_n192: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t200_n194;
  t200_n193: return 0.23144197463989258f;
  t200_n194: return 0.061205800622701645f;
  t200_n195: return -0.055401671677827835f;
  t200_n196: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t200_n216;
  t200_n197: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t200_n203;
  t200_n198: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t200_n202;
  t200_n199: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t200_n201;
  t200_n200: return 0.13532572984695435f;
  t200_n201: return -0.6721227765083313f;
  t200_n202: return 0.06481960415840149f;
  t200_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t200_n215;
  t200_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t200_n210;
  t200_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t200_n207;
  t200_n206: return -0.08708500117063522f;
  t200_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n209;
  t200_n208: return 0.05851421132683754f;
  t200_n209: return -0.033992599695920944f;
  t200_n210: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n214;
  t200_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t200_n213;
  t200_n212: return 0.048994265496730804f;
  t200_n213: return 0.08910602331161499f;
  t200_n214: return 0.01686248742043972f;
  t200_n215: return 0.12156980484724045f;
  t200_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t200_n226;
  t200_n217: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t200_n223;
  t200_n218: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n222;
  t200_n219: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t200_n221;
  t200_n220: return 0.05098274350166321f;
  t200_n221: return -0.06312844902276993f;
  t200_n222: return -0.298735111951828f;
  t200_n223: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t200_n225;
  t200_n224: return -0.31464478373527527f;
  t200_n225: return 0.0630483403801918f;
  t200_n226: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n230;
  t200_n227: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t200_n229;
  t200_n228: return 0.061335448175668716f;
  t200_n229: return -0.06283080577850342f;
  t200_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t200_n232;
  t200_n231: return 0.046680279076099396f;
  t200_n232: return 0.09778705984354019f;
  t200_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t200_n235;
  t200_n234: return -0.03723974525928497f;
  t200_n235: return -0.0038117794319987297f;
  t200_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t200_n240;
  t200_n237: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t200_n239;
  t200_n238: return -0.02326800487935543f;
  t200_n239: return 0.08717440068721771f;
  t200_n240: return 0.020330894738435745f;
  t200_n241: return 0.09055062383413315f;
  t200_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t200_n250;
  t200_n243: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t200_n249;
  t200_n244: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t200_n248;
  t200_n245: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t200_n247;
  t200_n246: return 0.06812115758657455f;
  t200_n247: return -0.15175892412662506f;
  t200_n248: return 0.09492678195238113f;
  t200_n249: return -0.0011831175070255995f;
  t200_n250: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t200_n254;
  t200_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t200_n253;
  t200_n252: return -0.16994914412498474f;
  t200_n253: return -0.00396287627518177f;
  t200_n254: return 0.014248006045818329f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree201(const Example& E) {
  t201_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t201_n244;
  t201_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t201_n3;
  t201_n2: return -0.00047630988410674036f;
  t201_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t201_n5;
  t201_n4: return -0.020651962608098984f;
  t201_n5: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t201_n47;
  t201_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t201_n32;
  t201_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n9;
  t201_n8: return -0.031234797090291977f;
  t201_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t201_n23;
  t201_n10: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t201_n12;
  t201_n11: return -0.005883995909243822f;
  t201_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t201_n14;
  t201_n13: return 0.02414948120713234f;
  t201_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t201_n16;
  t201_n15: return -0.1070014238357544f;
  t201_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t201_n18;
  t201_n17: return 0.0583610013127327f;
  t201_n18: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t201_n22;
  t201_n19: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n21;
  t201_n20: return 0.0958184003829956f;
  t201_n21: return -0.1305142641067505f;
  t201_n22: return -0.14398688077926636f;
  t201_n23: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t201_n25;
  t201_n24: return 0.020633716136217117f;
  t201_n25: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n27;
  t201_n26: return 0.009522299282252789f;
  t201_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n29;
  t201_n28: return -0.06988529860973358f;
  t201_n29: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t201_n31;
  t201_n30: return 0.0034042024053633213f;
  t201_n31: return -0.12430871278047562f;
  t201_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Namespace))) goto t201_n46;
  t201_n33: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t201_n43;
  t201_n34: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t201_n40;
  t201_n35: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t201_n37;
  t201_n36: return 0.027325663715600967f;
  t201_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n39;
  t201_n38: return 0.01176818273961544f;
  t201_n39: return 0.10403822362422943f;
  t201_n40: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t201_n42;
  t201_n41: return 0.15584753453731537f;
  t201_n42: return -0.07660208642482758f;
  t201_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t201_n45;
  t201_n44: return -0.010564321652054787f;
  t201_n45: return -0.015106831677258015f;
  t201_n46: return 0.061324089765548706f;
  t201_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t201_n61;
  t201_n48: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t201_n60;
  t201_n49: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t201_n51;
  t201_n50: return -0.08307820558547974f;
  t201_n51: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t201_n59;
  t201_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t201_n54;
  t201_n53: return 0.052608489990234375f;
  t201_n54: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n58;
  t201_n55: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t201_n57;
  t201_n56: return 0.13191205263137817f;
  t201_n57: return 0.11210702359676361f;
  t201_n58: return 0.016776930540800095f;
  t201_n59: return -0.11934904009103775f;
  t201_n60: return 0.00021293730242177844f;
  t201_n61: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t201_n189;
  t201_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n64;
  t201_n63: return -0.03691780939698219f;
  t201_n64: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t201_n172;
  t201_n65: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t201_n87;
  t201_n66: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t201_n74;
  t201_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t201_n69;
  t201_n68: return -0.0006814105436205864f;
  t201_n69: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t201_n71;
  t201_n70: return 0.004518701694905758f;
  t201_n71: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n73;
  t201_n72: return 0.037177640944719315f;
  t201_n73: return 0.10476706922054291f;
  t201_n74: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t201_n76;
  t201_n75: return 0.035150814801454544f;
  t201_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t201_n78;
  t201_n77: return -0.10397011041641235f;
  t201_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n80;
  t201_n79: return -0.016626425087451935f;
  t201_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t201_n82;
  t201_n81: return 0.0668802410364151f;
  t201_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n86;
  t201_n83: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t201_n85;
  t201_n84: return -0.044243887066841125f;
  t201_n85: return 0.024830272421240807f;
  t201_n86: return 0.01617601327598095f;
  t201_n87: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t201_n167;
  t201_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t201_n90;
  t201_n89: return 0.11046609282493591f;
  t201_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n100;
  t201_n91: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t201_n99;
  t201_n92: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t201_n94;
  t201_n93: return -0.18966834247112274f;
  t201_n94: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t201_n96;
  t201_n95: return -0.028266282752156258f;
  t201_n96: if (E.getNumReferences() >= 3270246400 /*118.0*/) goto t201_n98;
  t201_n97: return 0.12146101146936417f;
  t201_n98: return -0.024373851716518402f;
  t201_n99: return 0.09922514110803604f;
  t201_n100: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t201_n120;
  t201_n101: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t201_n115;
  t201_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t201_n106;
  t201_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n105;
  t201_n104: return -0.2812710404396057f;
  t201_n105: return 0.22685612738132477f;
  t201_n106: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t201_n110;
  t201_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n109;
  t201_n108: return -0.1986079216003418f;
  t201_n109: return 0.11877632886171341f;
  t201_n110: if (E.getNumReferences() >= 3212836864 /*1.0*/) goto t201_n114;
  t201_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n113;
  t201_n112: return -0.33209228515625f;
  t201_n113: return 0.16963447630405426f;
  t201_n114: return 0.1350494921207428f;
  t201_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t201_n119;
  t201_n116: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n118;
  t201_n117: return 0.10262347757816315f;
  t201_n118: return 0.0731617882847786f;
  t201_n119: return 0.1172204539179802f;
  t201_n120: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t201_n156;
  t201_n121: if (E.getNumReferences() >= 3268673536 /*106.0*/) goto t201_n155;
  t201_n122: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t201_n128;
  t201_n123: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t201_n127;
  t201_n124: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t201_n126;
  t201_n125: return 0.09519120305776596f;
  t201_n126: return 0.5164667963981628f;
  t201_n127: return -0.09019327163696289f;
  t201_n128: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t201_n136;
  t201_n129: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t201_n135;
  t201_n130: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n132;
  t201_n131: return -0.02377961575984955f;
  t201_n132: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t201_n134;
  t201_n133: return 0.10427368432283401f;
  t201_n134: return 0.18188223242759705f;
  t201_n135: return -0.0031540836207568645f;
  t201_n136: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t201_n154;
  t201_n137: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t201_n153;
  t201_n138: if (E.getNumReferences() >= 3249012736 /*21.0*/) goto t201_n148;
  t201_n139: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t201_n143;
  t201_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t201_n142;
  t201_n141: return 0.21293038129806519f;
  t201_n142: return 0.13644184172153473f;
  t201_n143: if (E.getNumReferences() >= 3246915584 /*17.0*/) goto t201_n145;
  t201_n144: return -0.036501444876194f;
  t201_n145: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t201_n147;
  t201_n146: return 0.10753285139799118f;
  t201_n147: return 0.115845687687397f;
  t201_n148: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t201_n150;
  t201_n149: return 0.12745270133018494f;
  t201_n150: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t201_n152;
  t201_n151: return 0.1079799234867096f;
  t201_n152: return -0.14331559836864471f;
  t201_n153: return 0.07231254875659943f;
  t201_n154: return -0.050296034663915634f;
  t201_n155: return -0.1857909858226776f;
  t201_n156: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n164;
  t201_n157: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t201_n159;
  t201_n158: return 0.1213027834892273f;
  t201_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t201_n163;
  t201_n160: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t201_n162;
  t201_n161: return 0.04954739287495613f;
  t201_n162: return 0.10508548468351364f;
  t201_n163: return 0.13441722095012665f;
  t201_n164: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t201_n166;
  t201_n165: return 0.13334481418132782f;
  t201_n166: return 0.16770081222057343f;
  t201_n167: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t201_n169;
  t201_n168: return 0.05412573367357254f;
  t201_n169: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t201_n171;
  t201_n170: return 0.10170585662126541f;
  t201_n171: return -2.5279407501220703f;
  t201_n172: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t201_n176;
  t201_n173: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t201_n175;
  t201_n174: return -0.002667909488081932f;
  t201_n175: return -0.059947021305561066f;
  t201_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n178;
  t201_n177: return -0.0052080461755394936f;
  t201_n178: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t201_n180;
  t201_n179: return 0.10757023841142654f;
  t201_n180: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t201_n188;
  t201_n181: if (E.getNumReferences() >= 3229614080 /*4.0*/) goto t201_n183;
  t201_n182: return 0.016508983448147774f;
  t201_n183: if (E.getNumReferences() >= 3257925632 /*44.0*/) goto t201_n187;
  t201_n184: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t201_n186;
  t201_n185: return 0.12457022070884705f;
  t201_n186: return 0.08913838863372803f;
  t201_n187: return 0.0803370326757431f;
  t201_n188: return 0.0006641975487582386f;
  t201_n189: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t201_n197;
  t201_n190: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n192;
  t201_n191: return -0.0005617315182462335f;
  t201_n192: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t201_n196;
  t201_n193: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t201_n195;
  t201_n194: return -0.006125560961663723f;
  t201_n195: return -0.07941841334104538f;
  t201_n196: return 0.02732391469180584f;
  t201_n197: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t201_n199;
  t201_n198: return 0.017030807211995125f;
  t201_n199: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t201_n205;
  t201_n200: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t201_n202;
  t201_n201: return -0.15263499319553375f;
  t201_n202: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t201_n204;
  t201_n203: return 0.1354769468307495f;
  t201_n204: return 0.054250650107860565f;
  t201_n205: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t201_n209;
  t201_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t201_n208;
  t201_n207: return 0.02970978058874607f;
  t201_n208: return 0.20321883261203766f;
  t201_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t201_n211;
  t201_n210: return -0.017637385055422783f;
  t201_n211: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t201_n215;
  t201_n212: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t201_n214;
  t201_n213: return -0.031619805842638016f;
  t201_n214: return 0.11041481792926788f;
  t201_n215: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t201_n243;
  t201_n216: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t201_n230;
  t201_n217: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t201_n219;
  t201_n218: return 0.014305219985544682f;
  t201_n219: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t201_n221;
  t201_n220: return 0.05810430273413658f;
  t201_n221: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n223;
  t201_n222: return 0.05525245890021324f;
  t201_n223: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t201_n229;
  t201_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n226;
  t201_n225: return -0.14324845373630524f;
  t201_n226: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t201_n228;
  t201_n227: return 0.1179121807217598f;
  t201_n228: return 0.019900141283869743f;
  t201_n229: return -0.04383092001080513f;
  t201_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t201_n232;
  t201_n231: return 0.008638624101877213f;
  t201_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t201_n242;
  t201_n233: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t201_n235;
  t201_n234: return 0.018621103838086128f;
  t201_n235: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t201_n239;
  t201_n236: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t201_n238;
  t201_n237: return 0.11149800568819046f;
  t201_n238: return 0.09242136031389236f;
  t201_n239: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t201_n241;
  t201_n240: return 0.07976624369621277f;
  t201_n241: return 0.02024233154952526f;
  t201_n242: return -0.058991286903619766f;
  t201_n243: return 0.002316157566383481f;
  t201_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t201_n246;
  t201_n245: return 0.007135366555303335f;
  t201_n246: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t201_n254;
  t201_n247: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t201_n253;
  t201_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t201_n252;
  t201_n249: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t201_n251;
  t201_n250: return 0.06431876122951508f;
  t201_n251: return -0.14445452392101288f;
  t201_n252: return 0.1008845865726471f;
  t201_n253: return -0.0008709663525223732f;
  t201_n254: return 0.008364851586520672f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree202(const Example& E) {
  t202_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t202_n254;
  t202_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t202_n3;
  t202_n2: return -0.000392021203879267f;
  t202_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n5;
  t202_n4: return -0.020546546205878258f;
  t202_n5: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t202_n253;
  t202_n6: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t202_n176;
  t202_n7: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t202_n21;
  t202_n8: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n10;
  t202_n9: return 0.025431349873542786f;
  t202_n10: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t202_n12;
  t202_n11: return -0.010474073700606823f;
  t202_n12: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t202_n20;
  t202_n13: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t202_n15;
  t202_n14: return 0.015953585505485535f;
  t202_n15: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t202_n19;
  t202_n16: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t202_n18;
  t202_n17: return 0.10663313418626785f;
  t202_n18: return -0.021021706983447075f;
  t202_n19: return 0.0718604028224945f;
  t202_n20: return 0.014327243901789188f;
  t202_n21: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t202_n71;
  t202_n22: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t202_n60;
  t202_n23: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n29;
  t202_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t202_n26;
  t202_n25: return 0.019530437886714935f;
  t202_n26: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t202_n28;
  t202_n27: return -0.02870994433760643f;
  t202_n28: return 0.026728054508566856f;
  t202_n29: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t202_n59;
  t202_n30: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t202_n42;
  t202_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n39;
  t202_n32: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t202_n36;
  t202_n33: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t202_n35;
  t202_n34: return -0.05015278607606888f;
  t202_n35: return -0.13671055436134338f;
  t202_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n38;
  t202_n37: return 0.04896999150514603f;
  t202_n38: return -0.017691675573587418f;
  t202_n39: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t202_n41;
  t202_n40: return 0.2717243731021881f;
  t202_n41: return 0.01260468177497387f;
  t202_n42: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n52;
  t202_n43: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t202_n45;
  t202_n44: return 0.11815714836120605f;
  t202_n45: if (E.getNumReferences() >= 3278929920 /*240.5*/) goto t202_n51;
  t202_n46: if (E.getNumReferences() >= 3277094912 /*212.5*/) goto t202_n50;
  t202_n47: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t202_n49;
  t202_n48: return 0.09418761730194092f;
  t202_n49: return -0.40954989194869995f;
  t202_n50: return 0.12077296525239944f;
  t202_n51: return -0.0338008813560009f;
  t202_n52: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t202_n54;
  t202_n53: return -0.10172433406114578f;
  t202_n54: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t202_n58;
  t202_n55: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n57;
  t202_n56: return -0.15420381724834442f;
  t202_n57: return 0.12863722443580627f;
  t202_n58: return 0.0029230352956801653f;
  t202_n59: return 0.13407723605632782f;
  t202_n60: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t202_n68;
  t202_n61: if (E.getNumReferences() >= 3332773120 /*21258.5*/) goto t202_n67;
  t202_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n66;
  t202_n63: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n65;
  t202_n64: return -0.10243230313062668f;
  t202_n65: return -0.3753570020198822f;
  t202_n66: return -0.04708632081747055f;
  t202_n67: return 0.11495395749807358f;
  t202_n68: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t202_n70;
  t202_n69: return 0.1042371541261673f;
  t202_n70: return -0.1076095923781395f;
  t202_n71: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t202_n169;
  t202_n72: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t202_n160;
  t202_n73: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t202_n147;
  t202_n74: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t202_n92;
  t202_n75: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n79;
  t202_n76: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t202_n78;
  t202_n77: return -0.02151193656027317f;
  t202_n78: return -0.41180410981178284f;
  t202_n79: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t202_n87;
  t202_n80: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t202_n82;
  t202_n81: return 0.05984000116586685f;
  t202_n82: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t202_n84;
  t202_n83: return 0.07101621478796005f;
  t202_n84: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t202_n86;
  t202_n85: return -0.11073615401983261f;
  t202_n86: return 0.3095932602882385f;
  t202_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n91;
  t202_n88: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n90;
  t202_n89: return -0.13243135809898376f;
  t202_n90: return -0.0963142067193985f;
  t202_n91: return 0.049084920436143875f;
  t202_n92: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n102;
  t202_n93: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t202_n95;
  t202_n94: return -0.08604786545038223f;
  t202_n95: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n97;
  t202_n96: return 0.10194612294435501f;
  t202_n97: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t202_n99;
  t202_n98: return -0.1866455078125f;
  t202_n99: if (E.getNumReferences() >= 3262119936 /*60.0*/) goto t202_n101;
  t202_n100: return 0.0988018661737442f;
  t202_n101: return -0.14379720389842987f;
  t202_n102: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t202_n138;
  t202_n103: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t202_n117;
  t202_n104: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t202_n116;
  t202_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n107;
  t202_n106: return -0.005292579066008329f;
  t202_n107: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t202_n115;
  t202_n108: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t202_n110;
  t202_n109: return -0.020810218527913094f;
  t202_n110: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n112;
  t202_n111: return 0.11614035815000534f;
  t202_n112: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t202_n114;
  t202_n113: return 0.3005189597606659f;
  t202_n114: return -0.047438979148864746f;
  t202_n115: return -0.0004653522337321192f;
  t202_n116: return -0.03233924135565758f;
  t202_n117: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t202_n137;
  t202_n118: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t202_n130;
  t202_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n123;
  t202_n120: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n122;
  t202_n121: return -0.14967665076255798f;
  t202_n122: return -0.10642863810062408f;
  t202_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n125;
  t202_n124: return 0.14039413630962372f;
  t202_n125: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t202_n127;
  t202_n126: return -0.056577153503894806f;
  t202_n127: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t202_n129;
  t202_n128: return 0.1247502788901329f;
  t202_n129: return -0.10042941570281982f;
  t202_n130: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t202_n132;
  t202_n131: return 0.13789357244968414f;
  t202_n132: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t202_n134;
  t202_n133: return -0.03899272158741951f;
  t202_n134: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n136;
  t202_n135: return 0.173732727766037f;
  t202_n136: return 0.1176210567355156f;
  t202_n137: return 0.016466598957777023f;
  t202_n138: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t202_n142;
  t202_n139: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n141;
  t202_n140: return -0.6253217458724976f;
  t202_n141: return 0.0024388842284679413f;
  t202_n142: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t202_n146;
  t202_n143: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t202_n145;
  t202_n144: return -0.22135639190673828f;
  t202_n145: return 0.14149077236652374f;
  t202_n146: return -0.005164178553968668f;
  t202_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n149;
  t202_n148: return -1.1131967306137085f;
  t202_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n151;
  t202_n150: return 0.2980473041534424f;
  t202_n151: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t202_n159;
  t202_n152: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t202_n158;
  t202_n153: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t202_n157;
  t202_n154: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t202_n156;
  t202_n155: return 0.09587884694337845f;
  t202_n156: return 0.05607042461633682f;
  t202_n157: return -0.013476797379553318f;
  t202_n158: return -0.48523440957069397f;
  t202_n159: return 0.11382262408733368f;
  t202_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n166;
  t202_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t202_n165;
  t202_n162: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t202_n164;
  t202_n163: return -0.16498684883117676f;
  t202_n164: return -0.4348449409008026f;
  t202_n165: return -0.09280028939247131f;
  t202_n166: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t202_n168;
  t202_n167: return -0.028880596160888672f;
  t202_n168: return 0.031699128448963165f;
  t202_n169: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n171;
  t202_n170: return 0.11657475680112839f;
  t202_n171: if (E.getNumReferences() >= 3282731008 /*341.0*/) goto t202_n173;
  t202_n172: return 0.10956519097089767f;
  t202_n173: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n175;
  t202_n174: return 0.08614609390497208f;
  t202_n175: return -0.061129890382289886f;
  t202_n176: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t202_n180;
  t202_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n179;
  t202_n178: return -0.12940238416194916f;
  t202_n179: return 0.007057188544422388f;
  t202_n180: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t202_n232;
  t202_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t202_n183;
  t202_n182: return 0.02697604149580002f;
  t202_n183: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t202_n185;
  t202_n184: return -0.007079871837049723f;
  t202_n185: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t202_n193;
  t202_n186: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t202_n188;
  t202_n187: return 0.1266094297170639f;
  t202_n188: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t202_n190;
  t202_n189: return -0.0629008561372757f;
  t202_n190: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t202_n192;
  t202_n191: return 0.09022194892168045f;
  t202_n192: return 0.05763941630721092f;
  t202_n193: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t202_n223;
  t202_n194: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t202_n214;
  t202_n195: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t202_n197;
  t202_n196: return -0.1675855815410614f;
  t202_n197: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t202_n201;
  t202_n198: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t202_n200;
  t202_n199: return -0.2819025218486786f;
  t202_n200: return 0.07519113272428513f;
  t202_n201: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t202_n213;
  t202_n202: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t202_n212;
  t202_n203: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t202_n205;
  t202_n204: return 0.1014089286327362f;
  t202_n205: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t202_n207;
  t202_n206: return -0.027563277631998062f;
  t202_n207: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t202_n211;
  t202_n208: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n210;
  t202_n209: return 0.08653315901756287f;
  t202_n210: return -0.058416418731212616f;
  t202_n211: return -0.5225893259048462f;
  t202_n212: return 0.11094887554645538f;
  t202_n213: return -0.14154313504695892f;
  t202_n214: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t202_n222;
  t202_n215: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t202_n221;
  t202_n216: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t202_n218;
  t202_n217: return -0.10057640075683594f;
  t202_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t202_n220;
  t202_n219: return 0.09928549081087112f;
  t202_n220: return 0.07748521119356155f;
  t202_n221: return 0.11398769915103912f;
  t202_n222: return -0.09411483258008957f;
  t202_n223: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t202_n225;
  t202_n224: return -0.08721726387739182f;
  t202_n225: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t202_n227;
  t202_n226: return -0.19217398762702942f;
  t202_n227: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t202_n231;
  t202_n228: if (E.getNumReferences() >= 3260153856 /*52.5*/) goto t202_n230;
  t202_n229: return 0.12368885427713394f;
  t202_n230: return 0.050787486135959625f;
  t202_n231: return 0.016926156356930733f;
  t202_n232: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t202_n250;
  t202_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t202_n241;
  t202_n234: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t202_n240;
  t202_n235: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t202_n237;
  t202_n236: return -0.18159723281860352f;
  t202_n237: if (E.getNumReferences() >= 3243245568 /*13.0*/) goto t202_n239;
  t202_n238: return 0.12364489585161209f;
  t202_n239: return -0.024701323360204697f;
  t202_n240: return 0.09911344200372696f;
  t202_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n249;
  t202_n242: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t202_n246;
  t202_n243: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t202_n245;
  t202_n244: return 0.09773346036672592f;
  t202_n245: return 0.07031174749135971f;
  t202_n246: if (E.getNumReferences() >= 3247439872 /*18.0*/) goto t202_n248;
  t202_n247: return 0.08177152276039124f;
  t202_n248: return -0.3197402358055115f;
  t202_n249: return -0.028537483885884285f;
  t202_n250: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n252;
  t202_n251: return 0.06423261761665344f;
  t202_n252: return 0.011914726346731186f;
  t202_n253: return 0.0003895792178809643f;
  t202_n254: return 0.007739389315247536f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree203(const Example& E) {
  t203_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t203_n254;
  t203_n1: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t203_n241;
  t203_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t203_n4;
  t203_n3: return -0.07001685351133347f;
  t203_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t203_n6;
  t203_n5: return -0.001069108140654862f;
  t203_n6: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t203_n34;
  t203_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Other))) goto t203_n11;
  t203_n8: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t203_n10;
  t203_n9: return -0.015707531943917274f;
  t203_n10: return -0.004269205033779144f;
  t203_n11: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t203_n33;
  t203_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t203_n16;
  t203_n13: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t203_n15;
  t203_n14: return 0.07858257740736008f;
  t203_n15: return 0.025970419868826866f;
  t203_n16: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t203_n18;
  t203_n17: return 0.020848432555794716f;
  t203_n18: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t203_n32;
  t203_n19: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t203_n21;
  t203_n20: return 0.061219025403261185f;
  t203_n21: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t203_n25;
  t203_n22: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t203_n24;
  t203_n23: return 0.10719464719295502f;
  t203_n24: return 0.08842584490776062f;
  t203_n25: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t203_n27;
  t203_n26: return -0.011043858714401722f;
  t203_n27: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t203_n29;
  t203_n28: return 0.11826110631227493f;
  t203_n29: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t203_n31;
  t203_n30: return 0.008819677866995335f;
  t203_n31: return 0.13203583657741547f;
  t203_n32: return -0.11302810162305832f;
  t203_n33: return -0.03406423702836037f;
  t203_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t203_n212;
  t203_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t203_n47;
  t203_n36: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t203_n40;
  t203_n37: if (E.getNumReferences() >= 3249012736 /*21.0*/) goto t203_n39;
  t203_n38: return -0.08527097851037979f;
  t203_n39: return 0.10761498659849167f;
  t203_n40: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t203_n42;
  t203_n41: return -0.018741009756922722f;
  t203_n42: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t203_n44;
  t203_n43: return -0.05030452087521553f;
  t203_n44: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t203_n46;
  t203_n45: return 0.10492318123579025f;
  t203_n46: return 0.04837169125676155f;
  t203_n47: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t203_n211;
  t203_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t203_n64;
  t203_n49: if (E.getNumReferences() >= 3277193216 /*214.0*/) goto t203_n61;
  t203_n50: if (E.getNumReferences() >= 3272572928 /*143.5*/) goto t203_n60;
  t203_n51: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t203_n57;
  t203_n52: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t203_n54;
  t203_n53: return -0.021546589210629463f;
  t203_n54: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t203_n56;
  t203_n55: return -0.2731027603149414f;
  t203_n56: return -0.038747262209653854f;
  t203_n57: if (E.getNumReferences() >= 3269132288 /*109.5*/) goto t203_n59;
  t203_n58: return 0.14069095253944397f;
  t203_n59: return 0.04652441665530205f;
  t203_n60: return -0.26008278131484985f;
  t203_n61: if (E.getNumReferences() >= 3277848576 /*224.0*/) goto t203_n63;
  t203_n62: return 0.09280730783939362f;
  t203_n63: return 0.002450913656502962f;
  t203_n64: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t203_n208;
  t203_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t203_n113;
  t203_n66: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t203_n82;
  t203_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t203_n69;
  t203_n68: return 0.03187849000096321f;
  t203_n69: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t203_n77;
  t203_n70: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t203_n74;
  t203_n71: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t203_n73;
  t203_n72: return -0.09773164242506027f;
  t203_n73: return 0.08698362112045288f;
  t203_n74: if (E.getNumReferences() >= 3270377472 /*119.0*/) goto t203_n76;
  t203_n75: return 0.1106627881526947f;
  t203_n76: return 0.03476638346910477f;
  t203_n77: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t203_n79;
  t203_n78: return 0.023855380713939667f;
  t203_n79: if (E.getNumReferences() >= 3247439872 /*18.0*/) goto t203_n81;
  t203_n80: return 0.12351249158382416f;
  t203_n81: return -0.23355883359909058f;
  t203_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t203_n86;
  t203_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t203_n85;
  t203_n84: return -0.1608843207359314f;
  t203_n85: return -0.09660622477531433f;
  t203_n86: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t203_n98;
  t203_n87: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t203_n97;
  t203_n88: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t203_n94;
  t203_n89: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t203_n93;
  t203_n90: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t203_n92;
  t203_n91: return 0.09874720126390457f;
  t203_n92: return -0.12102296203374863f;
  t203_n93: return -0.33819615840911865f;
  t203_n94: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t203_n96;
  t203_n95: return 0.1267314851284027f;
  t203_n96: return -0.5076966285705566f;
  t203_n97: return 0.10413751006126404f;
  t203_n98: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t203_n108;
  t203_n99: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t203_n101;
  t203_n100: return -0.15072515606880188f;
  t203_n101: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t203_n107;
  t203_n102: if (E.getNumReferences() >= 3263299584 /*65.0*/) goto t203_n106;
  t203_n103: if (E.getNumReferences() >= 3259760640 /*51.0*/) goto t203_n105;
  t203_n104: return 0.09894946962594986f;
  t203_n105: return -0.2399912029504776f;
  t203_n106: return 0.11795897781848907f;
  t203_n107: return -0.04994627460837364f;
  t203_n108: if (E.getNumReferences() >= 3212836864 /*1.0*/) goto t203_n112;
  t203_n109: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t203_n111;
  t203_n110: return -0.41311731934547424f;
  t203_n111: return 0.11614057421684265f;
  t203_n112: return -0.4917946457862854f;
  t203_n113: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t203_n207;
  t203_n114: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t203_n152;
  t203_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t203_n151;
  t203_n116: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t203_n122;
  t203_n117: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t203_n119;
  t203_n118: return 0.03690040111541748f;
  t203_n119: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t203_n121;
  t203_n120: return -0.04743293672800064f;
  t203_n121: return 0.04641037806868553f;
  t203_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t203_n128;
  t203_n123: if (E.getNumReferences() >= 3251634176 /*26.0*/) goto t203_n127;
  t203_n124: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t203_n126;
  t203_n125: return -0.2032732516527176f;
  t203_n126: return 0.12471210211515427f;
  t203_n127: return -0.015373938716948032f;
  t203_n128: if (E.getNumReferences() >= 3289767936 /*599.5*/) goto t203_n142;
  t203_n129: if (E.getNumReferences() >= 3277750272 /*222.5*/) goto t203_n139;
  t203_n130: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t203_n132;
  t203_n131: return -0.06270124763250351f;
  t203_n132: if (E.getNumReferences() >= 3271163904 /*125.0*/) goto t203_n138;
  t203_n133: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t203_n135;
  t203_n134: return 0.024718446657061577f;
  t203_n135: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t203_n137;
  t203_n136: return 0.10964567214250565f;
  t203_n137: return -0.24272985756397247f;
  t203_n138: return -0.03254718333482742f;
  t203_n139: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t203_n141;
  t203_n140: return -0.25791865587234497f;
  t203_n141: return 0.009174668230116367f;
  t203_n142: if (E.getNumReferences() >= 3293167616 /*807.0*/) goto t203_n148;
  t203_n143: if (E.getNumReferences() >= 3292635136 /*774.5*/) goto t203_n147;
  t203_n144: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t203_n146;
  t203_n145: return 0.09523293375968933f;
  t203_n146: return 0.0044600204564630985f;
  t203_n147: return 0.09941401332616806f;
  t203_n148: if (E.getNumReferences() >= 3296649216 /*1019.5*/) goto t203_n150;
  t203_n149: return -0.3356894254684448f;
  t203_n150: return -0.003472345881164074f;
  t203_n151: return 0.027970878407359123f;
  t203_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t203_n204;
  t203_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t203_n185;
  t203_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t203_n160;
  t203_n155: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t203_n157;
  t203_n156: return -0.060866374522447586f;
  t203_n157: if (E.getNumReferences() >= 3268804608 /*107.0*/) goto t203_n159;
  t203_n158: return 0.11832994222640991f;
  t203_n159: return 0.013701925985515118f;
  t203_n160: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t203_n178;
  t203_n161: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t203_n177;
  t203_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t203_n172;
  t203_n163: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t203_n165;
  t203_n164: return 0.19069983065128326f;
  t203_n165: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t203_n167;
  t203_n166: return 0.05857449769973755f;
  t203_n167: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t203_n171;
  t203_n168: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t203_n170;
  t203_n169: return 0.15460141003131866f;
  t203_n170: return 0.12643741071224213f;
  t203_n171: return -0.000344025349477306f;
  t203_n172: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t203_n176;
  t203_n173: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t203_n175;
  t203_n174: return 0.18423554301261902f;
  t203_n175: return -0.1833265721797943f;
  t203_n176: return 0.060600396245718f;
  t203_n177: return -0.0781233161687851f;
  t203_n178: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t203_n182;
  t203_n179: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t203_n181;
  t203_n180: return 0.009707543067634106f;
  t203_n181: return 0.08446159213781357f;
  t203_n182: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t203_n184;
  t203_n183: return -0.10447164624929428f;
  t203_n184: return 0.12452411651611328f;
  t203_n185: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t203_n189;
  t203_n186: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t203_n188;
  t203_n187: return 0.056155260652303696f;
  t203_n188: return 0.11779310554265976f;
  t203_n189: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t203_n191;
  t203_n190: return 0.054456256330013275f;
  t203_n191: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t203_n201;
  t203_n192: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t203_n196;
  t203_n193: if (E.getNumReferences() >= 3235905536 /*7.0*/) goto t203_n195;
  t203_n194: return 0.09893069416284561f;
  t203_n195: return -0.017664290964603424f;
  t203_n196: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t203_n198;
  t203_n197: return 0.12546870112419128f;
  t203_n198: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t203_n200;
  t203_n199: return 0.12453731894493103f;
  t203_n200: return -0.007627296261489391f;
  t203_n201: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t203_n203;
  t203_n202: return -0.1804688274860382f;
  t203_n203: return 0.10501769185066223f;
  t203_n204: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t203_n206;
  t203_n205: return 0.18283188343048096f;
  t203_n206: return 0.14116662740707397f;
  t203_n207: return -0.01603839360177517f;
  t203_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t203_n210;
  t203_n209: return 0.027564693242311478f;
  t203_n210: return -0.03238387778401375f;
  t203_n211: return 0.0007103539537638426f;
  t203_n212: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t203_n220;
  t203_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t203_n215;
  t203_n214: return -0.05193287879228592f;
  t203_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t203_n217;
  t203_n216: return 0.004684971179813147f;
  t203_n217: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t203_n219;
  t203_n218: return 0.0869184359908104f;
  t203_n219: return 0.021947575733065605f;
  t203_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t203_n232;
  t203_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t203_n223;
  t203_n222: return 0.0048154969699680805f;
  t203_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t203_n227;
  t203_n224: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t203_n226;
  t203_n225: return 0.025093426927924156f;
  t203_n226: return 0.04000544920563698f;
  t203_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t203_n229;
  t203_n228: return -0.004522291943430901f;
  t203_n229: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t203_n231;
  t203_n230: return 0.025130782276391983f;
  t203_n231: return -0.018524421378970146f;
  t203_n232: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t203_n240;
  t203_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t203_n239;
  t203_n234: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t203_n238;
  t203_n235: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t203_n237;
  t203_n236: return 0.09194625914096832f;
  t203_n237: return 0.0959152951836586f;
  t203_n238: return 0.049499012529850006f;
  t203_n239: return 0.06190428137779236f;
  t203_n240: return -0.040968891233205795f;
  t203_n241: if (E.getNumReferences() >= 3284877312 /*406.5*/) goto t203_n243;
  t203_n242: return -0.03519764542579651f;
  t203_n243: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t203_n253;
  t203_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t203_n252;
  t203_n245: if (E.getNumReferences() >= 3298754560 /*1272.0*/) goto t203_n251;
  t203_n246: if (E.getNumReferences() >= 3294642176 /*897.0*/) goto t203_n250;
  t203_n247: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t203_n249;
  t203_n248: return -0.18817374110221863f;
  t203_n249: return 0.5471271872520447f;
  t203_n250: return 0.21484492719173431f;
  t203_n251: return 0.07575211673974991f;
  t203_n252: return 0.06344889104366302f;
  t203_n253: return -0.06715303659439087f;
  t203_n254: return 0.006851886864751577f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree204(const Example& E) {
  t204_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t204_n2;
  t204_n1: return -0.0010963560780510306f;
  t204_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t204_n34;
  t204_n3: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t204_n21;
  t204_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t204_n20;
  t204_n5: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t204_n7;
  t204_n6: return -0.0711849257349968f;
  t204_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n19;
  t204_n8: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t204_n18;
  t204_n9: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t204_n17;
  t204_n10: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t204_n12;
  t204_n11: return -0.2646870017051697f;
  t204_n12: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t204_n14;
  t204_n13: return 0.10979988425970078f;
  t204_n14: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t204_n16;
  t204_n15: return 0.0937657430768013f;
  t204_n16: return -0.7697036266326904f;
  t204_n17: return 0.09204669296741486f;
  t204_n18: return -0.44721490144729614f;
  t204_n19: return -0.020586606115102768f;
  t204_n20: return -0.003962843678891659f;
  t204_n21: if (E.getNumReferences() >= 3364952880 /*297177.5*/) goto t204_n33;
  t204_n22: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t204_n28;
  t204_n23: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t204_n25;
  t204_n24: return 0.0025958979967981577f;
  t204_n25: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n27;
  t204_n26: return 0.10233745723962784f;
  t204_n27: return 0.1061476320028305f;
  t204_n28: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t204_n30;
  t204_n29: return 0.029491014778614044f;
  t204_n30: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t204_n32;
  t204_n31: return -0.36295580863952637f;
  t204_n32: return 0.07101372629404068f;
  t204_n33: return -0.013606654480099678f;
  t204_n34: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t204_n108;
  t204_n35: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t204_n41;
  t204_n36: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t204_n40;
  t204_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n39;
  t204_n38: return -0.00812511146068573f;
  t204_n39: return 0.006912569515407085f;
  t204_n40: return -0.0029214732348918915f;
  t204_n41: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t204_n103;
  t204_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t204_n102;
  t204_n43: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t204_n91;
  t204_n44: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t204_n90;
  t204_n45: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t204_n89;
  t204_n46: if (E.getNumReferences() >= 3290464256 /*642.0*/) goto t204_n84;
  t204_n47: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t204_n49;
  t204_n48: return -0.03488090634346008f;
  t204_n49: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t204_n61;
  t204_n50: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t204_n52;
  t204_n51: return -0.1609598845243454f;
  t204_n52: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t204_n60;
  t204_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t204_n55;
  t204_n54: return 0.031987182796001434f;
  t204_n55: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t204_n59;
  t204_n56: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t204_n58;
  t204_n57: return 0.10598579049110413f;
  t204_n58: return -0.19904688000679016f;
  t204_n59: return 0.0999307706952095f;
  t204_n60: return -0.08891782909631729f;
  t204_n61: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t204_n73;
  t204_n62: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t204_n70;
  t204_n63: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t204_n65;
  t204_n64: return -0.06496193259954453f;
  t204_n65: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t204_n67;
  t204_n66: return -0.7120181322097778f;
  t204_n67: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t204_n69;
  t204_n68: return 0.11613253504037857f;
  t204_n69: return 0.10735166072845459f;
  t204_n70: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t204_n72;
  t204_n71: return 0.08232500404119492f;
  t204_n72: return -0.1313568651676178f;
  t204_n73: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t204_n75;
  t204_n74: return -0.0312974750995636f;
  t204_n75: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t204_n83;
  t204_n76: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t204_n82;
  t204_n77: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t204_n79;
  t204_n78: return 0.06947941333055496f;
  t204_n79: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t204_n81;
  t204_n80: return 0.1449146866798401f;
  t204_n81: return -0.17249280214309692f;
  t204_n82: return 0.11963776499032974f;
  t204_n83: return -0.0135641535744071f;
  t204_n84: if (E.getNumReferences() >= 3298725888 /*1268.5*/) goto t204_n88;
  t204_n85: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t204_n87;
  t204_n86: return 0.11106114834547043f;
  t204_n87: return 0.07700547575950623f;
  t204_n88: return -0.07914097607135773f;
  t204_n89: return 0.04083215817809105f;
  t204_n90: return -0.07814992964267731f;
  t204_n91: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t204_n101;
  t204_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t204_n98;
  t204_n93: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t204_n97;
  t204_n94: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t204_n96;
  t204_n95: return 0.12128569930791855f;
  t204_n96: return 0.051809608936309814f;
  t204_n97: return 0.0024388963356614113f;
  t204_n98: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t204_n100;
  t204_n99: return 0.028625503182411194f;
  t204_n100: return -0.09804204851388931f;
  t204_n101: return -0.006407593376934528f;
  t204_n102: return 0.026990137994289398f;
  t204_n103: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t204_n105;
  t204_n104: return 0.013408572413027287f;
  t204_n105: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t204_n107;
  t204_n106: return 0.07165194302797318f;
  t204_n107: return -0.019617535173892975f;
  t204_n108: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t204_n242;
  t204_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t204_n241;
  t204_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t204_n240;
  t204_n111: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t204_n123;
  t204_n112: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t204_n114;
  t204_n113: return -0.014430858194828033f;
  t204_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t204_n118;
  t204_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t204_n117;
  t204_n116: return -0.05928156524896622f;
  t204_n117: return -0.023894408717751503f;
  t204_n118: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t204_n122;
  t204_n119: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t204_n121;
  t204_n120: return 0.011307849548757076f;
  t204_n121: return 0.10342016816139221f;
  t204_n122: return -0.09151016175746918f;
  t204_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t204_n239;
  t204_n124: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t204_n146;
  t204_n125: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t204_n135;
  t204_n126: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t204_n128;
  t204_n127: return 0.0029458908829838037f;
  t204_n128: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t204_n132;
  t204_n129: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t204_n131;
  t204_n130: return 0.10118865966796875f;
  t204_n131: return 0.12099126726388931f;
  t204_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t204_n134;
  t204_n133: return 0.05446150153875351f;
  t204_n134: return 0.11727790534496307f;
  t204_n135: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t204_n137;
  t204_n136: return -0.17428363859653473f;
  t204_n137: if (E.getNumReferences() >= 3324926976 /*11159.0*/) goto t204_n139;
  t204_n138: return -0.027245130389928818f;
  t204_n139: if (E.getNumReferences() >= 3327628800 /*13797.5*/) goto t204_n145;
  t204_n140: if (E.getNumReferences() >= 3327574016 /*13744.0*/) goto t204_n144;
  t204_n141: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t204_n143;
  t204_n142: return 0.06523814052343369f;
  t204_n143: return -0.37656113505363464f;
  t204_n144: return 0.1529272496700287f;
  t204_n145: return 0.006647639442235231f;
  t204_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t204_n224;
  t204_n147: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t204_n217;
  t204_n148: if (E.getNumReferences() >= 3281698816 /*309.5*/) goto t204_n184;
  t204_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n169;
  t204_n150: if (E.getNumReferences() >= 3272474624 /*142.0*/) goto t204_n168;
  t204_n151: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t204_n161;
  t204_n152: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t204_n160;
  t204_n153: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t204_n155;
  t204_n154: return 0.005777588579803705f;
  t204_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t204_n157;
  t204_n156: return -0.13377000391483307f;
  t204_n157: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t204_n159;
  t204_n158: return -0.040522798895835876f;
  t204_n159: return 0.07142258435487747f;
  t204_n160: return -0.5743013024330139f;
  t204_n161: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t204_n163;
  t204_n162: return 0.0874486193060875f;
  t204_n163: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t204_n165;
  t204_n164: return -0.6019573211669922f;
  t204_n165: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t204_n167;
  t204_n166: return 0.09955229610204697f;
  t204_n167: return -0.8018255829811096f;
  t204_n168: return -0.6640889644622803f;
  t204_n169: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t204_n183;
  t204_n170: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t204_n178;
  t204_n171: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t204_n173;
  t204_n172: return -0.06688416749238968f;
  t204_n173: if (E.getNumReferences() >= 3259236352 /*49.0*/) goto t204_n175;
  t204_n174: return 0.09801968187093735f;
  t204_n175: if (E.getNumReferences() >= 3278995456 /*241.5*/) goto t204_n177;
  t204_n176: return -0.01467046607285738f;
  t204_n177: return 0.0844988077878952f;
  t204_n178: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t204_n182;
  t204_n179: if (E.getNumReferences() >= 3243245568 /*13.0*/) goto t204_n181;
  t204_n180: return 0.034811485558748245f;
  t204_n181: return 0.11282128840684891f;
  t204_n182: return -0.09471707791090012f;
  t204_n183: return -0.6365606188774109f;
  t204_n184: if (E.getNumReferences() >= 3283763200 /*372.5*/) goto t204_n188;
  t204_n185: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t204_n187;
  t204_n186: return 0.11493932455778122f;
  t204_n187: return -0.00533424923196435f;
  t204_n188: if (E.getNumReferences() >= 3294494720 /*888.0*/) goto t204_n196;
  t204_n189: if (E.getNumReferences() >= 3293356032 /*818.5*/) goto t204_n195;
  t204_n190: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t204_n192;
  t204_n191: return -0.15784913301467896f;
  t204_n192: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t204_n194;
  t204_n193: return 0.09872069209814072f;
  t204_n194: return -0.005182112101465464f;
  t204_n195: return 0.10421105474233627f;
  t204_n196: if (E.getNumReferences() >= 3336764160 /*29053.5*/) goto t204_n212;
  t204_n197: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t204_n209;
  t204_n198: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t204_n200;
  t204_n199: return -0.2519446015357971f;
  t204_n200: if (E.getNumReferences() >= 3323915776 /*10171.5*/) goto t204_n208;
  t204_n201: if (E.getNumReferences() >= 3301511168 /*1608.5*/) goto t204_n205;
  t204_n202: if (E.getNumReferences() >= 3296882688 /*1043.5*/) goto t204_n204;
  t204_n203: return 0.10990212857723236f;
  t204_n204: return -0.45704302191734314f;
  t204_n205: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n207;
  t204_n206: return 0.09381222724914551f;
  t204_n207: return 0.02040606550872326f;
  t204_n208: return -0.4082866609096527f;
  t204_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n211;
  t204_n210: return -0.457282692193985f;
  t204_n211: return -0.08578485250473022f;
  t204_n212: if (E.getNumReferences() >= 3348072384 /*73487.5*/) goto t204_n216;
  t204_n213: if (E.getNumReferences() >= 3342563200 /*47991.5*/) goto t204_n215;
  t204_n214: return 0.022360196337103844f;
  t204_n215: return 0.09190305322408676f;
  t204_n216: return -0.05840012803673744f;
  t204_n217: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t204_n223;
  t204_n218: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t204_n222;
  t204_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n221;
  t204_n220: return 0.0462905578315258f;
  t204_n221: return -0.10876984149217606f;
  t204_n222: return -0.18747185170650482f;
  t204_n223: return -0.2127077728509903f;
  t204_n224: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t204_n228;
  t204_n225: if (E.getNumReferences() >= 3221225472 /*2.0*/) goto t204_n227;
  t204_n226: return 0.10263665020465851f;
  t204_n227: return 0.11245419830083847f;
  t204_n228: if (E.getNumReferences() >= 3273555968 /*158.5*/) goto t204_n234;
  t204_n229: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t204_n233;
  t204_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n232;
  t204_n231: return -1.4933841228485107f;
  t204_n232: return -0.02989800088107586f;
  t204_n233: return -0.0025578744243830442f;
  t204_n234: if (E.getNumReferences() >= 3285680128 /*431.0*/) goto t204_n238;
  t204_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n237;
  t204_n236: return 0.1056140884757042f;
  t204_n237: return 0.10217089205980301f;
  t204_n238: return 0.0462900772690773f;
  t204_n239: return 0.02373264729976654f;
  t204_n240: return 0.019157802686095238f;
  t204_n241: return 0.01758388988673687f;
  t204_n242: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t204_n244;
  t204_n243: return -2.418523217784241e-05f;
  t204_n244: if (E.getNumReferences() >= 3346171648 /*62087.0*/) goto t204_n248;
  t204_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t204_n247;
  t204_n246: return 0.05160350725054741f;
  t204_n247: return 0.1083984225988388f;
  t204_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t204_n250;
  t204_n249: return -0.006782049313187599f;
  t204_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t204_n252;
  t204_n251: return 0.020161915570497513f;
  t204_n252: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t204_n254;
  t204_n253: return 0.09316638857126236f;
  t204_n254: return 0.038224752992391586f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree205(const Example& E) {
  t205_n0: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t205_n254;
  t205_n1: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t205_n3;
  t205_n2: return -0.0035477662459015846f;
  t205_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t205_n29;
  t205_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t205_n28;
  t205_n5: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t205_n23;
  t205_n6: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t205_n22;
  t205_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t205_n11;
  t205_n8: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t205_n10;
  t205_n9: return 0.01886044256389141f;
  t205_n10: return -0.0679062083363533f;
  t205_n11: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t205_n13;
  t205_n12: return -0.010460665449500084f;
  t205_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t205_n15;
  t205_n14: return 0.005604830104857683f;
  t205_n15: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t205_n21;
  t205_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t205_n18;
  t205_n17: return -0.0550861731171608f;
  t205_n18: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t205_n20;
  t205_n19: return 0.11019105464220047f;
  t205_n20: return -0.31903377175331116f;
  t205_n21: return -0.0678732767701149f;
  t205_n22: return 0.013131817802786827f;
  t205_n23: if (E.getNumReferences() >= 3281272832 /*296.5*/) goto t205_n25;
  t205_n24: return 0.0005456277285702527f;
  t205_n25: if (E.getNumReferences() >= 3281747968 /*311.0*/) goto t205_n27;
  t205_n26: return 0.13034245371818542f;
  t205_n27: return 0.034457914531230927f;
  t205_n28: return 0.00675943773239851f;
  t205_n29: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t205_n95;
  t205_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t205_n32;
  t205_n31: return -0.0030549010261893272f;
  t205_n32: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t205_n66;
  t205_n33: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t205_n63;
  t205_n34: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t205_n58;
  t205_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t205_n57;
  t205_n36: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t205_n56;
  t205_n37: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t205_n47;
  t205_n38: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t205_n40;
  t205_n39: return -0.0861697643995285f;
  t205_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t205_n42;
  t205_n41: return 0.005463155452162027f;
  t205_n42: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t205_n46;
  t205_n43: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t205_n45;
  t205_n44: return 0.09558075666427612f;
  t205_n45: return -0.038364559412002563f;
  t205_n46: return 0.11317384243011475f;
  t205_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t205_n55;
  t205_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t205_n50;
  t205_n49: return 0.005533803254365921f;
  t205_n50: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t205_n54;
  t205_n51: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t205_n53;
  t205_n52: return 0.07757734507322311f;
  t205_n53: return 0.10486366599798203f;
  t205_n54: return -0.2776702344417572f;
  t205_n55: return 0.0954868346452713f;
  t205_n56: return 0.0458683967590332f;
  t205_n57: return 0.05358774587512016f;
  t205_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t205_n60;
  t205_n59: return 0.04352068901062012f;
  t205_n60: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t205_n62;
  t205_n61: return 0.11226142942905426f;
  t205_n62: return 0.11130339652299881f;
  t205_n63: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t205_n65;
  t205_n64: return -0.03697868064045906f;
  t205_n65: return 0.013159425929188728f;
  t205_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t205_n90;
  t205_n67: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t205_n69;
  t205_n68: return 0.02856064774096012f;
  t205_n69: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t205_n87;
  t205_n70: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t205_n86;
  t205_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t205_n83;
  t205_n72: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t205_n82;
  t205_n73: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t205_n81;
  t205_n74: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t205_n78;
  t205_n75: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t205_n77;
  t205_n76: return -0.18622790277004242f;
  t205_n77: return 0.1041909009218216f;
  t205_n78: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t205_n80;
  t205_n79: return 0.29756954312324524f;
  t205_n80: return 0.10714169591665268f;
  t205_n81: return 0.08021235466003418f;
  t205_n82: return -0.5348299741744995f;
  t205_n83: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t205_n85;
  t205_n84: return -0.18686848878860474f;
  t205_n85: return 0.1179603785276413f;
  t205_n86: return 0.024948392063379288f;
  t205_n87: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t205_n89;
  t205_n88: return 0.1168108806014061f;
  t205_n89: return -0.5182708501815796f;
  t205_n90: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t205_n92;
  t205_n91: return 0.05567968636751175f;
  t205_n92: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t205_n94;
  t205_n93: return 0.06389977782964706f;
  t205_n94: return 0.1037294864654541f;
  t205_n95: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t205_n125;
  t205_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t205_n120;
  t205_n97: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t205_n103;
  t205_n98: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t205_n100;
  t205_n99: return -0.008405827917158604f;
  t205_n100: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t205_n102;
  t205_n101: return 0.1071009635925293f;
  t205_n102: return 0.00684643629938364f;
  t205_n103: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t205_n111;
  t205_n104: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t205_n106;
  t205_n105: return -0.0535847432911396f;
  t205_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t205_n110;
  t205_n107: if (E.getNumReferences() >= 3291021312 /*676.0*/) goto t205_n109;
  t205_n108: return -0.12150327116250992f;
  t205_n109: return -0.6768559813499451f;
  t205_n110: return 0.01645197905600071f;
  t205_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t205_n113;
  t205_n112: return -0.015505786053836346f;
  t205_n113: if (E.getNumReferences() >= 3278536704 /*234.5*/) goto t205_n115;
  t205_n114: return -0.035544198006391525f;
  t205_n115: if (E.getNumReferences() >= 3283238912 /*356.5*/) goto t205_n117;
  t205_n116: return 0.11663801968097687f;
  t205_n117: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t205_n119;
  t205_n118: return -0.2533969283103943f;
  t205_n119: return 0.08129493147134781f;
  t205_n120: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t205_n122;
  t205_n121: return -0.0030390487518161535f;
  t205_n122: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t205_n124;
  t205_n123: return -0.014236174523830414f;
  t205_n124: return 0.034948382526636124f;
  t205_n125: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t205_n219;
  t205_n126: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t205_n178;
  t205_n127: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t205_n177;
  t205_n128: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t205_n130;
  t205_n129: return -0.025919213891029358f;
  t205_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t205_n174;
  t205_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t205_n133;
  t205_n132: return -0.16904820501804352f;
  t205_n133: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t205_n163;
  t205_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t205_n150;
  t205_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t205_n149;
  t205_n136: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t205_n138;
  t205_n137: return -0.052434369921684265f;
  t205_n138: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t205_n140;
  t205_n139: return -0.012674164958298206f;
  t205_n140: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t205_n142;
  t205_n141: return -0.07218658179044724f;
  t205_n142: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t205_n144;
  t205_n143: return 0.0982392281293869f;
  t205_n144: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t205_n146;
  t205_n145: return -0.09448806196451187f;
  t205_n146: if (E.getNumReferences() >= 3250061312 /*23.0*/) goto t205_n148;
  t205_n147: return 0.1103091910481453f;
  t205_n148: return 0.02045746147632599f;
  t205_n149: return 0.10525403171777725f;
  t205_n150: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t205_n162;
  t205_n151: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t205_n157;
  t205_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function))) goto t205_n154;
  t205_n153: return -0.03849552571773529f;
  t205_n154: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t205_n156;
  t205_n155: return -0.3878748118877411f;
  t205_n156: return 0.1155475601553917f;
  t205_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t205_n161;
  t205_n158: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t205_n160;
  t205_n159: return -0.3153485357761383f;
  t205_n160: return 0.05161213502287865f;
  t205_n161: return 0.09130112826824188f;
  t205_n162: return -0.02633504755795002f;
  t205_n163: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t205_n173;
  t205_n164: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t205_n168;
  t205_n165: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t205_n167;
  t205_n166: return 0.04238598793745041f;
  t205_n167: return 0.10043366253376007f;
  t205_n168: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t205_n172;
  t205_n169: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t205_n171;
  t205_n170: return 0.03221307694911957f;
  t205_n171: return 0.08747874200344086f;
  t205_n172: return 0.12038431316614151f;
  t205_n173: return -0.02020624838769436f;
  t205_n174: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t205_n176;
  t205_n175: return 0.1120791956782341f;
  t205_n176: return -0.05030927434563637f;
  t205_n177: return 0.05645355209708214f;
  t205_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t205_n182;
  t205_n179: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t205_n181;
  t205_n180: return 0.06251613795757294f;
  t205_n181: return -0.00698026642203331f;
  t205_n182: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t205_n214;
  t205_n183: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t205_n205;
  t205_n184: if (E.getNumReferences() >= 3273785344 /*162.0*/) goto t205_n200;
  t205_n185: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t205_n199;
  t205_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t205_n192;
  t205_n187: if (E.getNumReferences() >= 3267231744 /*95.0*/) goto t205_n189;
  t205_n188: return -0.11888431757688522f;
  t205_n189: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t205_n191;
  t205_n190: return 0.13727715611457825f;
  t205_n191: return -0.1296735554933548f;
  t205_n192: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t205_n196;
  t205_n193: if (E.getNumReferences() >= 3264872448 /*77.0*/) goto t205_n195;
  t205_n194: return 0.3656020164489746f;
  t205_n195: return 0.11410264670848846f;
  t205_n196: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t205_n198;
  t205_n197: return -0.04228447750210762f;
  t205_n198: return 0.15749594569206238f;
  t205_n199: return 0.11426349729299545f;
  t205_n200: if (E.getNumReferences() >= 3289128960 /*560.5*/) goto t205_n202;
  t205_n201: return -0.0561734177172184f;
  t205_n202: if (E.getNumReferences() >= 3292184576 /*747.0*/) goto t205_n204;
  t205_n203: return 0.12126725167036057f;
  t205_n204: return 0.0491623654961586f;
  t205_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t205_n209;
  t205_n206: if (E.getNumReferences() >= 3318051840 /*6318.5*/) goto t205_n208;
  t205_n207: return 0.059083350002765656f;
  t205_n208: return 0.11862736195325851f;
  t205_n209: if (E.getNumReferences() >= 3264741376 /*76.0*/) goto t205_n213;
  t205_n210: if (E.getNumReferences() >= 3264348160 /*73.0*/) goto t205_n212;
  t205_n211: return 0.10282683372497559f;
  t205_n212: return 0.11512108147144318f;
  t205_n213: return 0.09529612213373184f;
  t205_n214: if (E.getNumReferences() >= 3276406784 /*202.0*/) goto t205_n216;
  t205_n215: return -0.03593844175338745f;
  t205_n216: if (E.getNumReferences() >= 3277160448 /*213.5*/) goto t205_n218;
  t205_n217: return 0.1081932932138443f;
  t205_n218: return 0.03969117999076843f;
  t205_n219: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t205_n225;
  t205_n220: if (E.getNumReferences() >= 3335646464 /*26870.5*/) goto t205_n224;
  t205_n221: if (E.getNumReferences() >= 3334899200 /*25411.0*/) goto t205_n223;
  t205_n222: return 0.02410721965134144f;
  t205_n223: return 0.09914339333772659f;
  t205_n224: return -0.13698039948940277f;
  t205_n225: if (E.getNumReferences() >= 3279519744 /*249.5*/) goto t205_n239;
  t205_n226: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t205_n238;
  t205_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t205_n229;
  t205_n228: return -0.2247072011232376f;
  t205_n229: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t205_n237;
  t205_n230: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t205_n232;
  t205_n231: return 0.025906644761562347f;
  t205_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t205_n236;
  t205_n233: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t205_n235;
  t205_n234: return 0.10201434046030045f;
  t205_n235: return 0.04272887483239174f;
  t205_n236: return 0.05804390832781792f;
  t205_n237: return -0.11159816384315491f;
  t205_n238: return 0.01758561283349991f;
  t205_n239: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t205_n253;
  t205_n240: if (E.getNumReferences() >= 3336492544 /*28523.0*/) goto t205_n250;
  t205_n241: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t205_n245;
  t205_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t205_n244;
  t205_n243: return -0.09301857650279999f;
  t205_n244: return 0.07598742842674255f;
  t205_n245: if (E.getNumReferences() >= 3286794240 /*465.0*/) goto t205_n249;
  t205_n246: if (E.getNumReferences() >= 3283976192 /*379.0*/) goto t205_n248;
  t205_n247: return -0.018219074234366417f;
  t205_n248: return 0.12439907342195511f;
  t205_n249: return -0.02356892265379429f;
  t205_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t205_n252;
  t205_n251: return 0.057075291872024536f;
  t205_n252: return 0.09172344952821732f;
  t205_n253: return -0.10742436349391937f;
  t205_n254: return -0.0006409995257854462f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree206(const Example& E) {
  t206_n0: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t206_n146;
  t206_n1: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t206_n53;
  t206_n2: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t206_n4;
  t206_n3: return 0.00030466675525531173f;
  t206_n4: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t206_n6;
  t206_n5: return 0.002995490562170744f;
  t206_n6: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t206_n8;
  t206_n7: return -0.04431024193763733f;
  t206_n8: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t206_n52;
  t206_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n11;
  t206_n10: return -0.0036049981135874987f;
  t206_n11: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t206_n13;
  t206_n12: return -0.02023189701139927f;
  t206_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n15;
  t206_n14: return -0.08387969434261322f;
  t206_n15: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t206_n39;
  t206_n16: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t206_n20;
  t206_n17: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t206_n19;
  t206_n18: return 0.008643695153295994f;
  t206_n19: return 0.03568631783127785f;
  t206_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n30;
  t206_n21: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t206_n25;
  t206_n22: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t206_n24;
  t206_n23: return -0.014352276921272278f;
  t206_n24: return -0.38761410117149353f;
  t206_n25: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t206_n27;
  t206_n26: return -0.045622818171978f;
  t206_n27: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t206_n29;
  t206_n28: return -0.023206450045108795f;
  t206_n29: return 0.1437995433807373f;
  t206_n30: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t206_n32;
  t206_n31: return -0.011189529672265053f;
  t206_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t206_n34;
  t206_n33: return 0.03248169273138046f;
  t206_n34: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t206_n38;
  t206_n35: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t206_n37;
  t206_n36: return -0.14497621357440948f;
  t206_n37: return 0.11900793761014938f;
  t206_n38: return 0.17449761927127838f;
  t206_n39: if (E.getFileProximityDistance() >= 3254517760 /*31.5*/) goto t206_n51;
  t206_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t206_n50;
  t206_n41: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t206_n45;
  t206_n42: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t206_n44;
  t206_n43: return 0.02758372388780117f;
  t206_n44: return -0.10453066974878311f;
  t206_n45: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t206_n47;
  t206_n46: return -0.0917573869228363f;
  t206_n47: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t206_n49;
  t206_n48: return 0.11328768730163574f;
  t206_n49: return 0.15946070849895477f;
  t206_n50: return 0.017613016068935394f;
  t206_n51: return 0.10894112288951874f;
  t206_n52: return -0.014681218191981316f;
  t206_n53: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t206_n115;
  t206_n54: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t206_n80;
  t206_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t206_n77;
  t206_n56: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t206_n58;
  t206_n57: return -0.013997654430568218f;
  t206_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t206_n60;
  t206_n59: return 0.007749956101179123f;
  t206_n60: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t206_n62;
  t206_n61: return -0.102098748087883f;
  t206_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n72;
  t206_n63: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t206_n67;
  t206_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t206_n66;
  t206_n65: return -0.07478085905313492f;
  t206_n66: return 0.08687093108892441f;
  t206_n67: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t206_n71;
  t206_n68: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t206_n70;
  t206_n69: return 0.10155478119850159f;
  t206_n70: return -0.10064344108104706f;
  t206_n71: return -0.047463156282901764f;
  t206_n72: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t206_n74;
  t206_n73: return -0.18618425726890564f;
  t206_n74: if (E.getNumReferences() >= 3272474624 /*142.0*/) goto t206_n76;
  t206_n75: return 0.0962190330028534f;
  t206_n76: return 0.04502183571457863f;
  t206_n77: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t206_n79;
  t206_n78: return 0.006115940399467945f;
  t206_n79: return 0.016477437689900398f;
  t206_n80: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t206_n114;
  t206_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t206_n83;
  t206_n82: return -0.007474459707736969f;
  t206_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t206_n85;
  t206_n84: return 0.008726809173822403f;
  t206_n85: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t206_n87;
  t206_n86: return -0.01276147086173296f;
  t206_n87: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t206_n89;
  t206_n88: return 0.03148956969380379f;
  t206_n89: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t206_n113;
  t206_n90: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t206_n94;
  t206_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t206_n93;
  t206_n92: return 0.14016193151474f;
  t206_n93: return 0.10919283330440521f;
  t206_n94: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t206_n112;
  t206_n95: if (E.getNumReferences() >= 3273687040 /*160.5*/) goto t206_n111;
  t206_n96: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t206_n98;
  t206_n97: return 0.10892102867364883f;
  t206_n98: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n100;
  t206_n99: return -0.21550269424915314f;
  t206_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t206_n102;
  t206_n101: return 0.027614939957857132f;
  t206_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t206_n104;
  t206_n103: return 0.05478754639625549f;
  t206_n104: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t206_n108;
  t206_n105: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t206_n107;
  t206_n106: return 0.09820151329040527f;
  t206_n107: return 0.10882662981748581f;
  t206_n108: if (E.getNumReferences() >= 3269459968 /*112.0*/) goto t206_n110;
  t206_n109: return -0.17516399919986725f;
  t206_n110: return 0.10274002701044083f;
  t206_n111: return 0.010007492266595364f;
  t206_n112: return 0.03326047584414482f;
  t206_n113: return 0.07958962768316269f;
  t206_n114: return -0.0021893857046961784f;
  t206_n115: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t206_n127;
  t206_n116: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t206_n126;
  t206_n117: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t206_n125;
  t206_n118: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t206_n120;
  t206_n119: return -0.11236179620027542f;
  t206_n120: if (E.getNumReferences() >= 3271294976 /*126.0*/) goto t206_n124;
  t206_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t206_n123;
  t206_n122: return -0.02400903031229973f;
  t206_n123: return 0.12142115086317062f;
  t206_n124: return -0.020032566040754318f;
  t206_n125: return 0.0377773754298687f;
  t206_n126: return 0.013825050555169582f;
  t206_n127: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t206_n143;
  t206_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t206_n134;
  t206_n129: if (E.getNumReferences() >= 3308357632 /*2840.5*/) goto t206_n131;
  t206_n130: return -0.0043007200583815575f;
  t206_n131: if (E.getNumReferences() >= 3314521088 /*4594.5*/) goto t206_n133;
  t206_n132: return 0.15949225425720215f;
  t206_n133: return 0.10081212967634201f;
  t206_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t206_n136;
  t206_n135: return 0.0666273683309555f;
  t206_n136: if (E.getNumReferences() >= 3288948736 /*549.5*/) goto t206_n140;
  t206_n137: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t206_n139;
  t206_n138: return 0.08400831371545792f;
  t206_n139: return 0.14385637640953064f;
  t206_n140: if (E.getNumReferences() >= 3299913728 /*1413.5*/) goto t206_n142;
  t206_n141: return 0.16062921285629272f;
  t206_n142: return 0.014845959842205048f;
  t206_n143: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t206_n145;
  t206_n144: return 0.11609015613794327f;
  t206_n145: return 0.045305803418159485f;
  t206_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t206_n180;
  t206_n147: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t206_n149;
  t206_n148: return -0.03724260628223419f;
  t206_n149: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t206_n177;
  t206_n150: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t206_n174;
  t206_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t206_n155;
  t206_n152: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t206_n154;
  t206_n153: return -0.08677950501441956f;
  t206_n154: return 0.02297508344054222f;
  t206_n155: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t206_n161;
  t206_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t206_n160;
  t206_n157: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n159;
  t206_n158: return 0.03598761558532715f;
  t206_n159: return 0.09153573960065842f;
  t206_n160: return 0.08024707436561584f;
  t206_n161: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t206_n163;
  t206_n162: return -0.12084899842739105f;
  t206_n163: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t206_n171;
  t206_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t206_n170;
  t206_n165: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t206_n167;
  t206_n166: return 0.08359964191913605f;
  t206_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n169;
  t206_n168: return -0.05288542062044144f;
  t206_n169: return 0.03398735821247101f;
  t206_n170: return 0.05607308819890022f;
  t206_n171: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n173;
  t206_n172: return 0.08749064058065414f;
  t206_n173: return 0.09243574738502502f;
  t206_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n176;
  t206_n175: return -0.03634935989975929f;
  t206_n176: return -0.0024381475523114204f;
  t206_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n179;
  t206_n178: return -0.2127414345741272f;
  t206_n179: return 0.019211038947105408f;
  t206_n180: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t206_n196;
  t206_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t206_n185;
  t206_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n184;
  t206_n183: return -0.2653038501739502f;
  t206_n184: return 0.0629509910941124f;
  t206_n185: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t206_n189;
  t206_n186: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t206_n188;
  t206_n187: return 0.037605345249176025f;
  t206_n188: return 0.09729444980621338f;
  t206_n189: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t206_n191;
  t206_n190: return 0.11541631817817688f;
  t206_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t206_n195;
  t206_n192: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n194;
  t206_n193: return -0.35806435346603394f;
  t206_n194: return 0.051114119589328766f;
  t206_n195: return 0.04420414939522743f;
  t206_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t206_n204;
  t206_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t206_n199;
  t206_n198: return 0.1690506786108017f;
  t206_n199: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t206_n203;
  t206_n200: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t206_n202;
  t206_n201: return 0.05060715228319168f;
  t206_n202: return 0.09684379398822784f;
  t206_n203: return 0.013633021153509617f;
  t206_n204: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t206_n230;
  t206_n205: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n215;
  t206_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n212;
  t206_n207: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t206_n209;
  t206_n208: return 0.0312991589307785f;
  t206_n209: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t206_n211;
  t206_n210: return -0.11832619458436966f;
  t206_n211: return 0.06332023441791534f;
  t206_n212: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t206_n214;
  t206_n213: return 0.022915048524737358f;
  t206_n214: return -0.18948401510715485f;
  t206_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t206_n217;
  t206_n216: return -0.3555296063423157f;
  t206_n217: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t206_n225;
  t206_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t206_n220;
  t206_n219: return -0.06241333484649658f;
  t206_n220: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t206_n224;
  t206_n221: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t206_n223;
  t206_n222: return 0.04820972681045532f;
  t206_n223: return -0.005891005974262953f;
  t206_n224: return -0.15632393956184387f;
  t206_n225: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t206_n227;
  t206_n226: return 0.07001382857561111f;
  t206_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n229;
  t206_n228: return -0.14747102558612823f;
  t206_n229: return 0.0677383616566658f;
  t206_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n250;
  t206_n231: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t206_n249;
  t206_n232: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t206_n240;
  t206_n233: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t206_n237;
  t206_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t206_n236;
  t206_n235: return -0.0854288637638092f;
  t206_n236: return 0.055669281631708145f;
  t206_n237: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t206_n239;
  t206_n238: return 0.026705816388130188f;
  t206_n239: return -0.06650904566049576f;
  t206_n240: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t206_n242;
  t206_n241: return -0.11160854995250702f;
  t206_n242: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t206_n244;
  t206_n243: return 0.06519957631826401f;
  t206_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t206_n248;
  t206_n245: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t206_n247;
  t206_n246: return -0.0560855008661747f;
  t206_n247: return 0.04768288508057594f;
  t206_n248: return 0.033247824758291245f;
  t206_n249: return -0.20496970415115356f;
  t206_n250: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t206_n254;
  t206_n251: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t206_n253;
  t206_n252: return 0.09079285711050034f;
  t206_n253: return -0.08015575259923935f;
  t206_n254: return 0.017608022317290306f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree207(const Example& E) {
  t207_n0: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t207_n242;
  t207_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t207_n3;
  t207_n2: return -0.0010836465517058969f;
  t207_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t207_n241;
  t207_n4: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t207_n76;
  t207_n5: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t207_n45;
  t207_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Namespace))) goto t207_n8;
  t207_n7: return -0.007868895307183266f;
  t207_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t207_n10;
  t207_n9: return -0.03745245188474655f;
  t207_n10: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t207_n38;
  t207_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t207_n13;
  t207_n12: return -0.002521607792004943f;
  t207_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n33;
  t207_n14: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t207_n18;
  t207_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t207_n17;
  t207_n16: return -0.3619915246963501f;
  t207_n17: return 0.07339594513177872f;
  t207_n18: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t207_n24;
  t207_n19: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t207_n21;
  t207_n20: return 0.058266881853342056f;
  t207_n21: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t207_n23;
  t207_n22: return 0.10410748422145844f;
  t207_n23: return -0.002662548329681158f;
  t207_n24: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t207_n32;
  t207_n25: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t207_n31;
  t207_n26: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t207_n28;
  t207_n27: return -0.06242894008755684f;
  t207_n28: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t207_n30;
  t207_n29: return 0.0367981493473053f;
  t207_n30: return -0.17794597148895264f;
  t207_n31: return 0.09157723188400269f;
  t207_n32: return -0.1830906718969345f;
  t207_n33: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t207_n37;
  t207_n34: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t207_n36;
  t207_n35: return 0.030217107385396957f;
  t207_n36: return -0.12343194335699081f;
  t207_n37: return 0.023992205038666725f;
  t207_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t207_n44;
  t207_n39: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n41;
  t207_n40: return 0.01863795518875122f;
  t207_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t207_n43;
  t207_n42: return 0.025502551347017288f;
  t207_n43: return 0.0694282278418541f;
  t207_n44: return 0.0256210770457983f;
  t207_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t207_n47;
  t207_n46: return -0.09849271178245544f;
  t207_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t207_n49;
  t207_n48: return -0.03001004084944725f;
  t207_n49: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t207_n65;
  t207_n50: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t207_n52;
  t207_n51: return 0.03688960149884224f;
  t207_n52: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t207_n54;
  t207_n53: return 0.03910455107688904f;
  t207_n54: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t207_n60;
  t207_n55: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t207_n57;
  t207_n56: return 0.0995776578783989f;
  t207_n57: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t207_n59;
  t207_n58: return -0.37962576746940613f;
  t207_n59: return 0.07592754811048508f;
  t207_n60: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t207_n64;
  t207_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n63;
  t207_n62: return 0.1450325846672058f;
  t207_n63: return 0.15031063556671143f;
  t207_n64: return 0.11678744852542877f;
  t207_n65: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t207_n75;
  t207_n66: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t207_n74;
  t207_n67: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t207_n69;
  t207_n68: return 0.02698829397559166f;
  t207_n69: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t207_n71;
  t207_n70: return -0.025538699701428413f;
  t207_n71: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t207_n73;
  t207_n72: return -0.07556804269552231f;
  t207_n73: return -0.001447806367650628f;
  t207_n74: return -0.10558327287435532f;
  t207_n75: return 0.004778995644301176f;
  t207_n76: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t207_n228;
  t207_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t207_n101;
  t207_n78: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t207_n100;
  t207_n79: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t207_n81;
  t207_n80: return -0.02267676405608654f;
  t207_n81: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t207_n89;
  t207_n82: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t207_n84;
  t207_n83: return 0.01961805671453476f;
  t207_n84: if (E.getNumReferences() >= 3292217344 /*749.0*/) goto t207_n86;
  t207_n85: return -0.04217939078807831f;
  t207_n86: if (E.getNumReferences() >= 3294355456 /*879.5*/) goto t207_n88;
  t207_n87: return 0.09333177655935287f;
  t207_n88: return 0.031022757291793823f;
  t207_n89: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t207_n95;
  t207_n90: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t207_n94;
  t207_n91: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t207_n93;
  t207_n92: return 0.10982923209667206f;
  t207_n93: return 0.04203549027442932f;
  t207_n94: return 0.10966211557388306f;
  t207_n95: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t207_n99;
  t207_n96: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t207_n98;
  t207_n97: return 0.08434725552797318f;
  t207_n98: return 0.024528922513127327f;
  t207_n99: return -0.7611399292945862f;
  t207_n100: return 0.014229596592485905f;
  t207_n101: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t207_n141;
  t207_n102: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t207_n104;
  t207_n103: return 0.023578330874443054f;
  t207_n104: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t207_n106;
  t207_n105: return 0.008274541236460209f;
  t207_n106: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t207_n124;
  t207_n107: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t207_n117;
  t207_n108: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t207_n116;
  t207_n109: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t207_n111;
  t207_n110: return -0.34166237711906433f;
  t207_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t207_n115;
  t207_n112: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t207_n114;
  t207_n113: return 0.12026259303092957f;
  t207_n114: return -0.10990370810031891f;
  t207_n115: return 0.11780568212270737f;
  t207_n116: return -0.1223856508731842f;
  t207_n117: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t207_n123;
  t207_n118: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t207_n122;
  t207_n119: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t207_n121;
  t207_n120: return -0.12006104737520218f;
  t207_n121: return 0.12341353297233582f;
  t207_n122: return -0.023761656135320663f;
  t207_n123: return 0.11687703430652618f;
  t207_n124: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t207_n126;
  t207_n125: return 0.0007205422152765095f;
  t207_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n134;
  t207_n127: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t207_n129;
  t207_n128: return 0.08105167746543884f;
  t207_n129: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t207_n131;
  t207_n130: return -0.27352187037467957f;
  t207_n131: if (E.getNumReferences() >= 3262119936 /*60.0*/) goto t207_n133;
  t207_n132: return 0.09757094085216522f;
  t207_n133: return 0.04665127396583557f;
  t207_n134: if (E.getNumReferences() >= 3277848576 /*224.0*/) goto t207_n136;
  t207_n135: return 0.01041356660425663f;
  t207_n136: if (E.getNumReferences() >= 3285565440 /*427.5*/) goto t207_n140;
  t207_n137: if (E.getNumReferences() >= 3283468288 /*363.5*/) goto t207_n139;
  t207_n138: return 0.0865730494260788f;
  t207_n139: return 0.12328927963972092f;
  t207_n140: return -0.034440454095602036f;
  t207_n141: if (E.getNumReferences() >= 3281682432 /*309.0*/) goto t207_n189;
  t207_n142: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n158;
  t207_n143: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t207_n155;
  t207_n144: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t207_n146;
  t207_n145: return -0.004609002266079187f;
  t207_n146: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t207_n148;
  t207_n147: return -0.7399060130119324f;
  t207_n148: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t207_n152;
  t207_n149: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t207_n151;
  t207_n150: return -0.05524807795882225f;
  t207_n151: return 0.09704115241765976f;
  t207_n152: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t207_n154;
  t207_n153: return -0.2948804199695587f;
  t207_n154: return 0.004263921175152063f;
  t207_n155: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t207_n157;
  t207_n156: return 0.09906167536973953f;
  t207_n157: return 0.021306414157152176f;
  t207_n158: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t207_n188;
  t207_n159: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t207_n171;
  t207_n160: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t207_n162;
  t207_n161: return -0.3404685854911804f;
  t207_n162: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t207_n170;
  t207_n163: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t207_n165;
  t207_n164: return -0.004828606732189655f;
  t207_n165: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t207_n169;
  t207_n166: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t207_n168;
  t207_n167: return 0.10107937455177307f;
  t207_n168: return 0.06573403626680374f;
  t207_n169: return -0.05898715555667877f;
  t207_n170: return -0.06843451410531998f;
  t207_n171: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t207_n175;
  t207_n172: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t207_n174;
  t207_n173: return 0.1096217930316925f;
  t207_n174: return -0.06304028630256653f;
  t207_n175: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t207_n185;
  t207_n176: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t207_n182;
  t207_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t207_n179;
  t207_n178: return -0.020272724330425262f;
  t207_n179: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t207_n181;
  t207_n180: return 0.12619294226169586f;
  t207_n181: return -0.054739195853471756f;
  t207_n182: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t207_n184;
  t207_n183: return 0.10574911534786224f;
  t207_n184: return 0.1056370660662651f;
  t207_n185: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t207_n187;
  t207_n186: return -0.4772903323173523f;
  t207_n187: return 0.01289462298154831f;
  t207_n188: return -0.08863622695207596f;
  t207_n189: if (E.getNumReferences() >= 3283763200 /*372.5*/) goto t207_n201;
  t207_n190: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t207_n198;
  t207_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n193;
  t207_n192: return 0.11488017439842224f;
  t207_n193: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t207_n197;
  t207_n194: if (E.getNumReferences() >= 3283419136 /*362.0*/) goto t207_n196;
  t207_n195: return -0.1106596440076828f;
  t207_n196: return 0.12640169262886047f;
  t207_n197: return 0.12645691633224487f;
  t207_n198: if (E.getNumReferences() >= 3283550208 /*366.0*/) goto t207_n200;
  t207_n199: return -0.2900792360305786f;
  t207_n200: return 0.10090555995702744f;
  t207_n201: if (E.getNumReferences() >= 3293421568 /*822.5*/) goto t207_n209;
  t207_n202: if (E.getNumReferences() >= 3293257728 /*812.5*/) goto t207_n208;
  t207_n203: if (E.getNumReferences() >= 3291242496 /*689.5*/) goto t207_n207;
  t207_n204: if (E.getNumReferences() >= 3291013120 /*675.5*/) goto t207_n206;
  t207_n205: return 0.050858620554208755f;
  t207_n206: return 0.10807520151138306f;
  t207_n207: return -0.0946434885263443f;
  t207_n208: return 0.11256863176822662f;
  t207_n209: if (E.getNumReferences() >= 3334835456 /*25286.5*/) goto t207_n213;
  t207_n210: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t207_n212;
  t207_n211: return -0.048810068517923355f;
  t207_n212: return 0.0609462596476078f;
  t207_n213: if (E.getNumReferences() >= 3350636352 /*93518.5*/) goto t207_n227;
  t207_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t207_n216;
  t207_n215: return 0.0030309208668768406f;
  t207_n216: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t207_n226;
  t207_n217: if (E.getNumReferences() >= 3342139776 /*46337.5*/) goto t207_n221;
  t207_n218: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t207_n220;
  t207_n219: return -0.042293667793273926f;
  t207_n220: return 0.07718449831008911f;
  t207_n221: if (E.getNumReferences() >= 3347181120 /*66524.5*/) goto t207_n225;
  t207_n222: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t207_n224;
  t207_n223: return 0.0929814949631691f;
  t207_n224: return 0.13274706900119781f;
  t207_n225: return 0.0494009330868721f;
  t207_n226: return 0.10099977254867554f;
  t207_n227: return -0.05447947978973389f;
  t207_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t207_n230;
  t207_n229: return 0.008750151842832565f;
  t207_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t207_n236;
  t207_n231: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t207_n233;
  t207_n232: return -0.1749553084373474f;
  t207_n233: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t207_n235;
  t207_n234: return 0.10045239329338074f;
  t207_n235: return 0.08755211532115936f;
  t207_n236: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t207_n240;
  t207_n237: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t207_n239;
  t207_n238: return 0.1115797609090805f;
  t207_n239: return -0.09744933247566223f;
  t207_n240: return 0.03135960176587105f;
  t207_n241: return 0.00353439268656075f;
  t207_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t207_n244;
  t207_n243: return 0.005678664427250624f;
  t207_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n252;
  t207_n245: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t207_n249;
  t207_n246: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t207_n248;
  t207_n247: return -0.4062214195728302f;
  t207_n248: return 0.025344526395201683f;
  t207_n249: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t207_n251;
  t207_n250: return 0.10187803208827972f;
  t207_n251: return 0.05959952250123024f;
  t207_n252: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t207_n254;
  t207_n253: return 0.014127714559435844f;
  t207_n254: return -0.3529350757598877f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree208(const Example& E) {
  t208_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t208_n200;
  t208_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t208_n199;
  t208_n2: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t208_n50;
  t208_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n35;
  t208_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t208_n6;
  t208_n5: return -0.007929716259241104f;
  t208_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n8;
  t208_n7: return -0.030052881687879562f;
  t208_n8: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t208_n32;
  t208_n9: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t208_n29;
  t208_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t208_n28;
  t208_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t208_n25;
  t208_n12: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t208_n24;
  t208_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n15;
  t208_n14: return -0.6035733222961426f;
  t208_n15: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t208_n23;
  t208_n16: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t208_n22;
  t208_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t208_n21;
  t208_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t208_n20;
  t208_n19: return 0.11019840836524963f;
  t208_n20: return 0.2772600054740906f;
  t208_n21: return 0.17119383811950684f;
  t208_n22: return 0.05843434855341911f;
  t208_n23: return 0.0655573159456253f;
  t208_n24: return 0.07791076600551605f;
  t208_n25: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t208_n27;
  t208_n26: return 0.08751055598258972f;
  t208_n27: return -0.09210959821939468f;
  t208_n28: return 0.0266452357172966f;
  t208_n29: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t208_n31;
  t208_n30: return -0.0499877892434597f;
  t208_n31: return 0.03372820094227791f;
  t208_n32: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t208_n34;
  t208_n33: return 0.026314804330468178f;
  t208_n34: return -0.1017257422208786f;
  t208_n35: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t208_n49;
  t208_n36: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t208_n48;
  t208_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t208_n39;
  t208_n38: return 0.015743335708975792f;
  t208_n39: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t208_n41;
  t208_n40: return 0.028989968821406364f;
  t208_n41: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t208_n43;
  t208_n42: return -0.011502997018396854f;
  t208_n43: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t208_n45;
  t208_n44: return 0.022938229143619537f;
  t208_n45: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t208_n47;
  t208_n46: return 0.25574514269828796f;
  t208_n47: return 0.15364684164524078f;
  t208_n48: return -0.003028303384780884f;
  t208_n49: return 1.732500641082879e-05f;
  t208_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t208_n198;
  t208_n51: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t208_n109;
  t208_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n56;
  t208_n53: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t208_n55;
  t208_n54: return -0.06662417948246002f;
  t208_n55: return -0.17462460696697235f;
  t208_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t208_n58;
  t208_n57: return 0.0033876204397529364f;
  t208_n58: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t208_n100;
  t208_n59: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t208_n65;
  t208_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t208_n62;
  t208_n61: return -0.03687388077378273f;
  t208_n62: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t208_n64;
  t208_n63: return -0.009410233236849308f;
  t208_n64: return -0.06448911130428314f;
  t208_n65: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t208_n99;
  t208_n66: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t208_n98;
  t208_n67: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t208_n69;
  t208_n68: return 0.035989124327898026f;
  t208_n69: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t208_n97;
  t208_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n74;
  t208_n71: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t208_n73;
  t208_n72: return -0.004740554839372635f;
  t208_n73: return -0.21595795452594757f;
  t208_n74: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t208_n92;
  t208_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t208_n83;
  t208_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t208_n78;
  t208_n77: return 0.04854409769177437f;
  t208_n78: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t208_n82;
  t208_n79: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t208_n81;
  t208_n80: return 0.19816450774669647f;
  t208_n81: return 0.19548073410987854f;
  t208_n82: return 0.017313197255134583f;
  t208_n83: if (E.getNumReferences() >= 3258449920 /*46.0*/) goto t208_n85;
  t208_n84: return 0.11870185285806656f;
  t208_n85: if (E.getNumReferences() >= 3264741376 /*76.0*/) goto t208_n91;
  t208_n86: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t208_n88;
  t208_n87: return -0.16974686086177826f;
  t208_n88: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t208_n90;
  t208_n89: return -0.1405518651008606f;
  t208_n90: return 0.0840344950556755f;
  t208_n91: return 0.10459866374731064f;
  t208_n92: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t208_n96;
  t208_n93: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t208_n95;
  t208_n94: return -0.03467744588851929f;
  t208_n95: return 0.10368507355451584f;
  t208_n96: return -0.16643939912319183f;
  t208_n97: return 0.2210206389427185f;
  t208_n98: return -0.025116905570030212f;
  t208_n99: return -0.03699225187301636f;
  t208_n100: if (E.getNumReferences() >= 3295461376 /*947.0*/) goto t208_n108;
  t208_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n103;
  t208_n102: return -0.03431965783238411f;
  t208_n103: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t208_n107;
  t208_n104: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t208_n106;
  t208_n105: return 0.13116565346717834f;
  t208_n106: return -0.06189578399062157f;
  t208_n107: return -0.035231683403253555f;
  t208_n108: return 0.0938367173075676f;
  t208_n109: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t208_n111;
  t208_n110: return 0.013460252434015274f;
  t208_n111: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t208_n113;
  t208_n112: return 0.10262931138277054f;
  t208_n113: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t208_n197;
  t208_n114: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t208_n126;
  t208_n115: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t208_n125;
  t208_n116: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t208_n118;
  t208_n117: return 0.04020227864384651f;
  t208_n118: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t208_n120;
  t208_n119: return -0.09391450136899948f;
  t208_n120: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t208_n124;
  t208_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t208_n123;
  t208_n122: return -0.301787793636322f;
  t208_n123: return 0.11862265318632126f;
  t208_n124: return 0.08545906841754913f;
  t208_n125: return -0.019472122192382812f;
  t208_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t208_n194;
  t208_n127: if (E.getNumReferences() >= 3269656576 /*113.5*/) goto t208_n157;
  t208_n128: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t208_n156;
  t208_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t208_n147;
  t208_n130: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t208_n146;
  t208_n131: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t208_n135;
  t208_n132: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t208_n134;
  t208_n133: return 0.011087562888860703f;
  t208_n134: return 0.10401852428913116f;
  t208_n135: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t208_n137;
  t208_n136: return 0.0588640421628952f;
  t208_n137: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t208_n145;
  t208_n138: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t208_n144;
  t208_n139: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t208_n141;
  t208_n140: return 0.10174012184143066f;
  t208_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t208_n143;
  t208_n142: return 0.27072811126708984f;
  t208_n143: return 0.1602676659822464f;
  t208_n144: return -0.21442362666130066f;
  t208_n145: return 0.10241318494081497f;
  t208_n146: return -0.0692971795797348f;
  t208_n147: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t208_n155;
  t208_n148: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t208_n150;
  t208_n149: return 0.08248329162597656f;
  t208_n150: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t208_n154;
  t208_n151: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t208_n153;
  t208_n152: return 0.15798071026802063f;
  t208_n153: return 0.12306199222803116f;
  t208_n154: return -0.10291524976491928f;
  t208_n155: return 0.04468744993209839f;
  t208_n156: return -0.006859892513602972f;
  t208_n157: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t208_n161;
  t208_n158: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t208_n160;
  t208_n159: return -0.10153726488351822f;
  t208_n160: return 0.12404785305261612f;
  t208_n161: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t208_n191;
  t208_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t208_n188;
  t208_n163: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t208_n181;
  t208_n164: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t208_n178;
  t208_n165: if (E.getNumReferences() >= 3283697664 /*370.5*/) goto t208_n177;
  t208_n166: if (E.getNumReferences() >= 3275227136 /*184.0*/) goto t208_n174;
  t208_n167: if (E.getNumReferences() >= 3272998912 /*150.0*/) goto t208_n173;
  t208_n168: if (E.getNumReferences() >= 3272146944 /*137.0*/) goto t208_n172;
  t208_n169: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t208_n171;
  t208_n170: return 0.12865231931209564f;
  t208_n171: return -0.4780237376689911f;
  t208_n172: return 0.2391093373298645f;
  t208_n173: return -0.20671959221363068f;
  t208_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t208_n176;
  t208_n175: return 0.1225530356168747f;
  t208_n176: return 0.13616862893104553f;
  t208_n177: return 0.07116031646728516f;
  t208_n178: if (E.getNumReferences() >= 3287564288 /*488.5*/) goto t208_n180;
  t208_n179: return -0.0777750089764595f;
  t208_n180: return 0.109553262591362f;
  t208_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n183;
  t208_n182: return -0.21517546474933624f;
  t208_n183: if (E.getNumReferences() >= 3274866688 /*178.5*/) goto t208_n187;
  t208_n184: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t208_n186;
  t208_n185: return 0.07850000262260437f;
  t208_n186: return 0.127778559923172f;
  t208_n187: return 0.02171245403587818f;
  t208_n188: if (E.getNumReferences() >= 3279486976 /*249.0*/) goto t208_n190;
  t208_n189: return -0.14946699142456055f;
  t208_n190: return 0.0843239575624466f;
  t208_n191: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t208_n193;
  t208_n192: return -2.1929075717926025f;
  t208_n193: return 0.036476779729127884f;
  t208_n194: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t208_n196;
  t208_n195: return -0.05763304606080055f;
  t208_n196: return 0.11664365231990814f;
  t208_n197: return 0.0264977365732193f;
  t208_n198: return 0.018262416124343872f;
  t208_n199: return -0.00108834367711097f;
  t208_n200: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t208_n224;
  t208_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t208_n203;
  t208_n202: return 0.0017677274299785495f;
  t208_n203: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t208_n217;
  t208_n204: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t208_n214;
  t208_n205: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t208_n207;
  t208_n206: return 0.07534658908843994f;
  t208_n207: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t208_n211;
  t208_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n210;
  t208_n209: return -0.15269224345684052f;
  t208_n210: return 0.08317548781633377f;
  t208_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t208_n213;
  t208_n212: return 0.11733664572238922f;
  t208_n213: return 0.11521323025226593f;
  t208_n214: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t208_n216;
  t208_n215: return 0.09224221110343933f;
  t208_n216: return 0.052034150809049606f;
  t208_n217: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t208_n223;
  t208_n218: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t208_n220;
  t208_n219: return -0.28751876950263977f;
  t208_n220: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t208_n222;
  t208_n221: return 0.11667528003454208f;
  t208_n222: return 0.11714904755353928f;
  t208_n223: return -0.013398288749158382f;
  t208_n224: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t208_n254;
  t208_n225: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t208_n227;
  t208_n226: return -0.012126963585615158f;
  t208_n227: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t208_n253;
  t208_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t208_n244;
  t208_n229: if (E.getNumReferences() >= 3337711104 /*30903.0*/) goto t208_n235;
  t208_n230: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t208_n232;
  t208_n231: return -0.07246875762939453f;
  t208_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t208_n234;
  t208_n233: return -0.224242702126503f;
  t208_n234: return 0.0806955099105835f;
  t208_n235: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t208_n243;
  t208_n236: if (E.getNumReferences() >= 3338157568 /*31775.0*/) goto t208_n238;
  t208_n237: return 0.034233931452035904f;
  t208_n238: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t208_n240;
  t208_n239: return 0.09642582386732101f;
  t208_n240: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t208_n242;
  t208_n241: return 0.04433480277657509f;
  t208_n242: return 0.07721369713544846f;
  t208_n243: return 0.012367373332381248f;
  t208_n244: if (E.getNumReferences() >= 3351268608 /*98458.0*/) goto t208_n246;
  t208_n245: return 0.007677852641791105f;
  t208_n246: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t208_n252;
  t208_n247: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t208_n251;
  t208_n248: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t208_n250;
  t208_n249: return 0.6916908025741577f;
  t208_n250: return 0.08085692673921585f;
  t208_n251: return 0.046499043703079224f;
  t208_n252: return -0.1035330519080162f;
  t208_n253: return 0.08199305087327957f;
  t208_n254: return 0.007041280623525381f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree209(const Example& E) {
  t209_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t209_n2;
  t209_n1: return -0.0003465033369138837f;
  t209_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t209_n8;
  t209_n3: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t209_n7;
  t209_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t209_n6;
  t209_n5: return -0.13543663918972015f;
  t209_n6: return -0.0160287544131279f;
  t209_n7: return 0.0008366018300876021f;
  t209_n8: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t209_n28;
  t209_n9: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t209_n11;
  t209_n10: return 0.013153286650776863f;
  t209_n11: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t209_n23;
  t209_n12: if (E.getNumReferences() >= 3333870080 /*23401.0*/) goto t209_n18;
  t209_n13: if (E.getNumReferences() >= 3319278592 /*6917.5*/) goto t209_n15;
  t209_n14: return -0.00020976568339392543f;
  t209_n15: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t209_n17;
  t209_n16: return -77.64083862304688f;
  t209_n17: return -0.1996905505657196f;
  t209_n18: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t209_n22;
  t209_n19: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t209_n21;
  t209_n20: return 0.14888238906860352f;
  t209_n21: return 0.11757349967956543f;
  t209_n22: return 0.04041058570146561f;
  t209_n23: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t209_n25;
  t209_n24: return -0.0010687881149351597f;
  t209_n25: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t209_n27;
  t209_n26: return 0.010404223576188087f;
  t209_n27: return 0.02894306369125843f;
  t209_n28: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t209_n254;
  t209_n29: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t209_n201;
  t209_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t209_n64;
  t209_n31: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t209_n63;
  t209_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n34;
  t209_n33: return -0.016232207417488098f;
  t209_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t209_n48;
  t209_n35: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t209_n47;
  t209_n36: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t209_n44;
  t209_n37: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t209_n43;
  t209_n38: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t209_n42;
  t209_n39: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t209_n41;
  t209_n40: return 0.13135604560375214f;
  t209_n41: return 0.11758440732955933f;
  t209_n42: return 0.5387771129608154f;
  t209_n43: return 0.020576437935233116f;
  t209_n44: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t209_n46;
  t209_n45: return 0.0f;
  t209_n46: return 4.179494857788086f;
  t209_n47: return 0.10147550702095032f;
  t209_n48: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t209_n62;
  t209_n49: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t209_n53;
  t209_n50: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t209_n52;
  t209_n51: return -0.1357921063899994f;
  t209_n52: return 0.1650443971157074f;
  t209_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t209_n57;
  t209_n54: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t209_n56;
  t209_n55: return -0.08247492462396622f;
  t209_n56: return 0.16026712954044342f;
  t209_n57: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t209_n61;
  t209_n58: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t209_n60;
  t209_n59: return 0.001492500538006425f;
  t209_n60: return 0.13301414251327515f;
  t209_n61: return 0.8903722167015076f;
  t209_n62: return -0.04123705253005028f;
  t209_n63: return -0.07590065151453018f;
  t209_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t209_n66;
  t209_n65: return 0.00038580954424105585f;
  t209_n66: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t209_n200;
  t209_n67: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t209_n143;
  t209_n68: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t209_n142;
  t209_n69: if (E.getNumReferences() >= 3278340096 /*231.5*/) goto t209_n127;
  t209_n70: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t209_n78;
  t209_n71: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n75;
  t209_n72: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t209_n74;
  t209_n73: return 0.02004646509885788f;
  t209_n74: return 0.09024535864591599f;
  t209_n75: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t209_n77;
  t209_n76: return -0.028520731255412102f;
  t209_n77: return -0.09687400609254837f;
  t209_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n82;
  t209_n79: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t209_n81;
  t209_n80: return 0.03740652650594711f;
  t209_n81: return -0.011433849111199379f;
  t209_n82: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t209_n104;
  t209_n83: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t209_n97;
  t209_n84: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t209_n88;
  t209_n85: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t209_n87;
  t209_n86: return -0.1044330894947052f;
  t209_n87: return 0.01700557768344879f;
  t209_n88: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t209_n96;
  t209_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t209_n95;
  t209_n90: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t209_n92;
  t209_n91: return -0.019931234419345856f;
  t209_n92: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t209_n94;
  t209_n93: return 0.09965702891349792f;
  t209_n94: return 0.15214113891124725f;
  t209_n95: return 0.06685300916433334f;
  t209_n96: return 0.10777236521244049f;
  t209_n97: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t209_n99;
  t209_n98: return 0.11837547272443771f;
  t209_n99: if (E.getNumReferences() >= 3259236352 /*49.0*/) goto t209_n103;
  t209_n100: if (E.getNumReferences() >= 3235905536 /*7.0*/) goto t209_n102;
  t209_n101: return 0.19672620296478271f;
  t209_n102: return -0.4234304428100586f;
  t209_n103: return 0.1096452921628952f;
  t209_n104: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t209_n126;
  t209_n105: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t209_n117;
  t209_n106: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t209_n112;
  t209_n107: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t209_n111;
  t209_n108: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t209_n110;
  t209_n109: return -0.14892715215682983f;
  t209_n110: return -0.0364539697766304f;
  t209_n111: return 0.009138679131865501f;
  t209_n112: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t209_n116;
  t209_n113: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t209_n115;
  t209_n114: return -0.10497815161943436f;
  t209_n115: return 0.16719986498355865f;
  t209_n116: return 0.11280497908592224f;
  t209_n117: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t209_n125;
  t209_n118: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t209_n120;
  t209_n119: return 0.11913590133190155f;
  t209_n120: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t209_n122;
  t209_n121: return 0.08468074351549149f;
  t209_n122: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t209_n124;
  t209_n123: return 0.084744393825531f;
  t209_n124: return 0.12557491660118103f;
  t209_n125: return 0.021694505587220192f;
  t209_n126: return 0.12429366260766983f;
  t209_n127: if (E.getNumReferences() >= 3278503936 /*234.0*/) goto t209_n131;
  t209_n128: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t209_n130;
  t209_n129: return 0.1363212615251541f;
  t209_n130: return -0.10065226256847382f;
  t209_n131: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t209_n133;
  t209_n132: return -0.0038913642056286335f;
  t209_n133: if (E.getNumReferences() >= 3284353024 /*390.5*/) goto t209_n139;
  t209_n134: if (E.getNumReferences() >= 3282960384 /*348.0*/) goto t209_n136;
  t209_n135: return 0.08723988384008408f;
  t209_n136: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t209_n138;
  t209_n137: return 0.020879192277789116f;
  t209_n138: return 0.12989969551563263f;
  t209_n139: if (E.getNumReferences() >= 3334366208 /*24370.0*/) goto t209_n141;
  t209_n140: return 0.030592693015933037f;
  t209_n141: return 0.07497244328260422f;
  t209_n142: return -0.03951631113886833f;
  t209_n143: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t209_n185;
  t209_n144: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t209_n160;
  t209_n145: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t209_n147;
  t209_n146: return -0.016318337991833687f;
  t209_n147: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t209_n157;
  t209_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n156;
  t209_n149: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t209_n151;
  t209_n150: return 0.024448905140161514f;
  t209_n151: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t209_n153;
  t209_n152: return -0.01368767861276865f;
  t209_n153: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t209_n155;
  t209_n154: return 0.05452549830079079f;
  t209_n155: return 0.025257233530282974f;
  t209_n156: return -0.005159960128366947f;
  t209_n157: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t209_n159;
  t209_n158: return 0.11049284040927887f;
  t209_n159: return 0.1055283397436142f;
  t209_n160: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t209_n172;
  t209_n161: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n167;
  t209_n162: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t209_n166;
  t209_n163: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t209_n165;
  t209_n164: return 0.019568277522921562f;
  t209_n165: return 0.06687229126691818f;
  t209_n166: return 0.016869371756911278f;
  t209_n167: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t209_n169;
  t209_n168: return -0.07253467291593552f;
  t209_n169: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t209_n171;
  t209_n170: return 0.033546652644872665f;
  t209_n171: return 0.15775418281555176f;
  t209_n172: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t209_n184;
  t209_n173: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n183;
  t209_n174: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t209_n176;
  t209_n175: return 0.07990877330303192f;
  t209_n176: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t209_n178;
  t209_n177: return 0.02359831891953945f;
  t209_n178: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t209_n182;
  t209_n179: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t209_n181;
  t209_n180: return 0.06602393835783005f;
  t209_n181: return -0.34246620535850525f;
  t209_n182: return -0.12799367308616638f;
  t209_n183: return 0.05276767164468765f;
  t209_n184: return 0.004780441056936979f;
  t209_n185: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t209_n189;
  t209_n186: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t209_n188;
  t209_n187: return 0.06324028223752975f;
  t209_n188: return -0.06460803747177124f;
  t209_n189: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t209_n193;
  t209_n190: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t209_n192;
  t209_n191: return -0.10214801877737045f;
  t209_n192: return 0.11569949984550476f;
  t209_n193: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t209_n195;
  t209_n194: return -0.0020317945163697004f;
  t209_n195: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t209_n199;
  t209_n196: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n198;
  t209_n197: return -0.10769367218017578f;
  t209_n198: return 0.14581738412380219f;
  t209_n199: return 0.037463437765836716f;
  t209_n200: return -0.06049693003296852f;
  t209_n201: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t209_n253;
  t209_n202: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t209_n212;
  t209_n203: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t209_n205;
  t209_n204: return 0.0006702806567773223f;
  t209_n205: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t209_n207;
  t209_n206: return 0.02871757559478283f;
  t209_n207: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t209_n209;
  t209_n208: return -0.09091237932443619f;
  t209_n209: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t209_n211;
  t209_n210: return -0.14887316524982452f;
  t209_n211: return 0.028714284300804138f;
  t209_n212: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t209_n250;
  t209_n213: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t209_n233;
  t209_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t209_n218;
  t209_n215: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t209_n217;
  t209_n216: return -0.11173708736896515f;
  t209_n217: return 0.07038748264312744f;
  t209_n218: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t209_n226;
  t209_n219: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n223;
  t209_n220: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t209_n222;
  t209_n221: return 0.09719358384609222f;
  t209_n222: return 0.07017568498849869f;
  t209_n223: if (E.getNumReferences() >= 3247439872 /*18.0*/) goto t209_n225;
  t209_n224: return 0.0910455659031868f;
  t209_n225: return -0.24611681699752808f;
  t209_n226: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t209_n232;
  t209_n227: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t209_n229;
  t209_n228: return 0.14266616106033325f;
  t209_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n231;
  t209_n230: return 0.12757045030593872f;
  t209_n231: return 0.037185512483119965f;
  t209_n232: return 0.0470869280397892f;
  t209_n233: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t209_n245;
  t209_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n236;
  t209_n235: return 0.031975433230400085f;
  t209_n236: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t209_n240;
  t209_n237: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t209_n239;
  t209_n238: return 0.07479264587163925f;
  t209_n239: return 0.08757364004850388f;
  t209_n240: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t209_n244;
  t209_n241: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t209_n243;
  t209_n242: return -1.966653823852539f;
  t209_n243: return -0.03526495769619942f;
  t209_n244: return 0.08317942172288895f;
  t209_n245: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t209_n247;
  t209_n246: return 0.19294607639312744f;
  t209_n247: if (E.getNumReferences() >= 3328351232 /*14503.0*/) goto t209_n249;
  t209_n248: return 0.07741569727659225f;
  t209_n249: return -0.46834471821784973f;
  t209_n250: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t209_n252;
  t209_n251: return -0.044456083327531815f;
  t209_n252: return 0.009175770916044712f;
  t209_n253: return 0.004855211824178696f;
  t209_n254: return -0.06807418912649155f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree210(const Example& E) {
  t210_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t210_n240;
  t210_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t210_n91;
  t210_n2: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t210_n6;
  t210_n3: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t210_n5;
  t210_n4: return 0.007184136193245649f;
  t210_n5: return -0.005805002525448799f;
  t210_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t210_n84;
  t210_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t210_n83;
  t210_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t210_n66;
  t210_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t210_n21;
  t210_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t210_n16;
  t210_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t210_n15;
  t210_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n14;
  t210_n13: return -0.11359472572803497f;
  t210_n14: return -0.1534944325685501f;
  t210_n15: return -0.1067289263010025f;
  t210_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t210_n20;
  t210_n17: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n19;
  t210_n18: return 0.0327276773750782f;
  t210_n19: return -0.02362982928752899f;
  t210_n20: return 0.03294089064002037f;
  t210_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t210_n45;
  t210_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t210_n38;
  t210_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t210_n31;
  t210_n24: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t210_n30;
  t210_n25: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n29;
  t210_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n28;
  t210_n27: return -0.02771194465458393f;
  t210_n28: return -0.07469461858272552f;
  t210_n29: return -0.021338215097784996f;
  t210_n30: return -0.006165829487144947f;
  t210_n31: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t210_n37;
  t210_n32: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t210_n34;
  t210_n33: return 0.09008818119764328f;
  t210_n34: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t210_n36;
  t210_n35: return 0.09464267641305923f;
  t210_n36: return 0.06184849143028259f;
  t210_n37: return -0.05405690148472786f;
  t210_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t210_n40;
  t210_n39: return -0.060669660568237305f;
  t210_n40: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t210_n44;
  t210_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t210_n43;
  t210_n42: return 0.023147305473685265f;
  t210_n43: return -0.0032456654589623213f;
  t210_n44: return -0.005789491347968578f;
  t210_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t210_n65;
  t210_n46: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n50;
  t210_n47: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t210_n49;
  t210_n48: return 0.005291637033224106f;
  t210_n49: return 0.016832904890179634f;
  t210_n50: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t210_n64;
  t210_n51: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t210_n61;
  t210_n52: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t210_n58;
  t210_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t210_n55;
  t210_n54: return 0.018214061856269836f;
  t210_n55: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t210_n57;
  t210_n56: return 0.10822399705648422f;
  t210_n57: return -0.0650385245680809f;
  t210_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t210_n60;
  t210_n59: return -0.11154388636350632f;
  t210_n60: return 0.21212908625602722f;
  t210_n61: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t210_n63;
  t210_n62: return -0.1641658991575241f;
  t210_n63: return -0.25119316577911377f;
  t210_n64: return -0.00781001104041934f;
  t210_n65: return 0.03511415421962738f;
  t210_n66: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n68;
  t210_n67: return 0.011496446095407009f;
  t210_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t210_n78;
  t210_n69: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t210_n77;
  t210_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t210_n72;
  t210_n71: return 0.029213694855570793f;
  t210_n72: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t210_n74;
  t210_n73: return 0.12706013023853302f;
  t210_n74: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t210_n76;
  t210_n75: return 0.1803228110074997f;
  t210_n76: return 0.06360983103513718f;
  t210_n77: return 0.02532162517309189f;
  t210_n78: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t210_n82;
  t210_n79: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t210_n81;
  t210_n80: return 0.2378663271665573f;
  t210_n81: return 0.1243465319275856f;
  t210_n82: return -0.10131021589040756f;
  t210_n83: return -0.013252598233520985f;
  t210_n84: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t210_n90;
  t210_n85: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n87;
  t210_n86: return 0.10878200083971024f;
  t210_n87: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n89;
  t210_n88: return -0.6851146817207336f;
  t210_n89: return 0.02644304931163788f;
  t210_n90: return -0.0411803238093853f;
  t210_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t210_n107;
  t210_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t210_n106;
  t210_n93: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t210_n95;
  t210_n94: return -0.06510976701974869f;
  t210_n95: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t210_n97;
  t210_n96: return -0.01055991929024458f;
  t210_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t210_n99;
  t210_n98: return -0.0840660110116005f;
  t210_n99: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n105;
  t210_n100: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t210_n102;
  t210_n101: return -0.189814493060112f;
  t210_n102: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t210_n104;
  t210_n103: return 0.10009827464818954f;
  t210_n104: return -0.10544013231992722f;
  t210_n105: return 0.09495095908641815f;
  t210_n106: return 0.0009074579575099051f;
  t210_n107: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t210_n235;
  t210_n108: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t210_n112;
  t210_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t210_n111;
  t210_n110: return 0.00034292152849957347f;
  t210_n111: return 0.10642938315868378f;
  t210_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t210_n120;
  t210_n113: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t210_n119;
  t210_n114: if (E.getNumReferences() >= 3212836864 /*1.0*/) goto t210_n116;
  t210_n115: return 0.10436601936817169f;
  t210_n116: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t210_n118;
  t210_n117: return -0.0354156419634819f;
  t210_n118: return -1.3581041097640991f;
  t210_n119: return -0.022736448794603348f;
  t210_n120: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t210_n232;
  t210_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t210_n231;
  t210_n122: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t210_n148;
  t210_n123: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t210_n145;
  t210_n124: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t210_n132;
  t210_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t210_n131;
  t210_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n128;
  t210_n127: return -0.14166752994060516f;
  t210_n128: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t210_n130;
  t210_n129: return -0.5204707384109497f;
  t210_n130: return 0.027917688712477684f;
  t210_n131: return 0.009861885569989681f;
  t210_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t210_n136;
  t210_n133: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t210_n135;
  t210_n134: return -0.014073362573981285f;
  t210_n135: return 0.019379017874598503f;
  t210_n136: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n140;
  t210_n137: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t210_n139;
  t210_n138: return 0.046814270317554474f;
  t210_n139: return 0.009248413145542145f;
  t210_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t210_n144;
  t210_n141: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t210_n143;
  t210_n142: return -0.004246761091053486f;
  t210_n143: return -0.04522773623466492f;
  t210_n144: return 0.05896487459540367f;
  t210_n145: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t210_n147;
  t210_n146: return -0.07437112927436829f;
  t210_n147: return 0.15089809894561768f;
  t210_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t210_n174;
  t210_n149: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t210_n173;
  t210_n150: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t210_n164;
  t210_n151: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t210_n163;
  t210_n152: if (E.getNumReferences() >= 3252682752 /*28.0*/) goto t210_n160;
  t210_n153: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n159;
  t210_n154: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t210_n158;
  t210_n155: if (E.getNumReferences() >= 3229614080 /*4.0*/) goto t210_n157;
  t210_n156: return 0.09572633355855942f;
  t210_n157: return 0.029781091958284378f;
  t210_n158: return -0.21524783968925476f;
  t210_n159: return -0.07796575874090195f;
  t210_n160: if (E.getNumReferences() >= 3271491584 /*127.5*/) goto t210_n162;
  t210_n161: return 0.13118195533752441f;
  t210_n162: return -0.03984343260526657f;
  t210_n163: return -0.3002808690071106f;
  t210_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n170;
  t210_n165: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t210_n169;
  t210_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n168;
  t210_n167: return 0.11577632278203964f;
  t210_n168: return 0.059836067259311676f;
  t210_n169: return 0.07023251801729202f;
  t210_n170: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t210_n172;
  t210_n171: return -0.026954876258969307f;
  t210_n172: return 0.088923379778862f;
  t210_n173: return -0.013942532241344452f;
  t210_n174: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t210_n224;
  t210_n175: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t210_n189;
  t210_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n178;
  t210_n177: return 0.05440707132220268f;
  t210_n178: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n182;
  t210_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t210_n181;
  t210_n180: return 0.05907880887389183f;
  t210_n181: return 0.06397019326686859f;
  t210_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t210_n184;
  t210_n183: return -0.10330642759799957f;
  t210_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t210_n186;
  t210_n185: return 0.02756471373140812f;
  t210_n186: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t210_n188;
  t210_n187: return 0.09717992693185806f;
  t210_n188: return -0.14778541028499603f;
  t210_n189: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t210_n207;
  t210_n190: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t210_n198;
  t210_n191: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t210_n193;
  t210_n192: return 0.42307406663894653f;
  t210_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n195;
  t210_n194: return 0.1290668100118637f;
  t210_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t210_n197;
  t210_n196: return 0.0007603028789162636f;
  t210_n197: return 0.13539406657218933f;
  t210_n198: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t210_n200;
  t210_n199: return 0.7350807189941406f;
  t210_n200: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n202;
  t210_n201: return -0.32403311133384705f;
  t210_n202: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t210_n206;
  t210_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t210_n205;
  t210_n204: return -0.15193313360214233f;
  t210_n205: return 0.11325732618570328f;
  t210_n206: return 0.010443628765642643f;
  t210_n207: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t210_n209;
  t210_n208: return 0.03502590209245682f;
  t210_n209: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t210_n211;
  t210_n210: return -0.26442381739616394f;
  t210_n211: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t210_n215;
  t210_n212: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t210_n214;
  t210_n213: return 0.11526091396808624f;
  t210_n214: return 0.03263884037733078f;
  t210_n215: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t210_n217;
  t210_n216: return -0.20476983487606049f;
  t210_n217: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t210_n223;
  t210_n218: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t210_n222;
  t210_n219: if (E.getNumReferences() >= 3240099840 /*10.0*/) goto t210_n221;
  t210_n220: return 0.11584669351577759f;
  t210_n221: return 0.1006685271859169f;
  t210_n222: return 0.11083454638719559f;
  t210_n223: return 0.011183395981788635f;
  t210_n224: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t210_n226;
  t210_n225: return -0.026062900200486183f;
  t210_n226: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t210_n228;
  t210_n227: return -0.020047632977366447f;
  t210_n228: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t210_n230;
  t210_n229: return 0.04901443421840668f;
  t210_n230: return 0.013953210785984993f;
  t210_n231: return 0.00604663509875536f;
  t210_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n234;
  t210_n233: return 0.034731440246105194f;
  t210_n234: return 0.014800726436078548f;
  t210_n235: if (E.getNumReferences() >= 3282354176 /*329.5*/) goto t210_n237;
  t210_n236: return -0.02185334451496601f;
  t210_n237: if (E.getNumReferences() >= 3290128384 /*621.5*/) goto t210_n239;
  t210_n238: return 0.1151675432920456f;
  t210_n239: return 0.024226421490311623f;
  t210_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t210_n254;
  t210_n241: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t210_n243;
  t210_n242: return -0.005065925884991884f;
  t210_n243: if (E.getNumReferences() >= 3364952880 /*297177.5*/) goto t210_n253;
  t210_n244: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t210_n250;
  t210_n245: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t210_n247;
  t210_n246: return 0.005484310910105705f;
  t210_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n249;
  t210_n248: return 0.09569509327411652f;
  t210_n249: return 0.1006852388381958f;
  t210_n250: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t210_n252;
  t210_n251: return -0.21327656507492065f;
  t210_n252: return 0.014570512808859348f;
  t210_n253: return -0.010552647523581982f;
  t210_n254: return 0.0024400686379522085f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree211(const Example& E) {
  t211_n0: if (E.getNumReferences() >= 3306797056 /*2459.5*/) goto t211_n2;
  t211_n1: return -0.00034280316322110593f;
  t211_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t211_n6;
  t211_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t211_n5;
  t211_n4: return -0.07600048184394836f;
  t211_n5: return 0.011051119305193424f;
  t211_n6: if (E.getNumReferences() >= 3306835968 /*2469.0*/) goto t211_n10;
  t211_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t211_n9;
  t211_n8: return 0.05281812325119972f;
  t211_n9: return 0.10715220868587494f;
  t211_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t211_n12;
  t211_n11: return -0.003724026959389448f;
  t211_n12: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t211_n250;
  t211_n13: if (E.getNumReferences() >= 3343638400 /*52191.5*/) goto t211_n227;
  t211_n14: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t211_n16;
  t211_n15: return 0.00814634095877409f;
  t211_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t211_n180;
  t211_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t211_n77;
  t211_n18: if (E.getNumReferences() >= 3338619904 /*32678.0*/) goto t211_n66;
  t211_n19: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t211_n21;
  t211_n20: return -0.129803866147995f;
  t211_n21: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t211_n65;
  t211_n22: if (E.getNumReferences() >= 3331378176 /*18534.0*/) goto t211_n54;
  t211_n23: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t211_n53;
  t211_n24: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t211_n52;
  t211_n25: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t211_n29;
  t211_n26: if (E.getNumReferences() >= 3312386048 /*3824.0*/) goto t211_n28;
  t211_n27: return 0.12664274871349335f;
  t211_n28: return -0.07637408375740051f;
  t211_n29: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t211_n51;
  t211_n30: if (E.getNumReferences() >= 3329585664 /*15708.5*/) goto t211_n50;
  t211_n31: if (E.getNumReferences() >= 3325018624 /*11248.5*/) goto t211_n43;
  t211_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t211_n34;
  t211_n33: return 0.03271617367863655f;
  t211_n34: if (E.getNumReferences() >= 3315421184 /*5034.0*/) goto t211_n38;
  t211_n35: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t211_n37;
  t211_n36: return -0.863402783870697f;
  t211_n37: return 0.035410359501838684f;
  t211_n38: if (E.getNumReferences() >= 3322780160 /*9062.5*/) goto t211_n42;
  t211_n39: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t211_n41;
  t211_n40: return 0.10759830474853516f;
  t211_n41: return 0.036926236003637314f;
  t211_n42: return 0.06894124299287796f;
  t211_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t211_n49;
  t211_n44: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t211_n46;
  t211_n45: return 0.09811899811029434f;
  t211_n46: if (E.getNumReferences() >= 3328893952 /*15033.0*/) goto t211_n48;
  t211_n47: return 0.13498499989509583f;
  t211_n48: return -0.12574262917041779f;
  t211_n49: return 0.10809896886348724f;
  t211_n50: return -0.24305488169193268f;
  t211_n51: return -0.007153818849474192f;
  t211_n52: return -0.0516209751367569f;
  t211_n53: return -0.0837269201874733f;
  t211_n54: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t211_n64;
  t211_n55: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t211_n57;
  t211_n56: return 0.04613684490323067f;
  t211_n57: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t211_n61;
  t211_n58: if (E.getNumReferences() >= 3332774144 /*21260.5*/) goto t211_n60;
  t211_n59: return 0.11614754050970078f;
  t211_n60: return 0.1115524023771286f;
  t211_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t211_n63;
  t211_n62: return 0.07260771840810776f;
  t211_n63: return 0.10311765968799591f;
  t211_n64: return -0.05430222675204277f;
  t211_n65: return -0.11261744052171707f;
  t211_n66: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t211_n76;
  t211_n67: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t211_n71;
  t211_n68: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t211_n70;
  t211_n69: return 0.08920980989933014f;
  t211_n70: return -0.0028698768001049757f;
  t211_n71: if (E.getNumReferences() >= 3338736000 /*33041.5*/) goto t211_n75;
  t211_n72: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t211_n74;
  t211_n73: return -0.11459625512361526f;
  t211_n74: return 0.11848372966051102f;
  t211_n75: return 0.039685655385255814f;
  t211_n76: return -0.12060762941837311f;
  t211_n77: if (E.getNumReferences() >= 3340439680 /*39696.5*/) goto t211_n179;
  t211_n78: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t211_n160;
  t211_n79: if (E.getNumReferences() >= 3329258496 /*15389.0*/) goto t211_n137;
  t211_n80: if (E.getNumReferences() >= 3328425472 /*14575.5*/) goto t211_n128;
  t211_n81: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t211_n101;
  t211_n82: if (E.getNumReferences() >= 3317757952 /*6175.0*/) goto t211_n86;
  t211_n83: if (E.getNumReferences() >= 3308642304 /*2910.0*/) goto t211_n85;
  t211_n84: return -0.26457729935646057f;
  t211_n85: return 0.012462579645216465f;
  t211_n86: if (E.getNumReferences() >= 3318990848 /*6777.0*/) goto t211_n94;
  t211_n87: if (E.getNumReferences() >= 3318719488 /*6644.5*/) goto t211_n91;
  t211_n88: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t211_n90;
  t211_n89: return 0.079757921397686f;
  t211_n90: return 0.111492820084095f;
  t211_n91: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t211_n93;
  t211_n92: return 0.12136856466531754f;
  t211_n93: return 0.08109903335571289f;
  t211_n94: if (E.getNumReferences() >= 3325044224 /*11273.5*/) goto t211_n96;
  t211_n95: return 0.01442534290254116f;
  t211_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t211_n98;
  t211_n97: return 0.020566174760460854f;
  t211_n98: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t211_n100;
  t211_n99: return 0.11808637529611588f;
  t211_n100: return 0.08063694834709167f;
  t211_n101: if (E.getNumReferences() >= 3308173312 /*2795.5*/) goto t211_n105;
  t211_n102: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t211_n104;
  t211_n103: return 0.13261355459690094f;
  t211_n104: return 0.038967907428741455f;
  t211_n105: if (E.getNumReferences() >= 3320574976 /*7550.5*/) goto t211_n111;
  t211_n106: if (E.getNumReferences() >= 3320417280 /*7473.5*/) goto t211_n110;
  t211_n107: if (E.getNumReferences() >= 3316514816 /*5568.0*/) goto t211_n109;
  t211_n108: return -0.005203723441809416f;
  t211_n109: return 0.058509886264801025f;
  t211_n110: return 0.1148066446185112f;
  t211_n111: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t211_n123;
  t211_n112: if (E.getNumReferences() >= 3325662720 /*11877.5*/) goto t211_n120;
  t211_n113: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t211_n115;
  t211_n114: return -0.31298479437828064f;
  t211_n115: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t211_n117;
  t211_n116: return -0.13381317257881165f;
  t211_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t211_n119;
  t211_n118: return -0.5430344939231873f;
  t211_n119: return 0.10239288955926895f;
  t211_n120: if (E.getNumReferences() >= 3325985280 /*12192.5*/) goto t211_n122;
  t211_n121: return 0.14983539283275604f;
  t211_n122: return -0.06922974437475204f;
  t211_n123: if (E.getNumReferences() >= 3323087360 /*9362.5*/) goto t211_n127;
  t211_n124: if (E.getNumReferences() >= 3321165824 /*7839.0*/) goto t211_n126;
  t211_n125: return -0.546727180480957f;
  t211_n126: return 0.11391594260931015f;
  t211_n127: return -0.02081524021923542f;
  t211_n128: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t211_n134;
  t211_n129: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t211_n131;
  t211_n130: return -0.04680541530251503f;
  t211_n131: if (E.getNumReferences() >= 3328686080 /*14830.0*/) goto t211_n133;
  t211_n132: return 0.11390171200037003f;
  t211_n133: return 0.10034305602312088f;
  t211_n134: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t211_n136;
  t211_n135: return 0.12971511483192444f;
  t211_n136: return 0.1745920032262802f;
  t211_n137: if (E.getNumReferences() >= 3332353792 /*20439.5*/) goto t211_n153;
  t211_n138: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t211_n140;
  t211_n139: return -0.11700206995010376f;
  t211_n140: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t211_n144;
  t211_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t211_n143;
  t211_n142: return -0.8110145926475525f;
  t211_n143: return 0.09581031650304794f;
  t211_n144: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t211_n152;
  t211_n145: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t211_n147;
  t211_n146: return 0.027486121281981468f;
  t211_n147: if (E.getNumReferences() >= 3331103232 /*17997.0*/) goto t211_n151;
  t211_n148: if (E.getNumReferences() >= 3329836032 /*15953.0*/) goto t211_n150;
  t211_n149: return 0.06274215131998062f;
  t211_n150: return 0.10809224843978882f;
  t211_n151: return -0.4560227394104004f;
  t211_n152: return -0.32519662380218506f;
  t211_n153: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t211_n159;
  t211_n154: if (E.getNumReferences() >= 3336773376 /*29071.5*/) goto t211_n158;
  t211_n155: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t211_n157;
  t211_n156: return 0.021538112312555313f;
  t211_n157: return 0.07045447081327438f;
  t211_n158: return -0.08420618623495102f;
  t211_n159: return -0.20334933698177338f;
  t211_n160: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t211_n166;
  t211_n161: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t211_n163;
  t211_n162: return 0.09384621679782867f;
  t211_n163: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t211_n165;
  t211_n164: return 0.04236747696995735f;
  t211_n165: return 0.08365986496210098f;
  t211_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t211_n168;
  t211_n167: return 0.013080926612019539f;
  t211_n168: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t211_n170;
  t211_n169: return 0.09987849742174149f;
  t211_n170: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t211_n174;
  t211_n171: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t211_n173;
  t211_n172: return 0.0639449879527092f;
  t211_n173: return -0.17232026159763336f;
  t211_n174: if (E.getNumReferences() >= 3339230592 /*34973.5*/) goto t211_n176;
  t211_n175: return -0.05739501491189003f;
  t211_n176: if (E.getNumReferences() >= 3339662592 /*36661.0*/) goto t211_n178;
  t211_n177: return 0.1125185638666153f;
  t211_n178: return 0.009024559520184994f;
  t211_n179: return -0.11521992087364197f;
  t211_n180: if (E.getNumReferences() >= 3320613888 /*7569.5*/) goto t211_n200;
  t211_n181: if (E.getNumReferences() >= 3314667520 /*4666.0*/) goto t211_n199;
  t211_n182: if (E.getNumReferences() >= 3313434624 /*4080.0*/) goto t211_n196;
  t211_n183: if (E.getNumReferences() >= 3312861184 /*3940.0*/) goto t211_n195;
  t211_n184: if (E.getNumReferences() >= 3312044032 /*3740.5*/) goto t211_n194;
  t211_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t211_n187;
  t211_n186: return 0.018695656210184097f;
  t211_n187: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t211_n193;
  t211_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t211_n190;
  t211_n189: return -0.4568278193473816f;
  t211_n190: if (E.getNumReferences() >= 3309334528 /*3079.0*/) goto t211_n192;
  t211_n191: return 0.10949040949344635f;
  t211_n192: return -0.08714193850755692f;
  t211_n193: return 0.10743113607168198f;
  t211_n194: return 0.1199222281575203f;
  t211_n195: return -0.3930237889289856f;
  t211_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t211_n198;
  t211_n197: return 0.034540772438049316f;
  t211_n198: return 0.10737422108650208f;
  t211_n199: return -0.06603178381919861f;
  t211_n200: if (E.getNumReferences() >= 3327153152 /*13333.0*/) goto t211_n218;
  t211_n201: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t211_n205;
  t211_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t211_n204;
  t211_n203: return 0.07678180187940598f;
  t211_n204: return 0.10880625247955322f;
  t211_n205: if (E.getNumReferences() >= 3322342912 /*8635.5*/) goto t211_n209;
  t211_n206: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t211_n208;
  t211_n207: return 0.0635736808180809f;
  t211_n208: return 0.11638810485601425f;
  t211_n209: if (E.getNumReferences() >= 3324232192 /*10480.5*/) goto t211_n211;
  t211_n210: return 0.010297494009137154f;
  t211_n211: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t211_n217;
  t211_n212: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t211_n216;
  t211_n213: if (E.getNumReferences() >= 3324847616 /*11081.5*/) goto t211_n215;
  t211_n214: return 0.11211082339286804f;
  t211_n215: return 0.1123732402920723f;
  t211_n216: return -0.024774711579084396f;
  t211_n217: return 0.04998670518398285f;
  t211_n218: if (E.getNumReferences() >= 3336670976 /*28871.5*/) goto t211_n220;
  t211_n219: return 0.023349424824118614f;
  t211_n220: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t211_n226;
  t211_n221: if (E.getNumReferences() >= 3339203200 /*34866.5*/) goto t211_n225;
  t211_n222: if (E.getNumReferences() >= 3338937088 /*33827.0*/) goto t211_n224;
  t211_n223: return 0.10163851827383041f;
  t211_n224: return 0.12229029089212418f;
  t211_n225: return 0.06749463826417923f;
  t211_n226: return -0.17188115417957306f;
  t211_n227: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t211_n235;
  t211_n228: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t211_n230;
  t211_n229: return -0.16464141011238098f;
  t211_n230: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t211_n234;
  t211_n231: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t211_n233;
  t211_n232: return 0.11920545250177383f;
  t211_n233: return 0.12024819105863571f;
  t211_n234: return -0.13358068466186523f;
  t211_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t211_n239;
  t211_n236: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t211_n238;
  t211_n237: return -0.316056489944458f;
  t211_n238: return 0.03782785311341286f;
  t211_n239: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t211_n241;
  t211_n240: return -0.09027489274740219f;
  t211_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t211_n249;
  t211_n242: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t211_n244;
  t211_n243: return 0.15811240673065186f;
  t211_n244: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t211_n246;
  t211_n245: return 0.15299099683761597f;
  t211_n246: if (E.getNumReferences() >= 3344616064 /*56010.5*/) goto t211_n248;
  t211_n247: return 0.14035923779010773f;
  t211_n248: return -0.13746154308319092f;
  t211_n249: return 0.06429271399974823f;
  t211_n250: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t211_n252;
  t211_n251: return -0.005044121760874987f;
  t211_n252: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t211_n254;
  t211_n253: return 0.06194707006216049f;
  t211_n254: return -0.25445178151130676f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree212(const Example& E) {
  t212_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t212_n2;
  t212_n1: return -0.00024227119865827262f;
  t212_n2: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t212_n26;
  t212_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t212_n5;
  t212_n4: return 0.0021666993852704763f;
  t212_n5: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t212_n19;
  t212_n6: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t212_n16;
  t212_n7: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t212_n9;
  t212_n8: return 0.0701599195599556f;
  t212_n9: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t212_n15;
  t212_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t212_n12;
  t212_n11: return 0.042806509882211685f;
  t212_n12: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t212_n14;
  t212_n13: return -0.5804339051246643f;
  t212_n14: return 0.11154245585203171f;
  t212_n15: return 0.19756686687469482f;
  t212_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t212_n18;
  t212_n17: return 0.08912091702222824f;
  t212_n18: return 0.04920370504260063f;
  t212_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t212_n25;
  t212_n20: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t212_n22;
  t212_n21: return -0.26831361651420593f;
  t212_n22: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t212_n24;
  t212_n23: return 0.11431409418582916f;
  t212_n24: return 0.11046456545591354f;
  t212_n25: return -0.01137707382440567f;
  t212_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t212_n28;
  t212_n27: return -0.003050510073080659f;
  t212_n28: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t212_n118;
  t212_n29: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t212_n31;
  t212_n30: return 0.008543040603399277f;
  t212_n31: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t212_n117;
  t212_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t212_n94;
  t212_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t212_n93;
  t212_n34: if (E.getNumReferences() >= 3333043200 /*21786.0*/) goto t212_n54;
  t212_n35: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t212_n47;
  t212_n36: if (E.getNumReferences() >= 3332703744 /*21123.0*/) goto t212_n38;
  t212_n37: return -0.04531959444284439f;
  t212_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t212_n40;
  t212_n39: return -0.1600242704153061f;
  t212_n40: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t212_n46;
  t212_n41: if (E.getNumReferences() >= 3332892672 /*21492.0*/) goto t212_n45;
  t212_n42: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t212_n44;
  t212_n43: return 0.09165424853563309f;
  t212_n44: return 0.09544993937015533f;
  t212_n45: return 0.08278928697109222f;
  t212_n46: return -0.43282201886177063f;
  t212_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t212_n53;
  t212_n48: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t212_n52;
  t212_n49: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t212_n51;
  t212_n50: return 0.11366850137710571f;
  t212_n51: return -0.10614126175642014f;
  t212_n52: return 0.022841040045022964f;
  t212_n53: return 0.1033555343747139f;
  t212_n54: if (E.getNumReferences() >= 3340289792 /*39111.0*/) goto t212_n56;
  t212_n55: return -0.05481288582086563f;
  t212_n56: if (E.getNumReferences() >= 3340611840 /*40369.0*/) goto t212_n62;
  t212_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t212_n59;
  t212_n58: return 0.06247694417834282f;
  t212_n59: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t212_n61;
  t212_n60: return 0.25470808148384094f;
  t212_n61: return -0.11382563412189484f;
  t212_n62: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t212_n66;
  t212_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t212_n65;
  t212_n64: return -0.02210906706750393f;
  t212_n65: return 0.05485249310731888f;
  t212_n66: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t212_n92;
  t212_n67: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t212_n75;
  t212_n68: if (E.getNumReferences() >= 3349612032 /*85516.0*/) goto t212_n70;
  t212_n69: return -0.13171687722206116f;
  t212_n70: if (E.getNumReferences() >= 3356105632 /*141422.5*/) goto t212_n74;
  t212_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t212_n73;
  t212_n72: return -0.06198028847575188f;
  t212_n73: return 0.041745174676179886f;
  t212_n74: return -0.05486854165792465f;
  t212_n75: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t212_n91;
  t212_n76: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t212_n90;
  t212_n77: if (E.getNumReferences() >= 3366258096 /*337965.5*/) goto t212_n89;
  t212_n78: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t212_n86;
  t212_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t212_n85;
  t212_n80: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t212_n84;
  t212_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t212_n83;
  t212_n82: return -1.666892170906067f;
  t212_n83: return 0.14768746495246887f;
  t212_n84: return -0.19868230819702148f;
  t212_n85: return 0.07102274894714355f;
  t212_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t212_n88;
  t212_n87: return -1.6483917236328125f;
  t212_n88: return -0.12124619632959366f;
  t212_n89: return 0.01859564147889614f;
  t212_n90: return 0.08668447285890579f;
  t212_n91: return -0.014303416945040226f;
  t212_n92: return -0.0027234903536736965f;
  t212_n93: return 0.0006217919290065765f;
  t212_n94: if (E.getNumReferences() >= 3332305408 /*20345.0*/) goto t212_n104;
  t212_n95: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t212_n97;
  t212_n96: return -0.08241885900497437f;
  t212_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t212_n101;
  t212_n98: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t212_n100;
  t212_n99: return 0.13080167770385742f;
  t212_n100: return 0.18490338325500488f;
  t212_n101: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t212_n103;
  t212_n102: return 0.14738331735134125f;
  t212_n103: return 0.10541584342718124f;
  t212_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t212_n106;
  t212_n105: return -0.0023547462187707424f;
  t212_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t212_n114;
  t212_n107: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t212_n113;
  t212_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t212_n112;
  t212_n109: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t212_n111;
  t212_n110: return 0.026746833696961403f;
  t212_n111: return -0.41944748163223267f;
  t212_n112: return 0.04904739186167717f;
  t212_n113: return 0.03306254372000694f;
  t212_n114: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t212_n116;
  t212_n115: return 0.11360988020896912f;
  t212_n116: return -0.0049309078603982925f;
  t212_n117: return 0.14936725795269012f;
  t212_n118: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t212_n252;
  t212_n119: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t212_n153;
  t212_n120: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t212_n152;
  t212_n121: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t212_n123;
  t212_n122: return -0.021710488945245743f;
  t212_n123: if (E.getNumReferences() >= 3332396032 /*20522.0*/) goto t212_n133;
  t212_n124: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t212_n132;
  t212_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t212_n131;
  t212_n126: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t212_n128;
  t212_n127: return -0.31419506669044495f;
  t212_n128: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t212_n130;
  t212_n129: return -0.42176157236099243f;
  t212_n130: return 0.11305063217878342f;
  t212_n131: return 0.12764038145542145f;
  t212_n132: return 0.11837613582611084f;
  t212_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t212_n147;
  t212_n134: if (E.getNumReferences() >= 3334173440 /*23993.5*/) goto t212_n146;
  t212_n135: if (E.getNumReferences() >= 3333190144 /*22073.0*/) goto t212_n145;
  t212_n136: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t212_n138;
  t212_n137: return 0.2750869691371918f;
  t212_n138: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t212_n140;
  t212_n139: return -0.12331593781709671f;
  t212_n140: if (E.getNumReferences() >= 3333150720 /*21996.0*/) goto t212_n142;
  t212_n141: return 0.04112645983695984f;
  t212_n142: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t212_n144;
  t212_n143: return 0.11106878519058228f;
  t212_n144: return 0.05607255920767784f;
  t212_n145: return -0.008150896057486534f;
  t212_n146: return 0.10030964016914368f;
  t212_n147: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t212_n149;
  t212_n148: return 0.06307941675186157f;
  t212_n149: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t212_n151;
  t212_n150: return 0.11582539975643158f;
  t212_n151: return 0.09587429463863373f;
  t212_n152: return -0.026805054396390915f;
  t212_n153: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t212_n159;
  t212_n154: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t212_n156;
  t212_n155: return 0.09999288618564606f;
  t212_n156: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t212_n158;
  t212_n157: return 0.04092106223106384f;
  t212_n158: return 0.08225734531879425f;
  t212_n159: if (E.getNumReferences() >= 3341362816 /*43302.5*/) goto t212_n209;
  t212_n160: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t212_n200;
  t212_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t212_n179;
  t212_n162: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t212_n170;
  t212_n163: if (E.getNumReferences() >= 3338965376 /*33937.5*/) goto t212_n165;
  t212_n164: return -0.17273680865764618f;
  t212_n165: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t212_n167;
  t212_n166: return 0.03671666607260704f;
  t212_n167: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t212_n169;
  t212_n168: return 0.18307898938655853f;
  t212_n169: return 0.10397421568632126f;
  t212_n170: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t212_n172;
  t212_n171: return -0.17257709801197052f;
  t212_n172: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t212_n174;
  t212_n173: return 0.07165277749300003f;
  t212_n174: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t212_n176;
  t212_n175: return -0.11287416517734528f;
  t212_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t212_n178;
  t212_n177: return 0.08748944103717804f;
  t212_n178: return 0.11585824191570282f;
  t212_n179: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t212_n199;
  t212_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t212_n194;
  t212_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t212_n183;
  t212_n182: return 0.03292141854763031f;
  t212_n183: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t212_n189;
  t212_n184: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t212_n186;
  t212_n185: return 0.072577565908432f;
  t212_n186: if (E.getNumReferences() >= 3339662592 /*36661.0*/) goto t212_n188;
  t212_n187: return 0.11165206134319305f;
  t212_n188: return 0.06582724303007126f;
  t212_n189: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t212_n191;
  t212_n190: return -0.1412384808063507f;
  t212_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t212_n193;
  t212_n192: return -0.5677974820137024f;
  t212_n193: return 0.08650339394807816f;
  t212_n194: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t212_n198;
  t212_n195: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t212_n197;
  t212_n196: return -0.001021073549054563f;
  t212_n197: return 0.109201580286026f;
  t212_n198: return 0.049468033015728f;
  t212_n199: return 0.1130000427365303f;
  t212_n200: if (E.getNumReferences() >= 3338840320 /*33449.0*/) goto t212_n202;
  t212_n201: return -0.15795683860778809f;
  t212_n202: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t212_n206;
  t212_n203: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t212_n205;
  t212_n204: return 0.07129666954278946f;
  t212_n205: return 0.12230691313743591f;
  t212_n206: if (E.getFileProximityDistance() >= 3249537024 /*22.0*/) goto t212_n208;
  t212_n207: return 0.014091435819864273f;
  t212_n208: return -0.4039778709411621f;
  t212_n209: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t212_n215;
  t212_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t212_n212;
  t212_n211: return -0.06865368783473969f;
  t212_n212: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t212_n214;
  t212_n213: return -0.06876403093338013f;
  t212_n214: return 0.09989161789417267f;
  t212_n215: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t212_n229;
  t212_n216: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t212_n226;
  t212_n217: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t212_n219;
  t212_n218: return 0.029627038165926933f;
  t212_n219: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t212_n225;
  t212_n220: if (E.getNumReferences() >= 3346276992 /*62498.5*/) goto t212_n224;
  t212_n221: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t212_n223;
  t212_n222: return 0.08750510960817337f;
  t212_n223: return 0.11650906503200531f;
  t212_n224: return 0.09249580651521683f;
  t212_n225: return -0.013722024857997894f;
  t212_n226: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t212_n228;
  t212_n227: return 0.10366365313529968f;
  t212_n228: return -0.2946960926055908f;
  t212_n229: if (E.getNumReferences() >= 3344616064 /*56010.5*/) goto t212_n231;
  t212_n230: return 0.08377189934253693f;
  t212_n231: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t212_n245;
  t212_n232: if (E.getNumReferences() >= 3348338496 /*75566.5*/) goto t212_n242;
  t212_n233: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t212_n241;
  t212_n234: if (E.getNumReferences() >= 3345041664 /*57673.0*/) goto t212_n236;
  t212_n235: return -0.017432617023587227f;
  t212_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t212_n240;
  t212_n237: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t212_n239;
  t212_n238: return 0.012342731468379498f;
  t212_n239: return 0.1276673823595047f;
  t212_n240: return 0.10638733953237534f;
  t212_n241: return -0.03303537145256996f;
  t212_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t212_n244;
  t212_n243: return 0.07193852961063385f;
  t212_n244: return 0.016352398321032524f;
  t212_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t212_n247;
  t212_n246: return 0.04111986979842186f;
  t212_n247: if (E.getNumReferences() >= 3346307456 /*62617.5*/) goto t212_n249;
  t212_n248: return 0.09943270683288574f;
  t212_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t212_n251;
  t212_n250: return 0.022835224866867065f;
  t212_n251: return 0.09106514602899551f;
  t212_n252: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t212_n254;
  t212_n253: return -0.3171546757221222f;
  t212_n254: return 0.0019244570285081863f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree213(const Example& E) {
  t213_n0: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t213_n232;
  t213_n1: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t213_n103;
  t213_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t213_n102;
  t213_n3: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t213_n5;
  t213_n4: return -0.038584329187870026f;
  t213_n5: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t213_n49;
  t213_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t213_n8;
  t213_n7: return -0.11134029924869537f;
  t213_n8: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n10;
  t213_n9: return 0.03589673340320587f;
  t213_n10: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t213_n38;
  t213_n11: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t213_n13;
  t213_n12: return 0.038780685514211655f;
  t213_n13: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t213_n27;
  t213_n14: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t213_n16;
  t213_n15: return -0.06326399743556976f;
  t213_n16: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t213_n18;
  t213_n17: return 0.0037079579196870327f;
  t213_n18: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t213_n20;
  t213_n19: return -0.18766431510448456f;
  t213_n20: if (E.getNumReferences() >= 3278012416 /*226.5*/) goto t213_n24;
  t213_n21: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t213_n23;
  t213_n22: return 0.1112707182765007f;
  t213_n23: return 0.057256799191236496f;
  t213_n24: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t213_n26;
  t213_n25: return 0.09663420170545578f;
  t213_n26: return -0.10344807803630829f;
  t213_n27: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t213_n29;
  t213_n28: return 0.014559306204319f;
  t213_n29: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t213_n31;
  t213_n30: return 0.1106511801481247f;
  t213_n31: if (E.getNumReferences() >= 3288924160 /*548.0*/) goto t213_n37;
  t213_n32: if (E.getNumReferences() >= 3287007232 /*471.5*/) goto t213_n36;
  t213_n33: if (E.getNumReferences() >= 3282731008 /*341.0*/) goto t213_n35;
  t213_n34: return 0.10148146748542786f;
  t213_n35: return -0.16463883221149445f;
  t213_n36: return 0.11957104504108429f;
  t213_n37: return -0.15373878180980682f;
  t213_n38: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t213_n40;
  t213_n39: return -0.15105360746383667f;
  t213_n40: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t213_n42;
  t213_n41: return 0.11245090514421463f;
  t213_n42: if (E.getNumReferences() >= 3259760640 /*51.0*/) goto t213_n46;
  t213_n43: if (E.getNumReferences() >= 3249537024 /*22.0*/) goto t213_n45;
  t213_n44: return 0.14695754647254944f;
  t213_n45: return -0.3558984696865082f;
  t213_n46: if (E.getNumReferences() >= 3288883200 /*545.5*/) goto t213_n48;
  t213_n47: return 0.10898718982934952f;
  t213_n48: return -0.10586269199848175f;
  t213_n49: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t213_n51;
  t213_n50: return 0.0010674773948267102f;
  t213_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n53;
  t213_n52: return -0.025171570479869843f;
  t213_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t213_n55;
  t213_n54: return -0.06462769955396652f;
  t213_n55: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t213_n93;
  t213_n56: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t213_n58;
  t213_n57: return -0.04213368147611618f;
  t213_n58: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t213_n86;
  t213_n59: if (E.getNumReferences() >= 3272540160 /*143.0*/) goto t213_n85;
  t213_n60: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t213_n78;
  t213_n61: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t213_n69;
  t213_n62: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t213_n68;
  t213_n63: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t213_n65;
  t213_n64: return 0.12537048757076263f;
  t213_n65: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t213_n67;
  t213_n66: return -0.12013889849185944f;
  t213_n67: return 0.10819972306489944f;
  t213_n68: return -0.11299606412649155f;
  t213_n69: if (E.getNumReferences() >= 3259498496 /*50.0*/) goto t213_n77;
  t213_n70: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t213_n76;
  t213_n71: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t213_n75;
  t213_n72: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t213_n74;
  t213_n73: return 0.004870756063610315f;
  t213_n74: return 0.08671628683805466f;
  t213_n75: return 0.15114310383796692f;
  t213_n76: return -0.22427263855934143f;
  t213_n77: return 0.1110190898180008f;
  t213_n78: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t213_n84;
  t213_n79: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t213_n83;
  t213_n80: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t213_n82;
  t213_n81: return 0.12094075232744217f;
  t213_n82: return -0.11828576773405075f;
  t213_n83: return 0.12104195356369019f;
  t213_n84: return -0.11936046183109283f;
  t213_n85: return 0.10740459710359573f;
  t213_n86: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t213_n88;
  t213_n87: return -0.010994750075042248f;
  t213_n88: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t213_n92;
  t213_n89: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t213_n91;
  t213_n90: return 0.11075722426176071f;
  t213_n91: return -0.11053092777729034f;
  t213_n92: return 0.06779972463846207f;
  t213_n93: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t213_n95;
  t213_n94: return 0.025401171296834946f;
  t213_n95: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t213_n99;
  t213_n96: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t213_n98;
  t213_n97: return 0.08577165007591248f;
  t213_n98: return -0.007268555462360382f;
  t213_n99: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t213_n101;
  t213_n100: return -0.10173819214105606f;
  t213_n101: return 0.12139065563678741f;
  t213_n102: return 0.0007787266513332725f;
  t213_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t213_n121;
  t213_n104: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t213_n120;
  t213_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t213_n107;
  t213_n106: return -0.010821524076163769f;
  t213_n107: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t213_n117;
  t213_n108: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t213_n116;
  t213_n109: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t213_n115;
  t213_n110: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n112;
  t213_n111: return 0.08788023889064789f;
  t213_n112: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t213_n114;
  t213_n113: return -0.03482140973210335f;
  t213_n114: return 0.07851678878068924f;
  t213_n115: return 0.05363922938704491f;
  t213_n116: return -0.04978804290294647f;
  t213_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t213_n119;
  t213_n118: return -0.09235583990812302f;
  t213_n119: return 0.03852672874927521f;
  t213_n120: return -0.00033507472835481167f;
  t213_n121: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t213_n219;
  t213_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t213_n218;
  t213_n123: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t213_n181;
  t213_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t213_n128;
  t213_n125: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n127;
  t213_n126: return -0.015590827912092209f;
  t213_n127: return -0.18161889910697937f;
  t213_n128: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t213_n130;
  t213_n129: return -0.06319733709096909f;
  t213_n130: if (E.getNumReferences() >= 3369273984 /*432212.0*/) goto t213_n180;
  t213_n131: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t213_n133;
  t213_n132: return -0.03019639477133751f;
  t213_n133: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t213_n139;
  t213_n134: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t213_n136;
  t213_n135: return 0.2544310986995697f;
  t213_n136: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t213_n138;
  t213_n137: return 0.10707499086856842f;
  t213_n138: return 0.09112580120563507f;
  t213_n139: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t213_n153;
  t213_n140: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n144;
  t213_n141: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t213_n143;
  t213_n142: return -0.9978860020637512f;
  t213_n143: return -0.11291554570198059f;
  t213_n144: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t213_n152;
  t213_n145: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t213_n147;
  t213_n146: return -0.24286161363124847f;
  t213_n147: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t213_n151;
  t213_n148: if (E.getNumReferences() >= 3276406784 /*202.0*/) goto t213_n150;
  t213_n149: return 0.16355963051319122f;
  t213_n150: return 0.12571360170841217f;
  t213_n151: return -0.42285728454589844f;
  t213_n152: return -0.23861336708068848f;
  t213_n153: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n173;
  t213_n154: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t213_n164;
  t213_n155: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t213_n161;
  t213_n156: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t213_n158;
  t213_n157: return -0.23168642818927765f;
  t213_n158: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t213_n160;
  t213_n159: return 0.13862237334251404f;
  t213_n160: return -0.107292540371418f;
  t213_n161: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t213_n163;
  t213_n162: return 0.11016970872879028f;
  t213_n163: return 0.0747750774025917f;
  t213_n164: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t213_n166;
  t213_n165: return -0.08174756169319153f;
  t213_n166: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t213_n170;
  t213_n167: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t213_n169;
  t213_n168: return 0.11605176329612732f;
  t213_n169: return -0.10188496857881546f;
  t213_n170: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t213_n172;
  t213_n171: return -0.1844882369041443f;
  t213_n172: return 0.03304218128323555f;
  t213_n173: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t213_n177;
  t213_n174: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t213_n176;
  t213_n175: return 0.047180525958538055f;
  t213_n176: return -0.14470501244068146f;
  t213_n177: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t213_n179;
  t213_n178: return 0.08210038393735886f;
  t213_n179: return -0.19566710293293f;
  t213_n180: return -0.4765380322933197f;
  t213_n181: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t213_n207;
  t213_n182: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t213_n194;
  t213_n183: if (E.getNumReferences() >= 3359775840 /*198769.5*/) goto t213_n193;
  t213_n184: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t213_n186;
  t213_n185: return -0.060306597501039505f;
  t213_n186: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t213_n192;
  t213_n187: if (E.getNumReferences() >= 3280764928 /*281.0*/) goto t213_n191;
  t213_n188: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t213_n190;
  t213_n189: return 0.09754377603530884f;
  t213_n190: return -0.07009054720401764f;
  t213_n191: return -0.05732571333646774f;
  t213_n192: return -0.2788011133670807f;
  t213_n193: return -0.5354407429695129f;
  t213_n194: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t213_n196;
  t213_n195: return -0.33015358448028564f;
  t213_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t213_n206;
  t213_n197: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t213_n203;
  t213_n198: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t213_n200;
  t213_n199: return 0.07615012675523758f;
  t213_n200: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t213_n202;
  t213_n201: return 0.150972381234169f;
  t213_n202: return -0.6933717727661133f;
  t213_n203: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t213_n205;
  t213_n204: return 0.09257926046848297f;
  t213_n205: return 0.10916110128164291f;
  t213_n206: return 0.033111974596977234f;
  t213_n207: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t213_n209;
  t213_n208: return -0.05468262359499931f;
  t213_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t213_n211;
  t213_n210: return 0.0027049221098423004f;
  t213_n211: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t213_n215;
  t213_n212: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t213_n214;
  t213_n213: return -0.030440034344792366f;
  t213_n214: return 0.014172902330756187f;
  t213_n215: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n217;
  t213_n216: return -0.06369675695896149f;
  t213_n217: return 0.10233376175165176f;
  t213_n218: return 0.004626577254384756f;
  t213_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t213_n221;
  t213_n220: return 0.007392421830445528f;
  t213_n221: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t213_n231;
  t213_n222: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t213_n230;
  t213_n223: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t213_n229;
  t213_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n228;
  t213_n225: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t213_n227;
  t213_n226: return 0.08369781821966171f;
  t213_n227: return 0.09023391455411911f;
  t213_n228: return 0.07229241728782654f;
  t213_n229: return 0.06930773705244064f;
  t213_n230: return 0.049424923956394196f;
  t213_n231: return -0.028760729357600212f;
  t213_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t213_n236;
  t213_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t213_n235;
  t213_n234: return -0.13766084611415863f;
  t213_n235: return 0.005970544181764126f;
  t213_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t213_n242;
  t213_n237: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t213_n239;
  t213_n238: return -0.00678854389116168f;
  t213_n239: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t213_n241;
  t213_n240: return 0.10280074179172516f;
  t213_n241: return 0.06506579369306564f;
  t213_n242: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t213_n254;
  t213_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n253;
  t213_n244: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t213_n252;
  t213_n245: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t213_n247;
  t213_n246: return 0.05677603930234909f;
  t213_n247: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t213_n249;
  t213_n248: return -0.029898451641201973f;
  t213_n249: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t213_n251;
  t213_n250: return -0.055007968097925186f;
  t213_n251: return 0.0883178561925888f;
  t213_n252: return -0.006333341356366873f;
  t213_n253: return -0.15371762216091156f;
  t213_n254: return -0.264944463968277f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree214(const Example& E) {
  t214_n0: if (E.getNumReferences() >= 3320122368 /*7329.5*/) goto t214_n2;
  t214_n1: return -0.0002870055614039302f;
  t214_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t214_n4;
  t214_n3: return 0.010888426564633846f;
  t214_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t214_n6;
  t214_n5: return -0.03147226199507713f;
  t214_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t214_n8;
  t214_n7: return 0.004626988898962736f;
  t214_n8: if (E.getNumReferences() >= 3322645504 /*8931.0*/) goto t214_n52;
  t214_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t214_n43;
  t214_n10: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t214_n28;
  t214_n11: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t214_n21;
  t214_n12: if (E.getNumReferences() >= 3322376704 /*8668.5*/) goto t214_n20;
  t214_n13: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t214_n17;
  t214_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n16;
  t214_n15: return -0.31714561581611633f;
  t214_n16: return -0.09070657193660736f;
  t214_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n19;
  t214_n18: return -0.2510635554790497f;
  t214_n19: return 0.73582923412323f;
  t214_n20: return 0.11404082924127579f;
  t214_n21: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n25;
  t214_n22: if (E.getNumReferences() >= 3320899584 /*7709.0*/) goto t214_n24;
  t214_n23: return 0.08346317708492279f;
  t214_n24: return -0.31004348397254944f;
  t214_n25: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t214_n27;
  t214_n26: return -0.039201971143484116f;
  t214_n27: return 0.11466765403747559f;
  t214_n28: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t214_n40;
  t214_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n35;
  t214_n30: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t214_n32;
  t214_n31: return -0.026712778955698013f;
  t214_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t214_n34;
  t214_n33: return -0.043770261108875275f;
  t214_n34: return 0.107777900993824f;
  t214_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t214_n39;
  t214_n36: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t214_n38;
  t214_n37: return 0.11965706944465637f;
  t214_n38: return 0.06596916913986206f;
  t214_n39: return 0.116131491959095f;
  t214_n40: if (E.getNumReferences() >= 3322247680 /*8542.5*/) goto t214_n42;
  t214_n41: return -0.002935549942776561f;
  t214_n42: return 0.111217200756073f;
  t214_n43: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t214_n49;
  t214_n44: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t214_n46;
  t214_n45: return -0.017583901062607765f;
  t214_n46: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n48;
  t214_n47: return 0.12964873015880585f;
  t214_n48: return 0.03324296697974205f;
  t214_n49: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t214_n51;
  t214_n50: return 0.11587226390838623f;
  t214_n51: return 0.16062039136886597f;
  t214_n52: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t214_n74;
  t214_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n63;
  t214_n54: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n56;
  t214_n55: return -0.27370280027389526f;
  t214_n56: if (E.getNumReferences() >= 3338315520 /*32083.5*/) goto t214_n60;
  t214_n57: if (E.getNumReferences() >= 3326275072 /*12475.5*/) goto t214_n59;
  t214_n58: return 0.07983597368001938f;
  t214_n59: return -0.12832263112068176f;
  t214_n60: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t214_n62;
  t214_n61: return 0.06855403631925583f;
  t214_n62: return 0.10810581594705582f;
  t214_n63: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t214_n65;
  t214_n64: return 0.12000680714845657f;
  t214_n65: if (E.getNumReferences() >= 3330091008 /*16202.0*/) goto t214_n73;
  t214_n66: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n68;
  t214_n67: return 0.015592486597597599f;
  t214_n68: if (E.getNumReferences() >= 3326753280 /*12942.5*/) goto t214_n70;
  t214_n69: return -0.08533131331205368f;
  t214_n70: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t214_n72;
  t214_n71: return 0.17762616276741028f;
  t214_n72: return 0.027869468554854393f;
  t214_n73: return 0.03607572615146637f;
  t214_n74: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t214_n198;
  t214_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t214_n173;
  t214_n76: if (E.getNumReferences() >= 3326609920 /*12802.5*/) goto t214_n116;
  t214_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t214_n105;
  t214_n78: if (E.getNumReferences() >= 3325253120 /*11477.5*/) goto t214_n96;
  t214_n79: if (E.getNumReferences() >= 3324362240 /*10607.5*/) goto t214_n95;
  t214_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n82;
  t214_n81: return 0.008382498286664486f;
  t214_n82: if (E.getNumReferences() >= 3323899904 /*10156.0*/) goto t214_n84;
  t214_n83: return -0.07643213868141174f;
  t214_n84: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t214_n86;
  t214_n85: return -0.08064107596874237f;
  t214_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t214_n88;
  t214_n87: return 0.09850802272558212f;
  t214_n88: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n94;
  t214_n89: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t214_n93;
  t214_n90: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n92;
  t214_n91: return 0.1293942779302597f;
  t214_n92: return 0.08496277034282684f;
  t214_n93: return 0.0734051987528801f;
  t214_n94: return 0.014162966050207615f;
  t214_n95: return -0.11723638325929642f;
  t214_n96: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t214_n102;
  t214_n97: if (E.getNumReferences() >= 3325340672 /*11563.0*/) goto t214_n99;
  t214_n98: return 0.13306504487991333f;
  t214_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t214_n101;
  t214_n100: return 0.06680074334144592f;
  t214_n101: return 0.0834677517414093f;
  t214_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n104;
  t214_n103: return -0.06234924495220184f;
  t214_n104: return 0.09800145030021667f;
  t214_n105: if (E.getNumReferences() >= 3325920768 /*12129.5*/) goto t214_n115;
  t214_n106: if (E.getNumReferences() >= 3323780096 /*10039.0*/) goto t214_n110;
  t214_n107: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t214_n109;
  t214_n108: return 0.19238445162773132f;
  t214_n109: return 0.09549697488546371f;
  t214_n110: if (E.getNumReferences() >= 3324083200 /*10335.0*/) goto t214_n112;
  t214_n111: return -0.0697799026966095f;
  t214_n112: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n114;
  t214_n113: return 0.08319392055273056f;
  t214_n114: return -0.13908341526985168f;
  t214_n115: return 0.11377004534006119f;
  t214_n116: if (E.getNumReferences() >= 3335927040 /*27418.5*/) goto t214_n120;
  t214_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n119;
  t214_n118: return -0.31896698474884033f;
  t214_n119: return -0.02839004062116146f;
  t214_n120: if (E.getNumReferences() >= 3341598080 /*44221.5*/) goto t214_n152;
  t214_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t214_n137;
  t214_n122: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t214_n124;
  t214_n123: return -0.020913079380989075f;
  t214_n124: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t214_n134;
  t214_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t214_n127;
  t214_n126: return -0.18024486303329468f;
  t214_n127: if (E.getNumReferences() >= 3337728256 /*30936.5*/) goto t214_n129;
  t214_n128: return -0.1043701171875f;
  t214_n129: if (E.getNumReferences() >= 3339108096 /*34495.0*/) goto t214_n133;
  t214_n130: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n132;
  t214_n131: return 0.11823244392871857f;
  t214_n132: return 0.10882297903299332f;
  t214_n133: return 0.07193925231695175f;
  t214_n134: if (E.getNumReferences() >= 3337658112 /*30799.5*/) goto t214_n136;
  t214_n135: return 0.10868385434150696f;
  t214_n136: return 0.009166796691715717f;
  t214_n137: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n141;
  t214_n138: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n140;
  t214_n139: return 0.06419187784194946f;
  t214_n140: return 0.1110871359705925f;
  t214_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t214_n143;
  t214_n142: return 0.128351092338562f;
  t214_n143: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t214_n151;
  t214_n144: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t214_n146;
  t214_n145: return -0.027395905926823616f;
  t214_n146: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n148;
  t214_n147: return 0.11294347792863846f;
  t214_n148: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t214_n150;
  t214_n149: return -0.2120169997215271f;
  t214_n150: return 0.11812745779752731f;
  t214_n151: return 0.02794891782104969f;
  t214_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t214_n154;
  t214_n153: return 0.0044952561147511005f;
  t214_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n168;
  t214_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n167;
  t214_n156: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t214_n158;
  t214_n157: return 0.10603711009025574f;
  t214_n158: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t214_n162;
  t214_n159: if (E.getNumReferences() >= 3362744896 /*245161.0*/) goto t214_n161;
  t214_n160: return 0.057787202298641205f;
  t214_n161: return -0.9194465279579163f;
  t214_n162: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n166;
  t214_n163: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t214_n165;
  t214_n164: return 0.06287538260221481f;
  t214_n165: return 0.09742517024278641f;
  t214_n166: return -0.3007591962814331f;
  t214_n167: return -0.03357306867837906f;
  t214_n168: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t214_n172;
  t214_n169: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t214_n171;
  t214_n170: return 0.05574890598654747f;
  t214_n171: return 0.12912911176681519f;
  t214_n172: return 0.027890991419553757f;
  t214_n173: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t214_n183;
  t214_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n180;
  t214_n175: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t214_n179;
  t214_n176: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t214_n178;
  t214_n177: return 0.09937608242034912f;
  t214_n178: return -0.07205113768577576f;
  t214_n179: return -0.026530073955655098f;
  t214_n180: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n182;
  t214_n181: return 0.09924060106277466f;
  t214_n182: return 0.047594599425792694f;
  t214_n183: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n193;
  t214_n184: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t214_n190;
  t214_n185: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t214_n189;
  t214_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n188;
  t214_n187: return -0.18646296858787537f;
  t214_n188: return 0.12039343267679214f;
  t214_n189: return 0.026387637481093407f;
  t214_n190: if (E.getNumReferences() >= 3334366208 /*24370.0*/) goto t214_n192;
  t214_n191: return 0.11264252662658691f;
  t214_n192: return 0.02717312052845955f;
  t214_n193: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t214_n197;
  t214_n194: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t214_n196;
  t214_n195: return -0.8891561627388f;
  t214_n196: return 0.04908740893006325f;
  t214_n197: return -1.617780089378357f;
  t214_n198: if (E.getNumReferences() >= 3328154112 /*14310.5*/) goto t214_n202;
  t214_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n201;
  t214_n200: return -0.08260529488325119f;
  t214_n201: return 0.07058478891849518f;
  t214_n202: if (E.getNumReferences() >= 3329227264 /*15358.5*/) goto t214_n208;
  t214_n203: if (E.getNumReferences() >= 3329011200 /*15147.5*/) goto t214_n205;
  t214_n204: return -0.019525377079844475f;
  t214_n205: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t214_n207;
  t214_n206: return 0.07615108042955399f;
  t214_n207: return 0.1089276671409607f;
  t214_n208: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t214_n210;
  t214_n209: return -0.06473667919635773f;
  t214_n210: if (E.getNumReferences() >= 3335347712 /*26287.0*/) goto t214_n236;
  t214_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n213;
  t214_n212: return -0.6715956926345825f;
  t214_n213: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t214_n235;
  t214_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t214_n228;
  t214_n215: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n219;
  t214_n216: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t214_n218;
  t214_n217: return 0.003469789167866111f;
  t214_n218: return -1.0621860027313232f;
  t214_n219: if (E.getNumReferences() >= 3333913856 /*23486.5*/) goto t214_n225;
  t214_n220: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t214_n224;
  t214_n221: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t214_n223;
  t214_n222: return 0.09740115702152252f;
  t214_n223: return -0.1317017674446106f;
  t214_n224: return 0.11795584112405777f;
  t214_n225: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t214_n227;
  t214_n226: return 0.10800046473741531f;
  t214_n227: return -0.11789735406637192f;
  t214_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t214_n230;
  t214_n229: return 0.069916270673275f;
  t214_n230: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t214_n232;
  t214_n231: return 0.05694553628563881f;
  t214_n232: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n234;
  t214_n233: return 0.1446147859096527f;
  t214_n234: return 0.10448028892278671f;
  t214_n235: return 0.12190419435501099f;
  t214_n236: if (E.getNumReferences() >= 3336475136 /*28489.0*/) goto t214_n240;
  t214_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n239;
  t214_n238: return -0.12273971736431122f;
  t214_n239: return -1.1725796461105347f;
  t214_n240: if (E.getNumReferences() >= 3336705792 /*28939.5*/) goto t214_n244;
  t214_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n243;
  t214_n242: return 0.11483010649681091f;
  t214_n243: return -0.09398112446069717f;
  t214_n244: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t214_n246;
  t214_n245: return 0.021622629836201668f;
  t214_n246: if (E.getNumReferences() >= 3365641360 /*318692.5*/) goto t214_n254;
  t214_n247: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t214_n251;
  t214_n248: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t214_n250;
  t214_n249: return -0.01802697405219078f;
  t214_n250: return -0.2600855529308319f;
  t214_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t214_n253;
  t214_n252: return 0.03576497361063957f;
  t214_n253: return 0.09489196538925171f;
  t214_n254: return -0.24114148318767548f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree215(const Example& E) {
  t215_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t215_n116;
  t215_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t215_n115;
  t215_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t215_n4;
  t215_n3: return -0.000525520765222609f;
  t215_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t215_n22;
  t215_n5: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n7;
  t215_n6: return -0.005703703500330448f;
  t215_n7: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t215_n17;
  t215_n8: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t215_n10;
  t215_n9: return -0.04722366854548454f;
  t215_n10: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t215_n16;
  t215_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t215_n13;
  t215_n12: return -0.0781206265091896f;
  t215_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n15;
  t215_n14: return 0.11791439354419708f;
  t215_n15: return 0.054243385791778564f;
  t215_n16: return 0.005245584063231945f;
  t215_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t215_n21;
  t215_n18: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t215_n20;
  t215_n19: return -0.34689968824386597f;
  t215_n20: return 0.11722911149263382f;
  t215_n21: return -0.022749802097678185f;
  t215_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t215_n34;
  t215_n23: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t215_n29;
  t215_n24: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t215_n26;
  t215_n25: return -0.002081454498693347f;
  t215_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t215_n28;
  t215_n27: return 0.026640422642230988f;
  t215_n28: return 0.07987623661756516f;
  t215_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n33;
  t215_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t215_n32;
  t215_n31: return -0.014779129065573215f;
  t215_n32: return 0.038701944053173065f;
  t215_n33: return -0.003305490128695965f;
  t215_n34: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t215_n112;
  t215_n35: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t215_n71;
  t215_n36: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t215_n40;
  t215_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t215_n39;
  t215_n38: return -0.039769336581230164f;
  t215_n39: return 0.0009115125285461545f;
  t215_n40: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n46;
  t215_n41: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t215_n45;
  t215_n42: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n44;
  t215_n43: return 0.046948984265327454f;
  t215_n44: return 0.03934329003095627f;
  t215_n45: return -0.0455891489982605f;
  t215_n46: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t215_n58;
  t215_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag))) goto t215_n53;
  t215_n48: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t215_n52;
  t215_n49: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n51;
  t215_n50: return 0.025111375376582146f;
  t215_n51: return 0.04895181953907013f;
  t215_n52: return -0.07105673104524612f;
  t215_n53: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n55;
  t215_n54: return 0.07682692259550095f;
  t215_n55: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t215_n57;
  t215_n56: return 0.031781598925590515f;
  t215_n57: return -0.056963417679071426f;
  t215_n58: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t215_n70;
  t215_n59: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t215_n69;
  t215_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t215_n62;
  t215_n61: return 0.024763165041804314f;
  t215_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n64;
  t215_n63: return 0.08749526739120483f;
  t215_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t215_n66;
  t215_n65: return -0.029231049120426178f;
  t215_n66: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t215_n68;
  t215_n67: return 0.1331503540277481f;
  t215_n68: return 0.12108322232961655f;
  t215_n69: return 0.06975090503692627f;
  t215_n70: return -0.06495261937379837f;
  t215_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t215_n91;
  t215_n72: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n74;
  t215_n73: return 0.05505101755261421f;
  t215_n74: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t215_n90;
  t215_n75: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n89;
  t215_n76: if (E.getNumReferences() >= 3266576384 /*90.0*/) goto t215_n88;
  t215_n77: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t215_n83;
  t215_n78: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t215_n80;
  t215_n79: return 0.09805168211460114f;
  t215_n80: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t215_n82;
  t215_n81: return 0.12400797009468079f;
  t215_n82: return 0.09088419377803802f;
  t215_n83: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t215_n85;
  t215_n84: return 0.07802753150463104f;
  t215_n85: if (E.getNumReferences() >= 3261333504 /*57.0*/) goto t215_n87;
  t215_n86: return 0.1225515753030777f;
  t215_n87: return 0.07526053488254547f;
  t215_n88: return -0.24628549814224243f;
  t215_n89: return 0.08126703649759293f;
  t215_n90: return 0.051772166043519974f;
  t215_n91: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t215_n107;
  t215_n92: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t215_n100;
  t215_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t215_n95;
  t215_n94: return 0.022901147603988647f;
  t215_n95: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t215_n99;
  t215_n96: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t215_n98;
  t215_n97: return 0.15617425739765167f;
  t215_n98: return 0.11502187699079514f;
  t215_n99: return 0.08307646214962006f;
  t215_n100: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t215_n104;
  t215_n101: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t215_n103;
  t215_n102: return 0.12737838923931122f;
  t215_n103: return 0.10415448993444443f;
  t215_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t215_n106;
  t215_n105: return -0.021040260791778564f;
  t215_n106: return 0.11027085036039352f;
  t215_n107: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t215_n109;
  t215_n108: return 0.02897081896662712f;
  t215_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n111;
  t215_n110: return 0.13387419283390045f;
  t215_n111: return -0.11587819457054138f;
  t215_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t215_n114;
  t215_n113: return -0.4163915514945984f;
  t215_n114: return -0.014813479036092758f;
  t215_n115: return 0.0032182878348976374f;
  t215_n116: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t215_n148;
  t215_n117: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t215_n119;
  t215_n118: return -0.14818058907985687f;
  t215_n119: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n133;
  t215_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable))) goto t215_n122;
  t215_n121: return -0.05432320386171341f;
  t215_n122: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t215_n132;
  t215_n123: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n125;
  t215_n124: return 0.0027383421547710896f;
  t215_n125: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t215_n127;
  t215_n126: return 0.009675953537225723f;
  t215_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t215_n129;
  t215_n128: return 0.011303222738206387f;
  t215_n129: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t215_n131;
  t215_n130: return 0.5786706209182739f;
  t215_n131: return 0.07186882197856903f;
  t215_n132: return -0.007896797731518745f;
  t215_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t215_n141;
  t215_n134: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t215_n140;
  t215_n135: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t215_n139;
  t215_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t215_n138;
  t215_n137: return -0.16018126904964447f;
  t215_n138: return -0.10080654919147491f;
  t215_n139: return 0.0364135280251503f;
  t215_n140: return -0.019617266952991486f;
  t215_n141: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t215_n147;
  t215_n142: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t215_n144;
  t215_n143: return -0.046192195266485214f;
  t215_n144: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t215_n146;
  t215_n145: return 0.21823851764202118f;
  t215_n146: return -0.08865360915660858f;
  t215_n147: return 0.006617765408009291f;
  t215_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t215_n150;
  t215_n149: return -0.037581317126750946f;
  t215_n150: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t215_n252;
  t215_n151: if (E.getNumReferences() >= 3346496384 /*63355.5*/) goto t215_n251;
  t215_n152: if (E.getNumReferences() >= 3272671232 /*145.0*/) goto t215_n238;
  t215_n153: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t215_n203;
  t215_n154: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t215_n196;
  t215_n155: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t215_n191;
  t215_n156: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t215_n180;
  t215_n157: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t215_n161;
  t215_n158: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t215_n160;
  t215_n159: return 0.0008853496983647346f;
  t215_n160: return 0.09077930450439453f;
  t215_n161: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t215_n173;
  t215_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n164;
  t215_n163: return -0.12330087274312973f;
  t215_n164: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t215_n168;
  t215_n165: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t215_n167;
  t215_n166: return 0.13132409751415253f;
  t215_n167: return -0.2301696389913559f;
  t215_n168: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t215_n170;
  t215_n169: return 0.1214355081319809f;
  t215_n170: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t215_n172;
  t215_n171: return -0.23792606592178345f;
  t215_n172: return 0.10693183541297913f;
  t215_n173: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t215_n179;
  t215_n174: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t215_n178;
  t215_n175: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t215_n177;
  t215_n176: return -0.14392079412937164f;
  t215_n177: return 0.12296503782272339f;
  t215_n178: return 0.13665416836738586f;
  t215_n179: return 0.02031880058348179f;
  t215_n180: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t215_n182;
  t215_n181: return -0.028128651902079582f;
  t215_n182: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t215_n190;
  t215_n183: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t215_n187;
  t215_n184: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t215_n186;
  t215_n185: return 0.11477971076965332f;
  t215_n186: return -0.1523343175649643f;
  t215_n187: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t215_n189;
  t215_n188: return 0.11050964891910553f;
  t215_n189: return -0.05804747715592384f;
  t215_n190: return -0.02226955257356167f;
  t215_n191: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t215_n195;
  t215_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t215_n194;
  t215_n193: return 0.092868372797966f;
  t215_n194: return 0.11613620817661285f;
  t215_n195: return -0.19371113181114197f;
  t215_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t215_n198;
  t215_n197: return -0.2551135718822479f;
  t215_n198: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t215_n202;
  t215_n199: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t215_n201;
  t215_n200: return -0.2399294525384903f;
  t215_n201: return 0.24399256706237793f;
  t215_n202: return 0.02443704381585121f;
  t215_n203: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t215_n207;
  t215_n204: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t215_n206;
  t215_n205: return 0.09969279170036316f;
  t215_n206: return 0.12191115319728851f;
  t215_n207: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t215_n211;
  t215_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t215_n210;
  t215_n209: return 0.12552326917648315f;
  t215_n210: return -0.13855110108852386f;
  t215_n211: if (E.getNumReferences() >= 3272540160 /*143.0*/) goto t215_n235;
  t215_n212: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t215_n214;
  t215_n213: return -0.17821940779685974f;
  t215_n214: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n216;
  t215_n215: return 0.021591361612081528f;
  t215_n216: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t215_n232;
  t215_n217: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t215_n229;
  t215_n218: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t215_n224;
  t215_n219: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t215_n223;
  t215_n220: if (E.getNumReferences() >= 3258449920 /*46.0*/) goto t215_n222;
  t215_n221: return 0.10352117568254471f;
  t215_n222: return 0.07686344534158707f;
  t215_n223: return 0.11775027960538864f;
  t215_n224: if (E.getNumReferences() >= 3261857792 /*59.0*/) goto t215_n226;
  t215_n225: return 0.09951978921890259f;
  t215_n226: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t215_n228;
  t215_n227: return -0.10272402316331863f;
  t215_n228: return 0.20010511577129364f;
  t215_n229: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t215_n231;
  t215_n230: return -0.04739130660891533f;
  t215_n231: return 0.09895189851522446f;
  t215_n232: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t215_n234;
  t215_n233: return -0.03213965892791748f;
  t215_n234: return 0.11231318861246109f;
  t215_n235: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t215_n237;
  t215_n236: return 0.10536052286624908f;
  t215_n237: return -0.6354130506515503f;
  t215_n238: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t215_n240;
  t215_n239: return -0.02157493121922016f;
  t215_n240: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t215_n250;
  t215_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t215_n249;
  t215_n242: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t215_n248;
  t215_n243: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t215_n247;
  t215_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t215_n246;
  t215_n245: return 0.13393111526966095f;
  t215_n246: return 0.10933859646320343f;
  t215_n247: return -0.42699167132377625f;
  t215_n248: return -0.14027515053749084f;
  t215_n249: return 0.05877300351858139f;
  t215_n250: return 0.027630774304270744f;
  t215_n251: return 0.09270725399255753f;
  t215_n252: if (E.getNumReferences() >= 3280633856 /*277.0*/) goto t215_n254;
  t215_n253: return -0.060805656015872955f;
  t215_n254: return 0.14794358611106873f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree216(const Example& E) {
  t216_n0: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t216_n2;
  t216_n1: return -0.00042227344238199294f;
  t216_n2: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t216_n220;
  t216_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t216_n5;
  t216_n4: return 0.00130683823954314f;
  t216_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t216_n9;
  t216_n6: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t216_n8;
  t216_n7: return 0.09830807894468307f;
  t216_n8: return 0.01201418973505497f;
  t216_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t216_n11;
  t216_n10: return -0.03915531933307648f;
  t216_n11: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t216_n63;
  t216_n12: if (E.getNumReferences() >= 3278536704 /*234.5*/) goto t216_n48;
  t216_n13: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t216_n15;
  t216_n14: return -0.016588326543569565f;
  t216_n15: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t216_n39;
  t216_n16: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t216_n20;
  t216_n17: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t216_n19;
  t216_n18: return 0.13927271962165833f;
  t216_n19: return 0.010114709846675396f;
  t216_n20: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t216_n36;
  t216_n21: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t216_n35;
  t216_n22: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t216_n34;
  t216_n23: if (E.getNumReferences() >= 3275653120 /*190.5*/) goto t216_n33;
  t216_n24: if (E.getNumReferences() >= 3273785344 /*162.0*/) goto t216_n32;
  t216_n25: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t216_n31;
  t216_n26: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t216_n30;
  t216_n27: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t216_n29;
  t216_n28: return 0.10052326321601868f;
  t216_n29: return 0.026352858170866966f;
  t216_n30: return -0.3122096657752991f;
  t216_n31: return 0.10496004670858383f;
  t216_n32: return -0.15510249137878418f;
  t216_n33: return 0.09672574698925018f;
  t216_n34: return 0.00376117299310863f;
  t216_n35: return -0.24792984127998352f;
  t216_n36: if (E.getNumReferences() >= 3273850880 /*163.0*/) goto t216_n38;
  t216_n37: return 0.10442865639925003f;
  t216_n38: return -0.16130518913269043f;
  t216_n39: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t216_n41;
  t216_n40: return -0.012590248137712479f;
  t216_n41: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t216_n47;
  t216_n42: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t216_n44;
  t216_n43: return 0.047591567039489746f;
  t216_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t216_n46;
  t216_n45: return 0.06953401118516922f;
  t216_n46: return 0.11562833935022354f;
  t216_n47: return -0.021152131259441376f;
  t216_n48: if (E.getNumReferences() >= 3279962112 /*256.5*/) goto t216_n62;
  t216_n49: if (E.getNumReferences() >= 3279912960 /*255.5*/) goto t216_n59;
  t216_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t216_n58;
  t216_n51: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t216_n57;
  t216_n52: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t216_n54;
  t216_n53: return -0.052552588284015656f;
  t216_n54: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t216_n56;
  t216_n55: return 0.1148427352309227f;
  t216_n56: return -0.7943275570869446f;
  t216_n57: return -0.2794155180454254f;
  t216_n58: return 0.10251065343618393f;
  t216_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t216_n61;
  t216_n60: return -0.11292600631713867f;
  t216_n61: return 0.11089223623275757f;
  t216_n62: return 0.037896525114774704f;
  t216_n63: if (E.getNumReferences() >= 3289112576 /*559.5*/) goto t216_n89;
  t216_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t216_n66;
  t216_n65: return 0.02887973189353943f;
  t216_n66: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t216_n78;
  t216_n67: if (E.getNumReferences() >= 3274080256 /*166.5*/) goto t216_n77;
  t216_n68: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t216_n76;
  t216_n69: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t216_n71;
  t216_n70: return -0.593458354473114f;
  t216_n71: if (E.getNumReferences() >= 3270901760 /*123.0*/) goto t216_n75;
  t216_n72: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t216_n74;
  t216_n73: return 0.11164126545190811f;
  t216_n74: return -0.0562642402946949f;
  t216_n75: return 0.01523909904062748f;
  t216_n76: return 0.09853635728359222f;
  t216_n77: return -0.17112213373184204f;
  t216_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t216_n84;
  t216_n79: if (E.getNumReferences() >= 3278995456 /*241.5*/) goto t216_n83;
  t216_n80: if (E.getNumReferences() >= 3278635008 /*236.0*/) goto t216_n82;
  t216_n81: return -0.02366204932332039f;
  t216_n82: return 0.13154250383377075f;
  t216_n83: return -0.13233669102191925f;
  t216_n84: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t216_n88;
  t216_n85: if (E.getNumReferences() >= 3282501632 /*334.0*/) goto t216_n87;
  t216_n86: return 0.10017126053571701f;
  t216_n87: return -0.11612596362829208f;
  t216_n88: return 0.019580548629164696f;
  t216_n89: if (E.getNumReferences() >= 3289604096 /*589.5*/) goto t216_n107;
  t216_n90: if (E.getNumReferences() >= 3289571328 /*587.5*/) goto t216_n104;
  t216_n91: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t216_n99;
  t216_n92: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t216_n98;
  t216_n93: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t216_n95;
  t216_n94: return 0.04130119830369949f;
  t216_n95: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t216_n97;
  t216_n96: return 0.3567471206188202f;
  t216_n97: return -0.11600849777460098f;
  t216_n98: return -0.07924554497003555f;
  t216_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t216_n101;
  t216_n100: return 0.016801225021481514f;
  t216_n101: if (E.getNumReferences() >= 3289243648 /*567.5*/) goto t216_n103;
  t216_n102: return -0.10600447654724121f;
  t216_n103: return 0.11984860152006149f;
  t216_n104: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t216_n106;
  t216_n105: return 0.13968107104301453f;
  t216_n106: return -0.10692309588193893f;
  t216_n107: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t216_n119;
  t216_n108: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t216_n110;
  t216_n109: return 0.012611269019544125f;
  t216_n110: if (E.getNumReferences() >= 3296239616 /*994.5*/) goto t216_n116;
  t216_n111: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t216_n115;
  t216_n112: if (E.getNumReferences() >= 3292110848 /*742.5*/) goto t216_n114;
  t216_n113: return 0.05285589396953583f;
  t216_n114: return 0.11980435997247696f;
  t216_n115: return -0.08768893778324127f;
  t216_n116: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t216_n118;
  t216_n117: return -0.09506994485855103f;
  t216_n118: return 0.0950111448764801f;
  t216_n119: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t216_n163;
  t216_n120: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t216_n160;
  t216_n121: if (E.getNumReferences() >= 3333837824 /*23338.0*/) goto t216_n159;
  t216_n122: if (E.getNumReferences() >= 3330759936 /*17326.5*/) goto t216_n154;
  t216_n123: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t216_n151;
  t216_n124: if (E.getNumReferences() >= 3306760192 /*2450.5*/) goto t216_n136;
  t216_n125: if (E.getNumReferences() >= 3301900288 /*1656.0*/) goto t216_n135;
  t216_n126: if (E.getNumReferences() >= 3301597184 /*1619.0*/) goto t216_n132;
  t216_n127: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t216_n129;
  t216_n128: return 0.02310439758002758f;
  t216_n129: if (E.getNumReferences() >= 3294109696 /*864.5*/) goto t216_n131;
  t216_n130: return 0.10425969213247299f;
  t216_n131: return -0.08993607759475708f;
  t216_n132: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t216_n134;
  t216_n133: return -0.10790238529443741f;
  t216_n134: return 0.10989313572645187f;
  t216_n135: return -0.16692885756492615f;
  t216_n136: if (E.getNumReferences() >= 3309787136 /*3189.5*/) goto t216_n146;
  t216_n137: if (E.getNumReferences() >= 3308374016 /*2844.5*/) goto t216_n141;
  t216_n138: if (E.getNumReferences() >= 3306817536 /*2464.5*/) goto t216_n140;
  t216_n139: return 0.125457301735878f;
  t216_n140: return 0.017130622640252113f;
  t216_n141: if (E.getNumReferences() >= 3308611584 /*2902.5*/) goto t216_n143;
  t216_n142: return 0.12309537827968597f;
  t216_n143: if (E.getNumReferences() >= 3309082624 /*3017.5*/) goto t216_n145;
  t216_n144: return -0.03400636091828346f;
  t216_n145: return 0.1149035319685936f;
  t216_n146: if (E.getNumReferences() >= 3315510272 /*5077.5*/) goto t216_n148;
  t216_n147: return -0.09219524264335632f;
  t216_n148: if (E.getNumReferences() >= 3315605504 /*5124.0*/) goto t216_n150;
  t216_n149: return 0.12102101743221283f;
  t216_n150: return 0.043705809861421585f;
  t216_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t216_n153;
  t216_n152: return -0.04917812719941139f;
  t216_n153: return 0.09713238477706909f;
  t216_n154: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t216_n156;
  t216_n155: return 0.1833306849002838f;
  t216_n156: if (E.getNumReferences() >= 3331838976 /*19434.0*/) goto t216_n158;
  t216_n157: return 0.11225274205207825f;
  t216_n158: return -0.3427664041519165f;
  t216_n159: return -0.10945812612771988f;
  t216_n160: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t216_n162;
  t216_n161: return 0.1271008849143982f;
  t216_n162: return -0.16739386320114136f;
  t216_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t216_n165;
  t216_n164: return -0.12618006765842438f;
  t216_n165: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t216_n215;
  t216_n166: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t216_n168;
  t216_n167: return 0.06918357312679291f;
  t216_n168: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t216_n212;
  t216_n169: if (E.getNumReferences() >= 3296313344 /*999.0*/) goto t216_n171;
  t216_n170: return -0.04604402557015419f;
  t216_n171: if (E.getNumReferences() >= 3298639872 /*1258.0*/) goto t216_n185;
  t216_n172: if (E.getNumReferences() >= 3298521088 /*1243.5*/) goto t216_n184;
  t216_n173: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t216_n183;
  t216_n174: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t216_n176;
  t216_n175: return 0.31670746207237244f;
  t216_n176: if (E.getNumReferences() >= 3297247232 /*1088.0*/) goto t216_n178;
  t216_n177: return 0.09612846374511719f;
  t216_n178: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t216_n182;
  t216_n179: if (E.getNumReferences() >= 3298324480 /*1219.5*/) goto t216_n181;
  t216_n180: return 0.10760222375392914f;
  t216_n181: return 0.13080532848834991f;
  t216_n182: return -0.1001506969332695f;
  t216_n183: return -0.11622685194015503f;
  t216_n184: return 0.11830680072307587f;
  t216_n185: if (E.getNumReferences() >= 3305877504 /*2235.0*/) goto t216_n187;
  t216_n186: return -0.1306433230638504f;
  t216_n187: if (E.getNumReferences() >= 3318623232 /*6597.5*/) goto t216_n203;
  t216_n188: if (E.getNumReferences() >= 3317490688 /*6044.5*/) goto t216_n200;
  t216_n189: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t216_n195;
  t216_n190: if (E.getNumReferences() >= 3305918464 /*2245.0*/) goto t216_n192;
  t216_n191: return 0.11638836562633514f;
  t216_n192: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t216_n194;
  t216_n193: return -0.1718549281358719f;
  t216_n194: return 0.10190563648939133f;
  t216_n195: if (E.getNumReferences() >= 3313764352 /*4225.0*/) goto t216_n197;
  t216_n196: return 0.1131841391324997f;
  t216_n197: if (E.getNumReferences() >= 3315306496 /*4978.0*/) goto t216_n199;
  t216_n198: return 0.12106145173311234f;
  t216_n199: return -0.10175427049398422f;
  t216_n200: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t216_n202;
  t216_n201: return 0.11464734375476837f;
  t216_n202: return -0.36252033710479736f;
  t216_n203: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t216_n211;
  t216_n204: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t216_n210;
  t216_n205: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t216_n207;
  t216_n206: return 0.07455689460039139f;
  t216_n207: if (E.getNumReferences() >= 3322382336 /*8674.0*/) goto t216_n209;
  t216_n208: return -0.17359142005443573f;
  t216_n209: return 0.11067979037761688f;
  t216_n210: return -0.11481009423732758f;
  t216_n211: return -0.11455903947353363f;
  t216_n212: if (E.getNumReferences() >= 3293552640 /*830.5*/) goto t216_n214;
  t216_n213: return 0.10167878866195679f;
  t216_n214: return 0.01252567395567894f;
  t216_n215: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t216_n217;
  t216_n216: return -0.04822327941656113f;
  t216_n217: if (E.getNumReferences() >= 3293609984 /*834.0*/) goto t216_n219;
  t216_n218: return 0.16220572590827942f;
  t216_n219: return -0.1592671424150467f;
  t216_n220: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t216_n254;
  t216_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t216_n245;
  t216_n222: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t216_n224;
  t216_n223: return -0.03619561344385147f;
  t216_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t216_n226;
  t216_n225: return 0.028749406337738037f;
  t216_n226: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t216_n228;
  t216_n227: return -0.03201901540160179f;
  t216_n228: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t216_n238;
  t216_n229: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t216_n237;
  t216_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t216_n236;
  t216_n231: if (E.getNumReferences() >= 3270770688 /*122.0*/) goto t216_n235;
  t216_n232: if (E.getNumReferences() >= 3270246400 /*118.0*/) goto t216_n234;
  t216_n233: return -0.1409142017364502f;
  t216_n234: return 0.6049086451530457f;
  t216_n235: return -0.1897868514060974f;
  t216_n236: return 0.10252285748720169f;
  t216_n237: return 0.12700653076171875f;
  t216_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t216_n240;
  t216_n239: return 0.019850503653287888f;
  t216_n240: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t216_n242;
  t216_n241: return 0.042784105986356735f;
  t216_n242: if (E.getNumReferences() >= 3291521024 /*706.5*/) goto t216_n244;
  t216_n243: return 0.13322442770004272f;
  t216_n244: return -0.11470934003591537f;
  t216_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t216_n249;
  t216_n246: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t216_n248;
  t216_n247: return 0.03112628124654293f;
  t216_n248: return 0.09359526634216309f;
  t216_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t216_n251;
  t216_n250: return 0.09836075454950333f;
  t216_n251: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t216_n253;
  t216_n252: return 0.08233433216810226f;
  t216_n253: return -0.0030659001786261797f;
  t216_n254: return -0.0014829770661890507f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree217(const Example& E) {
  t217_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t217_n2;
  t217_n1: return -0.0010031349956989288f;
  t217_n2: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t217_n144;
  t217_n3: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t217_n117;
  t217_n4: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t217_n114;
  t217_n5: if (E.getNumReferences() >= 3329800192 /*15918.0*/) goto t217_n99;
  t217_n6: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t217_n68;
  t217_n7: if (E.getNumReferences() >= 3295674368 /*960.0*/) goto t217_n63;
  t217_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t217_n14;
  t217_n9: if (E.getNumReferences() >= 3267952640 /*100.5*/) goto t217_n13;
  t217_n10: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t217_n12;
  t217_n11: return -0.011030449531972408f;
  t217_n12: return 0.09890769422054291f;
  t217_n13: return -0.257757306098938f;
  t217_n14: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t217_n44;
  t217_n15: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t217_n43;
  t217_n16: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n42;
  t217_n17: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t217_n27;
  t217_n18: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t217_n24;
  t217_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t217_n23;
  t217_n20: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t217_n22;
  t217_n21: return -0.10686174780130386f;
  t217_n22: return 0.06086302548646927f;
  t217_n23: return 0.07435676455497742f;
  t217_n24: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t217_n26;
  t217_n25: return 0.11575817316770554f;
  t217_n26: return -0.10760723054409027f;
  t217_n27: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t217_n41;
  t217_n28: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t217_n34;
  t217_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t217_n31;
  t217_n30: return -0.8908320069313049f;
  t217_n31: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t217_n33;
  t217_n32: return 0.13768517971038818f;
  t217_n33: return 0.054045505821704865f;
  t217_n34: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t217_n38;
  t217_n35: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t217_n37;
  t217_n36: return -0.6958440542221069f;
  t217_n37: return 0.026372721418738365f;
  t217_n38: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t217_n40;
  t217_n39: return 0.09897935390472412f;
  t217_n40: return 0.18252570927143097f;
  t217_n41: return -0.27257469296455383f;
  t217_n42: return -1.2592651844024658f;
  t217_n43: return 0.20504413545131683f;
  t217_n44: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t217_n48;
  t217_n45: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t217_n47;
  t217_n46: return 0.11302939057350159f;
  t217_n47: return 0.06895532459020615f;
  t217_n48: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t217_n56;
  t217_n49: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t217_n53;
  t217_n50: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t217_n52;
  t217_n51: return 0.0687347948551178f;
  t217_n52: return 0.10341648012399673f;
  t217_n53: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t217_n55;
  t217_n54: return -0.2681749165058136f;
  t217_n55: return 0.11425712704658508f;
  t217_n56: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t217_n58;
  t217_n57: return -0.3635408878326416f;
  t217_n58: if (E.getNumReferences() >= 3257401344 /*42.0*/) goto t217_n60;
  t217_n59: return -0.25347670912742615f;
  t217_n60: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t217_n62;
  t217_n61: return 0.09865635633468628f;
  t217_n62: return 0.046441081911325455f;
  t217_n63: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t217_n65;
  t217_n64: return 0.09104075282812119f;
  t217_n65: if (E.getNumReferences() >= 3299438592 /*1355.5*/) goto t217_n67;
  t217_n66: return 0.11114445328712463f;
  t217_n67: return -0.1254349648952484f;
  t217_n68: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t217_n80;
  t217_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t217_n71;
  t217_n70: return -0.07910459488630295f;
  t217_n71: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t217_n77;
  t217_n72: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t217_n76;
  t217_n73: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t217_n75;
  t217_n74: return -0.3958820700645447f;
  t217_n75: return 0.061292462050914764f;
  t217_n76: return -0.06126067042350769f;
  t217_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t217_n79;
  t217_n78: return -0.059861645102500916f;
  t217_n79: return 0.11363227665424347f;
  t217_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t217_n98;
  t217_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t217_n83;
  t217_n82: return -0.031238365918397903f;
  t217_n83: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t217_n87;
  t217_n84: if (E.getNumReferences() >= 3278503936 /*234.0*/) goto t217_n86;
  t217_n85: return -0.1401977837085724f;
  t217_n86: return 0.11028064787387848f;
  t217_n87: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t217_n93;
  t217_n88: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t217_n90;
  t217_n89: return -0.8342272639274597f;
  t217_n90: if (E.getNumReferences() >= 3273392128 /*156.0*/) goto t217_n92;
  t217_n91: return 0.10595227777957916f;
  t217_n92: return -0.18355968594551086f;
  t217_n93: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t217_n95;
  t217_n94: return -0.006247977260500193f;
  t217_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t217_n97;
  t217_n96: return -0.16308417916297913f;
  t217_n97: return 0.073468878865242f;
  t217_n98: return -0.003453671233728528f;
  t217_n99: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t217_n113;
  t217_n100: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n106;
  t217_n101: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t217_n103;
  t217_n102: return 0.008809611201286316f;
  t217_n103: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t217_n105;
  t217_n104: return 0.11070871353149414f;
  t217_n105: return 0.03657947853207588f;
  t217_n106: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t217_n108;
  t217_n107: return -0.040783192962408066f;
  t217_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t217_n110;
  t217_n109: return 0.10729249566793442f;
  t217_n110: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t217_n112;
  t217_n111: return 0.10530047118663788f;
  t217_n112: return 0.10305453091859818f;
  t217_n113: return 0.013590898364782333f;
  t217_n114: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t217_n116;
  t217_n115: return -0.02598574198782444f;
  t217_n116: return -0.08945970982313156f;
  t217_n117: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t217_n133;
  t217_n118: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t217_n122;
  t217_n119: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t217_n121;
  t217_n120: return -0.023838022723793983f;
  t217_n121: return 0.49289724230766296f;
  t217_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t217_n124;
  t217_n123: return 0.04007376730442047f;
  t217_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t217_n126;
  t217_n125: return -0.10649235546588898f;
  t217_n126: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t217_n128;
  t217_n127: return 0.11469950526952744f;
  t217_n128: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t217_n132;
  t217_n129: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t217_n131;
  t217_n130: return 0.12704268097877502f;
  t217_n131: return -0.04082195460796356f;
  t217_n132: return -0.06189645454287529f;
  t217_n133: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t217_n135;
  t217_n134: return -0.03629394620656967f;
  t217_n135: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t217_n143;
  t217_n136: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t217_n138;
  t217_n137: return 0.028643686324357986f;
  t217_n138: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t217_n142;
  t217_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_DotMemberAccess))) goto t217_n141;
  t217_n140: return 0.010588440112769604f;
  t217_n141: return 0.1252843290567398f;
  t217_n142: return 0.022069983184337616f;
  t217_n143: return 0.003770767478272319f;
  t217_n144: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t217_n146;
  t217_n145: return 0.007766024209558964f;
  t217_n146: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t217_n254;
  t217_n147: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t217_n157;
  t217_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t217_n156;
  t217_n149: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t217_n153;
  t217_n150: if (E.getNumReferences() >= 3272376320 /*140.5*/) goto t217_n152;
  t217_n151: return -0.02314353920519352f;
  t217_n152: return -0.6600161790847778f;
  t217_n153: if (E.getNumReferences() >= 3273785344 /*162.0*/) goto t217_n155;
  t217_n154: return 0.1106143668293953f;
  t217_n155: return 0.027319997549057007f;
  t217_n156: return -0.007872313261032104f;
  t217_n157: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t217_n159;
  t217_n158: return -0.00014054676285013556f;
  t217_n159: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t217_n229;
  t217_n160: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t217_n218;
  t217_n161: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t217_n213;
  t217_n162: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t217_n164;
  t217_n163: return 0.007477906066924334f;
  t217_n164: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t217_n212;
  t217_n165: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t217_n207;
  t217_n166: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t217_n196;
  t217_n167: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t217_n191;
  t217_n168: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t217_n172;
  t217_n169: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t217_n171;
  t217_n170: return -0.04247983545064926f;
  t217_n171: return 0.08035223186016083f;
  t217_n172: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t217_n182;
  t217_n173: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t217_n181;
  t217_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t217_n176;
  t217_n175: return -0.14628155529499054f;
  t217_n176: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n180;
  t217_n177: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t217_n179;
  t217_n178: return 0.11212100833654404f;
  t217_n179: return 0.12297334522008896f;
  t217_n180: return 0.08515968918800354f;
  t217_n181: return 0.018086303025484085f;
  t217_n182: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t217_n184;
  t217_n183: return 0.008254573680460453f;
  t217_n184: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown))) goto t217_n186;
  t217_n185: return -0.14905470609664917f;
  t217_n186: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n188;
  t217_n187: return 0.11188908666372299f;
  t217_n188: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t217_n190;
  t217_n189: return 0.10005778074264526f;
  t217_n190: return -0.19504573941230774f;
  t217_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t217_n193;
  t217_n192: return 0.0005025587161071599f;
  t217_n193: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n195;
  t217_n194: return 0.10999051481485367f;
  t217_n195: return -0.11071505397558212f;
  t217_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t217_n198;
  t217_n197: return 0.11667162925004959f;
  t217_n198: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t217_n206;
  t217_n199: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n205;
  t217_n200: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t217_n204;
  t217_n201: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t217_n203;
  t217_n202: return 0.1300220638513565f;
  t217_n203: return 0.22597482800483704f;
  t217_n204: return -0.19305267930030823f;
  t217_n205: return -0.24544860422611237f;
  t217_n206: return 0.12004285305738449f;
  t217_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t217_n209;
  t217_n208: return -0.30434420704841614f;
  t217_n209: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t217_n211;
  t217_n210: return 0.1130967065691948f;
  t217_n211: return 0.011811706237494946f;
  t217_n212: return -0.018895236775279045f;
  t217_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t217_n215;
  t217_n214: return 0.018444141373038292f;
  t217_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n217;
  t217_n216: return 0.2458890825510025f;
  t217_n217: return 0.11400172859430313f;
  t217_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t217_n220;
  t217_n219: return -0.06402811408042908f;
  t217_n220: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t217_n222;
  t217_n221: return -0.04912007227540016f;
  t217_n222: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t217_n226;
  t217_n223: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t217_n225;
  t217_n224: return 0.2009124457836151f;
  t217_n225: return 0.08995403349399567f;
  t217_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t217_n228;
  t217_n227: return -0.10020433366298676f;
  t217_n228: return 0.06687547266483307f;
  t217_n229: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t217_n231;
  t217_n230: return -0.0921948105096817f;
  t217_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t217_n233;
  t217_n232: return -0.32329773902893066f;
  t217_n233: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t217_n235;
  t217_n234: return -0.14221078157424927f;
  t217_n235: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t217_n243;
  t217_n236: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t217_n240;
  t217_n237: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t217_n239;
  t217_n238: return 0.08753617107868195f;
  t217_n239: return 0.08083885163068771f;
  t217_n240: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t217_n242;
  t217_n241: return 0.12764301896095276f;
  t217_n242: return -0.0026930232997983694f;
  t217_n243: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t217_n247;
  t217_n244: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n246;
  t217_n245: return 0.10426784306764603f;
  t217_n246: return 0.041132230311632156f;
  t217_n247: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t217_n249;
  t217_n248: return -0.28356197476387024f;
  t217_n249: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t217_n251;
  t217_n250: return -0.15060824155807495f;
  t217_n251: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t217_n253;
  t217_n252: return 0.04848538339138031f;
  t217_n253: return 0.13108155131340027f;
  t217_n254: return 0.0011126826284453273f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree218(const Example& E) {
  t218_n0: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t218_n240;
  t218_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t218_n3;
  t218_n2: return -0.06687980145215988f;
  t218_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t218_n5;
  t218_n4: return -0.0006514281267300248f;
  t218_n5: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t218_n29;
  t218_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t218_n8;
  t218_n7: return -0.008412761613726616f;
  t218_n8: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t218_n26;
  t218_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t218_n13;
  t218_n10: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n12;
  t218_n11: return 0.07308908551931381f;
  t218_n12: return 0.012602676637470722f;
  t218_n13: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t218_n15;
  t218_n14: return 0.013083326630294323f;
  t218_n15: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t218_n25;
  t218_n16: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t218_n18;
  t218_n17: return 0.057400405406951904f;
  t218_n18: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t218_n22;
  t218_n19: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t218_n21;
  t218_n20: return 0.10722745209932327f;
  t218_n21: return 0.0841783955693245f;
  t218_n22: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t218_n24;
  t218_n23: return 0.041778892278671265f;
  t218_n24: return 0.1284351944923401f;
  t218_n25: return -0.10117891430854797f;
  t218_n26: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n28;
  t218_n27: return 0.02324928715825081f;
  t218_n28: return -0.09350517392158508f;
  t218_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t218_n237;
  t218_n30: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t218_n236;
  t218_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t218_n51;
  t218_n32: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n34;
  t218_n33: return 0.00016481344937346876f;
  t218_n34: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t218_n48;
  t218_n35: if (E.getNumReferences() >= 3287138304 /*475.5*/) goto t218_n47;
  t218_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n40;
  t218_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t218_n39;
  t218_n38: return -0.012250641360878944f;
  t218_n39: return 0.06755246967077255f;
  t218_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t218_n46;
  t218_n41: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t218_n45;
  t218_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t218_n44;
  t218_n43: return -0.028001265600323677f;
  t218_n44: return 0.11587221175432205f;
  t218_n45: return -0.10962562263011932f;
  t218_n46: return -0.029052678495645523f;
  t218_n47: return -0.11366710066795349f;
  t218_n48: if (E.getNumReferences() >= 3319227392 /*6892.5*/) goto t218_n50;
  t218_n49: return 0.0965060144662857f;
  t218_n50: return 0.03228959068655968f;
  t218_n51: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t218_n231;
  t218_n52: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t218_n224;
  t218_n53: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t218_n59;
  t218_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t218_n56;
  t218_n55: return -0.016199467703700066f;
  t218_n56: if (E.getNumReferences() >= 3261857792 /*59.0*/) goto t218_n58;
  t218_n57: return 0.047186970710754395f;
  t218_n58: return 0.10033006221055984f;
  t218_n59: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t218_n213;
  t218_n60: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t218_n184;
  t218_n61: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t218_n159;
  t218_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t218_n108;
  t218_n63: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t218_n97;
  t218_n64: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t218_n84;
  t218_n65: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n83;
  t218_n66: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n68;
  t218_n67: return -0.004584428854286671f;
  t218_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t218_n80;
  t218_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t218_n73;
  t218_n70: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t218_n72;
  t218_n71: return -0.229216068983078f;
  t218_n72: return 0.9254810214042664f;
  t218_n73: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t218_n77;
  t218_n74: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t218_n76;
  t218_n75: return 0.08588660508394241f;
  t218_n76: return -0.07741519808769226f;
  t218_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n79;
  t218_n78: return -0.06623642891645432f;
  t218_n79: return 0.11348358541727066f;
  t218_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t218_n82;
  t218_n81: return 0.10516740381717682f;
  t218_n82: return 0.05051616206765175f;
  t218_n83: return -0.02982134371995926f;
  t218_n84: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t218_n96;
  t218_n85: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n87;
  t218_n86: return -0.10797982662916183f;
  t218_n87: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t218_n95;
  t218_n88: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t218_n94;
  t218_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t218_n91;
  t218_n90: return -0.021138230338692665f;
  t218_n91: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t218_n93;
  t218_n92: return 0.11805906891822815f;
  t218_n93: return 0.041306912899017334f;
  t218_n94: return 0.11592099815607071f;
  t218_n95: return -0.30796077847480774f;
  t218_n96: return 0.12291610240936279f;
  t218_n97: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t218_n107;
  t218_n98: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t218_n102;
  t218_n99: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n101;
  t218_n100: return 0.026617661118507385f;
  t218_n101: return -0.09514368325471878f;
  t218_n102: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n104;
  t218_n103: return -0.2717358469963074f;
  t218_n104: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n106;
  t218_n105: return 0.11983019858598709f;
  t218_n106: return -0.05431463569402695f;
  t218_n107: return -0.25015997886657715f;
  t218_n108: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t218_n158;
  t218_n109: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t218_n151;
  t218_n110: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t218_n150;
  t218_n111: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t218_n113;
  t218_n112: return 0.03035021387040615f;
  t218_n113: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t218_n149;
  t218_n114: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t218_n124;
  t218_n115: if (E.getSymbolScopeDistance() >= 3247439872 /*18.0*/) goto t218_n123;
  t218_n116: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t218_n118;
  t218_n117: return 0.02914039045572281f;
  t218_n118: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n120;
  t218_n119: return 0.19384004175662994f;
  t218_n120: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t218_n122;
  t218_n121: return 0.13332802057266235f;
  t218_n122: return 0.04408691078424454f;
  t218_n123: return -0.0666075274348259f;
  t218_n124: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t218_n146;
  t218_n125: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n141;
  t218_n126: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t218_n138;
  t218_n127: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t218_n137;
  t218_n128: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n132;
  t218_n129: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t218_n131;
  t218_n130: return 0.1066240444779396f;
  t218_n131: return -0.10120614618062973f;
  t218_n132: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t218_n134;
  t218_n133: return 0.09771717339754105f;
  t218_n134: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n136;
  t218_n135: return 0.11109385639429092f;
  t218_n136: return 0.190725639462471f;
  t218_n137: return -0.24954010546207428f;
  t218_n138: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t218_n140;
  t218_n139: return 0.07146910578012466f;
  t218_n140: return 0.08680617064237595f;
  t218_n141: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t218_n143;
  t218_n142: return 0.019850362092256546f;
  t218_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n145;
  t218_n144: return 0.09857508540153503f;
  t218_n145: return -0.231610506772995f;
  t218_n146: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n148;
  t218_n147: return 0.11607499420642853f;
  t218_n148: return 0.10751819610595703f;
  t218_n149: return 0.026524176821112633f;
  t218_n150: return -0.07909636944532394f;
  t218_n151: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n157;
  t218_n152: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n156;
  t218_n153: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t218_n155;
  t218_n154: return -0.10636147111654282f;
  t218_n155: return 0.10549511760473251f;
  t218_n156: return 0.06536810100078583f;
  t218_n157: return 0.04336750507354736f;
  t218_n158: return -0.0701555609703064f;
  t218_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t218_n161;
  t218_n160: return 0.032450634986162186f;
  t218_n161: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t218_n175;
  t218_n162: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t218_n174;
  t218_n163: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t218_n173;
  t218_n164: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t218_n170;
  t218_n165: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n167;
  t218_n166: return 0.010321947745978832f;
  t218_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t218_n169;
  t218_n168: return -0.013276267796754837f;
  t218_n169: return 0.08716744184494019f;
  t218_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t218_n172;
  t218_n171: return 0.11165037751197815f;
  t218_n172: return 0.031122339889407158f;
  t218_n173: return -0.22127094864845276f;
  t218_n174: return -0.12431056797504425f;
  t218_n175: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t218_n181;
  t218_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t218_n178;
  t218_n177: return 0.12619896233081818f;
  t218_n178: if (E.getNumReferences() >= 3233808384 /*6.0*/) goto t218_n180;
  t218_n179: return 0.060200221836566925f;
  t218_n180: return 0.12404216825962067f;
  t218_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t218_n183;
  t218_n182: return -0.15922458469867706f;
  t218_n183: return 0.12720297276973724f;
  t218_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t218_n210;
  t218_n185: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t218_n197;
  t218_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t218_n194;
  t218_n187: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t218_n189;
  t218_n188: return 0.062277309596538544f;
  t218_n189: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t218_n193;
  t218_n190: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t218_n192;
  t218_n191: return 0.1143137738108635f;
  t218_n192: return 0.10803039371967316f;
  t218_n193: return 0.01666252501308918f;
  t218_n194: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n196;
  t218_n195: return 0.1125621572136879f;
  t218_n196: return -0.16042672097682953f;
  t218_n197: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t218_n199;
  t218_n198: return -0.10770215094089508f;
  t218_n199: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t218_n205;
  t218_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t218_n204;
  t218_n201: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t218_n203;
  t218_n202: return -0.2170666605234146f;
  t218_n203: return 0.10064862668514252f;
  t218_n204: return 0.10823383182287216f;
  t218_n205: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t218_n207;
  t218_n206: return -0.0205352995544672f;
  t218_n207: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t218_n209;
  t218_n208: return -0.167428120970726f;
  t218_n209: return 0.11330174654722214f;
  t218_n210: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t218_n212;
  t218_n211: return 0.1076781302690506f;
  t218_n212: return -0.4846667945384979f;
  t218_n213: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t218_n223;
  t218_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Type))) goto t218_n216;
  t218_n215: return 0.008229152299463749f;
  t218_n216: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n222;
  t218_n217: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t218_n219;
  t218_n218: return -0.16571053862571716f;
  t218_n219: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t218_n221;
  t218_n220: return 0.10704030841588974f;
  t218_n221: return 0.08608710765838623f;
  t218_n222: return 0.04329262301325798f;
  t218_n223: return -0.015886416658759117f;
  t218_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n230;
  t218_n225: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t218_n229;
  t218_n226: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t218_n228;
  t218_n227: return 0.23929741978645325f;
  t218_n228: return 0.11283261328935623f;
  t218_n229: return 0.07327662408351898f;
  t218_n230: return -0.17137601971626282f;
  t218_n231: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t218_n233;
  t218_n232: return -0.016408124938607216f;
  t218_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t218_n235;
  t218_n234: return -0.20551742613315582f;
  t218_n235: return 0.09723502397537231f;
  t218_n236: return 0.002026056870818138f;
  t218_n237: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t218_n239;
  t218_n238: return 0.08399609476327896f;
  t218_n239: return 0.0247713141143322f;
  t218_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t218_n242;
  t218_n241: return -0.11660344898700714f;
  t218_n242: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t218_n244;
  t218_n243: return -0.07861847430467606f;
  t218_n244: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t218_n254;
  t218_n245: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t218_n251;
  t218_n246: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t218_n250;
  t218_n247: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n249;
  t218_n248: return 0.02008635737001896f;
  t218_n249: return -0.46099480986595154f;
  t218_n250: return 0.06916245818138123f;
  t218_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t218_n253;
  t218_n252: return 0.08635368198156357f;
  t218_n253: return -0.07138938456773758f;
  t218_n254: return -0.13652417063713074f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree219(const Example& E) {
  t219_n0: if (E.getNumReferences() >= 3320122368 /*7329.5*/) goto t219_n2;
  t219_n1: return -0.0002871798351407051f;
  t219_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t219_n158;
  t219_n3: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t219_n135;
  t219_n4: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t219_n6;
  t219_n5: return 0.11026639491319656f;
  t219_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t219_n52;
  t219_n7: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t219_n41;
  t219_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t219_n12;
  t219_n9: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t219_n11;
  t219_n10: return -0.006861788686364889f;
  t219_n11: return -0.13774138689041138f;
  t219_n12: if (E.getNumReferences() >= 3320384512 /*7457.5*/) goto t219_n14;
  t219_n13: return 0.09488743543624878f;
  t219_n14: if (E.getNumReferences() >= 3349201152 /*82306.0*/) goto t219_n16;
  t219_n15: return 0.015709228813648224f;
  t219_n16: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t219_n36;
  t219_n17: if (E.getNumReferences() >= 3349883520 /*87637.0*/) goto t219_n27;
  t219_n18: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t219_n20;
  t219_n19: return -0.016346676275134087f;
  t219_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n26;
  t219_n21: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t219_n25;
  t219_n22: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t219_n24;
  t219_n23: return 0.07001525908708572f;
  t219_n24: return 0.10888645052909851f;
  t219_n25: return -0.3074924647808075f;
  t219_n26: return -0.019098928198218346f;
  t219_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n35;
  t219_n28: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t219_n32;
  t219_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t219_n31;
  t219_n30: return 0.09135683625936508f;
  t219_n31: return -0.48587432503700256f;
  t219_n32: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t219_n34;
  t219_n33: return 0.07272022217512131f;
  t219_n34: return -0.21524745225906372f;
  t219_n35: return -0.02864597737789154f;
  t219_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t219_n40;
  t219_n37: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t219_n39;
  t219_n38: return -0.06303388625383377f;
  t219_n39: return 0.012696568854153156f;
  t219_n40: return 0.08377932757139206f;
  t219_n41: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t219_n51;
  t219_n42: if (E.getNumReferences() >= 3339920896 /*37670.0*/) goto t219_n48;
  t219_n43: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t219_n45;
  t219_n44: return -0.029708590358495712f;
  t219_n45: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t219_n47;
  t219_n46: return -0.2964493930339813f;
  t219_n47: return 0.10708092153072357f;
  t219_n48: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n50;
  t219_n49: return 0.107644222676754f;
  t219_n50: return 0.11331918835639954f;
  t219_n51: return -0.07998481392860413f;
  t219_n52: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t219_n62;
  t219_n53: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t219_n55;
  t219_n54: return 0.01086331158876419f;
  t219_n55: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t219_n61;
  t219_n56: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t219_n58;
  t219_n57: return -0.11421144008636475f;
  t219_n58: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t219_n60;
  t219_n59: return 0.02444169670343399f;
  t219_n60: return -2.398956775665283f;
  t219_n61: return 0.13521896302700043f;
  t219_n62: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t219_n118;
  t219_n63: if (E.getNumReferences() >= 3331587072 /*18942.0*/) goto t219_n77;
  t219_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t219_n66;
  t219_n65: return 0.045178692787885666f;
  t219_n66: if (E.getNumReferences() >= 3323093504 /*9368.5*/) goto t219_n72;
  t219_n67: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t219_n69;
  t219_n68: return 0.18270361423492432f;
  t219_n69: if (E.getNumReferences() >= 3321240576 /*7875.5*/) goto t219_n71;
  t219_n70: return -0.11076626181602478f;
  t219_n71: return 0.07390555739402771f;
  t219_n72: if (E.getNumReferences() >= 3326120448 /*12324.5*/) goto t219_n76;
  t219_n73: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t219_n75;
  t219_n74: return -0.9260445237159729f;
  t219_n75: return -0.23514436185359955f;
  t219_n76: return -0.10233938694000244f;
  t219_n77: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t219_n85;
  t219_n78: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n82;
  t219_n79: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t219_n81;
  t219_n80: return 0.11284606903791428f;
  t219_n81: return 0.1032600924372673f;
  t219_n82: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t219_n84;
  t219_n83: return 0.06822185218334198f;
  t219_n84: return -0.12429855018854141f;
  t219_n85: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t219_n113;
  t219_n86: if (E.getNumReferences() >= 3346296960 /*62576.5*/) goto t219_n112;
  t219_n87: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t219_n103;
  t219_n88: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t219_n90;
  t219_n89: return -0.22139011323451996f;
  t219_n90: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t219_n100;
  t219_n91: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t219_n93;
  t219_n92: return -0.07560726255178452f;
  t219_n93: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t219_n99;
  t219_n94: if (E.getNumReferences() >= 3333914624 /*23488.0*/) goto t219_n98;
  t219_n95: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n97;
  t219_n96: return 0.09780397266149521f;
  t219_n97: return 0.09623435139656067f;
  t219_n98: return -0.10039415955543518f;
  t219_n99: return -0.3841157555580139f;
  t219_n100: if (E.getNumReferences() >= 3332280320 /*20296.0*/) goto t219_n102;
  t219_n101: return 0.18709148466587067f;
  t219_n102: return 0.024239961057901382f;
  t219_n103: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t219_n109;
  t219_n104: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t219_n108;
  t219_n105: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n107;
  t219_n106: return 0.08318104594945908f;
  t219_n107: return 0.07049217820167542f;
  t219_n108: return 0.17355823516845703f;
  t219_n109: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t219_n111;
  t219_n110: return 0.07108030468225479f;
  t219_n111: return 0.0285797156393528f;
  t219_n112: return -0.02753720059990883f;
  t219_n113: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n117;
  t219_n114: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t219_n116;
  t219_n115: return 0.06531620025634766f;
  t219_n116: return 0.11296183615922928f;
  t219_n117: return 0.057102516293525696f;
  t219_n118: if (E.getNumReferences() >= 3323093504 /*9368.5*/) goto t219_n120;
  t219_n119: return 0.13587334752082825f;
  t219_n120: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t219_n124;
  t219_n121: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t219_n123;
  t219_n122: return -0.05269906669855118f;
  t219_n123: return 0.043505940586328506f;
  t219_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n128;
  t219_n125: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t219_n127;
  t219_n126: return 0.1001744419336319f;
  t219_n127: return 0.03831495717167854f;
  t219_n128: if (E.getNumReferences() >= 3345021312 /*57593.5*/) goto t219_n134;
  t219_n129: if (E.getNumReferences() >= 3331398400 /*18573.5*/) goto t219_n131;
  t219_n130: return -0.12262364476919174f;
  t219_n131: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t219_n133;
  t219_n132: return 0.1062595546245575f;
  t219_n133: return 0.1280936300754547f;
  t219_n134: return 0.004729022271931171f;
  t219_n135: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n137;
  t219_n136: return -0.002846933901309967f;
  t219_n137: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t219_n157;
  t219_n138: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t219_n148;
  t219_n139: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t219_n141;
  t219_n140: return -0.20554961264133453f;
  t219_n141: if (E.getNumReferences() >= 3321499648 /*8002.0*/) goto t219_n143;
  t219_n142: return 0.30057641863822937f;
  t219_n143: if (E.getNumReferences() >= 3338025472 /*31517.0*/) goto t219_n147;
  t219_n144: if (E.getNumReferences() >= 3335809536 /*27189.0*/) goto t219_n146;
  t219_n145: return 0.1039772555232048f;
  t219_n146: return 0.10814107954502106f;
  t219_n147: return -0.07208351045846939f;
  t219_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t219_n150;
  t219_n149: return 0.03908349946141243f;
  t219_n150: if (E.getNumReferences() >= 3321825280 /*8161.0*/) goto t219_n156;
  t219_n151: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t219_n155;
  t219_n152: if (E.getNumReferences() >= 3321156608 /*7834.5*/) goto t219_n154;
  t219_n153: return 0.39890602231025696f;
  t219_n154: return 0.44075411558151245f;
  t219_n155: return 0.039460401982069016f;
  t219_n156: return 0.043814778327941895f;
  t219_n157: return 0.010941838845610619f;
  t219_n158: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t219_n160;
  t219_n159: return 2.9804268706357107e-05f;
  t219_n160: if (E.getNumReferences() >= 3322645504 /*8931.0*/) goto t219_n204;
  t219_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t219_n195;
  t219_n162: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t219_n178;
  t219_n163: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t219_n175;
  t219_n164: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t219_n170;
  t219_n165: if (E.getNumReferences() >= 3322376704 /*8668.5*/) goto t219_n167;
  t219_n166: return -0.18174302577972412f;
  t219_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t219_n169;
  t219_n168: return 0.11883532255887985f;
  t219_n169: return 0.07918595522642136f;
  t219_n170: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t219_n172;
  t219_n171: return -0.004703013226389885f;
  t219_n172: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t219_n174;
  t219_n173: return -0.029648859053850174f;
  t219_n174: return 0.11272532492876053f;
  t219_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t219_n177;
  t219_n176: return -0.03407619893550873f;
  t219_n177: return 0.13278351724147797f;
  t219_n178: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t219_n190;
  t219_n179: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t219_n185;
  t219_n180: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t219_n182;
  t219_n181: return -0.023239461705088615f;
  t219_n182: if (E.getNumReferences() >= 3321866240 /*8181.0*/) goto t219_n184;
  t219_n183: return -0.260050892829895f;
  t219_n184: return 0.1071646511554718f;
  t219_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t219_n189;
  t219_n186: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t219_n188;
  t219_n187: return 0.11798951029777527f;
  t219_n188: return 0.06292439252138138f;
  t219_n189: return 0.11586657911539078f;
  t219_n190: if (E.getNumReferences() >= 3322247680 /*8542.5*/) goto t219_n194;
  t219_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t219_n193;
  t219_n192: return -0.1371629536151886f;
  t219_n193: return 0.11046294122934341f;
  t219_n194: return 0.11029962450265884f;
  t219_n195: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t219_n203;
  t219_n196: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t219_n202;
  t219_n197: if (E.getNumReferences() >= 3322246144 /*8541.0*/) goto t219_n199;
  t219_n198: return 0.07555744051933289f;
  t219_n199: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t219_n201;
  t219_n200: return 0.10968028008937836f;
  t219_n201: return 0.15030264854431152f;
  t219_n202: return 0.04173419624567032f;
  t219_n203: return -0.09052210301160812f;
  t219_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t219_n208;
  t219_n205: if (E.getNumReferences() >= 3323132416 /*9406.5*/) goto t219_n207;
  t219_n206: return -0.11592847853899002f;
  t219_n207: return 0.006013138219714165f;
  t219_n208: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t219_n238;
  t219_n209: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t219_n233;
  t219_n210: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t219_n232;
  t219_n211: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n221;
  t219_n212: if (E.getNumReferences() >= 3327551488 /*13722.0*/) goto t219_n214;
  t219_n213: return -0.3162260949611664f;
  t219_n214: if (E.getNumReferences() >= 3329865216 /*15981.5*/) goto t219_n216;
  t219_n215: return 0.07771018892526627f;
  t219_n216: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t219_n218;
  t219_n217: return -0.10151152312755585f;
  t219_n218: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t219_n220;
  t219_n219: return 0.08465130627155304f;
  t219_n220: return -3.4845457077026367f;
  t219_n221: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t219_n223;
  t219_n222: return 0.03126731887459755f;
  t219_n223: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t219_n231;
  t219_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t219_n226;
  t219_n225: return 0.047633517533540726f;
  t219_n226: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t219_n230;
  t219_n227: if (E.getNumReferences() >= 3336739328 /*29005.0*/) goto t219_n229;
  t219_n228: return 0.100936159491539f;
  t219_n229: return -0.3158840239048004f;
  t219_n230: return 0.09113325923681259f;
  t219_n231: return -0.3347320258617401f;
  t219_n232: return -0.10274117439985275f;
  t219_n233: if (E.getNumReferences() >= 3351111424 /*97230.0*/) goto t219_n235;
  t219_n234: return -0.009352530352771282f;
  t219_n235: if (E.getNumReferences() >= 3363327264 /*254260.5*/) goto t219_n237;
  t219_n236: return 0.10551467537879944f;
  t219_n237: return 0.03570140153169632f;
  t219_n238: if (E.getNumReferences() >= 3326588928 /*12782.0*/) goto t219_n254;
  t219_n239: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n241;
  t219_n240: return -0.24669089913368225f;
  t219_n241: if (E.getNumReferences() >= 3326458880 /*12655.0*/) goto t219_n253;
  t219_n242: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t219_n246;
  t219_n243: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t219_n245;
  t219_n244: return 0.07210563123226166f;
  t219_n245: return 0.285317063331604f;
  t219_n246: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t219_n250;
  t219_n247: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t219_n249;
  t219_n248: return 0.08132252842187881f;
  t219_n249: return -0.05605793744325638f;
  t219_n250: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t219_n252;
  t219_n251: return -0.8455421328544617f;
  t219_n252: return 0.04745645448565483f;
  t219_n253: return 0.11655451357364655f;
  t219_n254: return 0.005353926215320826f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree220(const Example& E) {
  t220_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t220_n20;
  t220_n1: if (E.getNumReferences() >= 3348896192 /*79923.5*/) goto t220_n3;
  t220_n2: return -0.00011469097080407664f;
  t220_n3: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n5;
  t220_n4: return -0.035371746867895126f;
  t220_n5: if (E.getNumReferences() >= 3349481344 /*84495.0*/) goto t220_n13;
  t220_n6: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n12;
  t220_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t220_n11;
  t220_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t220_n10;
  t220_n9: return -0.2617010772228241f;
  t220_n10: return -0.1006150022149086f;
  t220_n11: return 0.0489719994366169f;
  t220_n12: return 0.05412977561354637f;
  t220_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t220_n19;
  t220_n14: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t220_n18;
  t220_n15: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t220_n17;
  t220_n16: return -0.45676857233047485f;
  t220_n17: return -0.10037455707788467f;
  t220_n18: return 0.0017019491642713547f;
  t220_n19: return -0.08948282897472382f;
  t220_n20: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t220_n120;
  t220_n21: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t220_n107;
  t220_n22: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t220_n76;
  t220_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t220_n51;
  t220_n24: if (E.getNumReferences() >= 3350198272 /*90096.0*/) goto t220_n50;
  t220_n25: if (E.getNumReferences() >= 3350124096 /*89516.5*/) goto t220_n37;
  t220_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n28;
  t220_n27: return 0.04137412831187248f;
  t220_n28: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n30;
  t220_n29: return 0.03665551543235779f;
  t220_n30: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t220_n32;
  t220_n31: return 0.09125558286905289f;
  t220_n32: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t220_n36;
  t220_n33: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t220_n35;
  t220_n34: return 0.1396683156490326f;
  t220_n35: return 0.03297015279531479f;
  t220_n36: return 0.09501620382070541f;
  t220_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n47;
  t220_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n46;
  t220_n39: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t220_n45;
  t220_n40: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t220_n44;
  t220_n41: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t220_n43;
  t220_n42: return 0.08638467639684677f;
  t220_n43: return 0.06940591335296631f;
  t220_n44: return 0.0803641676902771f;
  t220_n45: return -0.1383601427078247f;
  t220_n46: return -0.43895044922828674f;
  t220_n47: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t220_n49;
  t220_n48: return 0.08054228872060776f;
  t220_n49: return -0.23430590331554413f;
  t220_n50: return 0.0007682097493670881f;
  t220_n51: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t220_n53;
  t220_n52: return -0.045019492506980896f;
  t220_n53: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t220_n75;
  t220_n54: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n70;
  t220_n55: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t220_n69;
  t220_n56: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t220_n64;
  t220_n57: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t220_n59;
  t220_n58: return 0.08944042772054672f;
  t220_n59: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t220_n61;
  t220_n60: return 0.11000984907150269f;
  t220_n61: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t220_n63;
  t220_n62: return 0.10965163260698318f;
  t220_n63: return 0.1126919761300087f;
  t220_n64: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t220_n68;
  t220_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n67;
  t220_n66: return 0.0f;
  t220_n67: return 0.08760581910610199f;
  t220_n68: return 0.07132317870855331f;
  t220_n69: return -0.002471319632604718f;
  t220_n70: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t220_n72;
  t220_n71: return -0.2413262575864792f;
  t220_n72: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t220_n74;
  t220_n73: return 0.05213816463947296f;
  t220_n74: return -0.04640104994177818f;
  t220_n75: return 0.008235620334744453f;
  t220_n76: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t220_n104;
  t220_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t220_n103;
  t220_n78: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t220_n80;
  t220_n79: return 0.009480662643909454f;
  t220_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n82;
  t220_n81: return 0.009549867361783981f;
  t220_n82: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n86;
  t220_n83: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t220_n85;
  t220_n84: return -0.01632174663245678f;
  t220_n85: return 0.08875591307878494f;
  t220_n86: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t220_n88;
  t220_n87: return 0.10822810232639313f;
  t220_n88: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t220_n102;
  t220_n89: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t220_n91;
  t220_n90: return -0.10212647914886475f;
  t220_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t220_n93;
  t220_n92: return -0.10667525976896286f;
  t220_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t220_n101;
  t220_n94: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t220_n100;
  t220_n95: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t220_n97;
  t220_n96: return 0.09915022552013397f;
  t220_n97: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n99;
  t220_n98: return 0.10294072329998016f;
  t220_n99: return 0.07060275226831436f;
  t220_n100: return -0.3011460304260254f;
  t220_n101: return 0.04024690389633179f;
  t220_n102: return -0.17411789298057556f;
  t220_n103: return -0.031596675515174866f;
  t220_n104: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n106;
  t220_n105: return 0.047747571021318436f;
  t220_n106: return 0.02852672152221203f;
  t220_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t220_n117;
  t220_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n114;
  t220_n109: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n111;
  t220_n110: return 0.08710474520921707f;
  t220_n111: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t220_n113;
  t220_n112: return -0.23069927096366882f;
  t220_n113: return 0.0016129252035170794f;
  t220_n114: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t220_n116;
  t220_n115: return -0.07447045296430588f;
  t220_n116: return -0.6501142382621765f;
  t220_n117: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t220_n119;
  t220_n118: return 0.10501088947057724f;
  t220_n119: return -0.08090001344680786f;
  t220_n120: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t220_n122;
  t220_n121: return -0.023808812722563744f;
  t220_n122: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t220_n252;
  t220_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t220_n205;
  t220_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t220_n130;
  t220_n125: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t220_n129;
  t220_n126: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t220_n128;
  t220_n127: return -0.3131501376628876f;
  t220_n128: return 0.10431929677724838f;
  t220_n129: return -0.04405118152499199f;
  t220_n130: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n132;
  t220_n131: return 0.013870862312614918f;
  t220_n132: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t220_n182;
  t220_n133: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t220_n157;
  t220_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t220_n142;
  t220_n135: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n139;
  t220_n136: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n138;
  t220_n137: return -0.12748420238494873f;
  t220_n138: return -0.06451963633298874f;
  t220_n139: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t220_n141;
  t220_n140: return -0.20741139352321625f;
  t220_n141: return 0.09414362162351608f;
  t220_n142: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t220_n152;
  t220_n143: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t220_n151;
  t220_n144: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t220_n150;
  t220_n145: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t220_n147;
  t220_n146: return -0.1220133826136589f;
  t220_n147: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n149;
  t220_n148: return 1.4760808944702148f;
  t220_n149: return 0.6874833703041077f;
  t220_n150: return -0.6557489633560181f;
  t220_n151: return 0.13652096688747406f;
  t220_n152: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t220_n154;
  t220_n153: return 0.05084993317723274f;
  t220_n154: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n156;
  t220_n155: return -0.23554450273513794f;
  t220_n156: return 0.08616385608911514f;
  t220_n157: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t220_n169;
  t220_n158: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t220_n160;
  t220_n159: return 0.07451033592224121f;
  t220_n160: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n166;
  t220_n161: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t220_n165;
  t220_n162: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t220_n164;
  t220_n163: return 0.10022382438182831f;
  t220_n164: return -0.1986335664987564f;
  t220_n165: return 0.10394538938999176f;
  t220_n166: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t220_n168;
  t220_n167: return 0.08103229850530624f;
  t220_n168: return -0.023198138922452927f;
  t220_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t220_n173;
  t220_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t220_n172;
  t220_n171: return -0.02231059968471527f;
  t220_n172: return 0.401966392993927f;
  t220_n173: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t220_n181;
  t220_n174: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t220_n176;
  t220_n175: return -0.31142884492874146f;
  t220_n176: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n180;
  t220_n177: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t220_n179;
  t220_n178: return 0.07938862591981888f;
  t220_n179: return 0.04859745502471924f;
  t220_n180: return 0.03240375593304634f;
  t220_n181: return -0.05657605081796646f;
  t220_n182: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t220_n200;
  t220_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n199;
  t220_n184: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t220_n190;
  t220_n185: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t220_n187;
  t220_n186: return 0.06901320815086365f;
  t220_n187: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t220_n189;
  t220_n188: return -0.8137394785881042f;
  t220_n189: return 0.03529081866145134f;
  t220_n190: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t220_n192;
  t220_n191: return -0.19763709604740143f;
  t220_n192: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t220_n194;
  t220_n193: return 0.06005599722266197f;
  t220_n194: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t220_n196;
  t220_n195: return -0.09215755015611649f;
  t220_n196: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t220_n198;
  t220_n197: return 0.10035436600446701f;
  t220_n198: return 0.07965850085020065f;
  t220_n199: return -0.1650937795639038f;
  t220_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t220_n202;
  t220_n201: return 0.028174985200166702f;
  t220_n202: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t220_n204;
  t220_n203: return 0.11032072454690933f;
  t220_n204: return 0.07074002921581268f;
  t220_n205: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t220_n235;
  t220_n206: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t220_n224;
  t220_n207: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t220_n209;
  t220_n208: return 0.017008451744914055f;
  t220_n209: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t220_n211;
  t220_n210: return -0.17547406256198883f;
  t220_n211: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t220_n217;
  t220_n212: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n216;
  t220_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t220_n215;
  t220_n214: return 0.08146420866250992f;
  t220_n215: return 0.1280319094657898f;
  t220_n216: return -0.002228338271379471f;
  t220_n217: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n219;
  t220_n218: return 0.02842656895518303f;
  t220_n219: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t220_n221;
  t220_n220: return 0.04969435930252075f;
  t220_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t220_n223;
  t220_n222: return -0.12232983112335205f;
  t220_n223: return 0.1530240923166275f;
  t220_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t220_n226;
  t220_n225: return -0.00675103859975934f;
  t220_n226: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t220_n228;
  t220_n227: return 0.004424034617841244f;
  t220_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n232;
  t220_n229: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n231;
  t220_n230: return 0.09397722035646439f;
  t220_n231: return 0.10471799224615097f;
  t220_n232: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t220_n234;
  t220_n233: return 0.041284963488578796f;
  t220_n234: return 0.09271013736724854f;
  t220_n235: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t220_n243;
  t220_n236: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t220_n242;
  t220_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t220_n241;
  t220_n238: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t220_n240;
  t220_n239: return -0.40902242064476013f;
  t220_n240: return 0.03200112655758858f;
  t220_n241: return 0.10795408487319946f;
  t220_n242: return -0.032796263694763184f;
  t220_n243: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t220_n251;
  t220_n244: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t220_n250;
  t220_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t220_n247;
  t220_n246: return -0.5836882591247559f;
  t220_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t220_n249;
  t220_n248: return -0.0658218115568161f;
  t220_n249: return -0.24609962105751038f;
  t220_n250: return 0.0571601465344429f;
  t220_n251: return 0.0621040053665638f;
  t220_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t220_n254;
  t220_n253: return -0.0047187479212880135f;
  t220_n254: return 0.01402661856263876f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree221(const Example& E) {
  t221_n0: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t221_n2;
  t221_n1: return -0.0004431523266248405f;
  t221_n2: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t221_n150;
  t221_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t221_n5;
  t221_n4: return 0.0014763042563572526f;
  t221_n5: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t221_n85;
  t221_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t221_n14;
  t221_n7: if (E.getNumReferences() >= 3265986560 /*85.5*/) goto t221_n9;
  t221_n8: return -0.02680337429046631f;
  t221_n9: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t221_n13;
  t221_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t221_n12;
  t221_n11: return -0.15710371732711792f;
  t221_n12: return 0.13631659746170044f;
  t221_n13: return 0.018443288281559944f;
  t221_n14: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t221_n36;
  t221_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t221_n29;
  t221_n16: if (E.getNumReferences() >= 3269197824 /*110.0*/) goto t221_n18;
  t221_n17: return -0.21687090396881104f;
  t221_n18: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t221_n22;
  t221_n19: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t221_n21;
  t221_n20: return 0.05918824300169945f;
  t221_n21: return -0.31386277079582214f;
  t221_n22: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t221_n28;
  t221_n23: if (E.getNumReferences() >= 3275915264 /*194.5*/) goto t221_n27;
  t221_n24: if (E.getNumReferences() >= 3273195520 /*153.0*/) goto t221_n26;
  t221_n25: return 0.030193991959095f;
  t221_n26: return 0.11177805066108704f;
  t221_n27: return 0.005216841120272875f;
  t221_n28: return -0.01479509100317955f;
  t221_n29: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t221_n35;
  t221_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t221_n34;
  t221_n31: if (E.getNumReferences() >= 3264610304 /*75.0*/) goto t221_n33;
  t221_n32: return 0.1331404447555542f;
  t221_n33: return -0.19149574637413025f;
  t221_n34: return 0.09971196949481964f;
  t221_n35: return -0.11986604332923889f;
  t221_n36: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t221_n58;
  t221_n37: if (E.getNumReferences() >= 3265265664 /*80.0*/) goto t221_n51;
  t221_n38: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t221_n44;
  t221_n39: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t221_n43;
  t221_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t221_n42;
  t221_n41: return -0.1817041039466858f;
  t221_n42: return 0.36115437746047974f;
  t221_n43: return 0.10609369724988937f;
  t221_n44: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t221_n48;
  t221_n45: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t221_n47;
  t221_n46: return -0.08277030289173126f;
  t221_n47: return 0.1160583645105362f;
  t221_n48: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n50;
  t221_n49: return 0.10381554067134857f;
  t221_n50: return -0.0062139201909303665f;
  t221_n51: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t221_n55;
  t221_n52: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t221_n54;
  t221_n53: return 0.3387133777141571f;
  t221_n54: return 0.11108193546533585f;
  t221_n55: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n57;
  t221_n56: return 0.1053261086344719f;
  t221_n57: return -0.28326138854026794f;
  t221_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t221_n80;
  t221_n59: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n69;
  t221_n60: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t221_n68;
  t221_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t221_n63;
  t221_n62: return -0.19798709452152252f;
  t221_n63: if (E.getNumReferences() >= 3271098368 /*124.5*/) goto t221_n67;
  t221_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t221_n66;
  t221_n65: return 0.2597881257534027f;
  t221_n66: return -0.17352396249771118f;
  t221_n67: return 0.10593632608652115f;
  t221_n68: return -0.05437741428613663f;
  t221_n69: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t221_n75;
  t221_n70: if (E.getNumReferences() >= 3273850880 /*163.0*/) goto t221_n72;
  t221_n71: return 0.10757913440465927f;
  t221_n72: if (E.getNumReferences() >= 3289161728 /*562.5*/) goto t221_n74;
  t221_n73: return -0.12365040928125381f;
  t221_n74: return 0.108636274933815f;
  t221_n75: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t221_n79;
  t221_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t221_n78;
  t221_n77: return -0.7547285556793213f;
  t221_n78: return 0.050751376897096634f;
  t221_n79: return 0.12309613078832626f;
  t221_n80: if (E.getNumReferences() >= 3282042880 /*320.0*/) goto t221_n82;
  t221_n81: return -0.20658378303050995f;
  t221_n82: if (E.getNumReferences() >= 3285696512 /*431.5*/) goto t221_n84;
  t221_n83: return 0.1291450560092926f;
  t221_n84: return -0.3657907545566559f;
  t221_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t221_n147;
  t221_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t221_n88;
  t221_n87: return -0.06839060038328171f;
  t221_n88: if (E.getNumReferences() >= 3263168512 /*64.0*/) goto t221_n90;
  t221_n89: return 0.09482893347740173f;
  t221_n90: if (E.getNumReferences() >= 3302178816 /*1690.0*/) goto t221_n118;
  t221_n91: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t221_n103;
  t221_n92: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t221_n94;
  t221_n93: return 0.013703142292797565f;
  t221_n94: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t221_n96;
  t221_n95: return 0.10092336684465408f;
  t221_n96: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t221_n98;
  t221_n97: return 0.04548928514122963f;
  t221_n98: if (E.getNumReferences() >= 3272572928 /*143.5*/) goto t221_n102;
  t221_n99: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t221_n101;
  t221_n100: return 0.1012154147028923f;
  t221_n101: return 0.08982017636299133f;
  t221_n102: return 0.20592327415943146f;
  t221_n103: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t221_n115;
  t221_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t221_n112;
  t221_n105: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t221_n111;
  t221_n106: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t221_n110;
  t221_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t221_n109;
  t221_n108: return -0.7251617312431335f;
  t221_n109: return -0.2774731516838074f;
  t221_n110: return -0.15754912793636322f;
  t221_n111: return 0.01595480367541313f;
  t221_n112: if (E.getNumReferences() >= 3295076352 /*923.5*/) goto t221_n114;
  t221_n113: return 0.03278085216879845f;
  t221_n114: return -0.30949169397354126f;
  t221_n115: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t221_n117;
  t221_n116: return -0.04726943373680115f;
  t221_n117: return 0.06483691930770874f;
  t221_n118: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n132;
  t221_n119: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t221_n131;
  t221_n120: if (E.getNumReferences() >= 3337059584 /*29630.5*/) goto t221_n130;
  t221_n121: if (E.getNumReferences() >= 3317206016 /*5905.5*/) goto t221_n129;
  t221_n122: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t221_n126;
  t221_n123: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t221_n125;
  t221_n124: return 0.08031724393367767f;
  t221_n125: return 0.10859410464763641f;
  t221_n126: if (E.getNumReferences() >= 3309963264 /*3232.5*/) goto t221_n128;
  t221_n127: return -0.6920813322067261f;
  t221_n128: return 0.13977959752082825f;
  t221_n129: return -0.3142884075641632f;
  t221_n130: return 0.10789406299591064f;
  t221_n131: return 0.03991551697254181f;
  t221_n132: if (E.getNumReferences() >= 3305592832 /*2165.5*/) goto t221_n136;
  t221_n133: if (E.getNumReferences() >= 3304538112 /*1978.0*/) goto t221_n135;
  t221_n134: return 0.050108570605516434f;
  t221_n135: return 0.09601341933012009f;
  t221_n136: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t221_n138;
  t221_n137: return 0.018279774114489555f;
  t221_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t221_n144;
  t221_n139: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t221_n141;
  t221_n140: return -0.19201722741127014f;
  t221_n141: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t221_n143;
  t221_n142: return 0.0034943840000778437f;
  t221_n143: return 0.11760672926902771f;
  t221_n144: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t221_n146;
  t221_n145: return 0.10222864896059036f;
  t221_n146: return -0.054575107991695404f;
  t221_n147: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t221_n149;
  t221_n148: return -0.08667731285095215f;
  t221_n149: return 0.01557349693030119f;
  t221_n150: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t221_n242;
  t221_n151: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t221_n185;
  t221_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t221_n184;
  t221_n153: if (E.getNumReferences() >= 3375821112 /*749331.5*/) goto t221_n183;
  t221_n154: if (E.getNumReferences() >= 3369273984 /*432212.0*/) goto t221_n160;
  t221_n155: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t221_n157;
  t221_n156: return -0.027318241074681282f;
  t221_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t221_n159;
  t221_n158: return 0.038358256220817566f;
  t221_n159: return 0.10150964558124542f;
  t221_n160: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t221_n174;
  t221_n161: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t221_n165;
  t221_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t221_n164;
  t221_n163: return -0.17183853685855865f;
  t221_n164: return 0.06691091507673264f;
  t221_n165: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t221_n167;
  t221_n166: return -0.14997825026512146f;
  t221_n167: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t221_n169;
  t221_n168: return 0.04746823012828827f;
  t221_n169: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t221_n173;
  t221_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t221_n172;
  t221_n171: return -2.564284563064575f;
  t221_n172: return -0.4540286958217621f;
  t221_n173: return -0.004124297294765711f;
  t221_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t221_n178;
  t221_n175: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t221_n177;
  t221_n176: return -0.15870875120162964f;
  t221_n177: return 0.06601214408874512f;
  t221_n178: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t221_n182;
  t221_n179: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t221_n181;
  t221_n180: return 0.10181920230388641f;
  t221_n181: return 0.08925972133874893f;
  t221_n182: return 0.06354673206806183f;
  t221_n183: return 0.0057678367011249065f;
  t221_n184: return -0.020403288304805756f;
  t221_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t221_n187;
  t221_n186: return 0.0010508231353014708f;
  t221_n187: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t221_n193;
  t221_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t221_n190;
  t221_n189: return -0.36607253551483154f;
  t221_n190: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n192;
  t221_n191: return 0.06571311503648758f;
  t221_n192: return 0.09119603782892227f;
  t221_n193: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t221_n211;
  t221_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t221_n196;
  t221_n195: return -0.016552133485674858f;
  t221_n196: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t221_n202;
  t221_n197: if (E.getNumReferences() >= 3274604544 /*174.5*/) goto t221_n199;
  t221_n198: return -0.04966044798493385f;
  t221_n199: if (E.getNumReferences() >= 3275063296 /*181.5*/) goto t221_n201;
  t221_n200: return 0.17366145551204681f;
  t221_n201: return 0.13102905452251434f;
  t221_n202: if (E.getNumReferences() >= 3275489280 /*188.0*/) goto t221_n210;
  t221_n203: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t221_n207;
  t221_n204: if (E.getNumReferences() >= 3264086016 /*71.0*/) goto t221_n206;
  t221_n205: return 0.15517650544643402f;
  t221_n206: return -0.273497998714447f;
  t221_n207: if (E.getNumReferences() >= 3271819264 /*132.0*/) goto t221_n209;
  t221_n208: return 0.12977434694766998f;
  t221_n209: return 0.11834187060594559f;
  t221_n210: return -0.30568575859069824f;
  t221_n211: if (E.getNumReferences() >= 3325700096 /*11914.0*/) goto t221_n223;
  t221_n212: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t221_n214;
  t221_n213: return -0.012666957452893257f;
  t221_n214: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t221_n222;
  t221_n215: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t221_n217;
  t221_n216: return -0.21114756166934967f;
  t221_n217: if (E.getNumReferences() >= 3277160448 /*213.5*/) goto t221_n219;
  t221_n218: return -0.19365918636322021f;
  t221_n219: if (E.getNumReferences() >= 3287154688 /*476.0*/) goto t221_n221;
  t221_n220: return 0.13436463475227356f;
  t221_n221: return 0.07637438178062439f;
  t221_n222: return 0.03267310932278633f;
  t221_n223: if (E.getNumReferences() >= 3327105024 /*13286.0*/) goto t221_n241;
  t221_n224: if (E.getNumReferences() >= 3327053312 /*13235.5*/) goto t221_n236;
  t221_n225: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n227;
  t221_n226: return 0.07789953798055649f;
  t221_n227: if (E.getNumReferences() >= 3326541312 /*12735.5*/) goto t221_n229;
  t221_n228: return -0.11932701617479324f;
  t221_n229: if (E.getNumReferences() >= 3326945792 /*13130.5*/) goto t221_n233;
  t221_n230: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t221_n232;
  t221_n231: return 0.1052161231637001f;
  t221_n232: return 0.08220920711755753f;
  t221_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t221_n235;
  t221_n234: return -0.7856515049934387f;
  t221_n235: return 0.09613945335149765f;
  t221_n236: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t221_n238;
  t221_n237: return 0.8039295673370361f;
  t221_n238: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n240;
  t221_n239: return 0.11722541600465775f;
  t221_n240: return 0.010692157782614231f;
  t221_n241: return 0.020804692059755325f;
  t221_n242: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t221_n244;
  t221_n243: return -0.0072811977006495f;
  t221_n244: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t221_n252;
  t221_n245: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t221_n251;
  t221_n246: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t221_n250;
  t221_n247: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t221_n249;
  t221_n248: return -1.6343845129013062f;
  t221_n249: return 0.11205210536718369f;
  t221_n250: return 0.11772152781486511f;
  t221_n251: return 0.036850299686193466f;
  t221_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Expression))) goto t221_n254;
  t221_n253: return -0.020458951592445374f;
  t221_n254: return 0.04273314028978348f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree222(const Example& E) {
  t222_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t222_n2;
  t222_n1: return -0.0009913243120536208f;
  t222_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t222_n254;
  t222_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t222_n41;
  t222_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t222_n12;
  t222_n5: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t222_n9;
  t222_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n8;
  t222_n7: return 0.10024742782115936f;
  t222_n8: return -0.032472163438797f;
  t222_n9: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t222_n11;
  t222_n10: return -0.12431074678897858f;
  t222_n11: return -0.10010270029306412f;
  t222_n12: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t222_n22;
  t222_n13: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t222_n21;
  t222_n14: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t222_n20;
  t222_n15: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n19;
  t222_n16: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t222_n18;
  t222_n17: return 0.10220754891633987f;
  t222_n18: return 0.006657186429947615f;
  t222_n19: return 0.006973198149353266f;
  t222_n20: return -0.015567269176244736f;
  t222_n21: return -0.34291374683380127f;
  t222_n22: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t222_n40;
  t222_n23: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t222_n29;
  t222_n24: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t222_n26;
  t222_n25: return 0.09465155750513077f;
  t222_n26: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t222_n28;
  t222_n27: return 0.08048123866319656f;
  t222_n28: return -0.3783389627933502f;
  t222_n29: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t222_n31;
  t222_n30: return -0.017429599538445473f;
  t222_n31: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t222_n35;
  t222_n32: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n34;
  t222_n33: return 0.11538608372211456f;
  t222_n34: return 0.10158223658800125f;
  t222_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n39;
  t222_n36: if (E.getNumReferences() >= 3348209792 /*74561.0*/) goto t222_n38;
  t222_n37: return 0.07339314371347427f;
  t222_n38: return 0.02099578268826008f;
  t222_n39: return 0.02515452541410923f;
  t222_n40: return 0.10749462246894836f;
  t222_n41: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t222_n213;
  t222_n42: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t222_n212;
  t222_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t222_n151;
  t222_n44: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t222_n52;
  t222_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t222_n49;
  t222_n46: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t222_n48;
  t222_n47: return -0.044457800686359406f;
  t222_n48: return -0.014712007716298103f;
  t222_n49: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t222_n51;
  t222_n50: return -0.026271454989910126f;
  t222_n51: return 0.0012410692870616913f;
  t222_n52: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t222_n148;
  t222_n53: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t222_n121;
  t222_n54: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t222_n112;
  t222_n55: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t222_n89;
  t222_n56: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t222_n66;
  t222_n57: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t222_n65;
  t222_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t222_n60;
  t222_n59: return -0.022060833871364594f;
  t222_n60: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t222_n62;
  t222_n61: return 0.02892441488802433f;
  t222_n62: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n64;
  t222_n63: return -0.7602447867393494f;
  t222_n64: return 0.023381253704428673f;
  t222_n65: return 0.039736926555633545f;
  t222_n66: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t222_n88;
  t222_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t222_n75;
  t222_n68: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t222_n70;
  t222_n69: return -0.1826210469007492f;
  t222_n70: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t222_n72;
  t222_n71: return 0.0416053831577301f;
  t222_n72: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t222_n74;
  t222_n73: return -0.07995171844959259f;
  t222_n74: return 0.10966924577951431f;
  t222_n75: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t222_n77;
  t222_n76: return -0.09493739902973175f;
  t222_n77: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t222_n85;
  t222_n78: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t222_n84;
  t222_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t222_n81;
  t222_n80: return 0.002782676136121154f;
  t222_n81: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t222_n83;
  t222_n82: return 0.06502211093902588f;
  t222_n83: return 0.11392252147197723f;
  t222_n84: return -0.05015985667705536f;
  t222_n85: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t222_n87;
  t222_n86: return 0.08817116916179657f;
  t222_n87: return -0.10461770743131638f;
  t222_n88: return -0.16410866379737854f;
  t222_n89: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n103;
  t222_n90: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t222_n102;
  t222_n91: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t222_n99;
  t222_n92: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n98;
  t222_n93: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t222_n95;
  t222_n94: return -1.3377625942230225f;
  t222_n95: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t222_n97;
  t222_n96: return -0.052907269448041916f;
  t222_n97: return -0.9543269872665405f;
  t222_n98: return -0.020119424909353256f;
  t222_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t222_n101;
  t222_n100: return -0.671301007270813f;
  t222_n101: return 0.018250806257128716f;
  t222_n102: return -0.15926794707775116f;
  t222_n103: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t222_n105;
  t222_n104: return -0.04135599359869957f;
  t222_n105: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t222_n111;
  t222_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t222_n108;
  t222_n107: return -0.023091496899724007f;
  t222_n108: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t222_n110;
  t222_n109: return 0.09556233137845993f;
  t222_n110: return 0.08834864944219589f;
  t222_n111: return -0.14984093606472015f;
  t222_n112: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n114;
  t222_n113: return -0.04585503041744232f;
  t222_n114: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t222_n120;
  t222_n115: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t222_n117;
  t222_n116: return 0.03300366550683975f;
  t222_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t222_n119;
  t222_n118: return 0.045768097043037415f;
  t222_n119: return 0.10690542310476303f;
  t222_n120: return -0.02067176252603531f;
  t222_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t222_n147;
  t222_n122: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t222_n146;
  t222_n123: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t222_n133;
  t222_n124: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t222_n132;
  t222_n125: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t222_n131;
  t222_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n128;
  t222_n127: return 0.03216751664876938f;
  t222_n128: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t222_n130;
  t222_n129: return 0.06733831763267517f;
  t222_n130: return -0.11834114789962769f;
  t222_n131: return -0.13013607263565063f;
  t222_n132: return -0.049398425966501236f;
  t222_n133: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t222_n145;
  t222_n134: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t222_n140;
  t222_n135: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t222_n139;
  t222_n136: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t222_n138;
  t222_n137: return 0.09772950410842896f;
  t222_n138: return -0.07396718114614487f;
  t222_n139: return -0.02927916683256626f;
  t222_n140: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t222_n142;
  t222_n141: return -0.22054894268512726f;
  t222_n142: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t222_n144;
  t222_n143: return 0.09579051285982132f;
  t222_n144: return 0.032565437257289886f;
  t222_n145: return -0.0028690476901829243f;
  t222_n146: return -0.012289895676076412f;
  t222_n147: return 0.016243116930127144f;
  t222_n148: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n150;
  t222_n149: return -0.3718186616897583f;
  t222_n150: return -0.06361626833677292f;
  t222_n151: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t222_n165;
  t222_n152: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t222_n154;
  t222_n153: return -0.01601114124059677f;
  t222_n154: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t222_n164;
  t222_n155: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t222_n157;
  t222_n156: return 0.011600990779697895f;
  t222_n157: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t222_n161;
  t222_n158: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n160;
  t222_n159: return -0.09951991587877274f;
  t222_n160: return -0.037028249353170395f;
  t222_n161: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n163;
  t222_n162: return 0.06646394729614258f;
  t222_n163: return -0.0017417800845578313f;
  t222_n164: return 0.10244596749544144f;
  t222_n165: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t222_n211;
  t222_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t222_n188;
  t222_n167: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t222_n181;
  t222_n168: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t222_n170;
  t222_n169: return -0.0425318107008934f;
  t222_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n174;
  t222_n171: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t222_n173;
  t222_n172: return 0.08825137466192245f;
  t222_n173: return -0.21864619851112366f;
  t222_n174: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t222_n180;
  t222_n175: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n179;
  t222_n176: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t222_n178;
  t222_n177: return 0.12043821066617966f;
  t222_n178: return -0.10029661655426025f;
  t222_n179: return -0.12759210169315338f;
  t222_n180: return -0.18595321476459503f;
  t222_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n183;
  t222_n182: return -0.14385314285755157f;
  t222_n183: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t222_n187;
  t222_n184: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t222_n186;
  t222_n185: return -0.14611020684242249f;
  t222_n186: return 0.08829008042812347f;
  t222_n187: return -0.03846360370516777f;
  t222_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n202;
  t222_n189: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t222_n201;
  t222_n190: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t222_n198;
  t222_n191: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t222_n197;
  t222_n192: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n196;
  t222_n193: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t222_n195;
  t222_n194: return 0.13226456940174103f;
  t222_n195: return -0.24932228028774261f;
  t222_n196: return 0.12888680398464203f;
  t222_n197: return -0.11093797534704208f;
  t222_n198: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n200;
  t222_n199: return 0.13539353013038635f;
  t222_n200: return 0.16154596209526062f;
  t222_n201: return 0.04740780591964722f;
  t222_n202: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t222_n204;
  t222_n203: return -0.03813396021723747f;
  t222_n204: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t222_n206;
  t222_n205: return 0.014889082871377468f;
  t222_n206: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t222_n208;
  t222_n207: return 0.05886504799127579f;
  t222_n208: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t222_n210;
  t222_n209: return 0.17019899189472198f;
  t222_n210: return 0.10446176677942276f;
  t222_n211: return 0.007939757779240608f;
  t222_n212: return 0.0036925182212144136f;
  t222_n213: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t222_n247;
  t222_n214: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t222_n236;
  t222_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t222_n217;
  t222_n216: return -0.06384909152984619f;
  t222_n217: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t222_n229;
  t222_n218: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t222_n226;
  t222_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n221;
  t222_n220: return 0.01935068890452385f;
  t222_n221: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t222_n225;
  t222_n222: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t222_n224;
  t222_n223: return 0.10760246217250824f;
  t222_n224: return 0.018051689490675926f;
  t222_n225: return -0.01595795527100563f;
  t222_n226: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t222_n228;
  t222_n227: return -0.03193579614162445f;
  t222_n228: return 0.04729814454913139f;
  t222_n229: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t222_n235;
  t222_n230: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t222_n232;
  t222_n231: return 0.011933735571801662f;
  t222_n232: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t222_n234;
  t222_n233: return 0.21887102723121643f;
  t222_n234: return 0.11071616411209106f;
  t222_n235: return -0.6168844699859619f;
  t222_n236: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t222_n238;
  t222_n237: return 0.0026577410753816366f;
  t222_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t222_n240;
  t222_n239: return 0.08911927789449692f;
  t222_n240: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t222_n244;
  t222_n241: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t222_n243;
  t222_n242: return 0.09057794511318207f;
  t222_n243: return -0.28543782234191895f;
  t222_n244: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t222_n246;
  t222_n245: return 0.09310455620288849f;
  t222_n246: return 0.0649876669049263f;
  t222_n247: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n253;
  t222_n248: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t222_n252;
  t222_n249: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t222_n251;
  t222_n250: return 0.03159825876355171f;
  t222_n251: return -0.09844845533370972f;
  t222_n252: return 0.0008349312702193856f;
  t222_n253: return 0.02353634685277939f;
  t222_n254: return 0.002825578209012747f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree223(const Example& E) {
  t223_n0: if (E.getNumReferences() >= 3306797056 /*2459.5*/) goto t223_n2;
  t223_n1: return -0.00030225960654206574f;
  t223_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t223_n24;
  t223_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t223_n9;
  t223_n4: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t223_n6;
  t223_n5: return -0.08881086856126785f;
  t223_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t223_n8;
  t223_n7: return -0.1959427446126938f;
  t223_n8: return 0.0942753478884697f;
  t223_n9: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t223_n23;
  t223_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t223_n14;
  t223_n11: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t223_n13;
  t223_n12: return -0.0689210593700409f;
  t223_n13: return 0.10726407915353775f;
  t223_n14: if (E.getNumReferences() >= 3314636800 /*4651.0*/) goto t223_n16;
  t223_n15: return -0.10972477495670319f;
  t223_n16: if (E.getNumReferences() >= 3329863680 /*15980.0*/) goto t223_n22;
  t223_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t223_n19;
  t223_n18: return 0.06889516115188599f;
  t223_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t223_n21;
  t223_n20: return 0.11442457139492035f;
  t223_n21: return 0.12357226759195328f;
  t223_n22: return 0.06002621352672577f;
  t223_n23: return 0.010425308719277382f;
  t223_n24: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t223_n26;
  t223_n25: return -0.0005410931771621108f;
  t223_n26: if (E.getNumReferences() >= 3311265792 /*3550.5*/) goto t223_n94;
  t223_n27: if (E.getNumReferences() >= 3309664256 /*3159.5*/) goto t223_n65;
  t223_n28: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t223_n62;
  t223_n29: if (E.getNumReferences() >= 3306835968 /*2469.0*/) goto t223_n31;
  t223_n30: return 0.0955280140042305f;
  t223_n31: if (E.getNumReferences() >= 3309590528 /*3141.5*/) goto t223_n61;
  t223_n32: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t223_n34;
  t223_n33: return -0.17611229419708252f;
  t223_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t223_n60;
  t223_n35: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t223_n55;
  t223_n36: if (E.getNumReferences() >= 3308998656 /*2997.0*/) goto t223_n50;
  t223_n37: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t223_n41;
  t223_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t223_n40;
  t223_n39: return -0.37194597721099854f;
  t223_n40: return 0.001504627987742424f;
  t223_n41: if (E.getNumReferences() >= 3307941888 /*2739.0*/) goto t223_n47;
  t223_n42: if (E.getNumReferences() >= 3307663360 /*2671.0*/) goto t223_n46;
  t223_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t223_n45;
  t223_n44: return -0.03596928343176842f;
  t223_n45: return 0.11492031812667847f;
  t223_n46: return 0.12995092570781708f;
  t223_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t223_n49;
  t223_n48: return -0.1335853934288025f;
  t223_n49: return 0.07902020961046219f;
  t223_n50: if (E.getNumReferences() >= 3309209600 /*3048.5*/) goto t223_n52;
  t223_n51: return 0.11678127199411392f;
  t223_n52: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t223_n54;
  t223_n53: return -0.07342595607042313f;
  t223_n54: return 0.11602914333343506f;
  t223_n55: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t223_n59;
  t223_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t223_n58;
  t223_n57: return 0.035105083137750626f;
  t223_n58: return 0.11791567504405975f;
  t223_n59: return -0.13647301495075226f;
  t223_n60: return -0.0509699322283268f;
  t223_n61: return -0.2636476755142212f;
  t223_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t223_n64;
  t223_n63: return 0.050119418650865555f;
  t223_n64: return 0.10243455320596695f;
  t223_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t223_n91;
  t223_n66: if (E.getNumReferences() >= 3309780992 /*3188.0*/) goto t223_n70;
  t223_n67: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t223_n69;
  t223_n68: return 0.12744170427322388f;
  t223_n69: return 0.17016731202602386f;
  t223_n70: if (E.getNumReferences() >= 3311222784 /*3540.0*/) goto t223_n90;
  t223_n71: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t223_n83;
  t223_n72: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t223_n74;
  t223_n73: return -0.1631678342819214f;
  t223_n74: if (E.getNumReferences() >= 3311050752 /*3498.0*/) goto t223_n82;
  t223_n75: if (E.getNumReferences() >= 3310497792 /*3363.0*/) goto t223_n81;
  t223_n76: if (E.getNumReferences() >= 3310071808 /*3259.0*/) goto t223_n78;
  t223_n77: return 0.01882539689540863f;
  t223_n78: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t223_n80;
  t223_n79: return 0.05561196431517601f;
  t223_n80: return 0.13397717475891113f;
  t223_n81: return -0.05219866335391998f;
  t223_n82: return 0.11910708993673325f;
  t223_n83: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t223_n87;
  t223_n84: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t223_n86;
  t223_n85: return 0.1029561385512352f;
  t223_n86: return 0.07862360775470734f;
  t223_n87: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t223_n89;
  t223_n88: return -0.05364382639527321f;
  t223_n89: return 0.12241631001234055f;
  t223_n90: return 0.1295752078294754f;
  t223_n91: if (E.getNumReferences() >= 3310143488 /*3276.5*/) goto t223_n93;
  t223_n92: return 0.10899953544139862f;
  t223_n93: return -0.04017873480916023f;
  t223_n94: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t223_n150;
  t223_n95: if (E.getNumReferences() >= 3315609600 /*5126.0*/) goto t223_n101;
  t223_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion))) goto t223_n98;
  t223_n97: return -0.06706073135137558f;
  t223_n98: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t223_n100;
  t223_n99: return -0.1309879869222641f;
  t223_n100: return 0.10625500231981277f;
  t223_n101: if (E.getNumReferences() >= 3319521280 /*7036.0*/) goto t223_n127;
  t223_n102: if (E.getNumReferences() >= 3319400448 /*6977.0*/) goto t223_n126;
  t223_n103: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t223_n123;
  t223_n104: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t223_n112;
  t223_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t223_n111;
  t223_n106: if (E.getNumReferences() >= 3318719488 /*6644.5*/) goto t223_n108;
  t223_n107: return -0.1243208572268486f;
  t223_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t223_n110;
  t223_n109: return -0.13642992079257965f;
  t223_n110: return 0.10642664134502411f;
  t223_n111: return 0.10574585944414139f;
  t223_n112: if (E.getNumReferences() >= 3318799360 /*6683.5*/) goto t223_n122;
  t223_n113: if (E.getNumReferences() >= 3318719488 /*6644.5*/) goto t223_n121;
  t223_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t223_n118;
  t223_n115: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t223_n117;
  t223_n116: return 0.12274851649999619f;
  t223_n117: return 0.030897868797183037f;
  t223_n118: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t223_n120;
  t223_n119: return 0.14743511378765106f;
  t223_n120: return -0.052159152925014496f;
  t223_n121: return 0.11091358214616776f;
  t223_n122: return 0.008490953594446182f;
  t223_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t223_n125;
  t223_n124: return -0.13351579010486603f;
  t223_n125: return 0.04073944687843323f;
  t223_n126: return 0.11713580042123795f;
  t223_n127: if (E.getNumReferences() >= 3320465408 /*7497.0*/) goto t223_n129;
  t223_n128: return -0.12094520777463913f;
  t223_n129: if (E.getNumReferences() >= 3322556416 /*8844.0*/) goto t223_n149;
  t223_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t223_n144;
  t223_n131: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t223_n139;
  t223_n132: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t223_n134;
  t223_n133: return -0.016996344551444054f;
  t223_n134: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t223_n136;
  t223_n135: return -0.10727773606777191f;
  t223_n136: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t223_n138;
  t223_n137: return 0.13132824003696442f;
  t223_n138: return -0.27782392501831055f;
  t223_n139: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t223_n141;
  t223_n140: return 0.030611377209424973f;
  t223_n141: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t223_n143;
  t223_n142: return 0.11228463053703308f;
  t223_n143: return 0.09314531832933426f;
  t223_n144: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t223_n146;
  t223_n145: return 0.07088711112737656f;
  t223_n146: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t223_n148;
  t223_n147: return 0.11003460735082626f;
  t223_n148: return 0.14348922669887543f;
  t223_n149: return 0.006660331040620804f;
  t223_n150: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t223_n220;
  t223_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t223_n169;
  t223_n152: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t223_n156;
  t223_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t223_n155;
  t223_n154: return 0.01690451055765152f;
  t223_n155: return 0.09941917657852173f;
  t223_n156: if (E.getNumReferences() >= 3338411008 /*32270.0*/) goto t223_n166;
  t223_n157: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t223_n165;
  t223_n158: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t223_n160;
  t223_n159: return 0.005417082458734512f;
  t223_n160: if (E.getNumReferences() >= 3334486272 /*24604.5*/) goto t223_n164;
  t223_n161: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t223_n163;
  t223_n162: return -0.21156924962997437f;
  t223_n163: return -1.244766354560852f;
  t223_n164: return -0.058898571878671646f;
  t223_n165: return -0.3027057349681854f;
  t223_n166: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t223_n168;
  t223_n167: return 0.07982542365789413f;
  t223_n168: return 0.015450295060873032f;
  t223_n169: if (E.getNumReferences() >= 3330418688 /*16660.0*/) goto t223_n207;
  t223_n170: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t223_n204;
  t223_n171: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t223_n177;
  t223_n172: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t223_n176;
  t223_n173: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t223_n175;
  t223_n174: return 0.02882930263876915f;
  t223_n175: return 0.10187544673681259f;
  t223_n176: return -0.06716786324977875f;
  t223_n177: if (E.getNumReferences() >= 3326988288 /*13172.0*/) goto t223_n189;
  t223_n178: if (E.getNumReferences() >= 3322808320 /*9090.0*/) goto t223_n188;
  t223_n179: if (E.getNumReferences() >= 3319662592 /*7105.0*/) goto t223_n183;
  t223_n180: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t223_n182;
  t223_n181: return 0.10662314295768738f;
  t223_n182: return 0.01913699321448803f;
  t223_n183: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t223_n187;
  t223_n184: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t223_n186;
  t223_n185: return 0.07534017413854599f;
  t223_n186: return 0.12344542890787125f;
  t223_n187: return -0.02781509980559349f;
  t223_n188: return -0.06361326575279236f;
  t223_n189: if (E.getNumReferences() >= 3328450048 /*14599.5*/) goto t223_n193;
  t223_n190: if (E.getNumReferences() >= 3328288256 /*14441.5*/) goto t223_n192;
  t223_n191: return 0.10256063938140869f;
  t223_n192: return 0.111517995595932f;
  t223_n193: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t223_n199;
  t223_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t223_n198;
  t223_n195: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t223_n197;
  t223_n196: return 0.08950023353099823f;
  t223_n197: return 0.028373733162879944f;
  t223_n198: return -0.039194460958242416f;
  t223_n199: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t223_n203;
  t223_n200: if (E.getNumReferences() >= 3329443328 /*15569.5*/) goto t223_n202;
  t223_n201: return 0.0773523598909378f;
  t223_n202: return 0.11969128251075745f;
  t223_n203: return -0.025570955127477646f;
  t223_n204: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t223_n206;
  t223_n205: return -0.2741762697696686f;
  t223_n206: return 0.08904803544282913f;
  t223_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t223_n219;
  t223_n208: if (E.getNumReferences() >= 3347567040 /*69539.5*/) goto t223_n218;
  t223_n209: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t223_n217;
  t223_n210: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t223_n214;
  t223_n211: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t223_n213;
  t223_n212: return -0.21973657608032227f;
  t223_n213: return -0.00835697166621685f;
  t223_n214: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t223_n216;
  t223_n215: return 0.04417629539966583f;
  t223_n216: return -0.8623164296150208f;
  t223_n217: return 0.007995772175490856f;
  t223_n218: return 0.0412602424621582f;
  t223_n219: return 0.04690919071435928f;
  t223_n220: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t223_n226;
  t223_n221: if (E.getNumReferences() >= 3317711872 /*6152.5*/) goto t223_n223;
  t223_n222: return 0.11243002861738205f;
  t223_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t223_n225;
  t223_n224: return -0.04909931868314743f;
  t223_n225: return 0.0642022117972374f;
  t223_n226: if (E.getNumReferences() >= 3365715136 /*320998.0*/) goto t223_n248;
  t223_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t223_n243;
  t223_n228: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t223_n230;
  t223_n229: return -0.41158854961395264f;
  t223_n230: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t223_n236;
  t223_n231: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t223_n233;
  t223_n232: return 0.045621804893016815f;
  t223_n233: if (E.getNumReferences() >= 3339768960 /*37076.5*/) goto t223_n235;
  t223_n234: return 0.10890340059995651f;
  t223_n235: return 0.04154248163104057f;
  t223_n236: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t223_n238;
  t223_n237: return -0.1486285775899887f;
  t223_n238: if (E.getNumReferences() >= 3328615936 /*14761.5*/) goto t223_n240;
  t223_n239: return -0.10855929553508759f;
  t223_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t223_n242;
  t223_n241: return 0.07745000720024109f;
  t223_n242: return 0.10014621168375015f;
  t223_n243: if (E.getNumReferences() >= 3321041920 /*7778.5*/) goto t223_n247;
  t223_n244: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t223_n246;
  t223_n245: return 0.08618320524692535f;
  t223_n246: return 0.10713700205087662f;
  t223_n247: return 0.016089236363768578f;
  t223_n248: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t223_n250;
  t223_n249: return 0.10637218505144119f;
  t223_n250: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t223_n254;
  t223_n251: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t223_n253;
  t223_n252: return 0.09013295918703079f;
  t223_n253: return 0.07666965574026108f;
  t223_n254: return -0.037875182926654816f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree224(const Example& E) {
  t224_n0: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t224_n254;
  t224_n1: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t224_n3;
  t224_n2: return 0.002090038964524865f;
  t224_n3: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t224_n49;
  t224_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t224_n6;
  t224_n5: return 0.007970655336976051f;
  t224_n6: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t224_n48;
  t224_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t224_n41;
  t224_n8: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t224_n28;
  t224_n9: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t224_n15;
  t224_n10: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n12;
  t224_n11: return -0.009624226950109005f;
  t224_n12: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t224_n14;
  t224_n13: return 0.11904498934745789f;
  t224_n14: return -0.05007816106081009f;
  t224_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t224_n17;
  t224_n16: return -0.12307945638895035f;
  t224_n17: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t224_n27;
  t224_n18: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t224_n22;
  t224_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t224_n21;
  t224_n20: return -0.14290349185466766f;
  t224_n21: return 0.4916507303714752f;
  t224_n22: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t224_n26;
  t224_n23: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n25;
  t224_n24: return 0.0731588825583458f;
  t224_n25: return 0.1060326024889946f;
  t224_n26: return -0.10156445950269699f;
  t224_n27: return 0.11653025448322296f;
  t224_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t224_n38;
  t224_n29: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t224_n35;
  t224_n30: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t224_n34;
  t224_n31: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t224_n33;
  t224_n32: return -0.31851717829704285f;
  t224_n33: return 0.6899611353874207f;
  t224_n34: return -0.2799776792526245f;
  t224_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t224_n37;
  t224_n36: return -1.4092622995376587f;
  t224_n37: return 0.10753193497657776f;
  t224_n38: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t224_n40;
  t224_n39: return 0.0766822025179863f;
  t224_n40: return 0.12125874310731888f;
  t224_n41: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t224_n45;
  t224_n42: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t224_n44;
  t224_n43: return 0.118426114320755f;
  t224_n44: return -0.10801494121551514f;
  t224_n45: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n47;
  t224_n46: return 0.006017992272973061f;
  t224_n47: return 0.11493261903524399f;
  t224_n48: return -0.07552118599414825f;
  t224_n49: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t224_n249;
  t224_n50: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t224_n202;
  t224_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t224_n115;
  t224_n52: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t224_n86;
  t224_n53: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t224_n55;
  t224_n54: return 0.01360639464110136f;
  t224_n55: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t224_n59;
  t224_n56: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t224_n58;
  t224_n57: return 0.04151182994246483f;
  t224_n58: return -0.05344850942492485f;
  t224_n59: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t224_n85;
  t224_n60: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t224_n68;
  t224_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t224_n63;
  t224_n62: return 0.055362243205308914f;
  t224_n63: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t224_n65;
  t224_n64: return 0.03326638042926788f;
  t224_n65: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t224_n67;
  t224_n66: return 0.12040217220783234f;
  t224_n67: return -0.12194763869047165f;
  t224_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t224_n80;
  t224_n69: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t224_n77;
  t224_n70: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t224_n72;
  t224_n71: return 0.06697706878185272f;
  t224_n72: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n74;
  t224_n73: return 0.05167331174015999f;
  t224_n74: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t224_n76;
  t224_n75: return 0.1317444145679474f;
  t224_n76: return -0.12030099332332611f;
  t224_n77: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n79;
  t224_n78: return 0.04908344894647598f;
  t224_n79: return 0.1296328604221344f;
  t224_n80: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t224_n82;
  t224_n81: return 0.12855902314186096f;
  t224_n82: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t224_n84;
  t224_n83: return 0.1731124371290207f;
  t224_n84: return 0.13055290281772614f;
  t224_n85: return 0.0034022785257548094f;
  t224_n86: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t224_n94;
  t224_n87: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t224_n93;
  t224_n88: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t224_n92;
  t224_n89: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t224_n91;
  t224_n90: return -0.23700694739818573f;
  t224_n91: return 0.1081915944814682f;
  t224_n92: return 0.013142767362296581f;
  t224_n93: return 0.12475356459617615f;
  t224_n94: if (E.getNumReferences() >= 3282436096 /*332.0*/) goto t224_n98;
  t224_n95: if (E.getNumReferences() >= 3282223104 /*325.5*/) goto t224_n97;
  t224_n96: return 0.05066218599677086f;
  t224_n97: return 0.10012137144804001f;
  t224_n98: if (E.getNumReferences() >= 3311534080 /*3616.0*/) goto t224_n104;
  t224_n99: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t224_n101;
  t224_n100: return -0.041479095816612244f;
  t224_n101: if (E.getNumReferences() >= 3288514560 /*523.0*/) goto t224_n103;
  t224_n102: return 0.0839371457695961f;
  t224_n103: return -0.046843502670526505f;
  t224_n104: if (E.getNumReferences() >= 3313753088 /*4219.5*/) goto t224_n110;
  t224_n105: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t224_n107;
  t224_n106: return -0.10076704621315002f;
  t224_n107: if (E.getNumReferences() >= 3313506304 /*4099.0*/) goto t224_n109;
  t224_n108: return 0.10869736969470978f;
  t224_n109: return 0.1146240159869194f;
  t224_n110: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t224_n112;
  t224_n111: return 0.06858779489994049f;
  t224_n112: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t224_n114;
  t224_n113: return 0.06768777966499329f;
  t224_n114: return -0.5822276473045349f;
  t224_n115: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t224_n193;
  t224_n116: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t224_n164;
  t224_n117: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t224_n153;
  t224_n118: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t224_n148;
  t224_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t224_n129;
  t224_n120: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t224_n126;
  t224_n121: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t224_n125;
  t224_n122: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t224_n124;
  t224_n123: return -0.07862704247236252f;
  t224_n124: return 0.020481903105974197f;
  t224_n125: return -0.032830026000738144f;
  t224_n126: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t224_n128;
  t224_n127: return -0.046723347157239914f;
  t224_n128: return 0.10221507400274277f;
  t224_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t224_n143;
  t224_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t224_n132;
  t224_n131: return -0.11155829578638077f;
  t224_n132: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t224_n142;
  t224_n133: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t224_n135;
  t224_n134: return 0.028268828988075256f;
  t224_n135: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t224_n139;
  t224_n136: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t224_n138;
  t224_n137: return -0.05974140018224716f;
  t224_n138: return 0.11140148341655731f;
  t224_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t224_n141;
  t224_n140: return 0.12167350947856903f;
  t224_n141: return 0.11712241172790527f;
  t224_n142: return -0.024723181501030922f;
  t224_n143: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t224_n147;
  t224_n144: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t224_n146;
  t224_n145: return 0.15960706770420074f;
  t224_n146: return -0.10416930168867111f;
  t224_n147: return -0.10023993253707886f;
  t224_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t224_n152;
  t224_n149: if (E.getNumReferences() >= 3247964160 /*19.0*/) goto t224_n151;
  t224_n150: return 0.04162727668881416f;
  t224_n151: return 0.11127671599388123f;
  t224_n152: return 0.4157874584197998f;
  t224_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t224_n155;
  t224_n154: return -0.2628426253795624f;
  t224_n155: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t224_n157;
  t224_n156: return -0.08329572528600693f;
  t224_n157: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t224_n161;
  t224_n158: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t224_n160;
  t224_n159: return 0.0402182899415493f;
  t224_n160: return -0.530044436454773f;
  t224_n161: if (E.getNumReferences() >= 3284140032 /*384.0*/) goto t224_n163;
  t224_n162: return -0.12468789517879486f;
  t224_n163: return -1.0637089014053345f;
  t224_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t224_n166;
  t224_n165: return -0.1405564248561859f;
  t224_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t224_n168;
  t224_n167: return 0.03361406922340393f;
  t224_n168: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t224_n188;
  t224_n169: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t224_n171;
  t224_n170: return -0.011552898213267326f;
  t224_n171: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t224_n187;
  t224_n172: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t224_n180;
  t224_n173: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t224_n179;
  t224_n174: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t224_n178;
  t224_n175: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t224_n177;
  t224_n176: return 0.3902466595172882f;
  t224_n177: return 0.12858246266841888f;
  t224_n178: return -0.4032265841960907f;
  t224_n179: return -0.19712156057357788f;
  t224_n180: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t224_n184;
  t224_n181: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t224_n183;
  t224_n182: return -0.27597206830978394f;
  t224_n183: return 0.12999580800533295f;
  t224_n184: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t224_n186;
  t224_n185: return 0.10880408436059952f;
  t224_n186: return 0.1390291303396225f;
  t224_n187: return -0.029175005853176117f;
  t224_n188: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t224_n192;
  t224_n189: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t224_n191;
  t224_n190: return 0.028126342222094536f;
  t224_n191: return 0.14137108623981476f;
  t224_n192: return 0.10706236958503723f;
  t224_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t224_n201;
  t224_n194: if (E.getNumReferences() >= 3292766208 /*782.5*/) goto t224_n200;
  t224_n195: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t224_n197;
  t224_n196: return -0.12851545214653015f;
  t224_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t224_n199;
  t224_n198: return -0.9177517294883728f;
  t224_n199: return -0.012503090314567089f;
  t224_n200: return -0.04234965145587921f;
  t224_n201: return 0.08284295350313187f;
  t224_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t224_n240;
  t224_n203: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t224_n211;
  t224_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t224_n206;
  t224_n205: return -0.022888561710715294f;
  t224_n206: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n208;
  t224_n207: return 0.04268068075180054f;
  t224_n208: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t224_n210;
  t224_n209: return 0.11648062616586685f;
  t224_n210: return 0.05122195929288864f;
  t224_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t224_n213;
  t224_n212: return 0.007408101111650467f;
  t224_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t224_n219;
  t224_n214: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t224_n218;
  t224_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t224_n217;
  t224_n216: return -0.08174259960651398f;
  t224_n217: return 0.10520272701978683f;
  t224_n218: return 0.027344726026058197f;
  t224_n219: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t224_n233;
  t224_n220: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t224_n228;
  t224_n221: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n227;
  t224_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t224_n226;
  t224_n223: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t224_n225;
  t224_n224: return -0.4720199704170227f;
  t224_n225: return 0.01656191051006317f;
  t224_n226: return 0.08790045976638794f;
  t224_n227: return 0.10284260660409927f;
  t224_n228: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t224_n232;
  t224_n229: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n231;
  t224_n230: return 0.11345087736845016f;
  t224_n231: return -0.10090146958827972f;
  t224_n232: return 0.07714098691940308f;
  t224_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t224_n239;
  t224_n234: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t224_n238;
  t224_n235: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t224_n237;
  t224_n236: return -0.10079355537891388f;
  t224_n237: return 0.1393755078315735f;
  t224_n238: return 0.09350764006376266f;
  t224_n239: return 0.1080460399389267f;
  t224_n240: if (E.getSymbolScopeDistance() >= 3242196992 /*12.0*/) goto t224_n242;
  t224_n241: return 0.05204559490084648f;
  t224_n242: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t224_n246;
  t224_n243: if (E.getNumReferences() >= 3235905536 /*7.0*/) goto t224_n245;
  t224_n244: return 0.13454116880893707f;
  t224_n245: return -0.036885373294353485f;
  t224_n246: if (E.getNumReferences() >= 3261595648 /*58.0*/) goto t224_n248;
  t224_n247: return -0.06509009748697281f;
  t224_n248: return 0.10308516025543213f;
  t224_n249: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t224_n251;
  t224_n250: return -0.07751334458589554f;
  t224_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t224_n253;
  t224_n252: return -0.34576794505119324f;
  t224_n253: return 0.0026608342304825783f;
  t224_n254: return -0.0006344494759105146f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree225(const Example& E) {
  t225_n0: if (E.getNumReferences() >= 3306797056 /*2459.5*/) goto t225_n2;
  t225_n1: return -0.0003128302050754428f;
  t225_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t225_n4;
  t225_n3: return 0.009970094077289104f;
  t225_n4: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t225_n6;
  t225_n5: return -0.0010643479181453586f;
  t225_n6: if (E.getNumReferences() >= 3333341184 /*22368.0*/) goto t225_n252;
  t225_n7: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t225_n183;
  t225_n8: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t225_n156;
  t225_n9: if (E.getNumReferences() >= 3318231040 /*6406.0*/) goto t225_n27;
  t225_n10: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t225_n20;
  t225_n11: if (E.getNumReferences() >= 3306874880 /*2478.5*/) goto t225_n19;
  t225_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t225_n14;
  t225_n13: return 0.047852881252765656f;
  t225_n14: if (E.getNumReferences() >= 3306842112 /*2470.5*/) goto t225_n16;
  t225_n15: return 0.10095170885324478f;
  t225_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t225_n18;
  t225_n17: return -0.2895142734050751f;
  t225_n18: return 0.41574493050575256f;
  t225_n19: return 0.005380767397582531f;
  t225_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t225_n24;
  t225_n21: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t225_n23;
  t225_n22: return 0.10433246195316315f;
  t225_n23: return 0.027285929769277573f;
  t225_n24: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t225_n26;
  t225_n25: return 0.11709584295749664f;
  t225_n26: return 0.07099901884794235f;
  t225_n27: if (E.getNumReferences() >= 3318784000 /*6676.0*/) goto t225_n61;
  t225_n28: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t225_n36;
  t225_n29: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t225_n33;
  t225_n30: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t225_n32;
  t225_n31: return 0.10732364654541016f;
  t225_n32: return -0.012454461306333542f;
  t225_n33: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t225_n35;
  t225_n34: return 0.005057146772742271f;
  t225_n35: return 0.24568337202072144f;
  t225_n36: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t225_n46;
  t225_n37: if (E.getNumReferences() >= 3318706176 /*6638.0*/) goto t225_n45;
  t225_n38: if (E.getNumReferences() >= 3318537216 /*6555.5*/) goto t225_n44;
  t225_n39: if (E.getNumReferences() >= 3318477824 /*6526.5*/) goto t225_n43;
  t225_n40: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t225_n42;
  t225_n41: return 0.250222772359848f;
  t225_n42: return 0.13217505812644958f;
  t225_n43: return 0.13140086829662323f;
  t225_n44: return -0.454751193523407f;
  t225_n45: return 0.11255329847335815f;
  t225_n46: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t225_n54;
  t225_n47: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t225_n49;
  t225_n48: return 0.22767598927021027f;
  t225_n49: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t225_n51;
  t225_n50: return -0.009186173789203167f;
  t225_n51: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t225_n53;
  t225_n52: return 0.11637281626462936f;
  t225_n53: return 0.05535529553890228f;
  t225_n54: if (E.getNumReferences() >= 3318714368 /*6642.0*/) goto t225_n60;
  t225_n55: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t225_n57;
  t225_n56: return -0.11213743686676025f;
  t225_n57: if (E.getNumReferences() >= 3318256640 /*6418.5*/) goto t225_n59;
  t225_n58: return 0.1315479725599289f;
  t225_n59: return 0.09280383586883545f;
  t225_n60: return 0.13891412317752838f;
  t225_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t225_n63;
  t225_n62: return 0.008378828875720501f;
  t225_n63: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t225_n77;
  t225_n64: if (E.getNumReferences() >= 3320185856 /*7360.5*/) goto t225_n72;
  t225_n65: if (E.getNumReferences() >= 3319960576 /*7250.5*/) goto t225_n71;
  t225_n66: if (E.getNumReferences() >= 3319654400 /*7101.0*/) goto t225_n68;
  t225_n67: return -0.016371307894587517f;
  t225_n68: if (E.getNumReferences() >= 3319692288 /*7119.5*/) goto t225_n70;
  t225_n69: return 0.11892156302928925f;
  t225_n70: return 0.045820266008377075f;
  t225_n71: return 0.11863864213228226f;
  t225_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t225_n74;
  t225_n73: return -0.004869378171861172f;
  t225_n74: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t225_n76;
  t225_n75: return 0.10891716182231903f;
  t225_n76: return 0.06980974227190018f;
  t225_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t225_n89;
  t225_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t225_n80;
  t225_n79: return -0.017114335671067238f;
  t225_n80: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t225_n88;
  t225_n81: if (E.getNumReferences() >= 3327006208 /*13189.5*/) goto t225_n83;
  t225_n82: return 0.09628321975469589f;
  t225_n83: if (E.getNumReferences() >= 3327691264 /*13858.5*/) goto t225_n85;
  t225_n84: return 0.11125697195529938f;
  t225_n85: if (E.getNumReferences() >= 3331214336 /*18214.0*/) goto t225_n87;
  t225_n86: return -0.10845309495925903f;
  t225_n87: return 0.13731348514556885f;
  t225_n88: return 0.0380374975502491f;
  t225_n89: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t225_n95;
  t225_n90: if (E.getNumReferences() >= 3330558208 /*16932.5*/) goto t225_n92;
  t225_n91: return -0.01604125089943409f;
  t225_n92: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t225_n94;
  t225_n93: return 0.12386365979909897f;
  t225_n94: return -0.10821074992418289f;
  t225_n95: if (E.getNumReferences() >= 3324665856 /*10904.0*/) goto t225_n151;
  t225_n96: if (E.getNumReferences() >= 3324199424 /*10448.5*/) goto t225_n140;
  t225_n97: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t225_n117;
  t225_n98: if (E.getNumReferences() >= 3323001856 /*9279.0*/) goto t225_n116;
  t225_n99: if (E.getNumReferences() >= 3321178112 /*7845.0*/) goto t225_n101;
  t225_n100: return -0.00821286253631115f;
  t225_n101: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t225_n105;
  t225_n102: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t225_n104;
  t225_n103: return 0.05483260005712509f;
  t225_n104: return 0.11395349353551865f;
  t225_n105: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t225_n109;
  t225_n106: if (E.getNumReferences() >= 3321991168 /*8292.0*/) goto t225_n108;
  t225_n107: return 0.11436206847429276f;
  t225_n108: return -0.021011311560869217f;
  t225_n109: if (E.getNumReferences() >= 3322122752 /*8420.5*/) goto t225_n111;
  t225_n110: return -0.16106219589710236f;
  t225_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t225_n113;
  t225_n112: return -0.11745794117450714f;
  t225_n113: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t225_n115;
  t225_n114: return 0.11643092334270477f;
  t225_n115: return 0.09625356644392014f;
  t225_n116: return -0.13841097056865692f;
  t225_n117: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t225_n131;
  t225_n118: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t225_n120;
  t225_n119: return -0.04185833781957626f;
  t225_n120: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t225_n122;
  t225_n121: return -0.02782095968723297f;
  t225_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t225_n126;
  t225_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t225_n125;
  t225_n124: return 0.09778451174497604f;
  t225_n125: return 0.0820426344871521f;
  t225_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t225_n130;
  t225_n127: if (E.getNumReferences() >= 3321930240 /*8232.5*/) goto t225_n129;
  t225_n128: return 0.1148296594619751f;
  t225_n129: return -0.16420969367027283f;
  t225_n130: return 0.22774703800678253f;
  t225_n131: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t225_n137;
  t225_n132: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t225_n134;
  t225_n133: return 0.06030729040503502f;
  t225_n134: if (E.getNumReferences() >= 3320613888 /*7569.5*/) goto t225_n136;
  t225_n135: return 0.119156114757061f;
  t225_n136: return 0.13378971815109253f;
  t225_n137: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t225_n139;
  t225_n138: return 0.03995857387781143f;
  t225_n139: return 0.10314061492681503f;
  t225_n140: if (E.getNumReferences() >= 3324570112 /*10810.5*/) goto t225_n150;
  t225_n141: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t225_n149;
  t225_n142: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t225_n144;
  t225_n143: return -0.1168680191040039f;
  t225_n144: if (E.getNumReferences() >= 3324409856 /*10654.0*/) goto t225_n148;
  t225_n145: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t225_n147;
  t225_n146: return 0.11614633351564407f;
  t225_n147: return 0.0989418551325798f;
  t225_n148: return -0.10555911064147949f;
  t225_n149: return 0.09890850633382797f;
  t225_n150: return 0.11663348227739334f;
  t225_n151: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t225_n153;
  t225_n152: return -0.008974677883088589f;
  t225_n153: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t225_n155;
  t225_n154: return 0.08475401997566223f;
  t225_n155: return -0.07222270965576172f;
  t225_n156: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t225_n176;
  t225_n157: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t225_n161;
  t225_n158: if (E.getNumReferences() >= 3317563392 /*6080.0*/) goto t225_n160;
  t225_n159: return 0.01039116270840168f;
  t225_n160: return -0.5080410838127136f;
  t225_n161: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t225_n167;
  t225_n162: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t225_n164;
  t225_n163: return 0.040026016533374786f;
  t225_n164: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t225_n166;
  t225_n165: return 0.10378746688365936f;
  t225_n166: return 0.11416418850421906f;
  t225_n167: if (E.getNumReferences() >= 3321964544 /*8266.0*/) goto t225_n169;
  t225_n168: return 0.005507347639650106f;
  t225_n169: if (E.getNumReferences() >= 3322966016 /*9244.0*/) goto t225_n175;
  t225_n170: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t225_n172;
  t225_n171: return 0.09480433166027069f;
  t225_n172: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t225_n174;
  t225_n173: return 0.10718460381031036f;
  t225_n174: return 0.0951366201043129f;
  t225_n175: return 0.038687098771333694f;
  t225_n176: if (E.getNumReferences() >= 3314617344 /*4641.5*/) goto t225_n182;
  t225_n177: if (E.getNumReferences() >= 3312302080 /*3803.5*/) goto t225_n181;
  t225_n178: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t225_n180;
  t225_n179: return 0.08665508031845093f;
  t225_n180: return -0.5897219777107239f;
  t225_n181: return 0.10663345456123352f;
  t225_n182: return 0.03500879555940628f;
  t225_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace))) goto t225_n239;
  t225_n184: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t225_n186;
  t225_n185: return -0.06521189212799072f;
  t225_n186: if (E.getNumReferences() >= 3331489536 /*18751.5*/) goto t225_n192;
  t225_n187: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t225_n191;
  t225_n188: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t225_n190;
  t225_n189: return 0.14807188510894775f;
  t225_n190: return 0.11428626626729965f;
  t225_n191: return -0.06366360932588577f;
  t225_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t225_n194;
  t225_n193: return -0.08275913447141647f;
  t225_n194: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t225_n238;
  t225_n195: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t225_n221;
  t225_n196: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t225_n216;
  t225_n197: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t225_n199;
  t225_n198: return 0.021025976166129112f;
  t225_n199: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t225_n209;
  t225_n200: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t225_n202;
  t225_n201: return 0.10768400132656097f;
  t225_n202: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t225_n204;
  t225_n203: return 0.0406438447535038f;
  t225_n204: if (E.getNumReferences() >= 3332674048 /*21065.0*/) goto t225_n206;
  t225_n205: return -0.26403915882110596f;
  t225_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t225_n208;
  t225_n207: return -0.12938638031482697f;
  t225_n208: return 0.1251102089881897f;
  t225_n209: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t225_n211;
  t225_n210: return -0.003643566742539406f;
  t225_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t225_n213;
  t225_n212: return -0.16294331848621368f;
  t225_n213: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t225_n215;
  t225_n214: return 0.07668208330869675f;
  t225_n215: return -0.11286569386720657f;
  t225_n216: if (E.getNumReferences() >= 3332022528 /*19792.5*/) goto t225_n220;
  t225_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t225_n219;
  t225_n218: return -0.07339909672737122f;
  t225_n219: return 0.11608508974313736f;
  t225_n220: return 0.013748367317020893f;
  t225_n221: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t225_n231;
  t225_n222: if (E.getNumReferences() >= 3332378112 /*20487.0*/) goto t225_n224;
  t225_n223: return 0.06931395828723907f;
  t225_n224: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t225_n228;
  t225_n225: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t225_n227;
  t225_n226: return -0.06272171437740326f;
  t225_n227: return 0.11524982005357742f;
  t225_n228: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t225_n230;
  t225_n229: return -0.11932200938463211f;
  t225_n230: return 0.10788322240114212f;
  t225_n231: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t225_n233;
  t225_n232: return -0.16366365551948547f;
  t225_n233: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t225_n237;
  t225_n234: if (E.getNumReferences() >= 3332209408 /*20157.5*/) goto t225_n236;
  t225_n235: return 0.07750340551137924f;
  t225_n236: return 0.13266776502132416f;
  t225_n237: return 0.04152444377541542f;
  t225_n238: return 0.11445538699626923f;
  t225_n239: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t225_n241;
  t225_n240: return -0.10201117396354675f;
  t225_n241: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t225_n251;
  t225_n242: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t225_n246;
  t225_n243: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t225_n245;
  t225_n244: return 0.08496444672346115f;
  t225_n245: return -0.09028788655996323f;
  t225_n246: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t225_n248;
  t225_n247: return 0.10916098952293396f;
  t225_n248: if (E.getNumReferences() >= 3332746752 /*21207.0*/) goto t225_n250;
  t225_n249: return 0.14964279532432556f;
  t225_n250: return -1.0192757844924927f;
  t225_n251: return 0.09194037318229675f;
  t225_n252: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t225_n254;
  t225_n253: return -0.008205424062907696f;
  t225_n254: return 0.02984604984521866f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree226(const Example& E) {
  t226_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t226_n2;
  t226_n1: return -0.00017533040954731405f;
  t226_n2: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t226_n12;
  t226_n3: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n5;
  t226_n4: return 0.06059421971440315f;
  t226_n5: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t226_n7;
  t226_n6: return 0.12014567106962204f;
  t226_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t226_n9;
  t226_n8: return -0.11768745630979538f;
  t226_n9: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t226_n11;
  t226_n10: return 0.10627882927656174f;
  t226_n11: return 0.07569621503353119f;
  t226_n12: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t226_n14;
  t226_n13: return -0.050893932580947876f;
  t226_n14: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t226_n126;
  t226_n15: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t226_n99;
  t226_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t226_n50;
  t226_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t226_n33;
  t226_n18: if (E.getNumReferences() >= 3342077440 /*46094.0*/) goto t226_n32;
  t226_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t226_n21;
  t226_n20: return -0.15028971433639526f;
  t226_n21: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n31;
  t226_n22: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t226_n26;
  t226_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t226_n25;
  t226_n24: return -0.12919187545776367f;
  t226_n25: return 0.13873206079006195f;
  t226_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t226_n30;
  t226_n27: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t226_n29;
  t226_n28: return 0.02632182091474533f;
  t226_n29: return 0.10428933799266815f;
  t226_n30: return 0.12050057202577591f;
  t226_n31: return 0.09592633694410324f;
  t226_n32: return -0.02437111921608448f;
  t226_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t226_n35;
  t226_n34: return -0.1057472825050354f;
  t226_n35: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t226_n37;
  t226_n36: return 0.04941555857658386f;
  t226_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t226_n39;
  t226_n38: return 0.07102930545806885f;
  t226_n39: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t226_n41;
  t226_n40: return 0.028677286580204964f;
  t226_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n47;
  t226_n42: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t226_n44;
  t226_n43: return 0.3009549081325531f;
  t226_n44: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t226_n46;
  t226_n45: return 0.1140109971165657f;
  t226_n46: return 0.05849257856607437f;
  t226_n47: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t226_n49;
  t226_n48: return 0.1096707284450531f;
  t226_n49: return 0.06340867280960083f;
  t226_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t226_n62;
  t226_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t226_n53;
  t226_n52: return -0.11093426495790482f;
  t226_n53: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t226_n55;
  t226_n54: return -0.13194440305233002f;
  t226_n55: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n59;
  t226_n56: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t226_n58;
  t226_n57: return 1.5101317167282104f;
  t226_n58: return 0.1548532098531723f;
  t226_n59: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t226_n61;
  t226_n60: return 0.10808151215314865f;
  t226_n61: return 0.08787643164396286f;
  t226_n62: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t226_n98;
  t226_n63: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t226_n77;
  t226_n64: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t226_n66;
  t226_n65: return 0.10410407930612564f;
  t226_n66: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t226_n68;
  t226_n67: return -0.1627863496541977f;
  t226_n68: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t226_n74;
  t226_n69: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t226_n73;
  t226_n70: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t226_n72;
  t226_n71: return 0.07127110660076141f;
  t226_n72: return 0.05435521900653839f;
  t226_n73: return 0.06591964513063431f;
  t226_n74: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t226_n76;
  t226_n75: return 0.012570698745548725f;
  t226_n76: return 0.11143455654382706f;
  t226_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n79;
  t226_n78: return 0.1866176575422287f;
  t226_n79: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t226_n81;
  t226_n80: return -0.25499263405799866f;
  t226_n81: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t226_n95;
  t226_n82: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t226_n90;
  t226_n83: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n85;
  t226_n84: return 0.17246246337890625f;
  t226_n85: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t226_n87;
  t226_n86: return -0.05174802616238594f;
  t226_n87: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t226_n89;
  t226_n88: return 0.12429917603731155f;
  t226_n89: return 0.11589598655700684f;
  t226_n90: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n94;
  t226_n91: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t226_n93;
  t226_n92: return 0.11649461090564728f;
  t226_n93: return 0.11884228140115738f;
  t226_n94: return -0.12954485416412354f;
  t226_n95: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n97;
  t226_n96: return 0.08096186816692352f;
  t226_n97: return 0.1446511447429657f;
  t226_n98: return 0.007526626344770193f;
  t226_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t226_n111;
  t226_n100: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t226_n110;
  t226_n101: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t226_n109;
  t226_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n104;
  t226_n103: return 0.19348646700382233f;
  t226_n104: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t226_n106;
  t226_n105: return 0.2574588656425476f;
  t226_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n108;
  t226_n107: return 0.13187924027442932f;
  t226_n108: return 0.07128043472766876f;
  t226_n109: return -0.11533404141664505f;
  t226_n110: return -0.1314399540424347f;
  t226_n111: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t226_n117;
  t226_n112: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n114;
  t226_n113: return -0.10565377026796341f;
  t226_n114: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n116;
  t226_n115: return 0.15660344064235687f;
  t226_n116: return -0.0691312626004219f;
  t226_n117: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t226_n123;
  t226_n118: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t226_n122;
  t226_n119: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t226_n121;
  t226_n120: return 0.24964866042137146f;
  t226_n121: return -0.21387779712677002f;
  t226_n122: return 0.14104215800762177f;
  t226_n123: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n125;
  t226_n124: return -0.135724738240242f;
  t226_n125: return 0.10104583203792572f;
  t226_n126: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t226_n254;
  t226_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t226_n215;
  t226_n128: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t226_n132;
  t226_n129: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t226_n131;
  t226_n130: return -0.021687597036361694f;
  t226_n131: return -0.09556388109922409f;
  t226_n132: if (E.getNumReferences() >= 3349481088 /*84493.0*/) goto t226_n204;
  t226_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t226_n141;
  t226_n134: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t226_n136;
  t226_n135: return -0.07286463677883148f;
  t226_n136: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t226_n140;
  t226_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t226_n139;
  t226_n138: return -0.2354000210762024f;
  t226_n139: return 0.08816909790039062f;
  t226_n140: return -0.25773242115974426f;
  t226_n141: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t226_n155;
  t226_n142: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t226_n152;
  t226_n143: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t226_n151;
  t226_n144: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t226_n150;
  t226_n145: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t226_n147;
  t226_n146: return 0.03822246566414833f;
  t226_n147: if (E.getNumReferences() >= 3346276992 /*62498.5*/) goto t226_n149;
  t226_n148: return 0.11577289551496506f;
  t226_n149: return 0.06273055076599121f;
  t226_n150: return 0.10734102874994278f;
  t226_n151: return -0.01601097360253334f;
  t226_n152: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t226_n154;
  t226_n153: return 0.10322726517915726f;
  t226_n154: return -0.37292933464050293f;
  t226_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t226_n189;
  t226_n156: if (E.getNumReferences() >= 3348338496 /*75566.5*/) goto t226_n186;
  t226_n157: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t226_n167;
  t226_n158: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t226_n160;
  t226_n159: return 0.00546486908569932f;
  t226_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t226_n162;
  t226_n161: return -0.5416139364242554f;
  t226_n162: if (E.getNumReferences() >= 3345041664 /*57673.0*/) goto t226_n164;
  t226_n163: return 0.03691907227039337f;
  t226_n164: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t226_n166;
  t226_n165: return 0.09695029258728027f;
  t226_n166: return 0.126206636428833f;
  t226_n167: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t226_n185;
  t226_n168: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t226_n174;
  t226_n169: if (E.getNumReferences() >= 3345041664 /*57673.0*/) goto t226_n171;
  t226_n170: return -0.02581111341714859f;
  t226_n171: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t226_n173;
  t226_n172: return -0.08101769536733627f;
  t226_n173: return 0.07461884617805481f;
  t226_n174: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t226_n184;
  t226_n175: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t226_n183;
  t226_n176: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t226_n178;
  t226_n177: return 0.021471839398145676f;
  t226_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t226_n182;
  t226_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t226_n181;
  t226_n180: return -0.5624719262123108f;
  t226_n181: return -0.1072666347026825f;
  t226_n182: return 0.00288037839345634f;
  t226_n183: return 0.0036030018236488104f;
  t226_n184: return -0.026244422420859337f;
  t226_n185: return 0.07977208495140076f;
  t226_n186: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n188;
  t226_n187: return 0.0744422972202301f;
  t226_n188: return 0.0015545382630079985f;
  t226_n189: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t226_n199;
  t226_n190: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n198;
  t226_n191: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t226_n193;
  t226_n192: return -0.19075259566307068f;
  t226_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t226_n197;
  t226_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t226_n196;
  t226_n195: return 0.03950215503573418f;
  t226_n196: return 0.11681276559829712f;
  t226_n197: return 0.16383150219917297f;
  t226_n198: return 0.08784643560647964f;
  t226_n199: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t226_n201;
  t226_n200: return 0.04278680682182312f;
  t226_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t226_n203;
  t226_n202: return -1.1174371242523193f;
  t226_n203: return -0.017228977754712105f;
  t226_n204: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t226_n214;
  t226_n205: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t226_n213;
  t226_n206: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t226_n212;
  t226_n207: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t226_n211;
  t226_n208: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t226_n210;
  t226_n209: return 0.08030099421739578f;
  t226_n210: return -0.1909065693616867f;
  t226_n211: return 0.1061973050236702f;
  t226_n212: return -0.11897441744804382f;
  t226_n213: return -0.14962415397167206f;
  t226_n214: return -0.012308821082115173f;
  t226_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t226_n217;
  t226_n216: return -0.046996843069791794f;
  t226_n217: if (E.getNumReferences() >= 3348219712 /*74638.5*/) goto t226_n235;
  t226_n218: if (E.getNumReferences() >= 3345444992 /*59248.5*/) goto t226_n234;
  t226_n219: if (E.getNumReferences() >= 3345041664 /*57673.0*/) goto t226_n229;
  t226_n220: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t226_n228;
  t226_n221: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t226_n227;
  t226_n222: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t226_n226;
  t226_n223: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n225;
  t226_n224: return -0.32709574699401855f;
  t226_n225: return 0.10479336977005005f;
  t226_n226: return 0.10867258906364441f;
  t226_n227: return -0.009298094548285007f;
  t226_n228: return -0.12151088565587997f;
  t226_n229: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t226_n233;
  t226_n230: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t226_n232;
  t226_n231: return 0.1438698023557663f;
  t226_n232: return 0.11511214822530746f;
  t226_n233: return 0.16756704449653625f;
  t226_n234: return -0.07709601521492004f;
  t226_n235: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t226_n237;
  t226_n236: return -0.1924077421426773f;
  t226_n237: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n245;
  t226_n238: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t226_n240;
  t226_n239: return 0.06713894009590149f;
  t226_n240: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t226_n244;
  t226_n241: if (E.getNumReferences() >= 3349106816 /*81569.0*/) goto t226_n243;
  t226_n242: return 0.1149369329214096f;
  t226_n243: return -0.13899670541286469f;
  t226_n244: return 0.03760049492120743f;
  t226_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t226_n247;
  t226_n246: return 0.09792877733707428f;
  t226_n247: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t226_n249;
  t226_n248: return -0.1266481876373291f;
  t226_n249: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t226_n253;
  t226_n250: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n252;
  t226_n251: return 0.08630716055631638f;
  t226_n252: return 0.06802322715520859f;
  t226_n253: return -0.08548428863286972f;
  t226_n254: return 0.005633901804685593f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree227(const Example& E) {
  t227_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t227_n2;
  t227_n1: return -0.0001784097112249583f;
  t227_n2: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t227_n172;
  t227_n3: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t227_n143;
  t227_n4: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t227_n66;
  t227_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t227_n45;
  t227_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t227_n8;
  t227_n7: return -0.029774783179163933f;
  t227_n8: if (E.getNumReferences() >= 3342077440 /*46094.0*/) goto t227_n14;
  t227_n9: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t227_n11;
  t227_n10: return -0.015342934057116508f;
  t227_n11: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n13;
  t227_n12: return 0.11169496178627014f;
  t227_n13: return 0.09434407204389572f;
  t227_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t227_n16;
  t227_n15: return -0.11290477961301804f;
  t227_n16: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t227_n36;
  t227_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t227_n21;
  t227_n18: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t227_n20;
  t227_n19: return -0.1636817902326584f;
  t227_n20: return -0.5483795404434204f;
  t227_n21: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n25;
  t227_n22: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t227_n24;
  t227_n23: return -0.0018304219702258706f;
  t227_n24: return 0.18900862336158752f;
  t227_n25: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t227_n35;
  t227_n26: if (E.getNumReferences() >= 3342302208 /*46972.0*/) goto t227_n32;
  t227_n27: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t227_n29;
  t227_n28: return -0.11489814519882202f;
  t227_n29: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t227_n31;
  t227_n30: return 0.15102164447307587f;
  t227_n31: return 0.054211776703596115f;
  t227_n32: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t227_n34;
  t227_n33: return -0.23720631003379822f;
  t227_n34: return 0.07654022425413132f;
  t227_n35: return 0.10101586580276489f;
  t227_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t227_n38;
  t227_n37: return -0.2061801254749298f;
  t227_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n44;
  t227_n39: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t227_n43;
  t227_n40: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t227_n42;
  t227_n41: return 0.2272113412618637f;
  t227_n42: return 0.12145405262708664f;
  t227_n43: return -0.11287268251180649f;
  t227_n44: return 0.013823915272951126f;
  t227_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t227_n47;
  t227_n46: return -0.10238359868526459f;
  t227_n47: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t227_n49;
  t227_n48: return 0.04485302045941353f;
  t227_n49: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t227_n53;
  t227_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t227_n52;
  t227_n51: return 0.06705784797668457f;
  t227_n52: return 0.025912538170814514f;
  t227_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t227_n59;
  t227_n54: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t227_n56;
  t227_n55: return 0.21769873797893524f;
  t227_n56: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t227_n58;
  t227_n57: return 0.11280345171689987f;
  t227_n58: return 0.054599594324827194f;
  t227_n59: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t227_n61;
  t227_n60: return 0.10874810814857483f;
  t227_n61: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t227_n63;
  t227_n62: return -0.028749313205480576f;
  t227_n63: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t227_n65;
  t227_n64: return 0.12192407995462418f;
  t227_n65: return -0.4735482633113861f;
  t227_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t227_n78;
  t227_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t227_n69;
  t227_n68: return -0.11195701360702515f;
  t227_n69: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t227_n71;
  t227_n70: return -0.13795490562915802f;
  t227_n71: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t227_n75;
  t227_n72: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t227_n74;
  t227_n73: return 0.46745210886001587f;
  t227_n74: return 0.1373944729566574f;
  t227_n75: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t227_n77;
  t227_n76: return 0.10799949616193771f;
  t227_n77: return 0.08593820780515671f;
  t227_n78: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t227_n120;
  t227_n79: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n97;
  t227_n80: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t227_n96;
  t227_n81: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t227_n83;
  t227_n82: return 0.10378964245319366f;
  t227_n83: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t227_n85;
  t227_n84: return -0.16091430187225342f;
  t227_n85: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t227_n89;
  t227_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t227_n88;
  t227_n87: return 0.06278721988201141f;
  t227_n88: return 0.00185683136805892f;
  t227_n89: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t227_n95;
  t227_n90: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t227_n94;
  t227_n91: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t227_n93;
  t227_n92: return 0.05911604315042496f;
  t227_n93: return 0.1847732812166214f;
  t227_n94: return 0.04381415247917175f;
  t227_n95: return 0.08111384510993958f;
  t227_n96: return 0.148252934217453f;
  t227_n97: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t227_n119;
  t227_n98: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t227_n112;
  t227_n99: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t227_n111;
  t227_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t227_n102;
  t227_n101: return 0.07166149467229843f;
  t227_n102: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t227_n104;
  t227_n103: return 0.15227964520454407f;
  t227_n104: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t227_n106;
  t227_n105: return -0.04703279957175255f;
  t227_n106: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t227_n110;
  t227_n107: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t227_n109;
  t227_n108: return 0.09330936521291733f;
  t227_n109: return 0.15537357330322266f;
  t227_n110: return 0.10828143358230591f;
  t227_n111: return 0.07008079439401627f;
  t227_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t227_n118;
  t227_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t227_n115;
  t227_n114: return 0.09506946057081223f;
  t227_n115: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t227_n117;
  t227_n116: return 0.11674322187900543f;
  t227_n117: return 0.11245232820510864f;
  t227_n118: return 0.024940049275755882f;
  t227_n119: return 0.0989314392209053f;
  t227_n120: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t227_n132;
  t227_n121: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n125;
  t227_n122: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t227_n124;
  t227_n123: return 0.07233064621686935f;
  t227_n124: return 1.9874733686447144f;
  t227_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t227_n127;
  t227_n126: return 0.10433872044086456f;
  t227_n127: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t227_n131;
  t227_n128: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t227_n130;
  t227_n129: return 0.10722541064023972f;
  t227_n130: return 0.10660528391599655f;
  t227_n131: return 0.1402774304151535f;
  t227_n132: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t227_n134;
  t227_n133: return -0.002822215436026454f;
  t227_n134: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t227_n136;
  t227_n135: return -0.17707262933254242f;
  t227_n136: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n142;
  t227_n137: if (E.getNumReferences() >= 3343393536 /*51235.0*/) goto t227_n139;
  t227_n138: return -0.1288444548845291f;
  t227_n139: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t227_n141;
  t227_n140: return 0.14037805795669556f;
  t227_n141: return 0.07649464160203934f;
  t227_n142: return -0.2525664269924164f;
  t227_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t227_n153;
  t227_n144: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t227_n152;
  t227_n145: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t227_n151;
  t227_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t227_n148;
  t227_n147: return 0.14960524439811707f;
  t227_n148: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t227_n150;
  t227_n149: return 0.10312923789024353f;
  t227_n150: return 0.15892864763736725f;
  t227_n151: return -0.11157489567995071f;
  t227_n152: return -0.12919940054416656f;
  t227_n153: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t227_n159;
  t227_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n156;
  t227_n155: return -0.10491697490215302f;
  t227_n156: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t227_n158;
  t227_n157: return 0.15015733242034912f;
  t227_n158: return -0.06328748166561127f;
  t227_n159: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n167;
  t227_n160: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t227_n166;
  t227_n161: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t227_n165;
  t227_n162: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t227_n164;
  t227_n163: return 4.051187515258789f;
  t227_n164: return 0.3740459382534027f;
  t227_n165: return 0.14990685880184174f;
  t227_n166: return 0.05147432163357735f;
  t227_n167: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t227_n169;
  t227_n168: return 0.0979628637433052f;
  t227_n169: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t227_n171;
  t227_n170: return 0.129465714097023f;
  t227_n171: return 0.07955066859722137f;
  t227_n172: if (E.getNumReferences() >= 3344974336 /*57410.0*/) goto t227_n174;
  t227_n173: return -0.05105435475707054f;
  t227_n174: if (E.getNumReferences() >= 3345974912 /*61318.5*/) goto t227_n236;
  t227_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t227_n225;
  t227_n176: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t227_n184;
  t227_n177: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t227_n181;
  t227_n178: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t227_n180;
  t227_n179: return -0.020680787041783333f;
  t227_n180: return 0.13546112179756165f;
  t227_n181: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t227_n183;
  t227_n182: return 0.03925266116857529f;
  t227_n183: return 0.11682417243719101f;
  t227_n184: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t227_n208;
  t227_n185: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t227_n197;
  t227_n186: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t227_n190;
  t227_n187: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t227_n189;
  t227_n188: return 0.07963547855615616f;
  t227_n189: return -0.7520674467086792f;
  t227_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t227_n196;
  t227_n191: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t227_n195;
  t227_n192: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t227_n194;
  t227_n193: return 0.09329473227262497f;
  t227_n194: return 0.10875410586595535f;
  t227_n195: return -0.01898382045328617f;
  t227_n196: return 0.0868106260895729f;
  t227_n197: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t227_n199;
  t227_n198: return -0.19386409223079681f;
  t227_n199: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n207;
  t227_n200: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t227_n202;
  t227_n201: return -0.10748142749071121f;
  t227_n202: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t227_n206;
  t227_n203: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t227_n205;
  t227_n204: return 0.13354001939296722f;
  t227_n205: return -0.100342757999897f;
  t227_n206: return 0.12761887907981873f;
  t227_n207: return 0.039038367569446564f;
  t227_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t227_n224;
  t227_n209: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t227_n223;
  t227_n210: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t227_n214;
  t227_n211: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t227_n213;
  t227_n212: return 0.0568409338593483f;
  t227_n213: return -6.986021995544434f;
  t227_n214: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t227_n218;
  t227_n215: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t227_n217;
  t227_n216: return 0.07182060927152634f;
  t227_n217: return -0.7764049768447876f;
  t227_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t227_n220;
  t227_n219: return 0.0847851112484932f;
  t227_n220: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t227_n222;
  t227_n221: return 0.12761607766151428f;
  t227_n222: return 0.08718075603246689f;
  t227_n223: return -0.008372673764824867f;
  t227_n224: return 0.11229343712329865f;
  t227_n225: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t227_n229;
  t227_n226: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t227_n228;
  t227_n227: return 0.020786816254258156f;
  t227_n228: return -1.5353137254714966f;
  t227_n229: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t227_n231;
  t227_n230: return 0.14593325555324554f;
  t227_n231: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t227_n233;
  t227_n232: return 0.12205076217651367f;
  t227_n233: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n235;
  t227_n234: return 0.10971347242593765f;
  t227_n235: return 0.11538337916135788f;
  t227_n236: if (E.getNumReferences() >= 3348227392 /*74698.5*/) goto t227_n254;
  t227_n237: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t227_n245;
  t227_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t227_n240;
  t227_n239: return -0.03432999923825264f;
  t227_n240: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t227_n242;
  t227_n241: return -0.032425541430711746f;
  t227_n242: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t227_n244;
  t227_n243: return 0.06431389600038528f;
  t227_n244: return 0.08524066209793091f;
  t227_n245: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n247;
  t227_n246: return -0.1388789713382721f;
  t227_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t227_n249;
  t227_n248: return -0.10999248176813126f;
  t227_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t227_n251;
  t227_n250: return 0.08361630141735077f;
  t227_n251: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t227_n253;
  t227_n252: return 0.11745379865169525f;
  t227_n253: return 0.08703722059726715f;
  t227_n254: return 0.004652010276913643f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree228(const Example& E) {
  t228_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t228_n130;
  t228_n1: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t228_n3;
  t228_n2: return -0.0020938694942742586f;
  t228_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t228_n5;
  t228_n4: return -0.0007171322358772159f;
  t228_n5: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t228_n119;
  t228_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t228_n32;
  t228_n7: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t228_n31;
  t228_n8: if (E.getNumReferences() >= 3264217088 /*72.0*/) goto t228_n10;
  t228_n9: return -0.053366903215646744f;
  t228_n10: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t228_n20;
  t228_n11: if (E.getNumReferences() >= 3306246144 /*2325.0*/) goto t228_n19;
  t228_n12: if (E.getNumReferences() >= 3284074496 /*382.0*/) goto t228_n18;
  t228_n13: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t228_n17;
  t228_n14: if (E.getNumReferences() >= 3273097216 /*151.5*/) goto t228_n16;
  t228_n15: return 0.0661940947175026f;
  t228_n16: return -0.31901994347572327f;
  t228_n17: return 0.10841409116983414f;
  t228_n18: return 0.0960458517074585f;
  t228_n19: return -0.0951065719127655f;
  t228_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n22;
  t228_n21: return -0.8604269623756409f;
  t228_n22: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t228_n26;
  t228_n23: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t228_n25;
  t228_n24: return -0.10725698620080948f;
  t228_n25: return 0.03476792946457863f;
  t228_n26: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t228_n28;
  t228_n27: return -0.003748284885659814f;
  t228_n28: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t228_n30;
  t228_n29: return 0.10614235699176788f;
  t228_n30: return 0.06699591130018234f;
  t228_n31: return 0.11399231851100922f;
  t228_n32: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t228_n82;
  t228_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t228_n61;
  t228_n34: if (E.getNumReferences() >= 3276636160 /*205.5*/) goto t228_n48;
  t228_n35: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t228_n41;
  t228_n36: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t228_n38;
  t228_n37: return -0.021366465836763382f;
  t228_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t228_n40;
  t228_n39: return -0.10288263112306595f;
  t228_n40: return -0.035160914063453674f;
  t228_n41: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t228_n47;
  t228_n42: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t228_n46;
  t228_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t228_n45;
  t228_n44: return 0.06899964809417725f;
  t228_n45: return 0.12699712812900543f;
  t228_n46: return -0.005988071672618389f;
  t228_n47: return -0.025860577821731567f;
  t228_n48: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t228_n50;
  t228_n49: return -0.038596611469984055f;
  t228_n50: if (E.getNumReferences() >= 3285532672 /*426.5*/) goto t228_n60;
  t228_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t228_n55;
  t228_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n54;
  t228_n53: return -0.4010354280471802f;
  t228_n54: return 0.0786970779299736f;
  t228_n55: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n59;
  t228_n56: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t228_n58;
  t228_n57: return 0.10312933474779129f;
  t228_n58: return -0.079692043364048f;
  t228_n59: return 0.07326837629079819f;
  t228_n60: return 0.024279223755002022f;
  t228_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t228_n63;
  t228_n62: return -0.019442081451416016f;
  t228_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t228_n65;
  t228_n64: return 0.02636006474494934f;
  t228_n65: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t228_n67;
  t228_n66: return -0.01274182554334402f;
  t228_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t228_n69;
  t228_n68: return 0.020495561882853508f;
  t228_n69: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n71;
  t228_n70: return 0.0656266063451767f;
  t228_n71: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t228_n75;
  t228_n72: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t228_n74;
  t228_n73: return -0.10931634902954102f;
  t228_n74: return -0.0007593804621137679f;
  t228_n75: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t228_n77;
  t228_n76: return 0.024430034682154655f;
  t228_n77: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t228_n79;
  t228_n78: return 0.13949540257453918f;
  t228_n79: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t228_n81;
  t228_n80: return 0.025244319811463356f;
  t228_n81: return 0.11736910045146942f;
  t228_n82: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t228_n118;
  t228_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t228_n105;
  t228_n84: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t228_n94;
  t228_n85: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t228_n87;
  t228_n86: return -0.051212914288043976f;
  t228_n87: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t228_n89;
  t228_n88: return 0.10188090056180954f;
  t228_n89: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n93;
  t228_n90: if (E.getNumReferences() >= 3308521472 /*2880.5*/) goto t228_n92;
  t228_n91: return 0.08346503227949142f;
  t228_n92: return -0.042001236230134964f;
  t228_n93: return 0.011603347025811672f;
  t228_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t228_n98;
  t228_n95: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t228_n97;
  t228_n96: return -0.0711580440402031f;
  t228_n97: return 0.14415332674980164f;
  t228_n98: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t228_n104;
  t228_n99: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n101;
  t228_n100: return -0.10337429493665695f;
  t228_n101: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t228_n103;
  t228_n102: return 0.09964624047279358f;
  t228_n103: return 0.0034490376710891724f;
  t228_n104: return -0.21291767060756683f;
  t228_n105: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t228_n115;
  t228_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t228_n114;
  t228_n107: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t228_n109;
  t228_n108: return -0.0037963639479130507f;
  t228_n109: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t228_n111;
  t228_n110: return 0.04983769357204437f;
  t228_n111: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t228_n113;
  t228_n112: return -0.1556587517261505f;
  t228_n113: return 0.14768265187740326f;
  t228_n114: return 0.038851380348205566f;
  t228_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t228_n117;
  t228_n116: return 0.128191739320755f;
  t228_n117: return 0.1114841029047966f;
  t228_n118: return 0.004106199834495783f;
  t228_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t228_n121;
  t228_n120: return 0.0078915199264884f;
  t228_n121: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t228_n129;
  t228_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t228_n128;
  t228_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t228_n127;
  t228_n124: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t228_n126;
  t228_n125: return 0.08508305996656418f;
  t228_n126: return 0.062032002955675125f;
  t228_n127: return 0.08882758021354675f;
  t228_n128: return 0.05806632712483406f;
  t228_n129: return -0.03390425816178322f;
  t228_n130: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t228_n254;
  t228_n131: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t228_n227;
  t228_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t228_n176;
  t228_n133: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t228_n171;
  t228_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t228_n136;
  t228_n135: return -0.025350017473101616f;
  t228_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t228_n138;
  t228_n137: return -0.10232371091842651f;
  t228_n138: if (E.getNumReferences() >= 3342077440 /*46094.0*/) goto t228_n150;
  t228_n139: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t228_n147;
  t228_n140: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t228_n142;
  t228_n141: return -0.20336401462554932f;
  t228_n142: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t228_n144;
  t228_n143: return -0.04223497584462166f;
  t228_n144: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t228_n146;
  t228_n145: return 0.0901193767786026f;
  t228_n146: return 0.07141455262899399f;
  t228_n147: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n149;
  t228_n148: return 0.1084149181842804f;
  t228_n149: return 0.0926065444946289f;
  t228_n150: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t228_n164;
  t228_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t228_n153;
  t228_n152: return -0.1913919299840927f;
  t228_n153: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n155;
  t228_n154: return 0.035481639206409454f;
  t228_n155: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t228_n163;
  t228_n156: if (E.getNumReferences() >= 3342302208 /*46972.0*/) goto t228_n162;
  t228_n157: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t228_n159;
  t228_n158: return -0.10423970222473145f;
  t228_n159: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t228_n161;
  t228_n160: return 0.13150231540203094f;
  t228_n161: return 0.050808098167181015f;
  t228_n162: return -0.03774164989590645f;
  t228_n163: return 0.0987117812037468f;
  t228_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t228_n166;
  t228_n165: return -0.19768323004245758f;
  t228_n166: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n170;
  t228_n167: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t228_n169;
  t228_n168: return 0.11745845526456833f;
  t228_n169: return -0.11156768351793289f;
  t228_n170: return 0.01861785352230072f;
  t228_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t228_n173;
  t228_n172: return -0.09923283755779266f;
  t228_n173: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t228_n175;
  t228_n174: return 0.040841713547706604f;
  t228_n175: return 0.08992621302604675f;
  t228_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t228_n188;
  t228_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t228_n179;
  t228_n178: return -0.10467901080846786f;
  t228_n179: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t228_n181;
  t228_n180: return -0.13102716207504272f;
  t228_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t228_n185;
  t228_n182: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t228_n184;
  t228_n183: return 0.3700982928276062f;
  t228_n184: return 0.13577619194984436f;
  t228_n185: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t228_n187;
  t228_n186: return 0.10788735747337341f;
  t228_n187: return 0.08367250114679337f;
  t228_n188: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t228_n206;
  t228_n189: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n203;
  t228_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t228_n192;
  t228_n191: return 0.1190202385187149f;
  t228_n192: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t228_n194;
  t228_n193: return 0.10676082968711853f;
  t228_n194: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t228_n198;
  t228_n195: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n197;
  t228_n196: return 0.06294160336256027f;
  t228_n197: return 0.0016451382543891668f;
  t228_n198: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t228_n202;
  t228_n199: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t228_n201;
  t228_n200: return 0.06399407237768173f;
  t228_n201: return 0.035152729600667953f;
  t228_n202: return 0.07118792086839676f;
  t228_n203: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t228_n205;
  t228_n204: return -0.23192457854747772f;
  t228_n205: return 0.10371602326631546f;
  t228_n206: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t228_n218;
  t228_n207: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t228_n217;
  t228_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n212;
  t228_n209: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t228_n211;
  t228_n210: return 0.062303245067596436f;
  t228_n211: return 0.32017946243286133f;
  t228_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t228_n214;
  t228_n213: return 0.10394002497196198f;
  t228_n214: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t228_n216;
  t228_n215: return 0.1046372577548027f;
  t228_n216: return 0.13882383704185486f;
  t228_n217: return -0.0045111277140676975f;
  t228_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t228_n220;
  t228_n219: return -0.174350768327713f;
  t228_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n226;
  t228_n221: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t228_n223;
  t228_n222: return -0.1012093722820282f;
  t228_n223: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t228_n225;
  t228_n224: return 0.11997708678245544f;
  t228_n225: return 0.07229796051979065f;
  t228_n226: return -0.2868068218231201f;
  t228_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t228_n237;
  t228_n228: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t228_n236;
  t228_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t228_n235;
  t228_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n232;
  t228_n231: return 0.10028702765703201f;
  t228_n232: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t228_n234;
  t228_n233: return 0.09360408782958984f;
  t228_n234: return 0.1505088210105896f;
  t228_n235: return -0.1109347864985466f;
  t228_n236: return -0.12931962311267853f;
  t228_n237: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n247;
  t228_n238: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t228_n240;
  t228_n239: return -0.10461778193712234f;
  t228_n240: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t228_n246;
  t228_n241: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n243;
  t228_n242: return 0.0755339190363884f;
  t228_n243: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t228_n245;
  t228_n244: return 0.28811630606651306f;
  t228_n245: return 0.14119671285152435f;
  t228_n246: return 0.04623691737651825f;
  t228_n247: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t228_n249;
  t228_n248: return 0.11300083994865417f;
  t228_n249: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t228_n251;
  t228_n250: return 0.08564302325248718f;
  t228_n251: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t228_n253;
  t228_n252: return 0.1237017810344696f;
  t228_n253: return 0.07707984745502472f;
  t228_n254: return 0.0025088773109018803f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree229(const Example& E) {
  t229_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t229_n106;
  t229_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t229_n105;
  t229_n2: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t229_n102;
  t229_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n101;
  t229_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t229_n84;
  t229_n5: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t229_n7;
  t229_n6: return -0.008827724494040012f;
  t229_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t229_n9;
  t229_n8: return -0.08257732540369034f;
  t229_n9: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t229_n67;
  t229_n10: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t229_n62;
  t229_n11: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t229_n41;
  t229_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n16;
  t229_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n15;
  t229_n14: return -0.2549056112766266f;
  t229_n15: return -0.013391693122684956f;
  t229_n16: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t229_n34;
  t229_n17: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t229_n19;
  t229_n18: return 0.008759884163737297f;
  t229_n19: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t229_n31;
  t229_n20: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t229_n28;
  t229_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n25;
  t229_n22: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n24;
  t229_n23: return -0.009353257715702057f;
  t229_n24: return -0.13552676141262054f;
  t229_n25: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t229_n27;
  t229_n26: return -0.04347705841064453f;
  t229_n27: return 0.07215309143066406f;
  t229_n28: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t229_n30;
  t229_n29: return -0.01510439533740282f;
  t229_n30: return 0.04290100932121277f;
  t229_n31: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n33;
  t229_n32: return -0.014916523359715939f;
  t229_n33: return -0.11166251450777054f;
  t229_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t229_n36;
  t229_n35: return 0.016338763758540154f;
  t229_n36: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t229_n38;
  t229_n37: return 0.05040108785033226f;
  t229_n38: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t229_n40;
  t229_n39: return 0.10452084988355637f;
  t229_n40: return 0.07791754603385925f;
  t229_n41: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n43;
  t229_n42: return -0.059991154819726944f;
  t229_n43: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t229_n53;
  t229_n44: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t229_n52;
  t229_n45: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t229_n51;
  t229_n46: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t229_n48;
  t229_n47: return -0.2989765405654907f;
  t229_n48: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t229_n50;
  t229_n49: return 0.10537619888782501f;
  t229_n50: return 0.03177500516176224f;
  t229_n51: return 0.10094273835420609f;
  t229_n52: return 0.09336747974157333f;
  t229_n53: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t229_n59;
  t229_n54: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t229_n56;
  t229_n55: return -0.2969943881034851f;
  t229_n56: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t229_n58;
  t229_n57: return 0.04137731343507767f;
  t229_n58: return 0.10170945525169373f;
  t229_n59: if (E.getNumReferences() >= 3221225472 /*2.0*/) goto t229_n61;
  t229_n60: return 0.0730644017457962f;
  t229_n61: return -0.21666662395000458f;
  t229_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n66;
  t229_n63: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t229_n65;
  t229_n64: return 0.07628054916858673f;
  t229_n65: return 0.10125155001878738f;
  t229_n66: return -0.0033702098298817873f;
  t229_n67: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t229_n77;
  t229_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n72;
  t229_n69: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n71;
  t229_n70: return 0.10771392285823822f;
  t229_n71: return 0.054296303540468216f;
  t229_n72: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t229_n74;
  t229_n73: return -0.07144612818956375f;
  t229_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t229_n76;
  t229_n75: return 0.015265372581779957f;
  t229_n76: return 0.099054254591465f;
  t229_n77: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t229_n81;
  t229_n78: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n80;
  t229_n79: return -0.1963401734828949f;
  t229_n80: return 0.05990159884095192f;
  t229_n81: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n83;
  t229_n82: return -0.8378230929374695f;
  t229_n83: return 0.01191626861691475f;
  t229_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n86;
  t229_n85: return -0.025161609053611755f;
  t229_n86: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t229_n100;
  t229_n87: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n99;
  t229_n88: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t229_n98;
  t229_n89: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t229_n97;
  t229_n90: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n96;
  t229_n91: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t229_n95;
  t229_n92: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t229_n94;
  t229_n93: return 0.11072346568107605f;
  t229_n94: return 0.05482763424515724f;
  t229_n95: return 0.05376245453953743f;
  t229_n96: return 0.05075547844171524f;
  t229_n97: return 0.06831411272287369f;
  t229_n98: return 0.04491439834237099f;
  t229_n99: return 0.03189212828874588f;
  t229_n100: return 0.026526866480708122f;
  t229_n101: return 0.002963850973173976f;
  t229_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t229_n104;
  t229_n103: return 0.00531742861494422f;
  t229_n104: return 0.018470117822289467f;
  t229_n105: return -0.0009065884514711797f;
  t229_n106: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t229_n254;
  t229_n107: if (E.getNumReferences() >= 3343638400 /*52191.5*/) goto t229_n221;
  t229_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t229_n130;
  t229_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t229_n111;
  t229_n110: return -0.06392844021320343f;
  t229_n111: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n113;
  t229_n112: return -0.0039760032668709755f;
  t229_n113: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t229_n125;
  t229_n114: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t229_n120;
  t229_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n117;
  t229_n116: return 0.11529373377561569f;
  t229_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t229_n119;
  t229_n118: return 0.10106601566076279f;
  t229_n119: return 0.05986829102039337f;
  t229_n120: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t229_n124;
  t229_n121: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n123;
  t229_n122: return -0.21535570919513702f;
  t229_n123: return 0.09318668395280838f;
  t229_n124: return 0.13839493691921234f;
  t229_n125: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t229_n129;
  t229_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t229_n128;
  t229_n127: return -0.1355830878019333f;
  t229_n128: return 0.08163640648126602f;
  t229_n129: return -0.14924325048923492f;
  t229_n130: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t229_n220;
  t229_n131: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t229_n197;
  t229_n132: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t229_n196;
  t229_n133: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t229_n183;
  t229_n134: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t229_n142;
  t229_n135: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n137;
  t229_n136: return 0.01572791486978531f;
  t229_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n139;
  t229_n138: return -0.21939319372177124f;
  t229_n139: if (E.getNumReferences() >= 3341955584 /*45618.0*/) goto t229_n141;
  t229_n140: return 0.06294083595275879f;
  t229_n141: return -0.28125059604644775f;
  t229_n142: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t229_n152;
  t229_n143: if (E.getNumReferences() >= 3342524672 /*47841.0*/) goto t229_n145;
  t229_n144: return -0.028411677107214928f;
  t229_n145: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t229_n147;
  t229_n146: return 0.015040401369333267f;
  t229_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n151;
  t229_n148: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t229_n150;
  t229_n149: return 0.09776361286640167f;
  t229_n150: return -0.11542519927024841f;
  t229_n151: return 0.029418662190437317f;
  t229_n152: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t229_n164;
  t229_n153: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t229_n157;
  t229_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n156;
  t229_n155: return 0.10221483558416367f;
  t229_n156: return 0.0931411013007164f;
  t229_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n159;
  t229_n158: return -0.059975601732730865f;
  t229_n159: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t229_n161;
  t229_n160: return -0.022603441029787064f;
  t229_n161: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n163;
  t229_n162: return 0.07658649235963821f;
  t229_n163: return -0.10148660838603973f;
  t229_n164: if (E.getNumReferences() >= 3342302208 /*46972.0*/) goto t229_n182;
  t229_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n167;
  t229_n166: return -0.17286764085292816f;
  t229_n167: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t229_n173;
  t229_n168: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n170;
  t229_n169: return -0.15896688401699066f;
  t229_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n172;
  t229_n171: return 0.08780355006456375f;
  t229_n172: return 0.0678257867693901f;
  t229_n173: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t229_n179;
  t229_n174: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n176;
  t229_n175: return 0.1121138408780098f;
  t229_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n178;
  t229_n177: return -0.022557176649570465f;
  t229_n178: return 0.3873385190963745f;
  t229_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n181;
  t229_n180: return -0.2629566788673401f;
  t229_n181: return 0.09830786287784576f;
  t229_n182: return -0.2388119399547577f;
  t229_n183: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t229_n185;
  t229_n184: return 0.02421341836452484f;
  t229_n185: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t229_n195;
  t229_n186: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t229_n194;
  t229_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n193;
  t229_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n190;
  t229_n189: return -0.10094743967056274f;
  t229_n190: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t229_n192;
  t229_n191: return 0.06547456234693527f;
  t229_n192: return 0.05186571180820465f;
  t229_n193: return 0.03313888609409332f;
  t229_n194: return -0.011272563599050045f;
  t229_n195: return 0.1049414649605751f;
  t229_n196: return -0.031858544796705246f;
  t229_n197: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t229_n217;
  t229_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t229_n202;
  t229_n199: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n201;
  t229_n200: return -0.11555061489343643f;
  t229_n201: return 0.09685681015253067f;
  t229_n202: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t229_n210;
  t229_n203: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n209;
  t229_n204: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t229_n208;
  t229_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n207;
  t229_n206: return -0.11820590496063232f;
  t229_n207: return 0.1142498180270195f;
  t229_n208: return -0.11047748476266861f;
  t229_n209: return 0.004301621578633785f;
  t229_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n214;
  t229_n211: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t229_n213;
  t229_n212: return 0.2612631618976593f;
  t229_n213: return 0.13209940493106842f;
  t229_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t229_n216;
  t229_n215: return 0.1096639558672905f;
  t229_n216: return 0.08151865005493164f;
  t229_n217: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t229_n219;
  t229_n218: return 0.14829295873641968f;
  t229_n219: return 0.10006517171859741f;
  t229_n220: return -0.11246698349714279f;
  t229_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n227;
  t229_n222: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t229_n224;
  t229_n223: return 0.04845018312335014f;
  t229_n224: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t229_n226;
  t229_n225: return -0.2684631943702698f;
  t229_n226: return 0.10913858562707901f;
  t229_n227: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t229_n237;
  t229_n228: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n236;
  t229_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t229_n231;
  t229_n230: return -0.10174600780010223f;
  t229_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t229_n233;
  t229_n232: return 0.09252933412790298f;
  t229_n233: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t229_n235;
  t229_n234: return 0.11351688951253891f;
  t229_n235: return 0.10893280804157257f;
  t229_n236: return -0.031243404373526573f;
  t229_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t229_n243;
  t229_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t229_n240;
  t229_n239: return -0.12071814388036728f;
  t229_n240: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t229_n242;
  t229_n241: return 0.06616829335689545f;
  t229_n242: return 0.0844583660364151f;
  t229_n243: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t229_n247;
  t229_n244: if (E.getNumReferences() >= 3344048512 /*53793.5*/) goto t229_n246;
  t229_n245: return 0.08607526868581772f;
  t229_n246: return -0.23334987461566925f;
  t229_n247: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n253;
  t229_n248: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t229_n252;
  t229_n249: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t229_n251;
  t229_n250: return 0.1165936216711998f;
  t229_n251: return 0.15906639397144318f;
  t229_n252: return 0.11228322237730026f;
  t229_n253: return 0.04937702789902687f;
  t229_n254: return 0.0024762488901615143f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree230(const Example& E) {
  t230_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t230_n176;
  t230_n1: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t230_n3;
  t230_n2: return -0.002080228878185153f;
  t230_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t230_n5;
  t230_n4: return -0.0006614733138121665f;
  t230_n5: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t230_n119;
  t230_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t230_n8;
  t230_n7: return -0.02552991919219494f;
  t230_n8: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t230_n10;
  t230_n9: return 0.003411918645724654f;
  t230_n10: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t230_n38;
  t230_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t230_n29;
  t230_n12: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t230_n28;
  t230_n13: if (E.getNumReferences() >= 3280109568 /*261.0*/) goto t230_n25;
  t230_n14: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t230_n24;
  t230_n15: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t230_n21;
  t230_n16: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t230_n18;
  t230_n17: return 0.06678686290979385f;
  t230_n18: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t230_n20;
  t230_n19: return 0.09529092162847519f;
  t230_n20: return -0.11169867217540741f;
  t230_n21: if (E.getNumReferences() >= 3259760640 /*51.0*/) goto t230_n23;
  t230_n22: return 0.10431835800409317f;
  t230_n23: return -0.04054215922951698f;
  t230_n24: return -0.2909981608390808f;
  t230_n25: if (E.getNumReferences() >= 3281666048 /*308.5*/) goto t230_n27;
  t230_n26: return 0.1093577966094017f;
  t230_n27: return 0.050016868859529495f;
  t230_n28: return 0.002829896751791239f;
  t230_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t230_n31;
  t230_n30: return -0.020748674869537354f;
  t230_n31: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t230_n33;
  t230_n32: return -0.019679885357618332f;
  t230_n33: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t230_n37;
  t230_n34: if (E.getNumReferences() >= 3285794816 /*434.5*/) goto t230_n36;
  t230_n35: return 0.1067177951335907f;
  t230_n36: return 0.061771273612976074f;
  t230_n37: return 0.048770472407341f;
  t230_n38: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t230_n96;
  t230_n39: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t230_n51;
  t230_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t230_n42;
  t230_n41: return -0.01506817527115345f;
  t230_n42: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t230_n48;
  t230_n43: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t230_n45;
  t230_n44: return 0.13086001574993134f;
  t230_n45: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n47;
  t230_n46: return 0.04110679030418396f;
  t230_n47: return 0.10198889672756195f;
  t230_n48: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t230_n50;
  t230_n49: return -0.0007285083411261439f;
  t230_n50: return 0.12179415673017502f;
  t230_n51: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t230_n91;
  t230_n52: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t230_n82;
  t230_n53: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t230_n81;
  t230_n54: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t230_n60;
  t230_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t230_n59;
  t230_n56: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t230_n58;
  t230_n57: return 0.12562507390975952f;
  t230_n58: return -0.11342611908912659f;
  t230_n59: return 0.051991090178489685f;
  t230_n60: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t230_n62;
  t230_n61: return -0.006567520089447498f;
  t230_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t230_n74;
  t230_n63: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t230_n73;
  t230_n64: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t230_n66;
  t230_n65: return 0.042430102825164795f;
  t230_n66: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t230_n68;
  t230_n67: return 0.042333655059337616f;
  t230_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n72;
  t230_n69: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t230_n71;
  t230_n70: return 0.10877928137779236f;
  t230_n71: return 0.11058933287858963f;
  t230_n72: return -0.11308007687330246f;
  t230_n73: return 0.03411908447742462f;
  t230_n74: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t230_n78;
  t230_n75: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t230_n77;
  t230_n76: return -0.07554042339324951f;
  t230_n77: return 0.11842668801546097f;
  t230_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t230_n80;
  t230_n79: return 0.028000421822071075f;
  t230_n80: return 0.11909658461809158f;
  t230_n81: return -0.09875456988811493f;
  t230_n82: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t230_n84;
  t230_n83: return 0.01458948478102684f;
  t230_n84: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t230_n86;
  t230_n85: return 0.02567414380609989f;
  t230_n86: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t230_n88;
  t230_n87: return 0.029060887172818184f;
  t230_n88: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t230_n90;
  t230_n89: return 0.11559586971998215f;
  t230_n90: return 0.1029600277543068f;
  t230_n91: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t230_n95;
  t230_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n94;
  t230_n93: return 0.1015944555401802f;
  t230_n94: return -0.01633737049996853f;
  t230_n95: return -0.015297935344278812f;
  t230_n96: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t230_n118;
  t230_n97: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t230_n111;
  t230_n98: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t230_n104;
  t230_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t230_n101;
  t230_n100: return 0.06420346349477768f;
  t230_n101: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t230_n103;
  t230_n102: return -0.336605966091156f;
  t230_n103: return 0.11886945366859436f;
  t230_n104: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t230_n110;
  t230_n105: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t230_n109;
  t230_n106: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t230_n108;
  t230_n107: return 0.09681470692157745f;
  t230_n108: return -0.12330363690853119f;
  t230_n109: return -0.1304665356874466f;
  t230_n110: return -0.0027551574166864157f;
  t230_n111: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t230_n117;
  t230_n112: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t230_n114;
  t230_n113: return -0.024479741230607033f;
  t230_n114: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t230_n116;
  t230_n115: return 0.15297438204288483f;
  t230_n116: return 0.03553083911538124f;
  t230_n117: return -0.21458065509796143f;
  t230_n118: return 0.018479792401194572f;
  t230_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t230_n169;
  t230_n120: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t230_n154;
  t230_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t230_n153;
  t230_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t230_n130;
  t230_n123: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t230_n125;
  t230_n124: return -0.013301610015332699f;
  t230_n125: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t230_n127;
  t230_n126: return -0.06416908651590347f;
  t230_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t230_n129;
  t230_n128: return 0.014945494942367077f;
  t230_n129: return 0.08946972340345383f;
  t230_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t230_n140;
  t230_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n135;
  t230_n132: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t230_n134;
  t230_n133: return -0.4405210614204407f;
  t230_n134: return -0.02707890421152115f;
  t230_n135: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t230_n137;
  t230_n136: return 0.006203519646078348f;
  t230_n137: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t230_n139;
  t230_n138: return 0.08000630140304565f;
  t230_n139: return -0.10836916416883469f;
  t230_n140: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t230_n152;
  t230_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t230_n147;
  t230_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t230_n146;
  t230_n143: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t230_n145;
  t230_n144: return -0.03425687551498413f;
  t230_n145: return 0.040111470967531204f;
  t230_n146: return 0.016644541174173355f;
  t230_n147: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t230_n151;
  t230_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_DotMemberAccess))) goto t230_n150;
  t230_n149: return 0.04714867100119591f;
  t230_n150: return 0.07195115834474564f;
  t230_n151: return -0.010537962429225445f;
  t230_n152: return 0.020172150805592537f;
  t230_n153: return 0.019728554412722588f;
  t230_n154: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t230_n162;
  t230_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t230_n161;
  t230_n156: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n158;
  t230_n157: return 0.0024275665637105703f;
  t230_n158: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t230_n160;
  t230_n159: return -0.15115578472614288f;
  t230_n160: return 0.11574782431125641f;
  t230_n161: return 0.05199561268091202f;
  t230_n162: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t230_n168;
  t230_n163: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t230_n165;
  t230_n164: return -0.015063953585922718f;
  t230_n165: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t230_n167;
  t230_n166: return -0.016451891511678696f;
  t230_n167: return -0.08468936383724213f;
  t230_n168: return 0.01888909935951233f;
  t230_n169: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t230_n175;
  t230_n170: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t230_n174;
  t230_n171: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t230_n173;
  t230_n172: return 0.0785905197262764f;
  t230_n173: return 0.05003878474235535f;
  t230_n174: return 0.05226927250623703f;
  t230_n175: return -0.030620109289884567f;
  t230_n176: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t230_n254;
  t230_n177: if (E.getNumReferences() >= 3343638400 /*52191.5*/) goto t230_n225;
  t230_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t230_n196;
  t230_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t230_n181;
  t230_n180: return -0.0560782290995121f;
  t230_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t230_n183;
  t230_n182: return -0.003234793432056904f;
  t230_n183: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t230_n191;
  t230_n184: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t230_n190;
  t230_n185: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t230_n187;
  t230_n186: return 0.11469823867082596f;
  t230_n187: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n189;
  t230_n188: return 0.09894530475139618f;
  t230_n189: return 0.053832877427339554f;
  t230_n190: return 0.09909836947917938f;
  t230_n191: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t230_n195;
  t230_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t230_n194;
  t230_n193: return -0.12911589443683624f;
  t230_n194: return 0.0757497251033783f;
  t230_n195: return -0.13953116536140442f;
  t230_n196: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t230_n224;
  t230_n197: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t230_n201;
  t230_n198: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t230_n200;
  t230_n199: return 0.031612787395715714f;
  t230_n200: return -0.02796274796128273f;
  t230_n201: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t230_n221;
  t230_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t230_n212;
  t230_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t230_n207;
  t230_n204: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t230_n206;
  t230_n205: return -0.10218559950590134f;
  t230_n206: return 0.09472520649433136f;
  t230_n207: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t230_n211;
  t230_n208: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t230_n210;
  t230_n209: return 0.11006833612918854f;
  t230_n210: return -0.10933378338813782f;
  t230_n211: return 0.017741011455655098f;
  t230_n212: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n214;
  t230_n213: return -0.26286348700523376f;
  t230_n214: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t230_n218;
  t230_n215: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t230_n217;
  t230_n216: return 0.12425052374601364f;
  t230_n217: return 0.1295604705810547f;
  t230_n218: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t230_n220;
  t230_n219: return 0.1098533496260643f;
  t230_n220: return 0.07893981039524078f;
  t230_n221: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t230_n223;
  t230_n222: return 0.14473600685596466f;
  t230_n223: return 0.1000591292977333f;
  t230_n224: return -0.11130452156066895f;
  t230_n225: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t230_n231;
  t230_n226: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t230_n228;
  t230_n227: return 0.050039779394865036f;
  t230_n228: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t230_n230;
  t230_n229: return -0.22446170449256897f;
  t230_n230: return 0.10837358981370926f;
  t230_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t230_n245;
  t230_n232: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t230_n242;
  t230_n233: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t230_n241;
  t230_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n236;
  t230_n235: return -0.10133535414934158f;
  t230_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t230_n238;
  t230_n237: return 0.0909932404756546f;
  t230_n238: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t230_n240;
  t230_n239: return 0.11197250336408615f;
  t230_n240: return 0.1070016399025917f;
  t230_n241: return -0.02104800008237362f;
  t230_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t230_n244;
  t230_n243: return -0.09993122518062592f;
  t230_n244: return 0.0606209971010685f;
  t230_n245: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t230_n247;
  t230_n246: return -0.051896460354328156f;
  t230_n247: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t230_n253;
  t230_n248: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t230_n252;
  t230_n249: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t230_n251;
  t230_n250: return 0.1129627525806427f;
  t230_n251: return 0.1253780871629715f;
  t230_n252: return 0.10646212100982666f;
  t230_n253: return 0.04699995741248131f;
  t230_n254: return 0.0021298343781381845f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree231(const Example& E) {
  t231_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t231_n130;
  t231_n1: if (E.getNumReferences() >= 3338881664 /*33610.5*/) goto t231_n77;
  t231_n2: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t231_n30;
  t231_n3: if (E.getNumReferences() >= 3338797696 /*33282.5*/) goto t231_n29;
  t231_n4: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t231_n28;
  t231_n5: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t231_n7;
  t231_n6: return 0.0009012313676066697f;
  t231_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t231_n9;
  t231_n8: return 0.00619508558884263f;
  t231_n9: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t231_n27;
  t231_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n26;
  t231_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t231_n13;
  t231_n12: return 0.028381306678056717f;
  t231_n13: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t231_n19;
  t231_n14: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n16;
  t231_n15: return 0.02179938741028309f;
  t231_n16: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t231_n18;
  t231_n17: return -0.14775879681110382f;
  t231_n18: return 0.04747464507818222f;
  t231_n19: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t231_n21;
  t231_n20: return 0.03860820084810257f;
  t231_n21: if (E.getNumReferences() >= 3309017088 /*3001.5*/) goto t231_n23;
  t231_n22: return -0.03336794674396515f;
  t231_n23: if (E.getNumReferences() >= 3310295040 /*3313.5*/) goto t231_n25;
  t231_n24: return 0.12298686802387238f;
  t231_n25: return 0.002288965741172433f;
  t231_n26: return 0.003734458237886429f;
  t231_n27: return -0.030162999406456947f;
  t231_n28: return -0.0008571849321015179f;
  t231_n29: return -0.17032289505004883f;
  t231_n30: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t231_n36;
  t231_n31: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n33;
  t231_n32: return 0.01931159198284149f;
  t231_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t231_n35;
  t231_n34: return 0.052454959601163864f;
  t231_n35: return 0.1021847203373909f;
  t231_n36: if (E.getNumReferences() >= 3338855552 /*33508.5*/) goto t231_n46;
  t231_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t231_n39;
  t231_n38: return 0.09463291615247726f;
  t231_n39: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t231_n41;
  t231_n40: return 0.09625700861215591f;
  t231_n41: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t231_n43;
  t231_n42: return 0.12045193463563919f;
  t231_n43: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t231_n45;
  t231_n44: return 0.11038696020841599f;
  t231_n45: return -0.011528143659234047f;
  t231_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t231_n66;
  t231_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n49;
  t231_n48: return -0.1911729872226715f;
  t231_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n63;
  t231_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n54;
  t231_n51: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t231_n53;
  t231_n52: return -0.10786619037389755f;
  t231_n53: return 0.11895690858364105f;
  t231_n54: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t231_n58;
  t231_n55: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t231_n57;
  t231_n56: return 0.11791300773620605f;
  t231_n57: return -0.01977074146270752f;
  t231_n58: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t231_n60;
  t231_n59: return 0.04230313003063202f;
  t231_n60: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t231_n62;
  t231_n61: return 0.13733558356761932f;
  t231_n62: return 0.08747958391904831f;
  t231_n63: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t231_n65;
  t231_n64: return 0.1361626535654068f;
  t231_n65: return 0.07634949684143066f;
  t231_n66: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t231_n72;
  t231_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n71;
  t231_n68: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t231_n70;
  t231_n69: return 0.17244696617126465f;
  t231_n70: return 0.16950000822544098f;
  t231_n71: return 0.1448960155248642f;
  t231_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n76;
  t231_n73: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n75;
  t231_n74: return -0.10808490961790085f;
  t231_n75: return 0.10921952873468399f;
  t231_n76: return 0.1279817670583725f;
  t231_n77: if (E.getNumReferences() >= 3339031168 /*34194.5*/) goto t231_n79;
  t231_n78: return -0.20501375198364258f;
  t231_n79: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t231_n129;
  t231_n80: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t231_n106;
  t231_n81: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t231_n83;
  t231_n82: return -0.0065123094245791435f;
  t231_n83: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t231_n95;
  t231_n84: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t231_n90;
  t231_n85: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n89;
  t231_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t231_n88;
  t231_n87: return 0.029904965311288834f;
  t231_n88: return 0.08755147457122803f;
  t231_n89: return 0.11236118525266647f;
  t231_n90: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t231_n94;
  t231_n91: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t231_n93;
  t231_n92: return -16.69675636291504f;
  t231_n93: return 0.1014537587761879f;
  t231_n94: return -0.028648225590586662f;
  t231_n95: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t231_n103;
  t231_n96: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t231_n102;
  t231_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t231_n99;
  t231_n98: return 0.09570889919996262f;
  t231_n99: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t231_n101;
  t231_n100: return 0.11410635709762573f;
  t231_n101: return 0.12256407737731934f;
  t231_n102: return 0.07548188418149948f;
  t231_n103: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t231_n105;
  t231_n104: return -0.3149472177028656f;
  t231_n105: return 0.11245398223400116f;
  t231_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n114;
  t231_n107: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n109;
  t231_n108: return -0.07760737836360931f;
  t231_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n113;
  t231_n110: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t231_n112;
  t231_n111: return 0.09866248816251755f;
  t231_n112: return -0.37009701132774353f;
  t231_n113: return -0.2355956733226776f;
  t231_n114: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t231_n120;
  t231_n115: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t231_n119;
  t231_n116: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t231_n118;
  t231_n117: return -0.2086666226387024f;
  t231_n118: return 0.12299884110689163f;
  t231_n119: return -0.03942803293466568f;
  t231_n120: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t231_n126;
  t231_n121: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n125;
  t231_n122: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n124;
  t231_n123: return 0.11385894566774368f;
  t231_n124: return -0.08613656461238861f;
  t231_n125: return -0.03727278485894203f;
  t231_n126: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t231_n128;
  t231_n127: return -0.20136815309524536f;
  t231_n128: return 0.10896818339824677f;
  t231_n129: return -0.09057972580194473f;
  t231_n130: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t231_n254;
  t231_n131: if (E.getNumReferences() >= 3343638400 /*52191.5*/) goto t231_n179;
  t231_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t231_n152;
  t231_n133: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t231_n137;
  t231_n134: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t231_n136;
  t231_n135: return -0.06059994176030159f;
  t231_n136: return -0.21353879570960999f;
  t231_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t231_n139;
  t231_n138: return -0.0027919779531657696f;
  t231_n139: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t231_n147;
  t231_n140: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t231_n146;
  t231_n141: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n143;
  t231_n142: return 0.11334946751594543f;
  t231_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n145;
  t231_n144: return 0.09661832451820374f;
  t231_n145: return 0.05052567645907402f;
  t231_n146: return 0.0961642637848854f;
  t231_n147: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t231_n151;
  t231_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t231_n150;
  t231_n149: return -0.13412067294120789f;
  t231_n150: return 0.06790827959775925f;
  t231_n151: return -0.13605047762393951f;
  t231_n152: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t231_n178;
  t231_n153: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t231_n155;
  t231_n154: return 0.0222114697098732f;
  t231_n155: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t231_n175;
  t231_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t231_n166;
  t231_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t231_n161;
  t231_n158: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n160;
  t231_n159: return -0.10896036028862f;
  t231_n160: return 0.09264113754034042f;
  t231_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t231_n165;
  t231_n162: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t231_n164;
  t231_n163: return 0.1068584993481636f;
  t231_n164: return -0.10839614272117615f;
  t231_n165: return 0.008075808174908161f;
  t231_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n168;
  t231_n167: return -0.24044907093048096f;
  t231_n168: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n172;
  t231_n169: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t231_n171;
  t231_n170: return 0.1219019815325737f;
  t231_n171: return 0.12660382688045502f;
  t231_n172: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t231_n174;
  t231_n173: return 0.10994135588407516f;
  t231_n174: return 0.07584599405527115f;
  t231_n175: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t231_n177;
  t231_n176: return 0.13801875710487366f;
  t231_n177: return 0.10005316138267517f;
  t231_n178: return -0.11054067313671112f;
  t231_n179: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t231_n227;
  t231_n180: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t231_n224;
  t231_n181: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t231_n183;
  t231_n182: return -0.11090686172246933f;
  t231_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t231_n217;
  t231_n184: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n186;
  t231_n185: return 0.0014131860807538033f;
  t231_n186: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t231_n210;
  t231_n187: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t231_n189;
  t231_n188: return 1.5974023342132568f;
  t231_n189: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t231_n203;
  t231_n190: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t231_n194;
  t231_n191: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t231_n193;
  t231_n192: return 0.12295616418123245f;
  t231_n193: return -0.15749847888946533f;
  t231_n194: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t231_n200;
  t231_n195: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t231_n199;
  t231_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t231_n198;
  t231_n197: return 0.11173875629901886f;
  t231_n198: return 0.08985140919685364f;
  t231_n199: return 0.012673157267272472f;
  t231_n200: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t231_n202;
  t231_n201: return -0.19257064163684845f;
  t231_n202: return 0.10517048835754395f;
  t231_n203: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t231_n205;
  t231_n204: return 0.05812850967049599f;
  t231_n205: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t231_n209;
  t231_n206: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t231_n208;
  t231_n207: return -0.13885675370693207f;
  t231_n208: return 0.1257636547088623f;
  t231_n209: return -0.1169593334197998f;
  t231_n210: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n212;
  t231_n211: return -0.03505382314324379f;
  t231_n212: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t231_n214;
  t231_n213: return 0.10101723670959473f;
  t231_n214: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t231_n216;
  t231_n215: return 0.11903303116559982f;
  t231_n216: return -0.05713518708944321f;
  t231_n217: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t231_n219;
  t231_n218: return -0.10716363787651062f;
  t231_n219: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t231_n223;
  t231_n220: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t231_n222;
  t231_n221: return 0.09887635707855225f;
  t231_n222: return 0.10894297063350677f;
  t231_n223: return 0.02390589751303196f;
  t231_n224: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t231_n226;
  t231_n225: return -0.1805730015039444f;
  t231_n226: return 0.10760954767465591f;
  t231_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t231_n245;
  t231_n228: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t231_n238;
  t231_n229: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n237;
  t231_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n232;
  t231_n231: return -0.10120993107557297f;
  t231_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t231_n234;
  t231_n233: return 0.08895883709192276f;
  t231_n234: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t231_n236;
  t231_n235: return 0.10963042825460434f;
  t231_n236: return 0.10501892864704132f;
  t231_n237: return -0.019083362072706223f;
  t231_n238: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n244;
  t231_n239: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t231_n243;
  t231_n240: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t231_n242;
  t231_n241: return 0.19672761857509613f;
  t231_n242: return 0.053110040724277496f;
  t231_n243: return -0.02231592684984207f;
  t231_n244: return 0.07625479251146317f;
  t231_n245: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t231_n247;
  t231_n246: return -0.04719622805714607f;
  t231_n247: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n253;
  t231_n248: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t231_n252;
  t231_n249: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t231_n251;
  t231_n250: return 0.1097479909658432f;
  t231_n251: return 0.12170543521642685f;
  t231_n252: return 0.10350647568702698f;
  t231_n253: return 0.03925583139061928f;
  t231_n254: return 0.002021051710471511f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree232(const Example& E) {
  t232_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t232_n2;
  t232_n1: return -0.0002175923145841807f;
  t232_n2: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t232_n68;
  t232_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t232_n13;
  t232_n4: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t232_n6;
  t232_n5: return 0.013351277448236942f;
  t232_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t232_n12;
  t232_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t232_n9;
  t232_n8: return -0.10576687008142471f;
  t232_n9: if (E.getNumReferences() >= 3332800000 /*21311.0*/) goto t232_n11;
  t232_n10: return -0.527614951133728f;
  t232_n11: return 0.10669150203466415f;
  t232_n12: return 0.03513042628765106f;
  t232_n13: if (E.getNumReferences() >= 3332305408 /*20345.0*/) goto t232_n67;
  t232_n14: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t232_n58;
  t232_n15: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t232_n37;
  t232_n16: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t232_n28;
  t232_n17: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t232_n19;
  t232_n18: return 0.04416775330901146f;
  t232_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t232_n27;
  t232_n20: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t232_n22;
  t232_n21: return -0.19285982847213745f;
  t232_n22: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t232_n26;
  t232_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t232_n25;
  t232_n24: return 0.11460813134908676f;
  t232_n25: return 0.21841853857040405f;
  t232_n26: return -0.003321316558867693f;
  t232_n27: return 0.1014443039894104f;
  t232_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t232_n36;
  t232_n29: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t232_n31;
  t232_n30: return -0.2223345935344696f;
  t232_n31: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t232_n35;
  t232_n32: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t232_n34;
  t232_n33: return 0.10391656309366226f;
  t232_n34: return 0.11046796292066574f;
  t232_n35: return 0.10151181370019913f;
  t232_n36: return 0.017036404460668564f;
  t232_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t232_n39;
  t232_n38: return -0.08534416556358337f;
  t232_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t232_n49;
  t232_n40: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t232_n48;
  t232_n41: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t232_n43;
  t232_n42: return -0.07203520089387894f;
  t232_n43: if (E.getNumReferences() >= 3332040448 /*19827.5*/) goto t232_n45;
  t232_n44: return -0.3233402967453003f;
  t232_n45: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t232_n47;
  t232_n46: return 0.039011433720588684f;
  t232_n47: return 0.1364465206861496f;
  t232_n48: return -0.3571794331073761f;
  t232_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t232_n55;
  t232_n50: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t232_n52;
  t232_n51: return 0.0522361695766449f;
  t232_n52: if (E.getNumReferences() >= 3332040448 /*19827.5*/) goto t232_n54;
  t232_n53: return 0.11752546578645706f;
  t232_n54: return 0.03923153132200241f;
  t232_n55: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t232_n57;
  t232_n56: return 0.11188330501317978f;
  t232_n57: return 0.10663135349750519f;
  t232_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t232_n60;
  t232_n59: return 0.1768517643213272f;
  t232_n60: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t232_n64;
  t232_n61: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t232_n63;
  t232_n62: return -0.2021108716726303f;
  t232_n63: return 0.15252265334129333f;
  t232_n64: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t232_n66;
  t232_n65: return 0.12759356200695038f;
  t232_n66: return 0.09905426949262619f;
  t232_n67: return 0.022088568657636642f;
  t232_n68: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t232_n156;
  t232_n69: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t232_n109;
  t232_n70: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t232_n72;
  t232_n71: return -0.01908307895064354f;
  t232_n72: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t232_n80;
  t232_n73: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t232_n79;
  t232_n74: if (E.getNumReferences() >= 3334924800 /*25461.0*/) goto t232_n76;
  t232_n75: return -0.20799237489700317f;
  t232_n76: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t232_n78;
  t232_n77: return 0.16065415740013123f;
  t232_n78: return -0.11513452231884003f;
  t232_n79: return -0.050117213279008865f;
  t232_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t232_n82;
  t232_n81: return -0.2065330296754837f;
  t232_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t232_n84;
  t232_n83: return -0.005014016292989254f;
  t232_n84: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t232_n100;
  t232_n85: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t232_n87;
  t232_n86: return 0.10986679792404175f;
  t232_n87: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t232_n99;
  t232_n88: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t232_n98;
  t232_n89: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t232_n93;
  t232_n90: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t232_n92;
  t232_n91: return 0.04881748929619789f;
  t232_n92: return 0.09828509390354156f;
  t232_n93: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t232_n95;
  t232_n94: return 0.08941129595041275f;
  t232_n95: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t232_n97;
  t232_n96: return -0.126066192984581f;
  t232_n97: return 0.09164924919605255f;
  t232_n98: return -0.5337142944335938f;
  t232_n99: return -0.4070860743522644f;
  t232_n100: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t232_n102;
  t232_n101: return -0.025112923234701157f;
  t232_n102: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t232_n106;
  t232_n103: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t232_n105;
  t232_n104: return 0.07353940606117249f;
  t232_n105: return 0.09080211073160172f;
  t232_n106: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t232_n108;
  t232_n107: return 0.08144137263298035f;
  t232_n108: return -0.42888325452804565f;
  t232_n109: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t232_n153;
  t232_n110: if (E.getNumReferences() >= 3338024448 /*31515.0*/) goto t232_n148;
  t232_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t232_n127;
  t232_n112: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t232_n118;
  t232_n113: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t232_n115;
  t232_n114: return 0.10419655591249466f;
  t232_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t232_n117;
  t232_n116: return -0.029604805633425713f;
  t232_n117: return 0.1069948598742485f;
  t232_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t232_n126;
  t232_n119: if (E.getNumReferences() >= 3336972544 /*29460.5*/) goto t232_n123;
  t232_n120: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t232_n122;
  t232_n121: return -0.5102341771125793f;
  t232_n122: return -0.3265434205532074f;
  t232_n123: if (E.getNumReferences() >= 3337362176 /*30221.5*/) goto t232_n125;
  t232_n124: return 0.07568149268627167f;
  t232_n125: return -0.17462517321109772f;
  t232_n126: return -0.05886850878596306f;
  t232_n127: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t232_n129;
  t232_n128: return -0.10588689893484116f;
  t232_n129: if (E.getNumReferences() >= 3334778368 /*25175.0*/) goto t232_n131;
  t232_n130: return -0.04704712703824043f;
  t232_n131: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t232_n135;
  t232_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t232_n134;
  t232_n133: return 0.05607692897319794f;
  t232_n134: return 0.24042171239852905f;
  t232_n135: if (E.getNumReferences() >= 3336787456 /*29099.0*/) goto t232_n145;
  t232_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t232_n138;
  t232_n137: return -0.018560878932476044f;
  t232_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t232_n140;
  t232_n139: return -0.02819335088133812f;
  t232_n140: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t232_n144;
  t232_n141: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t232_n143;
  t232_n142: return 0.09885057806968689f;
  t232_n143: return -0.1454131156206131f;
  t232_n144: return 0.10690402239561081f;
  t232_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t232_n147;
  t232_n146: return 0.06556006520986557f;
  t232_n147: return 0.10866563022136688f;
  t232_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t232_n150;
  t232_n149: return -0.3831841051578522f;
  t232_n150: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t232_n152;
  t232_n151: return 0.06590266525745392f;
  t232_n152: return 0.10224578529596329f;
  t232_n153: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t232_n155;
  t232_n154: return 0.06898240000009537f;
  t232_n155: return -0.13598299026489258f;
  t232_n156: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t232_n158;
  t232_n157: return -0.021570244804024696f;
  t232_n158: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t232_n254;
  t232_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t232_n193;
  t232_n160: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t232_n162;
  t232_n161: return 0.00762323709204793f;
  t232_n162: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t232_n172;
  t232_n163: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t232_n167;
  t232_n164: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t232_n166;
  t232_n165: return 0.014726178720593452f;
  t232_n166: return 0.05899772047996521f;
  t232_n167: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t232_n169;
  t232_n168: return 0.028113756328821182f;
  t232_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t232_n171;
  t232_n170: return 0.059232816100120544f;
  t232_n171: return 0.04861968755722046f;
  t232_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t232_n174;
  t232_n173: return -0.004770119208842516f;
  t232_n174: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t232_n188;
  t232_n175: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t232_n177;
  t232_n176: return 0.05562581866979599f;
  t232_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t232_n187;
  t232_n178: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t232_n186;
  t232_n179: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t232_n183;
  t232_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t232_n182;
  t232_n181: return 0.06051088124513626f;
  t232_n182: return 0.08405157178640366f;
  t232_n183: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t232_n185;
  t232_n184: return 0.11275716125965118f;
  t232_n185: return -0.41546744108200073f;
  t232_n186: return 0.009930022992193699f;
  t232_n187: return 0.024009421467781067f;
  t232_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t232_n190;
  t232_n189: return 0.04968545213341713f;
  t232_n190: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t232_n192;
  t232_n191: return 0.1029479131102562f;
  t232_n192: return 0.10123127698898315f;
  t232_n193: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t232_n195;
  t232_n194: return -0.041376274079084396f;
  t232_n195: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t232_n235;
  t232_n196: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t232_n218;
  t232_n197: if (E.getNumReferences() >= 3340138112 /*38518.5*/) goto t232_n199;
  t232_n198: return -0.04374891519546509f;
  t232_n199: if (E.getNumReferences() >= 3340748416 /*40902.5*/) goto t232_n203;
  t232_n200: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t232_n202;
  t232_n201: return -0.10479623824357986f;
  t232_n202: return 0.5461077690124512f;
  t232_n203: if (E.getNumReferences() >= 3355687776 /*134893.5*/) goto t232_n217;
  t232_n204: if (E.getNumReferences() >= 3354956672 /*127271.0*/) goto t232_n212;
  t232_n205: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t232_n211;
  t232_n206: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t232_n208;
  t232_n207: return 0.04564337804913521f;
  t232_n208: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t232_n210;
  t232_n209: return 0.2094457596540451f;
  t232_n210: return 0.10663723945617676f;
  t232_n211: return -0.1394236832857132f;
  t232_n212: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t232_n216;
  t232_n213: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t232_n215;
  t232_n214: return -0.11440254002809525f;
  t232_n215: return 0.13331559300422668f;
  t232_n216: return -0.13223040103912354f;
  t232_n217: return -0.10879696160554886f;
  t232_n218: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t232_n222;
  t232_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t232_n221;
  t232_n220: return 0.09925760328769684f;
  t232_n221: return 0.05555868521332741f;
  t232_n222: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t232_n228;
  t232_n223: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t232_n225;
  t232_n224: return -0.14578159153461456f;
  t232_n225: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t232_n227;
  t232_n226: return -0.12822267413139343f;
  t232_n227: return 0.09625118970870972f;
  t232_n228: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t232_n230;
  t232_n229: return -0.10124228894710541f;
  t232_n230: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t232_n234;
  t232_n231: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t232_n233;
  t232_n232: return 0.09607437998056412f;
  t232_n233: return 0.040990691632032394f;
  t232_n234: return -0.0339815728366375f;
  t232_n235: if (E.getNumReferences() >= 3338881664 /*33610.5*/) goto t232_n245;
  t232_n236: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t232_n244;
  t232_n237: if (E.getNumReferences() >= 3338765056 /*33155.0*/) goto t232_n239;
  t232_n238: return -0.7941709756851196f;
  t232_n239: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t232_n241;
  t232_n240: return 0.11719724535942078f;
  t232_n241: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t232_n243;
  t232_n242: return 0.06299874931573868f;
  t232_n243: return 0.1077769547700882f;
  t232_n244: return 0.12481680512428284f;
  t232_n245: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t232_n251;
  t232_n246: if (E.getNumReferences() >= 3340945792 /*41673.5*/) goto t232_n248;
  t232_n247: return -0.1479800045490265f;
  t232_n248: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t232_n250;
  t232_n249: return -0.00164173380471766f;
  t232_n250: return -0.09719032794237137f;
  t232_n251: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t232_n253;
  t232_n252: return 0.02928837575018406f;
  t232_n253: return 0.07410646975040436f;
  t232_n254: return -0.0045210616663098335f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree233(const Example& E) {
  t233_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t233_n144;
  t233_n1: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t233_n3;
  t233_n2: return -0.0005938521353527904f;
  t233_n3: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t233_n85;
  t233_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t233_n12;
  t233_n5: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t233_n7;
  t233_n6: return 0.011752794496715069f;
  t233_n7: if (E.getNumReferences() >= 3334111488 /*23872.5*/) goto t233_n9;
  t233_n8: return 0.02771328203380108f;
  t233_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t233_n11;
  t233_n10: return 0.04685702174901962f;
  t233_n11: return 0.08852212876081467f;
  t233_n12: if (E.getNumReferences() >= 3332305408 /*20345.0*/) goto t233_n58;
  t233_n13: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t233_n49;
  t233_n14: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t233_n48;
  t233_n15: if (E.getNumReferences() >= 3332205568 /*20150.0*/) goto t233_n47;
  t233_n16: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t233_n18;
  t233_n17: return 0.03747617453336716f;
  t233_n18: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t233_n28;
  t233_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n27;
  t233_n20: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t233_n22;
  t233_n21: return -0.2004418522119522f;
  t233_n22: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t233_n26;
  t233_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t233_n25;
  t233_n24: return 0.10354270786046982f;
  t233_n25: return 0.1084311380982399f;
  t233_n26: return 0.09928238391876221f;
  t233_n27: return 0.007918983697891235f;
  t233_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t233_n30;
  t233_n29: return -0.02434728667140007f;
  t233_n30: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t233_n38;
  t233_n31: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t233_n33;
  t233_n32: return -0.06636527925729752f;
  t233_n33: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t233_n35;
  t233_n34: return -0.01093908492475748f;
  t233_n35: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t233_n37;
  t233_n36: return 0.11811843514442444f;
  t233_n37: return -0.29938235878944397f;
  t233_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t233_n44;
  t233_n39: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t233_n41;
  t233_n40: return 0.04895352944731712f;
  t233_n41: if (E.getNumReferences() >= 3332040448 /*19827.5*/) goto t233_n43;
  t233_n42: return 0.11669766902923584f;
  t233_n43: return 0.03666568174958229f;
  t233_n44: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t233_n46;
  t233_n45: return 0.10216780006885529f;
  t233_n46: return 0.10581912845373154f;
  t233_n47: return -0.1896388679742813f;
  t233_n48: return 0.026960918679833412f;
  t233_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t233_n51;
  t233_n50: return 0.15134292840957642f;
  t233_n51: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t233_n55;
  t233_n52: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t233_n54;
  t233_n53: return -0.206853985786438f;
  t233_n54: return 0.14843876659870148f;
  t233_n55: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t233_n57;
  t233_n56: return 0.12209930270910263f;
  t233_n57: return 0.09689514338970184f;
  t233_n58: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t233_n84;
  t233_n59: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t233_n61;
  t233_n60: return 0.03237846493721008f;
  t233_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t233_n63;
  t233_n62: return -0.2664927542209625f;
  t233_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t233_n81;
  t233_n64: if (E.getNumReferences() >= 3333319168 /*22325.0*/) goto t233_n70;
  t233_n65: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t233_n67;
  t233_n66: return -0.07484520971775055f;
  t233_n67: if (E.getNumReferences() >= 3332469248 /*20665.0*/) goto t233_n69;
  t233_n68: return 0.25090736150741577f;
  t233_n69: return -0.8357316255569458f;
  t233_n70: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t233_n78;
  t233_n71: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n73;
  t233_n72: return -0.10504280030727386f;
  t233_n73: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t233_n77;
  t233_n74: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t233_n76;
  t233_n75: return 0.14008572697639465f;
  t233_n76: return 0.08525371551513672f;
  t233_n77: return -0.010825074277818203f;
  t233_n78: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t233_n80;
  t233_n79: return 0.0858515202999115f;
  t233_n80: return -0.3088398277759552f;
  t233_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n83;
  t233_n82: return 0.137326180934906f;
  t233_n83: return 0.06173580884933472f;
  t233_n84: return 0.016018282622098923f;
  t233_n85: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t233_n143;
  t233_n86: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t233_n88;
  t233_n87: return -0.017152998596429825f;
  t233_n88: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t233_n134;
  t233_n89: if (E.getNumReferences() >= 3338024448 /*31515.0*/) goto t233_n131;
  t233_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t233_n98;
  t233_n91: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t233_n97;
  t233_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t233_n94;
  t233_n93: return -0.4919912815093994f;
  t233_n94: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t233_n96;
  t233_n95: return 0.10837584733963013f;
  t233_n96: return 0.04076884686946869f;
  t233_n97: return -0.0767202377319336f;
  t233_n98: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t233_n100;
  t233_n99: return -0.08820342272520065f;
  t233_n100: if (E.getNumReferences() >= 3334778368 /*25175.0*/) goto t233_n102;
  t233_n101: return -0.033321984112262726f;
  t233_n102: if (E.getNumReferences() >= 3334835456 /*25286.5*/) goto t233_n108;
  t233_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t233_n105;
  t233_n104: return -0.5333085060119629f;
  t233_n105: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t233_n107;
  t233_n106: return 0.09999001026153564f;
  t233_n107: return 0.0028470128308981657f;
  t233_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t233_n110;
  t233_n109: return 0.015066242776811123f;
  t233_n110: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t233_n130;
  t233_n111: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t233_n129;
  t233_n112: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t233_n118;
  t233_n113: if (E.getNumReferences() >= 3336242944 /*28035.5*/) goto t233_n115;
  t233_n114: return -0.18377794325351715f;
  t233_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t233_n117;
  t233_n116: return -0.24384310841560364f;
  t233_n117: return 0.09930337220430374f;
  t233_n118: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t233_n128;
  t233_n119: if (E.getNumReferences() >= 3334963456 /*25536.5*/) goto t233_n121;
  t233_n120: return -0.11101038753986359f;
  t233_n121: if (E.getNumReferences() >= 3335557632 /*26697.0*/) goto t233_n123;
  t233_n122: return 0.1016603335738182f;
  t233_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t233_n127;
  t233_n124: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t233_n126;
  t233_n125: return -0.0016548112034797668f;
  t233_n126: return 0.09737895429134369f;
  t233_n127: return 0.18110710382461548f;
  t233_n128: return 0.03149963542819023f;
  t233_n129: return -0.18441839516162872f;
  t233_n130: return -0.029339905828237534f;
  t233_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t233_n133;
  t233_n132: return -0.34630918502807617f;
  t233_n133: return 0.06326786428689957f;
  t233_n134: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t233_n136;
  t233_n135: return 0.06590069830417633f;
  t233_n136: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t233_n142;
  t233_n137: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t233_n141;
  t233_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t233_n140;
  t233_n139: return -1.0510250329971313f;
  t233_n140: return -0.19751206040382385f;
  t233_n141: return -0.18893134593963623f;
  t233_n142: return -0.019309530034661293f;
  t233_n143: return 0.004704170394688845f;
  t233_n144: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t233_n254;
  t233_n145: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t233_n251;
  t233_n146: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t233_n248;
  t233_n147: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t233_n169;
  t233_n148: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t233_n150;
  t233_n149: return -0.38432809710502625f;
  t233_n150: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t233_n164;
  t233_n151: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t233_n163;
  t233_n152: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t233_n162;
  t233_n153: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t233_n159;
  t233_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t233_n156;
  t233_n155: return -0.023091452196240425f;
  t233_n156: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t233_n158;
  t233_n157: return 0.10671047121286392f;
  t233_n158: return 0.1049206405878067f;
  t233_n159: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t233_n161;
  t233_n160: return -0.2375057488679886f;
  t233_n161: return 0.0636105090379715f;
  t233_n162: return -0.2869742214679718f;
  t233_n163: return -0.11038855463266373f;
  t233_n164: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t233_n168;
  t233_n165: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t233_n167;
  t233_n166: return -0.03490452095866203f;
  t233_n167: return -1.4856001138687134f;
  t233_n168: return -0.02099059894680977f;
  t233_n169: if (E.getNumReferences() >= 3323686912 /*9948.0*/) goto t233_n175;
  t233_n170: if (E.getNumReferences() >= 3322915840 /*9195.0*/) goto t233_n174;
  t233_n171: if (E.getNumReferences() >= 3322734080 /*9017.5*/) goto t233_n173;
  t233_n172: return 0.009365562349557877f;
  t233_n173: return 0.10373110324144363f;
  t233_n174: return -0.10950691252946854f;
  t233_n175: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t233_n201;
  t233_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t233_n198;
  t233_n177: if (E.getNumReferences() >= 3327652864 /*13821.0*/) goto t233_n191;
  t233_n178: if (E.getNumReferences() >= 3327370240 /*13545.0*/) goto t233_n190;
  t233_n179: if (E.getNumReferences() >= 3325806080 /*12017.5*/) goto t233_n183;
  t233_n180: if (E.getNumReferences() >= 3325388288 /*11609.5*/) goto t233_n182;
  t233_n181: return 0.07316327840089798f;
  t233_n182: return -0.32573115825653076f;
  t233_n183: if (E.getNumReferences() >= 3326233600 /*12435.0*/) goto t233_n185;
  t233_n184: return 0.07404986768960953f;
  t233_n185: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t233_n187;
  t233_n186: return -0.18325573205947876f;
  t233_n187: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t233_n189;
  t233_n188: return 0.13260243833065033f;
  t233_n189: return -0.22246991097927094f;
  t233_n190: return -0.1369585543870926f;
  t233_n191: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t233_n195;
  t233_n192: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n194;
  t233_n193: return 0.07560700178146362f;
  t233_n194: return 0.0010590020101517439f;
  t233_n195: if (E.getNumReferences() >= 3329677312 /*15798.0*/) goto t233_n197;
  t233_n196: return 0.0920475497841835f;
  t233_n197: return -0.10364165157079697f;
  t233_n198: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t233_n200;
  t233_n199: return 0.10492227971553802f;
  t233_n200: return -0.37957435846328735f;
  t233_n201: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t233_n205;
  t233_n202: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t233_n204;
  t233_n203: return -1.0983994007110596f;
  t233_n204: return -0.05572151020169258f;
  t233_n205: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t233_n223;
  t233_n206: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t233_n220;
  t233_n207: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t233_n217;
  t233_n208: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n216;
  t233_n209: if (E.getNumReferences() >= 3331214848 /*18215.0*/) goto t233_n211;
  t233_n210: return -0.11214805394411087f;
  t233_n211: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t233_n215;
  t233_n212: if (E.getNumReferences() >= 3333870080 /*23401.0*/) goto t233_n214;
  t233_n213: return -0.468962699174881f;
  t233_n214: return 0.07854576408863068f;
  t233_n215: return 0.09656433761119843f;
  t233_n216: return -0.00789732951670885f;
  t233_n217: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t233_n219;
  t233_n218: return 0.12265193462371826f;
  t233_n219: return 0.10525072365999222f;
  t233_n220: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t233_n222;
  t233_n221: return -0.012685306370258331f;
  t233_n222: return 0.09189572185277939f;
  t233_n223: if (E.getNumReferences() >= 3339407360 /*35664.0*/) goto t233_n239;
  t233_n224: if (E.getNumReferences() >= 3333245184 /*22180.5*/) goto t233_n232;
  t233_n225: if (E.getNumReferences() >= 3331678976 /*19121.5*/) goto t233_n227;
  t233_n226: return -0.049094121903181076f;
  t233_n227: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t233_n229;
  t233_n228: return -0.1760498434305191f;
  t233_n229: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t233_n231;
  t233_n230: return 0.12377896159887314f;
  t233_n231: return 0.11554112285375595f;
  t233_n232: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n238;
  t233_n233: if (E.getNumReferences() >= 3334268416 /*24179.0*/) goto t233_n237;
  t233_n234: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t233_n236;
  t233_n235: return -1.450974941253662f;
  t233_n236: return -0.48426318168640137f;
  t233_n237: return -0.06355147808790207f;
  t233_n238: return 0.01714138127863407f;
  t233_n239: if (E.getNumReferences() >= 3340199168 /*38757.0*/) goto t233_n243;
  t233_n240: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n242;
  t233_n241: return 0.08480694144964218f;
  t233_n242: return -0.022976407781243324f;
  t233_n243: if (E.getNumReferences() >= 3341699072 /*44616.0*/) goto t233_n245;
  t233_n244: return -0.7819960117340088f;
  t233_n245: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t233_n247;
  t233_n246: return 0.09866471588611603f;
  t233_n247: return 0.011643914505839348f;
  t233_n248: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t233_n250;
  t233_n249: return 0.15446262061595917f;
  t233_n250: return -0.10897192358970642f;
  t233_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t233_n253;
  t233_n252: return -0.10347583144903183f;
  t233_n253: return 0.006042052526026964f;
  t233_n254: return -0.00027679899358190596f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree234(const Example& E) {
  t234_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t234_n2;
  t234_n1: return -0.0010641446569934487f;
  t234_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t234_n30;
  t234_n3: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t234_n19;
  t234_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t234_n12;
  t234_n5: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t234_n7;
  t234_n6: return -0.01111754309386015f;
  t234_n7: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t234_n11;
  t234_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n10;
  t234_n9: return 0.06572400778532028f;
  t234_n10: return 0.01166597381234169f;
  t234_n11: return 0.0048749144189059734f;
  t234_n12: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t234_n14;
  t234_n13: return -0.003200339851900935f;
  t234_n14: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t234_n18;
  t234_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t234_n17;
  t234_n16: return 0.02646108902990818f;
  t234_n17: return 0.04694633185863495f;
  t234_n18: return -0.004244958516210318f;
  t234_n19: if (E.getNumReferences() >= 3364952880 /*297177.5*/) goto t234_n29;
  t234_n20: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t234_n26;
  t234_n21: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t234_n23;
  t234_n22: return 0.0037142287474125624f;
  t234_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t234_n25;
  t234_n24: return 0.09637418389320374f;
  t234_n25: return 0.06635073572397232f;
  t234_n26: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t234_n28;
  t234_n27: return -0.07227066904306412f;
  t234_n28: return 0.039050620049238205f;
  t234_n29: return -0.008722597733139992f;
  t234_n30: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t234_n114;
  t234_n31: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t234_n77;
  t234_n32: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t234_n76;
  t234_n33: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t234_n73;
  t234_n34: if (E.getNumReferences() >= 3263561728 /*67.0*/) goto t234_n60;
  t234_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t234_n37;
  t234_n36: return -0.03231161832809448f;
  t234_n37: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t234_n59;
  t234_n38: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t234_n48;
  t234_n39: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t234_n47;
  t234_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t234_n44;
  t234_n41: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n43;
  t234_n42: return -0.10541443526744843f;
  t234_n43: return 0.03405708819627762f;
  t234_n44: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n46;
  t234_n45: return 0.08433831483125687f;
  t234_n46: return -0.34463417530059814f;
  t234_n47: return -0.2939301133155823f;
  t234_n48: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t234_n52;
  t234_n49: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t234_n51;
  t234_n50: return 0.0909404307603836f;
  t234_n51: return 0.11231893301010132f;
  t234_n52: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t234_n54;
  t234_n53: return -0.02130432054400444f;
  t234_n54: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t234_n58;
  t234_n55: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t234_n57;
  t234_n56: return 0.08969686180353165f;
  t234_n57: return 0.11408265680074692f;
  t234_n58: return 0.021061616018414497f;
  t234_n59: return 0.1854536533355713f;
  t234_n60: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t234_n62;
  t234_n61: return 0.11668667197227478f;
  t234_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t234_n64;
  t234_n63: return -0.016515858471393585f;
  t234_n64: if (E.getNumReferences() >= 3267493888 /*97.0*/) goto t234_n66;
  t234_n65: return 0.09830311685800552f;
  t234_n66: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t234_n68;
  t234_n67: return -0.25196534395217896f;
  t234_n68: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t234_n70;
  t234_n69: return 0.08201935887336731f;
  t234_n70: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t234_n72;
  t234_n71: return -0.6481800079345703f;
  t234_n72: return 0.10095661878585815f;
  t234_n73: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t234_n75;
  t234_n74: return -0.06865804642438889f;
  t234_n75: return -0.003042042488232255f;
  t234_n76: return -0.04528150334954262f;
  t234_n77: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t234_n107;
  t234_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t234_n80;
  t234_n79: return 0.0011337555479258299f;
  t234_n80: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t234_n102;
  t234_n81: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t234_n91;
  t234_n82: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t234_n84;
  t234_n83: return 0.06308375298976898f;
  t234_n84: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n86;
  t234_n85: return 0.03440427407622337f;
  t234_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t234_n88;
  t234_n87: return 0.11465925723314285f;
  t234_n88: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t234_n90;
  t234_n89: return 0.07990569621324539f;
  t234_n90: return 0.11683782935142517f;
  t234_n91: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n99;
  t234_n92: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t234_n96;
  t234_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t234_n95;
  t234_n94: return 0.006473137065768242f;
  t234_n95: return 0.056696195155382156f;
  t234_n96: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t234_n98;
  t234_n97: return -0.017287397757172585f;
  t234_n98: return 0.036060530692338943f;
  t234_n99: if (E.getNumReferences() >= 3366959872 /*359896.0*/) goto t234_n101;
  t234_n100: return 0.008931558579206467f;
  t234_n101: return 0.1278890073299408f;
  t234_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t234_n104;
  t234_n103: return -0.08319851756095886f;
  t234_n104: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t234_n106;
  t234_n105: return 0.008745432831346989f;
  t234_n106: return 0.050278499722480774f;
  t234_n107: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t234_n109;
  t234_n108: return -0.06901729851961136f;
  t234_n109: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n113;
  t234_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t234_n112;
  t234_n111: return -0.13102243840694427f;
  t234_n112: return 0.008894229307770729f;
  t234_n113: return -0.03397110104560852f;
  t234_n114: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t234_n186;
  t234_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t234_n185;
  t234_n116: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t234_n158;
  t234_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t234_n119;
  t234_n118: return -0.01614421419799328f;
  t234_n119: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t234_n149;
  t234_n120: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t234_n146;
  t234_n121: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t234_n143;
  t234_n122: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t234_n142;
  t234_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Type))) goto t234_n135;
  t234_n124: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t234_n128;
  t234_n125: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n127;
  t234_n126: return -0.09395354241132736f;
  t234_n127: return 0.019595304504036903f;
  t234_n128: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t234_n134;
  t234_n129: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t234_n133;
  t234_n130: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t234_n132;
  t234_n131: return 0.05370555445551872f;
  t234_n132: return 0.10285641252994537f;
  t234_n133: return -0.18577730655670166f;
  t234_n134: return -0.0008067915332503617f;
  t234_n135: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t234_n137;
  t234_n136: return 0.05234040319919586f;
  t234_n137: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t234_n141;
  t234_n138: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t234_n140;
  t234_n139: return -0.02181210182607174f;
  t234_n140: return 0.09930787980556488f;
  t234_n141: return 0.12065129727125168f;
  t234_n142: return 0.1258840411901474f;
  t234_n143: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t234_n145;
  t234_n144: return 0.008208034560084343f;
  t234_n145: return -0.10311874002218246f;
  t234_n146: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t234_n148;
  t234_n147: return -0.024082016199827194f;
  t234_n148: return -0.3095194697380066f;
  t234_n149: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t234_n153;
  t234_n150: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t234_n152;
  t234_n151: return 0.10935230553150177f;
  t234_n152: return -0.8407748937606812f;
  t234_n153: if (E.getNumReferences() >= 3305666560 /*2183.5*/) goto t234_n155;
  t234_n154: return -0.04155762866139412f;
  t234_n155: if (E.getNumReferences() >= 3313434624 /*4080.0*/) goto t234_n157;
  t234_n156: return 0.09822956472635269f;
  t234_n157: return 0.04865462705492973f;
  t234_n158: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t234_n168;
  t234_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t234_n163;
  t234_n160: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t234_n162;
  t234_n161: return -0.02010677382349968f;
  t234_n162: return -0.08062451332807541f;
  t234_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t234_n165;
  t234_n164: return 0.005868602078408003f;
  t234_n165: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t234_n167;
  t234_n166: return 0.1339205950498581f;
  t234_n167: return 0.012874465435743332f;
  t234_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t234_n184;
  t234_n169: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t234_n183;
  t234_n170: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t234_n172;
  t234_n171: return 0.011560493148863316f;
  t234_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t234_n174;
  t234_n173: return -0.21194028854370117f;
  t234_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t234_n180;
  t234_n175: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t234_n179;
  t234_n176: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t234_n178;
  t234_n177: return 0.0007044454687274992f;
  t234_n178: return 0.11866720765829086f;
  t234_n179: return 0.018499203026294708f;
  t234_n180: if (E.getNumReferences() >= 3272179712 /*137.5*/) goto t234_n182;
  t234_n181: return 0.11911056190729141f;
  t234_n182: return -0.1852056235074997f;
  t234_n183: return -0.014004210010170937f;
  t234_n184: return 0.031970374286174774f;
  t234_n185: return 0.014202316291630268f;
  t234_n186: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t234_n250;
  t234_n187: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t234_n241;
  t234_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t234_n240;
  t234_n189: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t234_n207;
  t234_n190: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t234_n204;
  t234_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t234_n197;
  t234_n192: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t234_n196;
  t234_n193: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t234_n195;
  t234_n194: return -0.07281878590583801f;
  t234_n195: return 0.057040221989154816f;
  t234_n196: return -0.11314134299755096f;
  t234_n197: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t234_n199;
  t234_n198: return -0.24730738997459412f;
  t234_n199: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t234_n203;
  t234_n200: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t234_n202;
  t234_n201: return -0.4125252962112427f;
  t234_n202: return 0.1022844985127449f;
  t234_n203: return -0.7334324717521667f;
  t234_n204: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t234_n206;
  t234_n205: return -0.05168270319700241f;
  t234_n206: return 0.07568979263305664f;
  t234_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t234_n237;
  t234_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t234_n230;
  t234_n209: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t234_n221;
  t234_n210: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t234_n212;
  t234_n211: return 0.0032323964405804873f;
  t234_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t234_n214;
  t234_n213: return 0.01843658648431301f;
  t234_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t234_n216;
  t234_n215: return -0.20223072171211243f;
  t234_n216: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t234_n220;
  t234_n217: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t234_n219;
  t234_n218: return 0.13318543136119843f;
  t234_n219: return 0.22076627612113953f;
  t234_n220: return 0.08705823123455048f;
  t234_n221: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t234_n225;
  t234_n222: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t234_n224;
  t234_n223: return -0.024399301037192345f;
  t234_n224: return -0.1980247050523758f;
  t234_n225: if (E.getNumReferences() >= 3273424896 /*156.5*/) goto t234_n227;
  t234_n226: return -0.0841427892446518f;
  t234_n227: if (E.getNumReferences() >= 3279290368 /*246.0*/) goto t234_n229;
  t234_n228: return 0.08472174406051636f;
  t234_n229: return -0.018170202150940895f;
  t234_n230: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t234_n232;
  t234_n231: return 0.008128178305923939f;
  t234_n232: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t234_n234;
  t234_n233: return -0.011393863707780838f;
  t234_n234: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t234_n236;
  t234_n235: return 0.10887526720762253f;
  t234_n236: return -0.7164533734321594f;
  t234_n237: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t234_n239;
  t234_n238: return 0.023766275495290756f;
  t234_n239: return -0.0022357471752911806f;
  t234_n240: return 0.005250841844826937f;
  t234_n241: if (E.getNumReferences() >= 3346171648 /*62087.0*/) goto t234_n249;
  t234_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t234_n248;
  t234_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t234_n245;
  t234_n244: return -0.043395694345235825f;
  t234_n245: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t234_n247;
  t234_n246: return 0.09269299358129501f;
  t234_n247: return 0.04359079524874687f;
  t234_n248: return 0.10569348931312561f;
  t234_n249: return 0.012111459858715534f;
  t234_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t234_n254;
  t234_n251: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t234_n253;
  t234_n252: return -0.04753834754228592f;
  t234_n253: return 0.0026990517508238554f;
  t234_n254: return -0.0028170200530439615f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree235(const Example& E) {
  t235_n0: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t235_n2;
  t235_n1: return -0.0016964878886938095f;
  t235_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t235_n4;
  t235_n3: return -0.0004847196687478572f;
  t235_n4: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t235_n246;
  t235_n5: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t235_n15;
  t235_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t235_n12;
  t235_n7: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n9;
  t235_n8: return -0.002193744294345379f;
  t235_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n11;
  t235_n10: return -0.009936890564858913f;
  t235_n11: return -0.002969286637380719f;
  t235_n12: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t235_n14;
  t235_n13: return -0.005930924788117409f;
  t235_n14: return 0.006817126180976629f;
  t235_n15: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t235_n143;
  t235_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t235_n132;
  t235_n17: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t235_n85;
  t235_n18: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t235_n44;
  t235_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t235_n23;
  t235_n20: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n22;
  t235_n21: return -0.01780949905514717f;
  t235_n22: return -0.03894011676311493f;
  t235_n23: if (E.getNumReferences() >= 3279028224 /*242.0*/) goto t235_n35;
  t235_n24: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t235_n32;
  t235_n25: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t235_n29;
  t235_n26: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t235_n28;
  t235_n27: return 0.026560338214039803f;
  t235_n28: return 0.09051056951284409f;
  t235_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t235_n31;
  t235_n30: return -2.0699143409729004f;
  t235_n31: return -0.4000582993030548f;
  t235_n32: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t235_n34;
  t235_n33: return -0.06546232104301453f;
  t235_n34: return 0.01699988543987274f;
  t235_n35: if (E.getNumReferences() >= 3292487680 /*765.5*/) goto t235_n41;
  t235_n36: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t235_n38;
  t235_n37: return 0.07030005007982254f;
  t235_n38: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t235_n40;
  t235_n39: return 0.024904832243919373f;
  t235_n40: return 0.12278055399656296f;
  t235_n41: if (E.getNumReferences() >= 3293552640 /*830.5*/) goto t235_n43;
  t235_n42: return -0.7906782627105713f;
  t235_n43: return 0.04775385186076164f;
  t235_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t235_n66;
  t235_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n47;
  t235_n46: return -0.06871769577264786f;
  t235_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t235_n55;
  t235_n48: if (E.getNumReferences() >= 3307462656 /*2622.0*/) goto t235_n50;
  t235_n49: return -0.029296724125742912f;
  t235_n50: if (E.getNumReferences() >= 3312713728 /*3904.0*/) goto t235_n54;
  t235_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t235_n53;
  t235_n52: return 0.06635088473558426f;
  t235_n53: return 0.11519208550453186f;
  t235_n54: return 0.03867905214428902f;
  t235_n55: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t235_n65;
  t235_n56: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t235_n64;
  t235_n57: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t235_n63;
  t235_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n62;
  t235_n59: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t235_n61;
  t235_n60: return 0.06757719069719315f;
  t235_n61: return 0.10275302082300186f;
  t235_n62: return 0.09534895420074463f;
  t235_n63: return 0.02615673653781414f;
  t235_n64: return -0.2559110224246979f;
  t235_n65: return -0.07736318558454514f;
  t235_n66: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t235_n84;
  t235_n67: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t235_n71;
  t235_n68: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t235_n70;
  t235_n69: return 0.01858699321746826f;
  t235_n70: return 0.11028186231851578f;
  t235_n71: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t235_n75;
  t235_n72: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t235_n74;
  t235_n73: return 0.116029292345047f;
  t235_n74: return 0.09092079102993011f;
  t235_n75: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t235_n77;
  t235_n76: return -0.012631651014089584f;
  t235_n77: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t235_n81;
  t235_n78: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t235_n80;
  t235_n79: return -1.2225909233093262f;
  t235_n80: return 0.10112662613391876f;
  t235_n81: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t235_n83;
  t235_n82: return -0.11805037409067154f;
  t235_n83: return 0.07770910859107971f;
  t235_n84: return 0.033351462334394455f;
  t235_n85: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t235_n97;
  t235_n86: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t235_n88;
  t235_n87: return 0.015576930716633797f;
  t235_n88: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n92;
  t235_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n91;
  t235_n90: return -0.3781226575374603f;
  t235_n91: return -0.026370586827397346f;
  t235_n92: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t235_n94;
  t235_n93: return -0.21431861817836761f;
  t235_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t235_n96;
  t235_n95: return -0.031907819211483f;
  t235_n96: return 0.1623108983039856f;
  t235_n97: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t235_n119;
  t235_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t235_n118;
  t235_n99: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n101;
  t235_n100: return -0.0048116096295416355f;
  t235_n101: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t235_n109;
  t235_n102: if (E.getNumReferences() >= 3367651744 /*381517.0*/) goto t235_n108;
  t235_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t235_n105;
  t235_n104: return -0.0036206713411957026f;
  t235_n105: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t235_n107;
  t235_n106: return 0.09483110904693604f;
  t235_n107: return -0.11223690956830978f;
  t235_n108: return -0.8855460286140442f;
  t235_n109: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t235_n111;
  t235_n110: return -0.4161752760410309f;
  t235_n111: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t235_n117;
  t235_n112: if (E.getNumReferences() >= 3367651744 /*381517.0*/) goto t235_n114;
  t235_n113: return 0.049457233399152756f;
  t235_n114: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t235_n116;
  t235_n115: return -1.2128745317459106f;
  t235_n116: return 0.05999613553285599f;
  t235_n117: return -0.10053097456693649f;
  t235_n118: return 0.02401733584702015f;
  t235_n119: if (E.getNumReferences() >= 3362744896 /*245161.0*/) goto t235_n131;
  t235_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t235_n122;
  t235_n121: return 0.07191532105207443f;
  t235_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n130;
  t235_n123: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t235_n129;
  t235_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t235_n126;
  t235_n125: return -0.1092785894870758f;
  t235_n126: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t235_n128;
  t235_n127: return 0.023328006267547607f;
  t235_n128: return 0.08988340198993683f;
  t235_n129: return 0.11167822778224945f;
  t235_n130: return -0.7367027997970581f;
  t235_n131: return -0.008574661798775196f;
  t235_n132: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t235_n140;
  t235_n133: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n137;
  t235_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n136;
  t235_n135: return -0.032365262508392334f;
  t235_n136: return 0.0722571611404419f;
  t235_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n139;
  t235_n138: return -0.01386462152004242f;
  t235_n139: return 0.05044139176607132f;
  t235_n140: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t235_n142;
  t235_n141: return -0.005197540856897831f;
  t235_n142: return 0.01247369684278965f;
  t235_n143: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t235_n203;
  t235_n144: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t235_n196;
  t235_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t235_n151;
  t235_n146: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t235_n148;
  t235_n147: return 0.0006042178720235825f;
  t235_n148: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t235_n150;
  t235_n149: return -0.5456435084342957f;
  t235_n150: return -0.2044491022825241f;
  t235_n151: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t235_n195;
  t235_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t235_n176;
  t235_n153: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t235_n175;
  t235_n154: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t235_n170;
  t235_n155: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t235_n157;
  t235_n156: return -0.0013598862569779158f;
  t235_n157: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t235_n169;
  t235_n158: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t235_n162;
  t235_n159: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t235_n161;
  t235_n160: return 0.09541548043489456f;
  t235_n161: return 0.11100815236568451f;
  t235_n162: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t235_n164;
  t235_n163: return -0.14344114065170288f;
  t235_n164: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t235_n168;
  t235_n165: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t235_n167;
  t235_n166: return 0.05894634127616882f;
  t235_n167: return 0.11783327162265778f;
  t235_n168: return -0.15004995465278625f;
  t235_n169: return 0.022614311426877975f;
  t235_n170: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t235_n174;
  t235_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n173;
  t235_n172: return -0.11638084053993225f;
  t235_n173: return -0.04670265316963196f;
  t235_n174: return 0.025480138137936592f;
  t235_n175: return -0.035222165286540985f;
  t235_n176: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t235_n186;
  t235_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n185;
  t235_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n182;
  t235_n179: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t235_n181;
  t235_n180: return 0.003316278802230954f;
  t235_n181: return -0.2719312906265259f;
  t235_n182: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t235_n184;
  t235_n183: return -0.35100609064102173f;
  t235_n184: return 0.08525485545396805f;
  t235_n185: return 0.04693758487701416f;
  t235_n186: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t235_n188;
  t235_n187: return 0.11728863418102264f;
  t235_n188: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t235_n192;
  t235_n189: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t235_n191;
  t235_n190: return -0.07390407472848892f;
  t235_n191: return 0.11369853466749191f;
  t235_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n194;
  t235_n193: return 0.10565035790205002f;
  t235_n194: return -0.3244180977344513f;
  t235_n195: return -0.006096061319112778f;
  t235_n196: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t235_n200;
  t235_n197: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t235_n199;
  t235_n198: return -0.050258032977581024f;
  t235_n199: return 0.012700696475803852f;
  t235_n200: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t235_n202;
  t235_n201: return -0.13074424862861633f;
  t235_n202: return 0.1304989755153656f;
  t235_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t235_n237;
  t235_n204: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t235_n232;
  t235_n205: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t235_n211;
  t235_n206: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t235_n208;
  t235_n207: return -0.101736880838871f;
  t235_n208: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n210;
  t235_n209: return 0.10658983141183853f;
  t235_n210: return 0.11326320469379425f;
  t235_n211: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t235_n217;
  t235_n212: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t235_n216;
  t235_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n215;
  t235_n214: return 0.030833356082439423f;
  t235_n215: return 0.11488129198551178f;
  t235_n216: return -0.023241402581334114f;
  t235_n217: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t235_n223;
  t235_n218: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t235_n220;
  t235_n219: return 0.005372007377445698f;
  t235_n220: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t235_n222;
  t235_n221: return 0.10426837205886841f;
  t235_n222: return -0.24495472013950348f;
  t235_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t235_n231;
  t235_n224: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t235_n230;
  t235_n225: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t235_n229;
  t235_n226: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t235_n228;
  t235_n227: return 0.07457523047924042f;
  t235_n228: return 0.12908215820789337f;
  t235_n229: return 0.002747832564637065f;
  t235_n230: return -0.12644465267658234f;
  t235_n231: return 0.11676270514726639f;
  t235_n232: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t235_n236;
  t235_n233: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t235_n235;
  t235_n234: return -0.0998569130897522f;
  t235_n235: return 0.03600252419710159f;
  t235_n236: return 0.016587238758802414f;
  t235_n237: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t235_n243;
  t235_n238: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t235_n240;
  t235_n239: return 0.11754801124334335f;
  t235_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n242;
  t235_n241: return -0.8892221450805664f;
  t235_n242: return 0.079160675406456f;
  t235_n243: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t235_n245;
  t235_n244: return 0.04384787380695343f;
  t235_n245: return -0.146385058760643f;
  t235_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t235_n248;
  t235_n247: return 0.006987827364355326f;
  t235_n248: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t235_n254;
  t235_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n253;
  t235_n250: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t235_n252;
  t235_n251: return 0.0807112380862236f;
  t235_n252: return 0.0787934809923172f;
  t235_n253: return 0.05605660751461983f;
  t235_n254: return -0.014412764459848404f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree236(const Example& E) {
  t236_n0: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t236_n2;
  t236_n1: return -0.00022388073557522148f;
  t236_n2: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t236_n100;
  t236_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t236_n5;
  t236_n4: return 0.021413862705230713f;
  t236_n5: if (E.getNumReferences() >= 3332305408 /*20345.0*/) goto t236_n69;
  t236_n6: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t236_n60;
  t236_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t236_n47;
  t236_n8: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t236_n38;
  t236_n9: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t236_n37;
  t236_n10: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t236_n36;
  t236_n11: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t236_n15;
  t236_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t236_n14;
  t236_n13: return -0.002582325367256999f;
  t236_n14: return 0.34548279643058777f;
  t236_n15: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t236_n23;
  t236_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n22;
  t236_n17: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n19;
  t236_n18: return -0.5432167053222656f;
  t236_n19: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t236_n21;
  t236_n20: return 0.10651775449514389f;
  t236_n21: return 0.09453095495700836f;
  t236_n22: return 0.017146514728665352f;
  t236_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t236_n27;
  t236_n24: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t236_n26;
  t236_n25: return -0.04771795868873596f;
  t236_n26: return 0.14031246304512024f;
  t236_n27: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t236_n29;
  t236_n28: return -0.04640482738614082f;
  t236_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t236_n35;
  t236_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t236_n32;
  t236_n31: return 0.08718041330575943f;
  t236_n32: if (E.getNumReferences() >= 3332040448 /*19827.5*/) goto t236_n34;
  t236_n33: return 0.11592978984117508f;
  t236_n34: return 0.06074473634362221f;
  t236_n35: return 0.10821636766195297f;
  t236_n36: return -0.17309193313121796f;
  t236_n37: return 0.02680112235248089f;
  t236_n38: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t236_n40;
  t236_n39: return 0.10413626581430435f;
  t236_n40: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t236_n46;
  t236_n41: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t236_n43;
  t236_n42: return -0.0023156972602009773f;
  t236_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t236_n45;
  t236_n44: return 0.088651642203331f;
  t236_n45: return -0.17654521763324738f;
  t236_n46: return -0.506714940071106f;
  t236_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t236_n59;
  t236_n48: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n58;
  t236_n49: if (E.getNumReferences() >= 3332129024 /*20000.5*/) goto t236_n55;
  t236_n50: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t236_n54;
  t236_n51: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t236_n53;
  t236_n52: return 0.1117396429181099f;
  t236_n53: return -0.07267118990421295f;
  t236_n54: return -0.20418226718902588f;
  t236_n55: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t236_n57;
  t236_n56: return 0.036639951169490814f;
  t236_n57: return 0.12246359884738922f;
  t236_n58: return -0.042684487998485565f;
  t236_n59: return -0.2732391357421875f;
  t236_n60: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t236_n62;
  t236_n61: return 0.1297493875026703f;
  t236_n62: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n66;
  t236_n63: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t236_n65;
  t236_n64: return -0.1101173534989357f;
  t236_n65: return 0.14461782574653625f;
  t236_n66: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t236_n68;
  t236_n67: return 0.11980900913476944f;
  t236_n68: return 0.09856479614973068f;
  t236_n69: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t236_n91;
  t236_n70: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t236_n72;
  t236_n71: return 0.006605330388993025f;
  t236_n72: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n84;
  t236_n73: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t236_n81;
  t236_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t236_n76;
  t236_n75: return 0.016445279121398926f;
  t236_n76: if (E.getNumReferences() >= 3332378112 /*20487.0*/) goto t236_n80;
  t236_n77: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t236_n79;
  t236_n78: return -0.16835801303386688f;
  t236_n79: return 0.284547358751297f;
  t236_n80: return -0.6112586259841919f;
  t236_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n83;
  t236_n82: return 0.13270632922649384f;
  t236_n83: return 0.04944198951125145f;
  t236_n84: if (E.getNumReferences() >= 3333643008 /*22957.5*/) goto t236_n86;
  t236_n85: return 0.019561665132641792f;
  t236_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n88;
  t236_n87: return 0.09380579739809036f;
  t236_n88: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t236_n90;
  t236_n89: return 0.07525160163640976f;
  t236_n90: return -0.14553745090961456f;
  t236_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t236_n93;
  t236_n92: return -0.07841986417770386f;
  t236_n93: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t236_n95;
  t236_n94: return 0.023071832954883575f;
  t236_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t236_n99;
  t236_n96: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n98;
  t236_n97: return -0.00374954123981297f;
  t236_n98: return 0.27745646238327026f;
  t236_n99: return 0.09202833473682404f;
  t236_n100: if (E.getNumReferences() >= 3334783232 /*25184.5*/) goto t236_n106;
  t236_n101: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t236_n103;
  t236_n102: return -0.09694735705852509f;
  t236_n103: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t236_n105;
  t236_n104: return 0.12830929458141327f;
  t236_n105: return -0.19025078415870667f;
  t236_n106: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t236_n110;
  t236_n107: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t236_n109;
  t236_n108: return -0.010789294727146626f;
  t236_n109: return 0.005378338973969221f;
  t236_n110: if (E.getNumReferences() >= 3335643392 /*26864.5*/) goto t236_n136;
  t236_n111: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t236_n129;
  t236_n112: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t236_n126;
  t236_n113: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t236_n123;
  t236_n114: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t236_n116;
  t236_n115: return 0.10743792355060577f;
  t236_n116: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t236_n118;
  t236_n117: return -0.02725602686405182f;
  t236_n118: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t236_n120;
  t236_n119: return 0.03168267011642456f;
  t236_n120: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t236_n122;
  t236_n121: return 0.11634249985218048f;
  t236_n122: return 0.1117578074336052f;
  t236_n123: if (E.getNumReferences() >= 3335170304 /*25940.5*/) goto t236_n125;
  t236_n124: return 0.4724576473236084f;
  t236_n125: return -0.18554921448230743f;
  t236_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n128;
  t236_n127: return 0.14138925075531006f;
  t236_n128: return -0.11328788101673126f;
  t236_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t236_n131;
  t236_n130: return -0.36266660690307617f;
  t236_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t236_n135;
  t236_n132: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n134;
  t236_n133: return -0.12431108206510544f;
  t236_n134: return 0.10636324435472488f;
  t236_n135: return 0.10796187072992325f;
  t236_n136: if (E.getNumReferences() >= 3336316928 /*28180.0*/) goto t236_n152;
  t236_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t236_n149;
  t236_n138: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t236_n140;
  t236_n139: return -0.2971321642398834f;
  t236_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t236_n142;
  t236_n141: return -0.5702822208404541f;
  t236_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t236_n148;
  t236_n143: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t236_n147;
  t236_n144: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t236_n146;
  t236_n145: return 0.09031753242015839f;
  t236_n146: return -0.6836487650871277f;
  t236_n147: return 0.1034558042883873f;
  t236_n148: return 0.0019719155970960855f;
  t236_n149: if (E.getNumReferences() >= 3336061952 /*27682.0*/) goto t236_n151;
  t236_n150: return -0.4114331305027008f;
  t236_n151: return 0.11514627188444138f;
  t236_n152: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t236_n216;
  t236_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t236_n203;
  t236_n154: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n164;
  t236_n155: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t236_n157;
  t236_n156: return 0.016109244897961617f;
  t236_n157: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t236_n159;
  t236_n158: return -0.06612683832645416f;
  t236_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t236_n163;
  t236_n160: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n162;
  t236_n161: return 0.26597148180007935f;
  t236_n162: return -0.10034690797328949f;
  t236_n163: return -0.10120397806167603f;
  t236_n164: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t236_n202;
  t236_n165: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t236_n199;
  t236_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t236_n184;
  t236_n167: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t236_n171;
  t236_n168: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n170;
  t236_n169: return -0.036729276180267334f;
  t236_n170: return 0.0578865148127079f;
  t236_n171: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t236_n179;
  t236_n172: if (E.getNumReferences() >= 3338840960 /*33451.5*/) goto t236_n174;
  t236_n173: return 0.0008473021443933249f;
  t236_n174: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t236_n178;
  t236_n175: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t236_n177;
  t236_n176: return 0.1790025681257248f;
  t236_n177: return 0.06392008811235428f;
  t236_n178: return 0.11109161376953125f;
  t236_n179: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t236_n183;
  t236_n180: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t236_n182;
  t236_n181: return 0.09697183221578598f;
  t236_n182: return 0.06412011384963989f;
  t236_n183: return 0.044244568794965744f;
  t236_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t236_n188;
  t236_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n187;
  t236_n186: return 0.06347320973873138f;
  t236_n187: return 0.10942717641592026f;
  t236_n188: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t236_n198;
  t236_n189: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t236_n197;
  t236_n190: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t236_n192;
  t236_n191: return -0.0019197211368009448f;
  t236_n192: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t236_n194;
  t236_n193: return -0.021851247176527977f;
  t236_n194: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t236_n196;
  t236_n195: return 0.11983220279216766f;
  t236_n196: return 0.11114731431007385f;
  t236_n197: return 0.1252603828907013f;
  t236_n198: return 0.008456042967736721f;
  t236_n199: if (E.getNumReferences() >= 3337280256 /*30061.5*/) goto t236_n201;
  t236_n200: return 0.06732653081417084f;
  t236_n201: return -0.035623449832201004f;
  t236_n202: return 0.005391511134803295f;
  t236_n203: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t236_n213;
  t236_n204: if (E.getNumReferences() >= 3351111424 /*97230.0*/) goto t236_n210;
  t236_n205: if (E.getNumReferences() >= 3339744256 /*36980.0*/) goto t236_n209;
  t236_n206: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t236_n208;
  t236_n207: return 0.02651919424533844f;
  t236_n208: return 0.09740544110536575f;
  t236_n209: return -0.12483083456754684f;
  t236_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t236_n212;
  t236_n211: return 0.0465371310710907f;
  t236_n212: return 0.10390252619981766f;
  t236_n213: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t236_n215;
  t236_n214: return 0.027522793039679527f;
  t236_n215: return -0.48003441095352173f;
  t236_n216: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t236_n246;
  t236_n217: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t236_n223;
  t236_n218: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t236_n222;
  t236_n219: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t236_n221;
  t236_n220: return -0.4869035482406616f;
  t236_n221: return 0.01688479445874691f;
  t236_n222: return -0.018568281084299088f;
  t236_n223: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t236_n243;
  t236_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t236_n238;
  t236_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n237;
  t236_n226: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t236_n232;
  t236_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t236_n229;
  t236_n228: return -0.024015579372644424f;
  t236_n229: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t236_n231;
  t236_n230: return 0.10758604109287262f;
  t236_n231: return 0.0318157859146595f;
  t236_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t236_n236;
  t236_n233: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t236_n235;
  t236_n234: return -0.22383418679237366f;
  t236_n235: return -0.029082857072353363f;
  t236_n236: return 0.04015248641371727f;
  t236_n237: return 0.057412173599004745f;
  t236_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n240;
  t236_n239: return 0.07894423604011536f;
  t236_n240: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t236_n242;
  t236_n241: return 0.07389459758996964f;
  t236_n242: return -0.06094193458557129f;
  t236_n243: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t236_n245;
  t236_n244: return -0.008301163092255592f;
  t236_n245: return 0.012517380528151989f;
  t236_n246: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t236_n254;
  t236_n247: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t236_n253;
  t236_n248: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n252;
  t236_n249: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n251;
  t236_n250: return -0.12018615007400513f;
  t236_n251: return 0.10033727437257767f;
  t236_n252: return 0.040122270584106445f;
  t236_n253: return 0.10911203175783157f;
  t236_n254: return -0.19576920568943024f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree237(const Example& E) {
  t237_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t237_n84;
  t237_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t237_n3;
  t237_n2: return -5.1435225032037124e-05f;
  t237_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t237_n23;
  t237_n4: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t237_n22;
  t237_n5: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t237_n19;
  t237_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t237_n8;
  t237_n7: return 0.03168753534555435f;
  t237_n8: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t237_n18;
  t237_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t237_n13;
  t237_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t237_n12;
  t237_n11: return 0.12078577280044556f;
  t237_n12: return 0.10580737888813019f;
  t237_n13: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t237_n15;
  t237_n14: return 0.015372871421277523f;
  t237_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t237_n17;
  t237_n16: return -0.04225775972008705f;
  t237_n17: return 0.14001192152500153f;
  t237_n18: return -0.042311061173677444f;
  t237_n19: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t237_n21;
  t237_n20: return -0.022824382409453392f;
  t237_n21: return 0.011868756264448166f;
  t237_n22: return -0.01520537305623293f;
  t237_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t237_n25;
  t237_n24: return 0.0008434552000835538f;
  t237_n25: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t237_n83;
  t237_n26: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t237_n46;
  t237_n27: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t237_n29;
  t237_n28: return -0.005829721689224243f;
  t237_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t237_n31;
  t237_n30: return 0.0310814268887043f;
  t237_n31: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t237_n37;
  t237_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag))) goto t237_n34;
  t237_n33: return 0.02742479369044304f;
  t237_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t237_n36;
  t237_n35: return 0.06468179076910019f;
  t237_n36: return -0.00680284108966589f;
  t237_n37: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t237_n45;
  t237_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t237_n44;
  t237_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t237_n41;
  t237_n40: return 0.009207948110997677f;
  t237_n41: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t237_n43;
  t237_n42: return 0.08514373749494553f;
  t237_n43: return 0.10491642355918884f;
  t237_n44: return 0.06753301620483398f;
  t237_n45: return -0.0589970164000988f;
  t237_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t237_n64;
  t237_n47: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t237_n49;
  t237_n48: return 0.0623636320233345f;
  t237_n49: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t237_n63;
  t237_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t237_n62;
  t237_n51: if (E.getNumReferences() >= 3266576384 /*90.0*/) goto t237_n61;
  t237_n52: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t237_n58;
  t237_n53: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t237_n55;
  t237_n54: return 0.08653023838996887f;
  t237_n55: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t237_n57;
  t237_n56: return 0.12377000600099564f;
  t237_n57: return 0.08992923051118851f;
  t237_n58: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t237_n60;
  t237_n59: return 0.07436404377222061f;
  t237_n60: return 0.11396299302577972f;
  t237_n61: return -0.23711907863616943f;
  t237_n62: return 0.07143474370241165f;
  t237_n63: return 0.05342867970466614f;
  t237_n64: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t237_n78;
  t237_n65: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t237_n73;
  t237_n66: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t237_n68;
  t237_n67: return 0.014752237126231194f;
  t237_n68: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t237_n72;
  t237_n69: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t237_n71;
  t237_n70: return 0.14309346675872803f;
  t237_n71: return 0.10952333360910416f;
  t237_n72: return 0.07786242663860321f;
  t237_n73: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t237_n77;
  t237_n74: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t237_n76;
  t237_n75: return 0.12003489583730698f;
  t237_n76: return 0.08183428645133972f;
  t237_n77: return 0.04839726537466049f;
  t237_n78: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t237_n80;
  t237_n79: return 0.023361900821328163f;
  t237_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t237_n82;
  t237_n81: return 0.13361407816410065f;
  t237_n82: return -0.11291475594043732f;
  t237_n83: return -0.01508607342839241f;
  t237_n84: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t237_n98;
  t237_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t237_n97;
  t237_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t237_n96;
  t237_n87: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t237_n89;
  t237_n88: return -0.0457756482064724f;
  t237_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t237_n93;
  t237_n90: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t237_n92;
  t237_n91: return -0.1184995099902153f;
  t237_n92: return -0.566068708896637f;
  t237_n93: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t237_n95;
  t237_n94: return -0.08575249463319778f;
  t237_n95: return -0.8836507797241211f;
  t237_n96: return -0.07344246655702591f;
  t237_n97: return -0.002713852096349001f;
  t237_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t237_n100;
  t237_n99: return -0.03607690706849098f;
  t237_n100: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t237_n252;
  t237_n101: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t237_n179;
  t237_n102: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t237_n168;
  t237_n103: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t237_n163;
  t237_n104: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t237_n158;
  t237_n105: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t237_n111;
  t237_n106: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t237_n110;
  t237_n107: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t237_n109;
  t237_n108: return 0.03941700980067253f;
  t237_n109: return 0.09876066446304321f;
  t237_n110: return -0.09688885509967804f;
  t237_n111: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t237_n115;
  t237_n112: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t237_n114;
  t237_n113: return -0.08850392699241638f;
  t237_n114: return 0.11939424276351929f;
  t237_n115: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t237_n117;
  t237_n116: return -0.07308098673820496f;
  t237_n117: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t237_n135;
  t237_n118: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t237_n128;
  t237_n119: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t237_n127;
  t237_n120: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t237_n126;
  t237_n121: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t237_n125;
  t237_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t237_n124;
  t237_n123: return 0.10182283073663712f;
  t237_n124: return -0.004314585123211145f;
  t237_n125: return 0.11276565492153168f;
  t237_n126: return -0.09061479568481445f;
  t237_n127: return -0.11113514006137848f;
  t237_n128: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t237_n134;
  t237_n129: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t237_n131;
  t237_n130: return 0.13166847825050354f;
  t237_n131: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t237_n133;
  t237_n132: return 0.12197785079479218f;
  t237_n133: return -0.10657919198274612f;
  t237_n134: return 0.13186943531036377f;
  t237_n135: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t237_n137;
  t237_n136: return -0.16901233792304993f;
  t237_n137: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t237_n143;
  t237_n138: if (E.getNumReferences() >= 3259498496 /*50.0*/) goto t237_n142;
  t237_n139: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t237_n141;
  t237_n140: return 0.10752992331981659f;
  t237_n141: return -0.22814267873764038f;
  t237_n142: return 0.11521207541227341f;
  t237_n143: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t237_n155;
  t237_n144: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t237_n154;
  t237_n145: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t237_n149;
  t237_n146: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t237_n148;
  t237_n147: return 0.40778711438179016f;
  t237_n148: return -0.1681545525789261f;
  t237_n149: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t237_n151;
  t237_n150: return 0.05392639338970184f;
  t237_n151: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t237_n153;
  t237_n152: return 0.13264474272727966f;
  t237_n153: return 0.09425998479127884f;
  t237_n154: return -0.04256065934896469f;
  t237_n155: if (E.getNumReferences() >= 3285975040 /*440.0*/) goto t237_n157;
  t237_n156: return -0.13712544739246368f;
  t237_n157: return 0.09357529878616333f;
  t237_n158: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t237_n162;
  t237_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t237_n161;
  t237_n160: return 0.040087759494781494f;
  t237_n161: return 0.8495534658432007f;
  t237_n162: return 0.11176493018865585f;
  t237_n163: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t237_n167;
  t237_n164: if (E.getNumReferences() >= 3332634624 /*20988.0*/) goto t237_n166;
  t237_n165: return -0.11165913939476013f;
  t237_n166: return 0.0665389820933342f;
  t237_n167: return -0.07633604109287262f;
  t237_n168: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t237_n170;
  t237_n169: return 0.002507341792806983f;
  t237_n170: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t237_n178;
  t237_n171: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t237_n173;
  t237_n172: return -0.10228735208511353f;
  t237_n173: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t237_n177;
  t237_n174: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t237_n176;
  t237_n175: return 0.05970760062336922f;
  t237_n176: return 0.09972960501909256f;
  t237_n177: return 0.10642696171998978f;
  t237_n178: return 0.02763502672314644f;
  t237_n179: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t237_n205;
  t237_n180: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t237_n198;
  t237_n181: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t237_n183;
  t237_n182: return -0.010110598988831043f;
  t237_n183: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t237_n193;
  t237_n184: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t237_n192;
  t237_n185: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t237_n187;
  t237_n186: return -0.12259835749864578f;
  t237_n187: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t237_n191;
  t237_n188: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t237_n190;
  t237_n189: return 0.10751335322856903f;
  t237_n190: return -0.11914780735969543f;
  t237_n191: return -0.07859598100185394f;
  t237_n192: return 0.12416515499353409f;
  t237_n193: if (E.getNumReferences() >= 3333465344 /*22610.5*/) goto t237_n197;
  t237_n194: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t237_n196;
  t237_n195: return -0.26804426312446594f;
  t237_n196: return -0.27199122309684753f;
  t237_n197: return -0.014667797833681107f;
  t237_n198: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t237_n204;
  t237_n199: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t237_n203;
  t237_n200: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t237_n202;
  t237_n201: return -0.7299579977989197f;
  t237_n202: return 0.07285165786743164f;
  t237_n203: return 0.11124583333730698f;
  t237_n204: return 0.10308852046728134f;
  t237_n205: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t237_n245;
  t237_n206: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t237_n216;
  t237_n207: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t237_n209;
  t237_n208: return -0.10874655842781067f;
  t237_n209: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t237_n215;
  t237_n210: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t237_n212;
  t237_n211: return 0.1144028976559639f;
  t237_n212: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t237_n214;
  t237_n213: return -0.10437978059053421f;
  t237_n214: return 0.09122985601425171f;
  t237_n215: return -0.07614503055810928f;
  t237_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t237_n218;
  t237_n217: return -0.023366471752524376f;
  t237_n218: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t237_n224;
  t237_n219: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t237_n223;
  t237_n220: if (E.getSymbolScopeDistance() >= 3229614080 /*4.0*/) goto t237_n222;
  t237_n221: return 0.11945070326328278f;
  t237_n222: return -0.15441149473190308f;
  t237_n223: return 0.11582613736391068f;
  t237_n224: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t237_n244;
  t237_n225: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t237_n237;
  t237_n226: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t237_n236;
  t237_n227: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t237_n229;
  t237_n228: return 0.05946531519293785f;
  t237_n229: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t237_n235;
  t237_n230: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t237_n232;
  t237_n231: return 0.11844876408576965f;
  t237_n232: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t237_n234;
  t237_n233: return 0.10484350472688675f;
  t237_n234: return 0.09156773239374161f;
  t237_n235: return -0.299567848443985f;
  t237_n236: return -0.19454243779182434f;
  t237_n237: if (E.getNumReferences() >= 3265134592 /*79.0*/) goto t237_n243;
  t237_n238: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t237_n242;
  t237_n239: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t237_n241;
  t237_n240: return 0.06127196177840233f;
  t237_n241: return 0.14615048468112946f;
  t237_n242: return 0.09275482594966888f;
  t237_n243: return 0.05977306887507439f;
  t237_n244: return 0.003755465615540743f;
  t237_n245: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t237_n251;
  t237_n246: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t237_n250;
  t237_n247: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t237_n249;
  t237_n248: return -0.019398318603634834f;
  t237_n249: return 0.1077289804816246f;
  t237_n250: return 0.12174779921770096f;
  t237_n251: return 0.08868597447872162f;
  t237_n252: if (E.getNumReferences() >= 3280633856 /*277.0*/) goto t237_n254;
  t237_n253: return -0.04112422838807106f;
  t237_n254: return 0.1400744467973709f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree238(const Example& E) {
  t238_n0: if (E.getNumReferences() >= 3306510336 /*2389.5*/) goto t238_n6;
  t238_n1: if (E.getNumReferences() >= 3306272768 /*2331.5*/) goto t238_n3;
  t238_n2: return -0.0002945251762866974f;
  t238_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t238_n5;
  t238_n4: return -0.08431518822908401f;
  t238_n5: return -0.1791301667690277f;
  t238_n6: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t238_n12;
  t238_n7: if (E.getNumReferences() >= 3306528768 /*2394.0*/) goto t238_n11;
  t238_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t238_n10;
  t238_n9: return -0.10303020477294922f;
  t238_n10: return 0.11028960347175598f;
  t238_n11: return 0.009634477086365223f;
  t238_n12: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t238_n14;
  t238_n13: return -0.0009304296690970659f;
  t238_n14: if (E.getNumReferences() >= 3346195456 /*62180.0*/) goto t238_n212;
  t238_n15: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t238_n199;
  t238_n16: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t238_n198;
  t238_n17: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t238_n25;
  t238_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t238_n20;
  t238_n19: return 0.04767290875315666f;
  t238_n20: if (E.getNumReferences() >= 3321453568 /*7979.5*/) goto t238_n24;
  t238_n21: if (E.getNumReferences() >= 3317408768 /*6004.5*/) goto t238_n23;
  t238_n22: return 0.03863966464996338f;
  t238_n23: return 0.12355863302946091f;
  t238_n24: return 0.051193565130233765f;
  t238_n25: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t238_n143;
  t238_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t238_n86;
  t238_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t238_n85;
  t238_n28: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t238_n66;
  t238_n29: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t238_n31;
  t238_n30: return -0.08232881128787994f;
  t238_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t238_n33;
  t238_n32: return -0.03980744630098343f;
  t238_n33: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t238_n61;
  t238_n34: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t238_n60;
  t238_n35: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t238_n37;
  t238_n36: return -0.13966867327690125f;
  t238_n37: if (E.getNumReferences() >= 3336769792 /*29064.5*/) goto t238_n49;
  t238_n38: if (E.getNumReferences() >= 3335832832 /*27234.5*/) goto t238_n48;
  t238_n39: if (E.getNumReferences() >= 3330932480 /*17663.5*/) goto t238_n47;
  t238_n40: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t238_n44;
  t238_n41: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n43;
  t238_n42: return 0.1205008327960968f;
  t238_n43: return -0.20741243660449982f;
  t238_n44: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n46;
  t238_n45: return -0.15187089145183563f;
  t238_n46: return 0.10174985229969025f;
  t238_n47: return -0.19678078591823578f;
  t238_n48: return 0.11677782982587814f;
  t238_n49: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t238_n51;
  t238_n50: return -0.03948301449418068f;
  t238_n51: if (E.getNumReferences() >= 3340710656 /*40755.0*/) goto t238_n53;
  t238_n52: return 0.14153407514095306f;
  t238_n53: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n55;
  t238_n54: return -0.14702636003494263f;
  t238_n55: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t238_n57;
  t238_n56: return 0.03492799773812294f;
  t238_n57: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t238_n59;
  t238_n58: return 0.2563248872756958f;
  t238_n59: return 0.1043776422739029f;
  t238_n60: return -0.03371497243642807f;
  t238_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t238_n63;
  t238_n62: return -0.1891191005706787f;
  t238_n63: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t238_n65;
  t238_n64: return -0.1303589791059494f;
  t238_n65: return 0.09929847717285156f;
  t238_n66: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t238_n76;
  t238_n67: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t238_n69;
  t238_n68: return -0.08115930110216141f;
  t238_n69: if (E.getNumReferences() >= 3308478464 /*2870.0*/) goto t238_n75;
  t238_n70: if (E.getNumReferences() >= 3307792384 /*2702.5*/) goto t238_n72;
  t238_n71: return 0.1373133361339569f;
  t238_n72: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t238_n74;
  t238_n73: return -0.10332739353179932f;
  t238_n74: return 0.11881046742200851f;
  t238_n75: return 0.02383965253829956f;
  t238_n76: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n78;
  t238_n77: return 0.010991232469677925f;
  t238_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t238_n82;
  t238_n79: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t238_n81;
  t238_n80: return -0.46058303117752075f;
  t238_n81: return 0.10541371256113052f;
  t238_n82: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t238_n84;
  t238_n83: return 0.1199665367603302f;
  t238_n84: return 0.08058198541402817f;
  t238_n85: return 0.05009876564145088f;
  t238_n86: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t238_n140;
  t238_n87: if (E.getNumReferences() >= 3333043200 /*21786.0*/) goto t238_n129;
  t238_n88: if (E.getNumReferences() >= 3332993536 /*21689.0*/) goto t238_n126;
  t238_n89: if (E.getNumReferences() >= 3316685824 /*5651.5*/) goto t238_n91;
  t238_n90: return 0.006964432075619698f;
  t238_n91: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t238_n93;
  t238_n92: return 0.006884814240038395f;
  t238_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t238_n95;
  t238_n94: return 0.01812676340341568f;
  t238_n95: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t238_n99;
  t238_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t238_n98;
  t238_n97: return -0.0608956404030323f;
  t238_n98: return 0.10811587423086166f;
  t238_n99: if (E.getNumReferences() >= 3328404480 /*14555.0*/) goto t238_n123;
  t238_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t238_n102;
  t238_n101: return 0.019625768065452576f;
  t238_n102: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t238_n106;
  t238_n103: if (E.getNumReferences() >= 3316792320 /*5703.5*/) goto t238_n105;
  t238_n104: return 0.12034271657466888f;
  t238_n105: return 0.012675575911998749f;
  t238_n106: if (E.getNumReferences() >= 3322110464 /*8408.5*/) goto t238_n108;
  t238_n107: return 0.04211173951625824f;
  t238_n108: if (E.getNumReferences() >= 3322934784 /*9213.5*/) goto t238_n116;
  t238_n109: if (E.getNumReferences() >= 3322621952 /*8908.0*/) goto t238_n113;
  t238_n110: if (E.getNumReferences() >= 3322180096 /*8476.5*/) goto t238_n112;
  t238_n111: return 0.10851346701383591f;
  t238_n112: return 0.0101082194596529f;
  t238_n113: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n115;
  t238_n114: return 0.11550536751747131f;
  t238_n115: return -0.022607725113630295f;
  t238_n116: if (E.getNumReferences() >= 3324676608 /*10914.5*/) goto t238_n122;
  t238_n117: if (E.getNumReferences() >= 3324197888 /*10447.0*/) goto t238_n119;
  t238_n118: return 0.06706180423498154f;
  t238_n119: if (E.getNumReferences() >= 3324302336 /*10549.0*/) goto t238_n121;
  t238_n120: return 0.10797446966171265f;
  t238_n121: return 0.09468881785869598f;
  t238_n122: return 0.009508221410214901f;
  t238_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t238_n125;
  t238_n124: return 0.047596462070941925f;
  t238_n125: return 0.08549313247203827f;
  t238_n126: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t238_n128;
  t238_n127: return 0.08053221553564072f;
  t238_n128: return -0.055051546543836594f;
  t238_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t238_n131;
  t238_n130: return -0.03670007362961769f;
  t238_n131: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t238_n133;
  t238_n132: return -0.015828508883714676f;
  t238_n133: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t238_n139;
  t238_n134: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t238_n138;
  t238_n135: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t238_n137;
  t238_n136: return 0.10437315702438354f;
  t238_n137: return 0.10284220427274704f;
  t238_n138: return 0.09688892215490341f;
  t238_n139: return 0.027469931170344353f;
  t238_n140: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t238_n142;
  t238_n141: return 0.12044437229633331f;
  t238_n142: return 0.087065689265728f;
  t238_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t238_n145;
  t238_n144: return 0.007267417386174202f;
  t238_n145: if (E.getNumReferences() >= 3320657920 /*7591.0*/) goto t238_n157;
  t238_n146: if (E.getNumReferences() >= 3313014784 /*3977.5*/) goto t238_n154;
  t238_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t238_n149;
  t238_n148: return 0.026871172711253166f;
  t238_n149: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t238_n153;
  t238_n150: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t238_n152;
  t238_n151: return 0.11144774407148361f;
  t238_n152: return -0.010710001923143864f;
  t238_n153: return 0.10507358610630035f;
  t238_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t238_n156;
  t238_n155: return -0.07340134680271149f;
  t238_n156: return 0.039475612342357635f;
  t238_n157: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t238_n197;
  t238_n158: if (E.getNumReferences() >= 3342715264 /*48585.5*/) goto t238_n190;
  t238_n159: if (E.getNumReferences() >= 3329272320 /*15402.5*/) goto t238_n189;
  t238_n160: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n176;
  t238_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t238_n169;
  t238_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t238_n164;
  t238_n163: return -0.011288020759820938f;
  t238_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t238_n166;
  t238_n165: return -0.07570052146911621f;
  t238_n166: if (E.getNumReferences() >= 3324484096 /*10726.5*/) goto t238_n168;
  t238_n167: return 0.11585585027933121f;
  t238_n168: return 0.04190701246261597f;
  t238_n169: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t238_n171;
  t238_n170: return 0.1209324300289154f;
  t238_n171: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t238_n173;
  t238_n172: return 0.102461077272892f;
  t238_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t238_n175;
  t238_n174: return 0.05308203771710396f;
  t238_n175: return 0.25214433670043945f;
  t238_n176: if (E.getNumReferences() >= 3325046272 /*11275.5*/) goto t238_n182;
  t238_n177: if (E.getNumReferences() >= 3321261056 /*7885.5*/) goto t238_n179;
  t238_n178: return 0.08924742043018341f;
  t238_n179: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t238_n181;
  t238_n180: return -0.32754138112068176f;
  t238_n181: return 0.02115589566528797f;
  t238_n182: if (E.getNumReferences() >= 3326581248 /*12774.5*/) goto t238_n186;
  t238_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t238_n185;
  t238_n184: return 0.1277487725019455f;
  t238_n185: return 0.11960749328136444f;
  t238_n186: if (E.getNumReferences() >= 3328893952 /*15033.0*/) goto t238_n188;
  t238_n187: return -0.00679310318082571f;
  t238_n188: return 0.0878482311964035f;
  t238_n189: return 0.029134346172213554f;
  t238_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t238_n194;
  t238_n191: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t238_n193;
  t238_n192: return -0.15772350132465363f;
  t238_n193: return 0.10596992075443268f;
  t238_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n196;
  t238_n195: return 0.09858328104019165f;
  t238_n196: return 0.09423080086708069f;
  t238_n197: return -0.019318021833896637f;
  t238_n198: return 0.08733847737312317f;
  t238_n199: if (E.getNumReferences() >= 3306622976 /*2417.0*/) goto t238_n203;
  t238_n200: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n202;
  t238_n201: return 0.11277218163013458f;
  t238_n202: return 0.04899050295352936f;
  t238_n203: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t238_n205;
  t238_n204: return 0.020884785801172256f;
  t238_n205: if (E.getNumReferences() >= 3314617344 /*4641.5*/) goto t238_n211;
  t238_n206: if (E.getNumReferences() >= 3312302080 /*3803.5*/) goto t238_n210;
  t238_n207: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n209;
  t238_n208: return 0.08541683852672577f;
  t238_n209: return -0.5983622074127197f;
  t238_n210: return 0.10659342259168625f;
  t238_n211: return -0.04316575825214386f;
  t238_n212: if (E.getNumReferences() >= 3348227392 /*74698.5*/) goto t238_n230;
  t238_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t238_n217;
  t238_n214: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t238_n216;
  t238_n215: return -0.09732650220394135f;
  t238_n216: return 0.021578503772616386f;
  t238_n217: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t238_n227;
  t238_n218: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t238_n220;
  t238_n219: return -0.0488477498292923f;
  t238_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t238_n222;
  t238_n221: return -0.17026780545711517f;
  t238_n222: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n226;
  t238_n223: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t238_n225;
  t238_n224: return 0.09425278007984161f;
  t238_n225: return 0.04298793897032738f;
  t238_n226: return 0.03146488592028618f;
  t238_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n229;
  t238_n228: return 0.03603697195649147f;
  t238_n229: return 0.10851415991783142f;
  t238_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t238_n252;
  t238_n231: if (E.getNumReferences() >= 3356105632 /*141422.5*/) goto t238_n249;
  t238_n232: if (E.getNumReferences() >= 3356017152 /*140040.0*/) goto t238_n240;
  t238_n233: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t238_n237;
  t238_n234: if (E.getNumReferences() >= 3348960256 /*80424.0*/) goto t238_n236;
  t238_n235: return 0.04093145951628685f;
  t238_n236: return -0.04027732461690903f;
  t238_n237: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t238_n239;
  t238_n238: return 0.09415601193904877f;
  t238_n239: return 0.01046594325453043f;
  t238_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t238_n242;
  t238_n241: return -0.04566184803843498f;
  t238_n242: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n246;
  t238_n243: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t238_n245;
  t238_n244: return 0.10166231542825699f;
  t238_n245: return 0.1108425110578537f;
  t238_n246: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t238_n248;
  t238_n247: return -0.48887914419174194f;
  t238_n248: return 0.0955863893032074f;
  t238_n249: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t238_n251;
  t238_n250: return -0.2639353275299072f;
  t238_n251: return -0.019048606976866722f;
  t238_n252: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t238_n254;
  t238_n253: return -0.004719079937785864f;
  t238_n254: return 0.03310784325003624f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree239(const Example& E) {
  t239_n0: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t239_n2;
  t239_n1: return -0.0016929218545556068f;
  t239_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t239_n4;
  t239_n3: return -0.0004881874774582684f;
  t239_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t239_n28;
  t239_n5: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t239_n7;
  t239_n6: return -0.01806524582207203f;
  t239_n7: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t239_n9;
  t239_n8: return -0.00014090290642343462f;
  t239_n9: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t239_n11;
  t239_n10: return 0.01219144370406866f;
  t239_n11: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t239_n27;
  t239_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t239_n14;
  t239_n13: return -0.10924138873815536f;
  t239_n14: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t239_n16;
  t239_n15: return 0.11810197681188583f;
  t239_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n26;
  t239_n17: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t239_n25;
  t239_n18: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t239_n24;
  t239_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t239_n21;
  t239_n20: return -0.04167279601097107f;
  t239_n21: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t239_n23;
  t239_n22: return 0.09619231522083282f;
  t239_n23: return 0.036379389464855194f;
  t239_n24: return 0.09221871942281723f;
  t239_n25: return 0.0014299002941697836f;
  t239_n26: return -1.1435747146606445f;
  t239_n27: return -0.002403068821877241f;
  t239_n28: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t239_n238;
  t239_n29: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t239_n31;
  t239_n30: return 0.004531803075224161f;
  t239_n31: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t239_n97;
  t239_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t239_n72;
  t239_n33: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t239_n71;
  t239_n34: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t239_n64;
  t239_n35: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t239_n37;
  t239_n36: return 0.1041426807641983f;
  t239_n37: if (E.getNumReferences() >= 3279962112 /*256.5*/) goto t239_n43;
  t239_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n40;
  t239_n39: return -0.3251800835132599f;
  t239_n40: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t239_n42;
  t239_n41: return 0.09853597730398178f;
  t239_n42: return 0.03257157281041145f;
  t239_n43: if (E.getNumReferences() >= 3281666048 /*308.5*/) goto t239_n45;
  t239_n44: return 0.11281442642211914f;
  t239_n45: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t239_n63;
  t239_n46: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t239_n48;
  t239_n47: return -0.0037673565093427896f;
  t239_n48: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t239_n62;
  t239_n49: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t239_n51;
  t239_n50: return 0.11357583105564117f;
  t239_n51: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t239_n53;
  t239_n52: return -0.005594304762780666f;
  t239_n53: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t239_n57;
  t239_n54: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n56;
  t239_n55: return 0.11156981438398361f;
  t239_n56: return 0.06752243638038635f;
  t239_n57: if (E.getNumReferences() >= 3292536832 /*768.5*/) goto t239_n59;
  t239_n58: return 0.11478089541196823f;
  t239_n59: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n61;
  t239_n60: return 0.026791831478476524f;
  t239_n61: return 0.11933645606040955f;
  t239_n62: return -0.044720470905303955f;
  t239_n63: return -0.0823153406381607f;
  t239_n64: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t239_n70;
  t239_n65: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t239_n67;
  t239_n66: return 0.0752767026424408f;
  t239_n67: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t239_n69;
  t239_n68: return 0.09258256107568741f;
  t239_n69: return -0.10782159119844437f;
  t239_n70: return -0.3432041108608246f;
  t239_n71: return 0.01070599164813757f;
  t239_n72: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t239_n96;
  t239_n73: if (E.getNumReferences() >= 3302137856 /*1685.0*/) goto t239_n93;
  t239_n74: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t239_n88;
  t239_n75: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t239_n87;
  t239_n76: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t239_n78;
  t239_n77: return -0.028283799067139626f;
  t239_n78: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t239_n82;
  t239_n79: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t239_n81;
  t239_n80: return 0.1738157421350479f;
  t239_n81: return -0.3618260324001312f;
  t239_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t239_n84;
  t239_n83: return -0.2822236120700836f;
  t239_n84: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n86;
  t239_n85: return 0.16054287552833557f;
  t239_n86: return 0.05542551353573799f;
  t239_n87: return -0.22503572702407837f;
  t239_n88: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t239_n90;
  t239_n89: return -0.3064989447593689f;
  t239_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t239_n92;
  t239_n91: return -0.1170511320233345f;
  t239_n92: return 0.0856415256857872f;
  t239_n93: if (E.getNumReferences() >= 3306971136 /*2502.0*/) goto t239_n95;
  t239_n94: return 0.11686757951974869f;
  t239_n95: return -0.010503273457288742f;
  t239_n96: return 0.005814883857965469f;
  t239_n97: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t239_n107;
  t239_n98: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n102;
  t239_n99: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t239_n101;
  t239_n100: return 0.12200180441141129f;
  t239_n101: return 0.01759653352200985f;
  t239_n102: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t239_n104;
  t239_n103: return 0.07667386531829834f;
  t239_n104: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n106;
  t239_n105: return 0.13254275918006897f;
  t239_n106: return 0.02206791564822197f;
  t239_n107: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t239_n237;
  t239_n108: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t239_n222;
  t239_n109: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n193;
  t239_n110: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t239_n112;
  t239_n111: return -0.02204040065407753f;
  t239_n112: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t239_n188;
  t239_n113: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t239_n167;
  t239_n114: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t239_n166;
  t239_n115: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t239_n135;
  t239_n116: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n132;
  t239_n117: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t239_n129;
  t239_n118: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t239_n128;
  t239_n119: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t239_n123;
  t239_n120: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t239_n122;
  t239_n121: return 0.07752551883459091f;
  t239_n122: return -0.10316836088895798f;
  t239_n123: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n125;
  t239_n124: return 0.12264664471149445f;
  t239_n125: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t239_n127;
  t239_n126: return 0.0903065875172615f;
  t239_n127: return -0.42400479316711426f;
  t239_n128: return 0.011571393348276615f;
  t239_n129: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t239_n131;
  t239_n130: return 0.08862986415624619f;
  t239_n131: return 0.10862839221954346f;
  t239_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t239_n134;
  t239_n133: return -0.05265258252620697f;
  t239_n134: return 1.0442376136779785f;
  t239_n135: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t239_n147;
  t239_n136: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t239_n144;
  t239_n137: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t239_n139;
  t239_n138: return 0.05020782724022865f;
  t239_n139: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t239_n143;
  t239_n140: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n142;
  t239_n141: return 0.09628400951623917f;
  t239_n142: return 0.1076788604259491f;
  t239_n143: return 0.10349985957145691f;
  t239_n144: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n146;
  t239_n145: return -0.7363951206207275f;
  t239_n146: return 0.05320395156741142f;
  t239_n147: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t239_n151;
  t239_n148: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t239_n150;
  t239_n149: return 0.1061878651380539f;
  t239_n150: return -0.012840408831834793f;
  t239_n151: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t239_n153;
  t239_n152: return 0.00789994839578867f;
  t239_n153: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t239_n157;
  t239_n154: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n156;
  t239_n155: return -0.2042015939950943f;
  t239_n156: return 0.07538007944822311f;
  t239_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t239_n165;
  t239_n158: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t239_n160;
  t239_n159: return -0.048874638974666595f;
  t239_n160: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n164;
  t239_n161: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t239_n163;
  t239_n162: return 0.13985179364681244f;
  t239_n163: return 0.11195360124111176f;
  t239_n164: return 0.04829764738678932f;
  t239_n165: return 0.14802701771259308f;
  t239_n166: return -0.10633137822151184f;
  t239_n167: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t239_n169;
  t239_n168: return -0.11099422723054886f;
  t239_n169: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t239_n171;
  t239_n170: return -0.23952151834964752f;
  t239_n171: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n173;
  t239_n172: return -0.0318976454436779f;
  t239_n173: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t239_n179;
  t239_n174: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t239_n178;
  t239_n175: if (E.getNumReferences() >= 3239051264 /*9.0*/) goto t239_n177;
  t239_n176: return 0.09686847776174545f;
  t239_n177: return -0.17608405649662018f;
  t239_n178: return 0.09128738194704056f;
  t239_n179: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t239_n181;
  t239_n180: return -0.10673452168703079f;
  t239_n181: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t239_n183;
  t239_n182: return 0.11105432361364365f;
  t239_n183: if (E.getNumReferences() >= 3247439872 /*18.0*/) goto t239_n187;
  t239_n184: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t239_n186;
  t239_n185: return -0.42080947756767273f;
  t239_n186: return 0.10107319802045822f;
  t239_n187: return 0.0758405402302742f;
  t239_n188: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t239_n190;
  t239_n189: return 0.1569335162639618f;
  t239_n190: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t239_n192;
  t239_n191: return 0.07475024461746216f;
  t239_n192: return -0.04409709572792053f;
  t239_n193: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t239_n201;
  t239_n194: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t239_n196;
  t239_n195: return 0.10397030413150787f;
  t239_n196: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t239_n198;
  t239_n197: return -0.04269061237573624f;
  t239_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n200;
  t239_n199: return 0.10603206604719162f;
  t239_n200: return 0.06843029707670212f;
  t239_n201: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t239_n213;
  t239_n202: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t239_n208;
  t239_n203: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t239_n205;
  t239_n204: return -0.07808300852775574f;
  t239_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n207;
  t239_n206: return -0.06554105877876282f;
  t239_n207: return -0.17703987658023834f;
  t239_n208: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t239_n210;
  t239_n209: return 0.017559364438056946f;
  t239_n210: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t239_n212;
  t239_n211: return 0.11769122630357742f;
  t239_n212: return 0.13367368280887604f;
  t239_n213: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t239_n215;
  t239_n214: return -0.02192419022321701f;
  t239_n215: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n219;
  t239_n216: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t239_n218;
  t239_n217: return -0.07191582024097443f;
  t239_n218: return 0.11885355412960052f;
  t239_n219: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t239_n221;
  t239_n220: return 0.08755003660917282f;
  t239_n221: return 0.03431760147213936f;
  t239_n222: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t239_n228;
  t239_n223: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t239_n227;
  t239_n224: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n226;
  t239_n225: return 0.12480472773313522f;
  t239_n226: return 0.023843908682465553f;
  t239_n227: return 0.015225752256810665f;
  t239_n228: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t239_n234;
  t239_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n231;
  t239_n230: return 0.028373975306749344f;
  t239_n231: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t239_n233;
  t239_n232: return -0.09293878078460693f;
  t239_n233: return 0.11094542592763901f;
  t239_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n236;
  t239_n235: return 0.016023149713873863f;
  t239_n236: return 0.11992646753787994f;
  t239_n237: return 0.006870684213936329f;
  t239_n238: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t239_n254;
  t239_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t239_n243;
  t239_n240: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n242;
  t239_n241: return 0.019212966784834862f;
  t239_n242: return -0.005429632030427456f;
  t239_n243: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t239_n253;
  t239_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n252;
  t239_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t239_n247;
  t239_n246: return 0.0713188573718071f;
  t239_n247: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n251;
  t239_n248: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t239_n250;
  t239_n249: return 0.08320864289999008f;
  t239_n250: return 0.07129298895597458f;
  t239_n251: return 0.039818815886974335f;
  t239_n252: return 0.05954679474234581f;
  t239_n253: return -0.030411247164011f;
  t239_n254: return 0.12407396733760834f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree240(const Example& E) {
  t240_n0: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t240_n2;
  t240_n1: return -0.0004754458204843104f;
  t240_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t240_n234;
  t240_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t240_n5;
  t240_n4: return -0.016822611913084984f;
  t240_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t240_n11;
  t240_n6: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t240_n10;
  t240_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t240_n9;
  t240_n8: return -0.026837563142180443f;
  t240_n9: return 0.03502151742577553f;
  t240_n10: return 0.12367028743028641f;
  t240_n11: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t240_n203;
  t240_n12: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t240_n128;
  t240_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t240_n33;
  t240_n14: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t240_n22;
  t240_n15: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t240_n17;
  t240_n16: return -0.006280119530856609f;
  t240_n17: if (E.getNumReferences() >= 3265265664 /*80.0*/) goto t240_n21;
  t240_n18: if (E.getNumReferences() >= 3262119936 /*60.0*/) goto t240_n20;
  t240_n19: return -0.4754709303379059f;
  t240_n20: return 0.11628332734107971f;
  t240_n21: return -0.023576488718390465f;
  t240_n22: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t240_n32;
  t240_n23: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t240_n27;
  t240_n24: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t240_n26;
  t240_n25: return 0.09646379947662354f;
  t240_n26: return 0.14275120198726654f;
  t240_n27: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t240_n29;
  t240_n28: return -0.07836821675300598f;
  t240_n29: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t240_n31;
  t240_n30: return 0.11629479378461838f;
  t240_n31: return -0.20922642946243286f;
  t240_n32: return 0.021024782210588455f;
  t240_n33: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t240_n35;
  t240_n34: return 0.03388875350356102f;
  t240_n35: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t240_n123;
  t240_n36: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t240_n122;
  t240_n37: if (E.getNumReferences() >= 3357822688 /*168251.5*/) goto t240_n121;
  t240_n38: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t240_n76;
  t240_n39: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t240_n41;
  t240_n40: return 0.04785376042127609f;
  t240_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t240_n69;
  t240_n42: if (E.getNumReferences() >= 3291308032 /*693.5*/) goto t240_n66;
  t240_n43: if (E.getNumReferences() >= 3280584704 /*275.5*/) goto t240_n65;
  t240_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t240_n46;
  t240_n45: return -0.12057238817214966f;
  t240_n46: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t240_n54;
  t240_n47: if (E.getNumReferences() >= 3277914112 /*225.0*/) goto t240_n53;
  t240_n48: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t240_n50;
  t240_n49: return 0.10285972058773041f;
  t240_n50: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t240_n52;
  t240_n51: return 0.09576405584812164f;
  t240_n52: return -0.27773338556289673f;
  t240_n53: return 0.11043841391801834f;
  t240_n54: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t240_n60;
  t240_n55: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t240_n59;
  t240_n56: if (E.getNumReferences() >= 3260416000 /*53.5*/) goto t240_n58;
  t240_n57: return -0.45596399903297424f;
  t240_n58: return 0.11644545197486877f;
  t240_n59: return -0.1160360649228096f;
  t240_n60: if (E.getNumReferences() >= 3268870144 /*107.5*/) goto t240_n62;
  t240_n61: return 0.016826007515192032f;
  t240_n62: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t240_n64;
  t240_n63: return 0.10202235728502274f;
  t240_n64: return 0.04312444478273392f;
  t240_n65: return -0.20312952995300293f;
  t240_n66: if (E.getNumReferences() >= 3293487104 /*826.5*/) goto t240_n68;
  t240_n67: return 0.1007300615310669f;
  t240_n68: return 0.02813171036541462f;
  t240_n69: if (E.getNumReferences() >= 3269066752 /*109.0*/) goto t240_n73;
  t240_n70: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n72;
  t240_n71: return 0.013891187496483326f;
  t240_n72: return 0.0986388772726059f;
  t240_n73: if (E.getNumReferences() >= 3272081408 /*136.0*/) goto t240_n75;
  t240_n74: return 0.12860652804374695f;
  t240_n75: return -0.28182411193847656f;
  t240_n76: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t240_n78;
  t240_n77: return 0.10147961229085922f;
  t240_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t240_n116;
  t240_n79: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t240_n81;
  t240_n80: return -0.2383030205965042f;
  t240_n81: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t240_n83;
  t240_n82: return 0.08572627604007721f;
  t240_n83: if (E.getNumReferences() >= 3283517440 /*365.0*/) goto t240_n107;
  t240_n84: if (E.getNumReferences() >= 3268870144 /*107.5*/) goto t240_n92;
  t240_n85: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t240_n89;
  t240_n86: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t240_n88;
  t240_n87: return -0.4302809536457062f;
  t240_n88: return 0.0822673812508583f;
  t240_n89: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n91;
  t240_n90: return -0.5599217414855957f;
  t240_n91: return 0.052474021911621094f;
  t240_n92: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t240_n94;
  t240_n93: return 0.11027955263853073f;
  t240_n94: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t240_n106;
  t240_n95: if (E.getNumReferences() >= 3277783040 /*223.0*/) goto t240_n105;
  t240_n96: if (E.getNumReferences() >= 3273588736 /*159.0*/) goto t240_n100;
  t240_n97: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t240_n99;
  t240_n98: return -0.2743324041366577f;
  t240_n99: return 0.08371678739786148f;
  t240_n100: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t240_n102;
  t240_n101: return 0.09931459277868271f;
  t240_n102: if (E.getNumReferences() >= 3276079104 /*197.0*/) goto t240_n104;
  t240_n103: return -0.3757486343383789f;
  t240_n104: return 0.07312420010566711f;
  t240_n105: return -0.1498406082391739f;
  t240_n106: return 0.1041615679860115f;
  t240_n107: if (E.getNumReferences() >= 3307436032 /*2615.5*/) goto t240_n109;
  t240_n108: return -0.1610880196094513f;
  t240_n109: if (E.getNumReferences() >= 3315365888 /*5007.0*/) goto t240_n113;
  t240_n110: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t240_n112;
  t240_n111: return 0.08923061937093735f;
  t240_n112: return 0.11913466453552246f;
  t240_n113: if (E.getNumReferences() >= 3330320640 /*16468.5*/) goto t240_n115;
  t240_n114: return -0.8525256514549255f;
  t240_n115: return 0.0012525112833827734f;
  t240_n116: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t240_n118;
  t240_n117: return 0.10337620973587036f;
  t240_n118: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t240_n120;
  t240_n119: return 0.08281085640192032f;
  t240_n120: return -0.43004146218299866f;
  t240_n121: return -0.3988597095012665f;
  t240_n122: return 0.05107990652322769f;
  t240_n123: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t240_n127;
  t240_n124: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t240_n126;
  t240_n125: return -0.11085085570812225f;
  t240_n126: return 0.021015707403421402f;
  t240_n127: return -0.021317118778824806f;
  t240_n128: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t240_n130;
  t240_n129: return 0.017718298360705376f;
  t240_n130: if (E.getNumReferences() >= 3331557888 /*18885.0*/) goto t240_n192;
  t240_n131: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t240_n143;
  t240_n132: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n142;
  t240_n133: if (E.getNumReferences() >= 3310508032 /*3365.5*/) goto t240_n141;
  t240_n134: if (E.getNumReferences() >= 3285663744 /*430.5*/) goto t240_n136;
  t240_n135: return -0.3967925012111664f;
  t240_n136: if (E.getNumReferences() >= 3291455488 /*702.5*/) goto t240_n138;
  t240_n137: return 0.1056346446275711f;
  t240_n138: if (E.getNumReferences() >= 3309215744 /*3050.0*/) goto t240_n140;
  t240_n139: return -0.3425101935863495f;
  t240_n140: return 0.09051606804132462f;
  t240_n141: return -0.7534515261650085f;
  t240_n142: return -0.03908267244696617f;
  t240_n143: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t240_n179;
  t240_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t240_n176;
  t240_n145: if (E.getNumReferences() >= 3324132864 /*10383.5*/) goto t240_n175;
  t240_n146: if (E.getNumReferences() >= 3323790336 /*10049.0*/) goto t240_n174;
  t240_n147: if (E.getNumReferences() >= 3322210304 /*8506.0*/) goto t240_n173;
  t240_n148: if (E.getNumReferences() >= 3319786496 /*7165.5*/) goto t240_n170;
  t240_n149: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t240_n151;
  t240_n150: return -0.02533995360136032f;
  t240_n151: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t240_n169;
  t240_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n162;
  t240_n153: if (E.getNumReferences() >= 3281764352 /*311.5*/) goto t240_n155;
  t240_n154: return -0.2770109176635742f;
  t240_n155: if (E.getNumReferences() >= 3294363648 /*880.0*/) goto t240_n157;
  t240_n156: return 0.10335253179073334f;
  t240_n157: if (E.getNumReferences() >= 3301511168 /*1608.5*/) goto t240_n159;
  t240_n158: return -0.05996205285191536f;
  t240_n159: if (E.getNumReferences() >= 3312558080 /*3866.0*/) goto t240_n161;
  t240_n160: return 0.10640125721693039f;
  t240_n161: return -0.11487974226474762f;
  t240_n162: if (E.getNumReferences() >= 3283369984 /*360.5*/) goto t240_n168;
  t240_n163: if (E.getNumReferences() >= 3281682432 /*309.0*/) goto t240_n167;
  t240_n164: if (E.getNumReferences() >= 3271950336 /*134.0*/) goto t240_n166;
  t240_n165: return 0.08097883313894272f;
  t240_n166: return -0.3058198094367981f;
  t240_n167: return 0.12463012337684631f;
  t240_n168: return -0.07816372066736221f;
  t240_n169: return -0.04142913967370987f;
  t240_n170: if (E.getNumReferences() >= 3321036800 /*7776.0*/) goto t240_n172;
  t240_n171: return 0.11606843769550323f;
  t240_n172: return -0.1188897043466568f;
  t240_n173: return -0.30716222524642944f;
  t240_n174: return 0.08669893443584442f;
  t240_n175: return -0.09565165638923645f;
  t240_n176: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t240_n178;
  t240_n177: return 0.05893312767148018f;
  t240_n178: return 0.10989690572023392f;
  t240_n179: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t240_n191;
  t240_n180: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n186;
  t240_n181: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t240_n185;
  t240_n182: if (E.getNumReferences() >= 3269197824 /*110.0*/) goto t240_n184;
  t240_n183: return -0.42099931836128235f;
  t240_n184: return 0.09490638226270676f;
  t240_n185: return -0.36597150564193726f;
  t240_n186: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t240_n188;
  t240_n187: return 0.02067597024142742f;
  t240_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t240_n190;
  t240_n189: return -0.706843376159668f;
  t240_n190: return -0.0604146271944046f;
  t240_n191: return -0.02529534511268139f;
  t240_n192: if (E.getNumReferences() >= 3332209408 /*20157.5*/) goto t240_n202;
  t240_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t240_n201;
  t240_n194: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t240_n200;
  t240_n195: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t240_n199;
  t240_n196: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t240_n198;
  t240_n197: return 0.19412000477313995f;
  t240_n198: return 0.013597289100289345f;
  t240_n199: return 0.1126006543636322f;
  t240_n200: return -0.06878284364938736f;
  t240_n201: return -0.3329028785228729f;
  t240_n202: return 0.00013901761849410832f;
  t240_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t240_n207;
  t240_n204: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t240_n206;
  t240_n205: return -0.021633341908454895f;
  t240_n206: return 0.19809651374816895f;
  t240_n207: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t240_n209;
  t240_n208: return 0.006289023440331221f;
  t240_n209: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t240_n233;
  t240_n210: if (E.getNumReferences() >= 3346296960 /*62576.5*/) goto t240_n220;
  t240_n211: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t240_n219;
  t240_n212: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t240_n216;
  t240_n213: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n215;
  t240_n214: return 0.08714669197797775f;
  t240_n215: return 0.027704352512955666f;
  t240_n216: if (E.getNumReferences() >= 3343032192 /*49823.5*/) goto t240_n218;
  t240_n217: return -0.30379414558410645f;
  t240_n218: return 0.1191243901848793f;
  t240_n219: return 0.06077314168214798f;
  t240_n220: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t240_n228;
  t240_n221: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t240_n223;
  t240_n222: return -0.024538015946745872f;
  t240_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n227;
  t240_n224: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t240_n226;
  t240_n225: return -0.18491016328334808f;
  t240_n226: return 0.09216825664043427f;
  t240_n227: return 0.0049872430972754955f;
  t240_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n232;
  t240_n229: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t240_n231;
  t240_n230: return 0.028698090463876724f;
  t240_n231: return 0.08901993930339813f;
  t240_n232: return 0.020085005089640617f;
  t240_n233: return 0.010349598713219166f;
  t240_n234: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t240_n236;
  t240_n235: return -0.0006645562825724483f;
  t240_n236: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t240_n238;
  t240_n237: return 0.03328157588839531f;
  t240_n238: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t240_n254;
  t240_n239: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t240_n243;
  t240_n240: if (E.getNumReferences() >= 3260153856 /*52.5*/) goto t240_n242;
  t240_n241: return -0.08701115101575851f;
  t240_n242: return 0.1459837555885315f;
  t240_n243: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t240_n249;
  t240_n244: if (E.getNumReferences() >= 3288834048 /*542.5*/) goto t240_n246;
  t240_n245: return 0.06893644481897354f;
  t240_n246: if (E.getNumReferences() >= 3305973760 /*2258.5*/) goto t240_n248;
  t240_n247: return 0.14952890574932098f;
  t240_n248: return 0.11020484566688538f;
  t240_n249: if (E.getNumReferences() >= 3308357632 /*2840.5*/) goto t240_n251;
  t240_n250: return 0.003554086433723569f;
  t240_n251: if (E.getNumReferences() >= 3315506176 /*5075.5*/) goto t240_n253;
  t240_n252: return 0.13049198687076569f;
  t240_n253: return 0.10072603076696396f;
  t240_n254: return 0.044840335845947266f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree241(const Example& E) {
  t241_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t241_n2;
  t241_n1: return -0.00031889279489405453f;
  t241_n2: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t241_n254;
  t241_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t241_n23;
  t241_n4: if (E.getNumReferences() >= 3323708928 /*9969.5*/) goto t241_n16;
  t241_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t241_n7;
  t241_n6: return 0.0030734564643353224f;
  t241_n7: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t241_n9;
  t241_n8: return 0.011034179478883743f;
  t241_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n11;
  t241_n10: return 0.02268020249903202f;
  t241_n11: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t241_n13;
  t241_n12: return 0.08460575342178345f;
  t241_n13: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t241_n15;
  t241_n14: return 0.11321432888507843f;
  t241_n15: return 0.012118586339056492f;
  t241_n16: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t241_n22;
  t241_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t241_n19;
  t241_n18: return 0.049503762274980545f;
  t241_n19: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t241_n21;
  t241_n20: return 0.10452258586883545f;
  t241_n21: return -0.23941659927368164f;
  t241_n22: return 0.013390183448791504f;
  t241_n23: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t241_n25;
  t241_n24: return 0.005121992435306311f;
  t241_n25: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t241_n37;
  t241_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t241_n36;
  t241_n27: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t241_n35;
  t241_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n30;
  t241_n29: return -0.010323172435164452f;
  t241_n30: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t241_n34;
  t241_n31: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t241_n33;
  t241_n32: return -0.30521318316459656f;
  t241_n33: return -0.0834137499332428f;
  t241_n34: return -0.049566641449928284f;
  t241_n35: return 0.09970404952764511f;
  t241_n36: return -0.0060514602810144424f;
  t241_n37: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t241_n169;
  t241_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t241_n164;
  t241_n39: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t241_n77;
  t241_n40: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t241_n60;
  t241_n41: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t241_n59;
  t241_n42: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t241_n44;
  t241_n43: return -0.06306396424770355f;
  t241_n44: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t241_n48;
  t241_n45: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t241_n47;
  t241_n46: return 0.07520659267902374f;
  t241_n47: return -0.03359297662973404f;
  t241_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t241_n54;
  t241_n49: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t241_n53;
  t241_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n52;
  t241_n51: return 0.03425564989447594f;
  t241_n52: return -0.5554457902908325f;
  t241_n53: return -0.43309375643730164f;
  t241_n54: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t241_n56;
  t241_n55: return 0.01741253398358822f;
  t241_n56: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t241_n58;
  t241_n57: return 0.11048698425292969f;
  t241_n58: return 0.02742314152419567f;
  t241_n59: return -0.12922370433807373f;
  t241_n60: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t241_n76;
  t241_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t241_n71;
  t241_n62: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t241_n64;
  t241_n63: return -0.16172197461128235f;
  t241_n64: if (E.getNumReferences() >= 3235905536 /*7.0*/) goto t241_n66;
  t241_n65: return 0.14386136829853058f;
  t241_n66: if (E.getNumReferences() >= 3252158464 /*27.0*/) goto t241_n70;
  t241_n67: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t241_n69;
  t241_n68: return -0.12075906246900558f;
  t241_n69: return 0.1023542508482933f;
  t241_n70: return -0.11917737126350403f;
  t241_n71: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t241_n73;
  t241_n72: return 0.11289621889591217f;
  t241_n73: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t241_n75;
  t241_n74: return -0.1231093779206276f;
  t241_n75: return 0.07695458829402924f;
  t241_n76: return 0.10074523836374283f;
  t241_n77: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t241_n131;
  t241_n78: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t241_n112;
  t241_n79: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t241_n85;
  t241_n80: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t241_n84;
  t241_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t241_n83;
  t241_n82: return -0.06691452860832214f;
  t241_n83: return -0.005183847155421972f;
  t241_n84: return 0.0830283984541893f;
  t241_n85: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t241_n95;
  t241_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t241_n92;
  t241_n87: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t241_n91;
  t241_n88: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t241_n90;
  t241_n89: return -0.13518522679805756f;
  t241_n90: return 0.10290350764989853f;
  t241_n91: return 0.09870067983865738f;
  t241_n92: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t241_n94;
  t241_n93: return 0.06434974074363708f;
  t241_n94: return -0.37314674258232117f;
  t241_n95: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n97;
  t241_n96: return -0.060244474560022354f;
  t241_n97: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t241_n99;
  t241_n98: return -0.08180879056453705f;
  t241_n99: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t241_n109;
  t241_n100: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t241_n104;
  t241_n101: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t241_n103;
  t241_n102: return 0.07510316371917725f;
  t241_n103: return 0.11504116654396057f;
  t241_n104: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t241_n108;
  t241_n105: if (E.getNumReferences() >= 3289014272 /*553.5*/) goto t241_n107;
  t241_n106: return 0.08797058463096619f;
  t241_n107: return 0.04999915510416031f;
  t241_n108: return 0.006032351870089769f;
  t241_n109: if (E.getNumReferences() >= 3266379776 /*88.5*/) goto t241_n111;
  t241_n110: return 0.0746794044971466f;
  t241_n111: return -0.4367775619029999f;
  t241_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t241_n126;
  t241_n113: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t241_n115;
  t241_n114: return 0.005553332157433033f;
  t241_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t241_n119;
  t241_n116: if (E.getNumReferences() >= 3325290496 /*11514.0*/) goto t241_n118;
  t241_n117: return -0.022771397605538368f;
  t241_n118: return 0.07443307340145111f;
  t241_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n123;
  t241_n120: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t241_n122;
  t241_n121: return 0.09269339591264725f;
  t241_n122: return 0.04285329207777977f;
  t241_n123: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t241_n125;
  t241_n124: return 0.03931164741516113f;
  t241_n125: return 0.1271916627883911f;
  t241_n126: if (E.getNumReferences() >= 3277357056 /*216.5*/) goto t241_n128;
  t241_n127: return -0.009314036928117275f;
  t241_n128: if (E.getNumReferences() >= 3298672640 /*1262.0*/) goto t241_n130;
  t241_n129: return -0.6297067999839783f;
  t241_n130: return -0.03177985921502113f;
  t241_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n139;
  t241_n132: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t241_n138;
  t241_n133: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t241_n137;
  t241_n134: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t241_n136;
  t241_n135: return 0.46274012327194214f;
  t241_n136: return 0.018629413098096848f;
  t241_n137: return 0.12678535282611847f;
  t241_n138: return 0.011360838077962399f;
  t241_n139: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t241_n145;
  t241_n140: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t241_n142;
  t241_n141: return -0.05360225588083267f;
  t241_n142: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t241_n144;
  t241_n143: return 0.09890687465667725f;
  t241_n144: return 0.0696510598063469f;
  t241_n145: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t241_n157;
  t241_n146: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t241_n156;
  t241_n147: if (E.getNumReferences() >= 3296755712 /*1028.0*/) goto t241_n153;
  t241_n148: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t241_n150;
  t241_n149: return 0.11691572517156601f;
  t241_n150: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t241_n152;
  t241_n151: return -0.3818754553794861f;
  t241_n152: return -0.03652709722518921f;
  t241_n153: if (E.getNumReferences() >= 3342540544 /*47903.0*/) goto t241_n155;
  t241_n154: return 0.11752401292324066f;
  t241_n155: return 0.06260769814252853f;
  t241_n156: return 0.047910548746585846f;
  t241_n157: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t241_n163;
  t241_n158: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t241_n162;
  t241_n159: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t241_n161;
  t241_n160: return 0.11714202165603638f;
  t241_n161: return 0.029578587040305138f;
  t241_n162: return 0.045789819210767746f;
  t241_n163: return -0.0377354621887207f;
  t241_n164: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t241_n168;
  t241_n165: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t241_n167;
  t241_n166: return 0.10153556615114212f;
  t241_n167: return 0.043062347918748856f;
  t241_n168: return 0.21241040527820587f;
  t241_n169: if (E.getNumReferences() >= 3269066752 /*109.0*/) goto t241_n225;
  t241_n170: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n178;
  t241_n171: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t241_n173;
  t241_n172: return -0.021858589723706245f;
  t241_n173: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t241_n177;
  t241_n174: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t241_n176;
  t241_n175: return -0.1266472488641739f;
  t241_n176: return 0.006181780248880386f;
  t241_n177: return 0.05839533731341362f;
  t241_n178: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t241_n200;
  t241_n179: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t241_n197;
  t241_n180: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t241_n192;
  t241_n181: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t241_n189;
  t241_n182: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t241_n188;
  t241_n183: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t241_n185;
  t241_n184: return -0.4096609652042389f;
  t241_n185: if (E.getFileProximityDistance() >= 3238002688 /*8.0*/) goto t241_n187;
  t241_n186: return 0.3862212598323822f;
  t241_n187: return -0.13556452095508575f;
  t241_n188: return -0.014235349372029305f;
  t241_n189: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t241_n191;
  t241_n190: return -0.1755097657442093f;
  t241_n191: return 0.04348307475447655f;
  t241_n192: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t241_n194;
  t241_n193: return 0.09416031837463379f;
  t241_n194: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t241_n196;
  t241_n195: return 0.08012592047452927f;
  t241_n196: return 0.014102858491241932f;
  t241_n197: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t241_n199;
  t241_n198: return -0.8212521076202393f;
  t241_n199: return -0.11076177656650543f;
  t241_n200: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t241_n206;
  t241_n201: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t241_n205;
  t241_n202: if (E.getNumReferences() >= 3255828480 /*36.0*/) goto t241_n204;
  t241_n203: return 0.009225054644048214f;
  t241_n204: return 0.13718000054359436f;
  t241_n205: return -0.9921821355819702f;
  t241_n206: if (E.getNumReferences() >= 3258974208 /*48.0*/) goto t241_n224;
  t241_n207: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t241_n223;
  t241_n208: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t241_n220;
  t241_n209: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t241_n217;
  t241_n210: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t241_n212;
  t241_n211: return 0.08332151919603348f;
  t241_n212: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t241_n214;
  t241_n213: return -0.04729318246245384f;
  t241_n214: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t241_n216;
  t241_n215: return 0.042762573808431625f;
  t241_n216: return 0.06317666918039322f;
  t241_n217: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t241_n219;
  t241_n218: return -0.7822275757789612f;
  t241_n219: return -0.017977511510252953f;
  t241_n220: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t241_n222;
  t241_n221: return 0.10013934224843979f;
  t241_n222: return 0.15096499025821686f;
  t241_n223: return -0.02739504911005497f;
  t241_n224: return 0.11015935987234116f;
  t241_n225: if (E.getNumReferences() >= 3289784320 /*600.5*/) goto t241_n239;
  t241_n226: if (E.getNumReferences() >= 3287810048 /*496.0*/) goto t241_n236;
  t241_n227: if (E.getNumReferences() >= 3274014720 /*165.5*/) goto t241_n235;
  t241_n228: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t241_n230;
  t241_n229: return 0.12912246584892273f;
  t241_n230: if (E.getNumReferences() >= 3272376320 /*140.5*/) goto t241_n232;
  t241_n231: return -0.060532547533512115f;
  t241_n232: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t241_n234;
  t241_n233: return -0.2940422296524048f;
  t241_n234: return 0.10365653783082962f;
  t241_n235: return -0.012259368784725666f;
  t241_n236: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t241_n238;
  t241_n237: return 0.09645882248878479f;
  t241_n238: return 0.09397386014461517f;
  t241_n239: if (E.getNumReferences() >= 3305295872 /*2093.0*/) goto t241_n247;
  t241_n240: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t241_n246;
  t241_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t241_n245;
  t241_n242: if (E.getNumReferences() >= 3299385344 /*1349.0*/) goto t241_n244;
  t241_n243: return -0.48323705792427063f;
  t241_n244: return -1.1121833324432373f;
  t241_n245: return -0.0989876314997673f;
  t241_n246: return 0.05183260887861252f;
  t241_n247: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t241_n251;
  t241_n248: if (E.getNumReferences() >= 3306676224 /*2430.0*/) goto t241_n250;
  t241_n249: return 0.10444844514131546f;
  t241_n250: return 0.09511885046958923f;
  t241_n251: if (E.getNumReferences() >= 3325117440 /*11345.0*/) goto t241_n253;
  t241_n252: return -0.25829365849494934f;
  t241_n253: return 0.07775874435901642f;
  t241_n254: return -0.0003493283875286579f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree242(const Example& E) {
  t242_n0: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t242_n2;
  t242_n1: return -0.0004759879084303975f;
  t242_n2: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t242_n180;
  t242_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t242_n81;
  t242_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t242_n6;
  t242_n5: return 0.003826610976830125f;
  t242_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t242_n74;
  t242_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t242_n21;
  t242_n8: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t242_n20;
  t242_n9: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t242_n11;
  t242_n10: return 0.01226250734180212f;
  t242_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t242_n13;
  t242_n12: return -0.10197734832763672f;
  t242_n13: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t242_n19;
  t242_n14: if (E.getNumReferences() >= 3275751424 /*192.0*/) goto t242_n18;
  t242_n15: if (E.getNumReferences() >= 3266641920 /*90.5*/) goto t242_n17;
  t242_n16: return 0.01774969883263111f;
  t242_n17: return 0.10950680077075958f;
  t242_n18: return -0.1168958768248558f;
  t242_n19: return -0.3354310989379883f;
  t242_n20: return -0.13776348531246185f;
  t242_n21: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t242_n73;
  t242_n22: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t242_n56;
  t242_n23: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t242_n25;
  t242_n24: return -0.08577151596546173f;
  t242_n25: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t242_n35;
  t242_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t242_n32;
  t242_n27: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t242_n31;
  t242_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t242_n30;
  t242_n29: return -0.824708878993988f;
  t242_n30: return -0.1876383125782013f;
  t242_n31: return -0.010720578022301197f;
  t242_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t242_n34;
  t242_n33: return -0.2424316257238388f;
  t242_n34: return 0.12780441343784332f;
  t242_n35: if (E.getNumReferences() >= 3268214784 /*102.5*/) goto t242_n39;
  t242_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t242_n38;
  t242_n37: return 0.029840027913451195f;
  t242_n38: return 0.11760036647319794f;
  t242_n39: if (E.getNumReferences() >= 3272966144 /*149.5*/) goto t242_n41;
  t242_n40: return -0.04387642815709114f;
  t242_n41: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t242_n47;
  t242_n42: if (E.getNumReferences() >= 3274178560 /*168.0*/) goto t242_n46;
  t242_n43: if (E.getNumReferences() >= 3273293824 /*154.5*/) goto t242_n45;
  t242_n44: return 0.0936851054430008f;
  t242_n45: return 0.024105727672576904f;
  t242_n46: return 0.11770384013652802f;
  t242_n47: if (E.getNumReferences() >= 3275620352 /*190.0*/) goto t242_n49;
  t242_n48: return -0.6160053610801697f;
  t242_n49: if (E.getNumReferences() >= 3275948032 /*195.0*/) goto t242_n51;
  t242_n50: return 0.09475556015968323f;
  t242_n51: if (E.getNumReferences() >= 3278077952 /*227.5*/) goto t242_n53;
  t242_n52: return -0.2309671938419342f;
  t242_n53: if (E.getNumReferences() >= 3280044032 /*259.0*/) goto t242_n55;
  t242_n54: return 0.10431579500436783f;
  t242_n55: return 0.03978181630373001f;
  t242_n56: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t242_n66;
  t242_n57: if (E.getNumReferences() >= 3266510848 /*89.5*/) goto t242_n61;
  t242_n58: if (E.getNumReferences() >= 3265986560 /*85.5*/) goto t242_n60;
  t242_n59: return 0.0027261136565357447f;
  t242_n60: return 0.12948425114154816f;
  t242_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t242_n63;
  t242_n62: return -0.03820207715034485f;
  t242_n63: if (E.getNumReferences() >= 3280633856 /*277.0*/) goto t242_n65;
  t242_n64: return 0.10605953633785248f;
  t242_n65: return 0.0008893201593309641f;
  t242_n66: if (E.getNumReferences() >= 3289227264 /*566.5*/) goto t242_n68;
  t242_n67: return 0.11801600456237793f;
  t242_n68: if (E.getNumReferences() >= 3295485952 /*948.5*/) goto t242_n70;
  t242_n69: return -0.1886707842350006f;
  t242_n70: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t242_n72;
  t242_n71: return 0.1041620597243309f;
  t242_n72: return 0.110979825258255f;
  t242_n73: return 0.014157609082758427f;
  t242_n74: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t242_n76;
  t242_n75: return 0.029648326337337494f;
  t242_n76: if (E.getNumReferences() >= 3266838528 /*92.0*/) goto t242_n78;
  t242_n77: return -0.20731233060359955f;
  t242_n78: if (E.getNumReferences() >= 3286859776 /*467.0*/) goto t242_n80;
  t242_n79: return 0.13193732500076294f;
  t242_n80: return -0.07842736691236496f;
  t242_n81: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t242_n177;
  t242_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t242_n84;
  t242_n83: return -0.007396592292934656f;
  t242_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t242_n86;
  t242_n85: return 0.016364455223083496f;
  t242_n86: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t242_n138;
  t242_n87: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t242_n133;
  t242_n88: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t242_n94;
  t242_n89: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t242_n93;
  t242_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t242_n92;
  t242_n91: return -0.12205569446086884f;
  t242_n92: return 0.4533081352710724f;
  t242_n93: return 0.1093655675649643f;
  t242_n94: if (E.getNumReferences() >= 3271491584 /*127.5*/) goto t242_n116;
  t242_n95: if (E.getNumReferences() >= 3270967296 /*123.5*/) goto t242_n115;
  t242_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t242_n98;
  t242_n97: return -0.11001890897750854f;
  t242_n98: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t242_n106;
  t242_n99: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t242_n101;
  t242_n100: return -0.016758233308792114f;
  t242_n101: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t242_n105;
  t242_n102: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t242_n104;
  t242_n103: return 0.39730966091156006f;
  t242_n104: return 0.11711296439170837f;
  t242_n105: return 0.1177123561501503f;
  t242_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t242_n112;
  t242_n107: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t242_n111;
  t242_n108: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t242_n110;
  t242_n109: return 0.10546103119850159f;
  t242_n110: return 0.09514773637056351f;
  t242_n111: return -0.2045021504163742f;
  t242_n112: if (E.getNumReferences() >= 3269328896 /*111.0*/) goto t242_n114;
  t242_n113: return -0.07458905130624771f;
  t242_n114: return 0.11988051980733871f;
  t242_n115: return 0.1319401115179062f;
  t242_n116: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t242_n118;
  t242_n117: return -0.027810320258140564f;
  t242_n118: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t242_n120;
  t242_n119: return -0.10649131238460541f;
  t242_n120: if (E.getNumReferences() >= 3273850880 /*163.0*/) goto t242_n124;
  t242_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t242_n123;
  t242_n122: return -0.10755404829978943f;
  t242_n123: return 0.10549180954694748f;
  t242_n124: if (E.getNumReferences() >= 3287580672 /*489.0*/) goto t242_n128;
  t242_n125: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t242_n127;
  t242_n126: return -0.047495026141405106f;
  t242_n127: return 0.22140797972679138f;
  t242_n128: if (E.getNumReferences() >= 3292299264 /*754.0*/) goto t242_n132;
  t242_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t242_n131;
  t242_n130: return 0.11127340793609619f;
  t242_n131: return 0.09917575120925903f;
  t242_n132: return 0.05608639866113663f;
  t242_n133: if (E.getNumReferences() >= 3318054912 /*6320.0*/) goto t242_n135;
  t242_n134: return 0.007940681651234627f;
  t242_n135: if (E.getNumReferences() >= 3319092224 /*6826.5*/) goto t242_n137;
  t242_n136: return 0.1779320389032364f;
  t242_n137: return 0.04571641981601715f;
  t242_n138: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t242_n158;
  t242_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t242_n151;
  t242_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t242_n142;
  t242_n141: return 0.005732151214033365f;
  t242_n142: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t242_n150;
  t242_n143: if (E.getNumReferences() >= 3264020480 /*70.5*/) goto t242_n149;
  t242_n144: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t242_n146;
  t242_n145: return -0.10489640384912491f;
  t242_n146: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t242_n148;
  t242_n147: return 0.11532219499349594f;
  t242_n148: return -0.07451590150594711f;
  t242_n149: return 0.11027500033378601f;
  t242_n150: return 0.02755456231534481f;
  t242_n151: if (E.getNumReferences() >= 3267756032 /*99.0*/) goto t242_n153;
  t242_n152: return -0.19179879128932953f;
  t242_n153: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t242_n155;
  t242_n154: return 0.10716381669044495f;
  t242_n155: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t242_n157;
  t242_n156: return 0.05614479258656502f;
  t242_n157: return 0.10998804867267609f;
  t242_n158: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t242_n162;
  t242_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t242_n161;
  t242_n160: return 0.01232842542231083f;
  t242_n161: return 0.12131825089454651f;
  t242_n162: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t242_n170;
  t242_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t242_n165;
  t242_n164: return -0.03403427451848984f;
  t242_n165: if (E.getNumReferences() >= 3290537984 /*646.5*/) goto t242_n169;
  t242_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t242_n168;
  t242_n167: return 0.019937114790081978f;
  t242_n168: return 0.12404908984899521f;
  t242_n169: return -0.11405602842569351f;
  t242_n170: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t242_n174;
  t242_n171: if (E.getNumReferences() >= 3276570624 /*204.5*/) goto t242_n173;
  t242_n172: return 0.10040375590324402f;
  t242_n173: return 0.05527634546160698f;
  t242_n174: if (E.getNumReferences() >= 3291521024 /*706.5*/) goto t242_n176;
  t242_n175: return 0.12809059023857117f;
  t242_n176: return -0.3986850678920746f;
  t242_n177: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t242_n179;
  t242_n178: return -0.004274423699826002f;
  t242_n179: return 0.007294195704162121f;
  t242_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t242_n184;
  t242_n181: if (E.getNumReferences() >= 3319477248 /*7014.5*/) goto t242_n183;
  t242_n182: return -0.03101371042430401f;
  t242_n183: return 0.03001571260392666f;
  t242_n184: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t242_n186;
  t242_n185: return 0.021812953054904938f;
  t242_n186: if (E.getNumReferences() >= 3290316800 /*633.0*/) goto t242_n230;
  t242_n187: if (E.getNumReferences() >= 3289153536 /*562.0*/) goto t242_n213;
  t242_n188: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t242_n206;
  t242_n189: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t242_n205;
  t242_n190: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t242_n198;
  t242_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t242_n193;
  t242_n192: return 0.09175601601600647f;
  t242_n193: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t242_n195;
  t242_n194: return -0.26476964354515076f;
  t242_n195: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t242_n197;
  t242_n196: return 0.1748036891222f;
  t242_n197: return 0.024145212024450302f;
  t242_n198: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t242_n200;
  t242_n199: return -0.13450616598129272f;
  t242_n200: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t242_n204;
  t242_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t242_n203;
  t242_n202: return -0.11206885427236557f;
  t242_n203: return 0.14191827178001404f;
  t242_n204: return -0.11878100782632828f;
  t242_n205: return -0.03853902220726013f;
  t242_n206: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t242_n210;
  t242_n207: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t242_n209;
  t242_n208: return 0.030464615672826767f;
  t242_n209: return 0.0439116433262825f;
  t242_n210: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t242_n212;
  t242_n211: return -0.3010175824165344f;
  t242_n212: return 0.08832195401191711f;
  t242_n213: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t242_n225;
  t242_n214: if (E.getNumReferences() >= 3289210880 /*565.5*/) goto t242_n216;
  t242_n215: return 0.12431932985782623f;
  t242_n216: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t242_n218;
  t242_n217: return -0.02070598304271698f;
  t242_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t242_n220;
  t242_n219: return 0.0933123230934143f;
  t242_n220: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t242_n224;
  t242_n221: if (E.getNumReferences() >= 3289735168 /*597.5*/) goto t242_n223;
  t242_n222: return 0.06162954866886139f;
  t242_n223: return 0.11079247295856476f;
  t242_n224: return -0.0075329928658902645f;
  t242_n225: if (E.getNumReferences() >= 3289374720 /*575.5*/) goto t242_n227;
  t242_n226: return 0.14513441920280457f;
  t242_n227: if (E.getFilterLength() >= 3247177728 /*17.5*/) goto t242_n229;
  t242_n228: return 0.1002577468752861f;
  t242_n229: return 0.10810086876153946f;
  t242_n230: if (E.getNumReferences() >= 3308015616 /*2757.0*/) goto t242_n232;
  t242_n231: return -0.020037777721881866f;
  t242_n232: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t242_n250;
  t242_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t242_n235;
  t242_n234: return 0.00937426183372736f;
  t242_n235: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t242_n249;
  t242_n236: if (E.getNumReferences() >= 3318737920 /*6653.5*/) goto t242_n244;
  t242_n237: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t242_n243;
  t242_n238: if (E.getNumReferences() >= 3310948352 /*3473.0*/) goto t242_n240;
  t242_n239: return 0.11846938729286194f;
  t242_n240: if (E.getNumReferences() >= 3315686400 /*5163.5*/) goto t242_n242;
  t242_n241: return -0.015767790377140045f;
  t242_n242: return 0.08829144388437271f;
  t242_n243: return -0.04678162932395935f;
  t242_n244: if (E.getNumReferences() >= 3319330816 /*6943.0*/) goto t242_n246;
  t242_n245: return 0.12276113033294678f;
  t242_n246: if (E.getNumReferences() >= 3346507648 /*63399.5*/) goto t242_n248;
  t242_n247: return 0.08637462556362152f;
  t242_n248: return -0.36267808079719543f;
  t242_n249: return 0.045882321894168854f;
  t242_n250: if (E.getNumReferences() >= 3308521472 /*2880.5*/) goto t242_n254;
  t242_n251: if (E.getNumReferences() >= 3308406784 /*2852.5*/) goto t242_n253;
  t242_n252: return 0.02250438556075096f;
  t242_n253: return 0.13372932374477386f;
  t242_n254: return 0.009136805310845375f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree243(const Example& E) {
  t243_n0: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t243_n114;
  t243_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t243_n3;
  t243_n2: return -0.014291533268988132f;
  t243_n3: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t243_n5;
  t243_n4: return -0.0005509261391125619f;
  t243_n5: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t243_n23;
  t243_n6: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t243_n20;
  t243_n7: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t243_n17;
  t243_n8: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t243_n12;
  t243_n9: if (E.getNumReferences() >= 3241148416 /*11.0*/) goto t243_n11;
  t243_n10: return -0.10391980409622192f;
  t243_n11: return 1.1342415809631348f;
  t243_n12: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t243_n14;
  t243_n13: return 0.13612185418605804f;
  t243_n14: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t243_n16;
  t243_n15: return 0.10808280855417252f;
  t243_n16: return 0.05430961027741432f;
  t243_n17: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t243_n19;
  t243_n18: return 0.12031567841768265f;
  t243_n19: return -0.3301578760147095f;
  t243_n20: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t243_n22;
  t243_n21: return 0.02162541076540947f;
  t243_n22: return 0.009455448016524315f;
  t243_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t243_n111;
  t243_n24: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t243_n26;
  t243_n25: return -0.0033411122858524323f;
  t243_n26: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t243_n28;
  t243_n27: return 0.014438895508646965f;
  t243_n28: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t243_n56;
  t243_n29: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t243_n43;
  t243_n30: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t243_n42;
  t243_n31: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t243_n33;
  t243_n32: return -0.19664739072322845f;
  t243_n33: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t243_n41;
  t243_n34: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t243_n36;
  t243_n35: return 0.055700648576021194f;
  t243_n36: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t243_n40;
  t243_n37: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t243_n39;
  t243_n38: return -0.12449770420789719f;
  t243_n39: return 0.09992267191410065f;
  t243_n40: return 0.05022849515080452f;
  t243_n41: return 0.05698341131210327f;
  t243_n42: return -0.013981223106384277f;
  t243_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t243_n55;
  t243_n44: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t243_n48;
  t243_n45: if (E.getNumReferences() >= 3238002688 /*8.0*/) goto t243_n47;
  t243_n46: return 0.027302047237753868f;
  t243_n47: return 0.10574794560670853f;
  t243_n48: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t243_n54;
  t243_n49: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t243_n51;
  t243_n50: return 0.032823849469423294f;
  t243_n51: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t243_n53;
  t243_n52: return 0.1069963127374649f;
  t243_n53: return -0.1182061955332756f;
  t243_n54: return -0.007231312338262796f;
  t243_n55: return 0.0027437659446150064f;
  t243_n56: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t243_n86;
  t243_n57: if (E.getNumReferences() >= 3317581824 /*6089.0*/) goto t243_n79;
  t243_n58: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t243_n78;
  t243_n59: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t243_n65;
  t243_n60: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t243_n62;
  t243_n61: return 0.05645768716931343f;
  t243_n62: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t243_n64;
  t243_n63: return 0.11663532257080078f;
  t243_n64: return -0.10207562893629074f;
  t243_n65: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t243_n67;
  t243_n66: return 0.12864680588245392f;
  t243_n67: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t243_n71;
  t243_n68: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t243_n70;
  t243_n69: return 0.07577745616436005f;
  t243_n70: return 0.11221788078546524f;
  t243_n71: if (E.getNumReferences() >= 3272540160 /*143.0*/) goto t243_n77;
  t243_n72: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t243_n74;
  t243_n73: return -0.1103539988398552f;
  t243_n74: if (E.getNumReferences() >= 3260809216 /*55.0*/) goto t243_n76;
  t243_n75: return -0.10405811667442322f;
  t243_n76: return 0.1430792212486267f;
  t243_n77: return 0.10389986634254456f;
  t243_n78: return 0.009411065839231014f;
  t243_n79: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t243_n85;
  t243_n80: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t243_n82;
  t243_n81: return 0.15151536464691162f;
  t243_n82: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t243_n84;
  t243_n83: return -0.10495420545339584f;
  t243_n84: return 0.10743152350187302f;
  t243_n85: return 0.052397504448890686f;
  t243_n86: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t243_n100;
  t243_n87: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t243_n89;
  t243_n88: return -0.04555375128984451f;
  t243_n89: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t243_n93;
  t243_n90: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t243_n92;
  t243_n91: return -0.2144087851047516f;
  t243_n92: return 0.15991081297397614f;
  t243_n93: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t243_n95;
  t243_n94: return -0.13069681823253632f;
  t243_n95: if (E.getNumReferences() >= 3262906368 /*63.0*/) goto t243_n99;
  t243_n96: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t243_n98;
  t243_n97: return 0.09650484472513199f;
  t243_n98: return 0.07841862738132477f;
  t243_n99: return 0.04504390060901642f;
  t243_n100: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t243_n102;
  t243_n101: return -0.3108496367931366f;
  t243_n102: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t243_n104;
  t243_n103: return -0.4520431160926819f;
  t243_n104: if (E.getNumReferences() >= 3274047488 /*166.0*/) goto t243_n106;
  t243_n105: return -0.1284266859292984f;
  t243_n106: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t243_n108;
  t243_n107: return 0.0640367865562439f;
  t243_n108: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t243_n110;
  t243_n109: return -0.13704781234264374f;
  t243_n110: return 0.1044459268450737f;
  t243_n111: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t243_n113;
  t243_n112: return -0.030986500903964043f;
  t243_n113: return 0.06695182621479034f;
  t243_n114: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t243_n252;
  t243_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t243_n245;
  t243_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t243_n166;
  t243_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t243_n163;
  t243_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t243_n120;
  t243_n119: return 0.0017976780654862523f;
  t243_n120: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t243_n162;
  t243_n121: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t243_n157;
  t243_n122: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t243_n134;
  t243_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n133;
  t243_n124: if (E.getNumReferences() >= 3324926976 /*11159.0*/) goto t243_n126;
  t243_n125: return -0.005709650926291943f;
  t243_n126: if (E.getNumReferences() >= 3326202880 /*12405.0*/) goto t243_n132;
  t243_n127: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t243_n131;
  t243_n128: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t243_n130;
  t243_n129: return 0.1055377870798111f;
  t243_n130: return 0.10520443320274353f;
  t243_n131: return 0.0993914008140564f;
  t243_n132: return 0.016647033393383026f;
  t243_n133: return 0.017875803634524345f;
  t243_n134: if (E.getNumReferences() >= 3308414976 /*2854.5*/) goto t243_n146;
  t243_n135: if (E.getNumReferences() >= 3295502336 /*949.5*/) goto t243_n145;
  t243_n136: if (E.getNumReferences() >= 3281895424 /*315.5*/) goto t243_n142;
  t243_n137: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t243_n141;
  t243_n138: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t243_n140;
  t243_n139: return 0.0033077914267778397f;
  t243_n140: return -0.04108559712767601f;
  t243_n141: return 0.0161689855158329f;
  t243_n142: if (E.getNumReferences() >= 3282157568 /*323.5*/) goto t243_n144;
  t243_n143: return 0.11308705061674118f;
  t243_n144: return 0.023911116644740105f;
  t243_n145: return -0.12551161646842957f;
  t243_n146: if (E.getNumReferences() >= 3310059520 /*3256.0*/) goto t243_n154;
  t243_n147: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t243_n149;
  t243_n148: return 0.11764741688966751f;
  t243_n149: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t243_n151;
  t243_n150: return 0.009585648775100708f;
  t243_n151: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t243_n153;
  t243_n152: return 0.31590190529823303f;
  t243_n153: return 0.3004128336906433f;
  t243_n154: if (E.getFileProximityDistance() >= 3238002688 /*8.0*/) goto t243_n156;
  t243_n155: return 0.11037294566631317f;
  t243_n156: return 0.00491925235837698f;
  t243_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n161;
  t243_n158: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t243_n160;
  t243_n159: return 0.05798967555165291f;
  t243_n160: return -0.06327749788761139f;
  t243_n161: return -0.029953544959425926f;
  t243_n162: return -0.026990626007318497f;
  t243_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t243_n165;
  t243_n164: return -0.038948219269514084f;
  t243_n165: return -0.02800331450998783f;
  t243_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t243_n176;
  t243_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t243_n169;
  t243_n168: return -0.0016750250943005085f;
  t243_n169: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t243_n171;
  t243_n170: return 0.0004362122272141278f;
  t243_n171: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t243_n173;
  t243_n172: return 0.019873708486557007f;
  t243_n173: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t243_n175;
  t243_n174: return 0.08645296096801758f;
  t243_n175: return 0.0368146151304245f;
  t243_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t243_n182;
  t243_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t243_n179;
  t243_n178: return 0.03553200885653496f;
  t243_n179: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t243_n181;
  t243_n180: return 0.037773314863443375f;
  t243_n181: return 0.0513138473033905f;
  t243_n182: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t243_n224;
  t243_n183: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t243_n185;
  t243_n184: return 0.023729586973786354f;
  t243_n185: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t243_n193;
  t243_n186: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n192;
  t243_n187: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t243_n189;
  t243_n188: return -0.17837275564670563f;
  t243_n189: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t243_n191;
  t243_n190: return 0.10443465411663055f;
  t243_n191: return 0.0916736051440239f;
  t243_n192: return -0.011968466453254223f;
  t243_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t243_n215;
  t243_n194: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t243_n214;
  t243_n195: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t243_n197;
  t243_n196: return 0.027018923312425613f;
  t243_n197: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t243_n205;
  t243_n198: if (E.getNumReferences() >= 3344088704 /*53950.5*/) goto t243_n200;
  t243_n199: return 0.11912516504526138f;
  t243_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n204;
  t243_n201: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t243_n203;
  t243_n202: return -0.11253441870212555f;
  t243_n203: return 0.12185664474964142f;
  t243_n204: return -0.5120013356208801f;
  t243_n205: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t243_n209;
  t243_n206: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t243_n208;
  t243_n207: return 0.11825064569711685f;
  t243_n208: return 0.06693071126937866f;
  t243_n209: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t243_n211;
  t243_n210: return 0.041056420654058456f;
  t243_n211: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t243_n213;
  t243_n212: return 0.1300847828388214f;
  t243_n213: return 0.10001510381698608f;
  t243_n214: return -0.008232975378632545f;
  t243_n215: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n223;
  t243_n216: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t243_n222;
  t243_n217: if (E.getNumReferences() >= 3333923840 /*23506.0*/) goto t243_n221;
  t243_n218: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t243_n220;
  t243_n219: return -0.13309794664382935f;
  t243_n220: return 0.11051501333713531f;
  t243_n221: return 0.02886749804019928f;
  t243_n222: return 0.10195942223072052f;
  t243_n223: return 0.05794066563248634f;
  t243_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t243_n236;
  t243_n225: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n227;
  t243_n226: return 0.06696901470422745f;
  t243_n227: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t243_n229;
  t243_n228: return 0.054118331521749496f;
  t243_n229: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t243_n233;
  t243_n230: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t243_n232;
  t243_n231: return -0.2066965401172638f;
  t243_n232: return 0.12663054466247559f;
  t243_n233: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t243_n235;
  t243_n234: return 0.28745418787002563f;
  t243_n235: return 0.05778895318508148f;
  t243_n236: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t243_n238;
  t243_n237: return -0.035839006304740906f;
  t243_n238: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t243_n242;
  t243_n239: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n241;
  t243_n240: return 0.07311569899320602f;
  t243_n241: return 0.03474023565649986f;
  t243_n242: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t243_n244;
  t243_n243: return 0.1476123034954071f;
  t243_n244: return 0.10874636471271515f;
  t243_n245: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t243_n251;
  t243_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t243_n248;
  t243_n247: return -0.013290917500853539f;
  t243_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t243_n250;
  t243_n249: return -0.10172094404697418f;
  t243_n250: return 0.063081756234169f;
  t243_n251: return 0.009790889918804169f;
  t243_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t243_n254;
  t243_n253: return -0.1103893518447876f;
  t243_n254: return -0.0005365421529859304f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree244(const Example& E) {
  t244_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t244_n70;
  t244_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t244_n3;
  t244_n2: return 0.0003301998949609697f;
  t244_n3: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t244_n67;
  t244_n4: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t244_n50;
  t244_n5: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t244_n39;
  t244_n6: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t244_n8;
  t244_n7: return -0.03369836136698723f;
  t244_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t244_n20;
  t244_n9: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t244_n11;
  t244_n10: return -2.4025357561185956e-05f;
  t244_n11: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n19;
  t244_n12: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t244_n14;
  t244_n13: return 0.14650844037532806f;
  t244_n14: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t244_n16;
  t244_n15: return 0.11384714394807816f;
  t244_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t244_n18;
  t244_n17: return -0.06431182473897934f;
  t244_n18: return 0.10649868100881577f;
  t244_n19: return 0.02011309564113617f;
  t244_n20: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t244_n32;
  t244_n21: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t244_n29;
  t244_n22: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t244_n28;
  t244_n23: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t244_n27;
  t244_n24: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n26;
  t244_n25: return 0.02368502877652645f;
  t244_n26: return 0.10225816071033478f;
  t244_n27: return 1.0298571586608887f;
  t244_n28: return -0.3979690372943878f;
  t244_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t244_n31;
  t244_n30: return 0.4781031608581543f;
  t244_n31: return 0.14136268198490143f;
  t244_n32: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t244_n34;
  t244_n33: return -0.03818484768271446f;
  t244_n34: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t244_n38;
  t244_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t244_n37;
  t244_n36: return -0.17682458460330963f;
  t244_n37: return 0.11422798782587051f;
  t244_n38: return 0.07595492154359818f;
  t244_n39: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t244_n41;
  t244_n40: return -0.12090957909822464f;
  t244_n41: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t244_n43;
  t244_n42: return 0.08227939158678055f;
  t244_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t244_n49;
  t244_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t244_n48;
  t244_n45: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t244_n47;
  t244_n46: return 0.15647192299365997f;
  t244_n47: return 0.2740269601345062f;
  t244_n48: return 0.0814194455742836f;
  t244_n49: return 0.0946827232837677f;
  t244_n50: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t244_n66;
  t244_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t244_n53;
  t244_n52: return 0.0007919298950582743f;
  t244_n53: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t244_n55;
  t244_n54: return 0.015351654030382633f;
  t244_n55: if (E.getNumReferences() >= 3282616320 /*337.5*/) goto t244_n61;
  t244_n56: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t244_n60;
  t244_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t244_n59;
  t244_n58: return -0.0800805315375328f;
  t244_n59: return 0.019320553168654442f;
  t244_n60: return -0.07072221487760544f;
  t244_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n63;
  t244_n62: return -0.3905004858970642f;
  t244_n63: if (E.getNumReferences() >= 3283795968 /*373.5*/) goto t244_n65;
  t244_n64: return 0.1155547946691513f;
  t244_n65: return 0.04623846709728241f;
  t244_n66: return 0.018320254981517792f;
  t244_n67: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t244_n69;
  t244_n68: return 0.007123477756977081f;
  t244_n69: return -0.052703842520713806f;
  t244_n70: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t244_n148;
  t244_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t244_n113;
  t244_n72: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t244_n80;
  t244_n73: if (E.getNumReferences() >= 3309346816 /*3082.0*/) goto t244_n75;
  t244_n74: return -0.01450700405985117f;
  t244_n75: if (E.getNumReferences() >= 3309430784 /*3102.5*/) goto t244_n79;
  t244_n76: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t244_n78;
  t244_n77: return 0.1951405256986618f;
  t244_n78: return 0.1437387615442276f;
  t244_n79: return 0.006733370013535023f;
  t244_n80: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t244_n100;
  t244_n81: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t244_n91;
  t244_n82: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n84;
  t244_n83: return -0.06972792744636536f;
  t244_n84: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t244_n90;
  t244_n85: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t244_n87;
  t244_n86: return 0.00023431057343259454f;
  t244_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t244_n89;
  t244_n88: return 0.06310588121414185f;
  t244_n89: return 0.10379229485988617f;
  t244_n90: return -0.13570536673069f;
  t244_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t244_n93;
  t244_n92: return 0.012195263989269733f;
  t244_n93: if (E.getNumReferences() >= 3288375296 /*514.5*/) goto t244_n97;
  t244_n94: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t244_n96;
  t244_n95: return -0.3951488733291626f;
  t244_n96: return 0.10901526361703873f;
  t244_n97: if (E.getNumReferences() >= 3297292288 /*1093.5*/) goto t244_n99;
  t244_n98: return 0.031208543106913567f;
  t244_n99: return 0.13518132269382477f;
  t244_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t244_n104;
  t244_n101: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t244_n103;
  t244_n102: return 0.015342269092798233f;
  t244_n103: return -0.15972721576690674f;
  t244_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t244_n110;
  t244_n105: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t244_n107;
  t244_n106: return -0.2941517233848572f;
  t244_n107: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t244_n109;
  t244_n108: return 0.03311007842421532f;
  t244_n109: return 0.07948721200227737f;
  t244_n110: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t244_n112;
  t244_n111: return 0.0961519181728363f;
  t244_n112: return 0.04664061218500137f;
  t244_n113: if (E.getNumReferences() >= 3297431552 /*1110.5*/) goto t244_n147;
  t244_n114: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t244_n116;
  t244_n115: return -0.18999233841896057f;
  t244_n116: if (E.getNumReferences() >= 3297239040 /*1087.0*/) goto t244_n146;
  t244_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n139;
  t244_n118: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t244_n124;
  t244_n119: if (E.getNumReferences() >= 3294199808 /*870.0*/) goto t244_n121;
  t244_n120: return -0.1356641799211502f;
  t244_n121: if (E.getNumReferences() >= 3295920128 /*975.0*/) goto t244_n123;
  t244_n122: return 0.5645748972892761f;
  t244_n123: return -0.12123937904834747f;
  t244_n124: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t244_n134;
  t244_n125: if (E.getNumReferences() >= 3285139456 /*414.5*/) goto t244_n127;
  t244_n126: return -0.09795570373535156f;
  t244_n127: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t244_n129;
  t244_n128: return 0.10829298198223114f;
  t244_n129: if (E.getNumReferences() >= 3285762048 /*433.5*/) goto t244_n131;
  t244_n130: return 0.1174982339143753f;
  t244_n131: if (E.getNumReferences() >= 3286564864 /*458.0*/) goto t244_n133;
  t244_n132: return -0.1671314537525177f;
  t244_n133: return 0.10250408947467804f;
  t244_n134: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t244_n136;
  t244_n135: return -0.13077226281166077f;
  t244_n136: if (E.getNumReferences() >= 3293782016 /*844.5*/) goto t244_n138;
  t244_n137: return 0.06490969657897949f;
  t244_n138: return 0.1291416883468628f;
  t244_n139: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t244_n143;
  t244_n140: if (E.getNumReferences() >= 3285794816 /*434.5*/) goto t244_n142;
  t244_n141: return 0.104634590446949f;
  t244_n142: return -0.09637051075696945f;
  t244_n143: if (E.getNumReferences() >= 3292962816 /*794.5*/) goto t244_n145;
  t244_n144: return 0.1065298393368721f;
  t244_n145: return 0.06299653649330139f;
  t244_n146: return 0.11427310109138489f;
  t244_n147: return -0.03182745352387428f;
  t244_n148: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t244_n254;
  t244_n149: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t244_n239;
  t244_n150: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t244_n212;
  t244_n151: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n211;
  t244_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t244_n154;
  t244_n153: return 0.03331127017736435f;
  t244_n154: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t244_n156;
  t244_n155: return -0.17457027733325958f;
  t244_n156: if (E.getNumReferences() >= 3293175808 /*807.5*/) goto t244_n178;
  t244_n157: if (E.getNumReferences() >= 3293093888 /*802.5*/) goto t244_n175;
  t244_n158: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t244_n170;
  t244_n159: if (E.getNumReferences() >= 3289579520 /*588.0*/) goto t244_n169;
  t244_n160: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t244_n164;
  t244_n161: if (E.getNumReferences() >= 3289546752 /*586.0*/) goto t244_n163;
  t244_n162: return -0.12147478759288788f;
  t244_n163: return 0.1419927328824997f;
  t244_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t244_n168;
  t244_n165: if (E.getNumReferences() >= 3288530944 /*524.0*/) goto t244_n167;
  t244_n166: return 0.1344689130783081f;
  t244_n167: return -0.702090859413147f;
  t244_n168: return 0.228294238448143f;
  t244_n169: return -0.022097334265708923f;
  t244_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t244_n172;
  t244_n171: return -0.019196704030036926f;
  t244_n172: if (E.getNumReferences() >= 3291521024 /*706.5*/) goto t244_n174;
  t244_n173: return 0.11944755166769028f;
  t244_n174: return 0.05109637230634689f;
  t244_n175: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t244_n177;
  t244_n176: return 0.12241429090499878f;
  t244_n177: return -0.33031633496284485f;
  t244_n178: if (E.getNumReferences() >= 3300868096 /*1530.0*/) goto t244_n180;
  t244_n179: return -0.10437213629484177f;
  t244_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t244_n192;
  t244_n181: if (E.getNumReferences() >= 3300925440 /*1537.0*/) goto t244_n183;
  t244_n182: return 0.12238885462284088f;
  t244_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t244_n185;
  t244_n184: return -0.04028942063450813f;
  t244_n185: if (E.getNumReferences() >= 3318054912 /*6320.0*/) goto t244_n187;
  t244_n186: return 0.11140915006399155f;
  t244_n187: if (E.getNumReferences() >= 3319748608 /*7147.0*/) goto t244_n189;
  t244_n188: return 0.20038889348506927f;
  t244_n189: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t244_n191;
  t244_n190: return 0.10976547747850418f;
  t244_n191: return -0.5514982342720032f;
  t244_n192: if (E.getNumReferences() >= 3307524096 /*2637.0*/) goto t244_n202;
  t244_n193: if (E.getNumReferences() >= 3302617088 /*1743.5*/) goto t244_n195;
  t244_n194: return -0.02188606560230255f;
  t244_n195: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t244_n201;
  t244_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t244_n200;
  t244_n197: if (E.getNumReferences() >= 3305805824 /*2217.5*/) goto t244_n199;
  t244_n198: return -0.2382974773645401f;
  t244_n199: return 0.10288917273283005f;
  t244_n200: return 0.13783864676952362f;
  t244_n201: return 0.0891818106174469f;
  t244_n202: if (E.getNumReferences() >= 3324208128 /*10457.0*/) goto t244_n204;
  t244_n203: return -0.0547371469438076f;
  t244_n204: if (E.getNumReferences() >= 3335664640 /*26906.0*/) goto t244_n210;
  t244_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t244_n207;
  t244_n206: return 0.07053167372941971f;
  t244_n207: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t244_n209;
  t244_n208: return 0.0990854948759079f;
  t244_n209: return 0.12583529949188232f;
  t244_n210: return 0.016131166368722916f;
  t244_n211: return -0.05708512291312218f;
  t244_n212: if (E.getNumReferences() >= 3289849856 /*604.5*/) goto t244_n224;
  t244_n213: if (E.getNumReferences() >= 3289677824 /*594.0*/) goto t244_n223;
  t244_n214: if (E.getNumReferences() >= 3288891392 /*546.0*/) goto t244_n222;
  t244_n215: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t244_n217;
  t244_n216: return -0.23175247013568878f;
  t244_n217: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t244_n221;
  t244_n218: if (E.getNumReferences() >= 3285975040 /*440.0*/) goto t244_n220;
  t244_n219: return 0.10314856469631195f;
  t244_n220: return 0.06443853676319122f;
  t244_n221: return -0.12297823280096054f;
  t244_n222: return 0.1117144376039505f;
  t244_n223: return 0.11669021844863892f;
  t244_n224: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t244_n232;
  t244_n225: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t244_n227;
  t244_n226: return -0.3987245261669159f;
  t244_n227: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t244_n231;
  t244_n228: if (E.getNumReferences() >= 3323833856 /*10091.5*/) goto t244_n230;
  t244_n229: return 0.10726531594991684f;
  t244_n230: return -0.16552285850048065f;
  t244_n231: return -0.004747792612761259f;
  t244_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t244_n234;
  t244_n233: return 0.017330963164567947f;
  t244_n234: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t244_n236;
  t244_n235: return 0.11179793626070023f;
  t244_n236: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t244_n238;
  t244_n237: return -0.23300890624523163f;
  t244_n238: return 0.11388379335403442f;
  t244_n239: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t244_n243;
  t244_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t244_n242;
  t244_n241: return -0.5118319392204285f;
  t244_n242: return 0.09417217969894409f;
  t244_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n245;
  t244_n244: return -0.022110674530267715f;
  t244_n245: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t244_n253;
  t244_n246: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t244_n248;
  t244_n247: return 0.043006181716918945f;
  t244_n248: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t244_n250;
  t244_n249: return -0.003245291067287326f;
  t244_n250: if (E.getNumReferences() >= 3299438592 /*1355.5*/) goto t244_n252;
  t244_n251: return 0.11472619324922562f;
  t244_n252: return -0.12033799290657043f;
  t244_n253: return 0.10840333998203278f;
  t244_n254: return 0.0003836951800622046f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree245(const Example& E) {
  t245_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t245_n124;
  t245_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t245_n3;
  t245_n2: return -0.00011064585123676807f;
  t245_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t245_n47;
  t245_n4: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t245_n46;
  t245_n5: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t245_n21;
  t245_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t245_n10;
  t245_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t245_n9;
  t245_n8: return -0.11244378238916397f;
  t245_n9: return 0.048492755740880966f;
  t245_n10: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t245_n20;
  t245_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t245_n15;
  t245_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t245_n14;
  t245_n13: return 0.12855151295661926f;
  t245_n14: return 0.10310903936624527f;
  t245_n15: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t245_n17;
  t245_n16: return 0.003911765292286873f;
  t245_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t245_n19;
  t245_n18: return -0.01695842295885086f;
  t245_n19: return 0.13589034974575043f;
  t245_n20: return -0.015047436580061913f;
  t245_n21: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t245_n23;
  t245_n22: return -0.020676765590906143f;
  t245_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t245_n25;
  t245_n24: return -0.004557366482913494f;
  t245_n25: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t245_n45;
  t245_n26: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t245_n28;
  t245_n27: return -0.14976535737514496f;
  t245_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t245_n44;
  t245_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t245_n37;
  t245_n30: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t245_n34;
  t245_n31: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t245_n33;
  t245_n32: return 0.0617416612803936f;
  t245_n33: return -0.12019100785255432f;
  t245_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t245_n36;
  t245_n35: return 0.03576066344976425f;
  t245_n36: return 0.08868538588285446f;
  t245_n37: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t245_n39;
  t245_n38: return 0.11449883878231049f;
  t245_n39: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t245_n43;
  t245_n40: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t245_n42;
  t245_n41: return 0.027373045682907104f;
  t245_n42: return 0.0982280895113945f;
  t245_n43: return -0.4453681707382202f;
  t245_n44: return 0.0156412273645401f;
  t245_n45: return -0.4615057110786438f;
  t245_n46: return -0.015643637627363205f;
  t245_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t245_n57;
  t245_n48: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t245_n56;
  t245_n49: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t245_n51;
  t245_n50: return -0.013596965000033379f;
  t245_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t245_n55;
  t245_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t245_n54;
  t245_n53: return -0.06614430993795395f;
  t245_n54: return 0.00830259919166565f;
  t245_n55: return 0.019345181062817574f;
  t245_n56: return 0.002447353210300207f;
  t245_n57: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t245_n123;
  t245_n58: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t245_n122;
  t245_n59: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t245_n85;
  t245_n60: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t245_n64;
  t245_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t245_n63;
  t245_n62: return -0.03188754990696907f;
  t245_n63: return 0.016677651554346085f;
  t245_n64: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t245_n74;
  t245_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t245_n67;
  t245_n66: return 0.024278447031974792f;
  t245_n67: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t245_n73;
  t245_n68: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t245_n72;
  t245_n69: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t245_n71;
  t245_n70: return 0.05284853279590607f;
  t245_n71: return 0.07039400190114975f;
  t245_n72: return 0.0561978705227375f;
  t245_n73: return -0.015889327973127365f;
  t245_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t245_n76;
  t245_n75: return -0.06134013831615448f;
  t245_n76: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t245_n78;
  t245_n77: return 0.05738753825426102f;
  t245_n78: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t245_n84;
  t245_n79: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t245_n81;
  t245_n80: return 0.08201143890619278f;
  t245_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t245_n83;
  t245_n82: return -0.04640079289674759f;
  t245_n83: return 0.12280134111642838f;
  t245_n84: return 0.016654403880238533f;
  t245_n85: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t245_n119;
  t245_n86: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t245_n118;
  t245_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t245_n101;
  t245_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t245_n90;
  t245_n89: return 0.05913282558321953f;
  t245_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t245_n92;
  t245_n91: return 0.12262842059135437f;
  t245_n92: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t245_n94;
  t245_n93: return 0.02766485884785652f;
  t245_n94: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t245_n100;
  t245_n95: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t245_n99;
  t245_n96: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t245_n98;
  t245_n97: return 0.14077168703079224f;
  t245_n98: return 0.04460734501481056f;
  t245_n99: return 0.10030096769332886f;
  t245_n100: return 0.0745137631893158f;
  t245_n101: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t245_n117;
  t245_n102: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t245_n112;
  t245_n103: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t245_n111;
  t245_n104: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t245_n110;
  t245_n105: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t245_n109;
  t245_n106: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t245_n108;
  t245_n107: return -0.14958761632442474f;
  t245_n108: return 0.27534809708595276f;
  t245_n109: return 0.16077187657356262f;
  t245_n110: return 0.06670229882001877f;
  t245_n111: return 0.010340163484215736f;
  t245_n112: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t245_n114;
  t245_n113: return 0.12400427460670471f;
  t245_n114: if (E.getNumReferences() >= 3233808384 /*6.0*/) goto t245_n116;
  t245_n115: return -0.027259277179837227f;
  t245_n116: return 0.11707102507352829f;
  t245_n117: return 0.03778110817074776f;
  t245_n118: return 0.1108861118555069f;
  t245_n119: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t245_n121;
  t245_n120: return -0.005056349094957113f;
  t245_n121: return 0.12463697791099548f;
  t245_n122: return -0.007567864377051592f;
  t245_n123: return 6.791210034862161e-05f;
  t245_n124: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t245_n126;
  t245_n125: return -0.013692625798285007f;
  t245_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t245_n128;
  t245_n127: return -0.03606732189655304f;
  t245_n128: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t245_n246;
  t245_n129: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t245_n135;
  t245_n130: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t245_n132;
  t245_n131: return 0.02681570313870907f;
  t245_n132: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t245_n134;
  t245_n133: return -0.10911396890878677f;
  t245_n134: return 0.09149918705224991f;
  t245_n135: if (E.getSymbolScopeDistance() >= 3240099840 /*10.0*/) goto t245_n227;
  t245_n136: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t245_n146;
  t245_n137: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t245_n139;
  t245_n138: return 0.06242399662733078f;
  t245_n139: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t245_n143;
  t245_n140: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t245_n142;
  t245_n141: return 0.32932448387145996f;
  t245_n142: return -0.05837811902165413f;
  t245_n143: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t245_n145;
  t245_n144: return 0.08548314869403839f;
  t245_n145: return 0.02536473609507084f;
  t245_n146: if (E.getNumReferences() >= 3316817920 /*5716.0*/) goto t245_n214;
  t245_n147: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t245_n213;
  t245_n148: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t245_n202;
  t245_n149: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t245_n195;
  t245_n150: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t245_n156;
  t245_n151: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t245_n153;
  t245_n152: return -0.05886473506689072f;
  t245_n153: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t245_n155;
  t245_n154: return 0.12765702605247498f;
  t245_n155: return 0.0f;
  t245_n156: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t245_n170;
  t245_n157: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t245_n159;
  t245_n158: return -0.12612244486808777f;
  t245_n159: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t245_n169;
  t245_n160: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t245_n162;
  t245_n161: return 0.05903898552060127f;
  t245_n162: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t245_n164;
  t245_n163: return 0.09855317324399948f;
  t245_n164: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t245_n168;
  t245_n165: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t245_n167;
  t245_n166: return 0.1043551117181778f;
  t245_n167: return -0.11030663549900055f;
  t245_n168: return -0.01942594163119793f;
  t245_n169: return -0.24372056126594543f;
  t245_n170: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t245_n174;
  t245_n171: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t245_n173;
  t245_n172: return 0.12733310461044312f;
  t245_n173: return 0.013837252743542194f;
  t245_n174: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t245_n194;
  t245_n175: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t245_n187;
  t245_n176: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t245_n186;
  t245_n177: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t245_n179;
  t245_n178: return 0.015183751471340656f;
  t245_n179: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t245_n185;
  t245_n180: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t245_n182;
  t245_n181: return 0.11817993968725204f;
  t245_n182: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t245_n184;
  t245_n183: return -0.18427947163581848f;
  t245_n184: return 0.1066359207034111f;
  t245_n185: return -0.0013510639546439052f;
  t245_n186: return -0.13613788783550262f;
  t245_n187: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t245_n193;
  t245_n188: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t245_n190;
  t245_n189: return -0.13498610258102417f;
  t245_n190: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t245_n192;
  t245_n191: return -0.12893474102020264f;
  t245_n192: return 0.13863377273082733f;
  t245_n193: return 0.010986575856804848f;
  t245_n194: return -0.15748481452465057f;
  t245_n195: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t245_n197;
  t245_n196: return 0.11138173937797546f;
  t245_n197: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t245_n199;
  t245_n198: return -0.10193940252065659f;
  t245_n199: if (E.getNumReferences() >= 3246391296 /*16.0*/) goto t245_n201;
  t245_n200: return 0.03370087966322899f;
  t245_n201: return 0.1146424412727356f;
  t245_n202: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t245_n212;
  t245_n203: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t245_n211;
  t245_n204: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t245_n206;
  t245_n205: return 0.11946383118629456f;
  t245_n206: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t245_n208;
  t245_n207: return -0.2384461760520935f;
  t245_n208: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t245_n210;
  t245_n209: return 0.04969491437077522f;
  t245_n210: return 0.1076115220785141f;
  t245_n211: return 0.10597473382949829f;
  t245_n212: return 0.06463758647441864f;
  t245_n213: return -0.038876697421073914f;
  t245_n214: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t245_n218;
  t245_n215: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t245_n217;
  t245_n216: return 0.12789955735206604f;
  t245_n217: return -0.13243982195854187f;
  t245_n218: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t245_n226;
  t245_n219: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t245_n221;
  t245_n220: return -0.27306121587753296f;
  t245_n221: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t245_n225;
  t245_n222: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t245_n224;
  t245_n223: return 0.06734191626310349f;
  t245_n224: return 0.096831314265728f;
  t245_n225: return -0.1760173738002777f;
  t245_n226: return -0.23426438868045807f;
  t245_n227: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t245_n245;
  t245_n228: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t245_n236;
  t245_n229: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t245_n235;
  t245_n230: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t245_n232;
  t245_n231: return 0.06680751591920853f;
  t245_n232: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t245_n234;
  t245_n233: return 0.10936983674764633f;
  t245_n234: return -0.12920063734054565f;
  t245_n235: return -0.04631899669766426f;
  t245_n236: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t245_n242;
  t245_n237: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t245_n241;
  t245_n238: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t245_n240;
  t245_n239: return 0.03550605848431587f;
  t245_n240: return 0.1073891818523407f;
  t245_n241: return -0.04423518106341362f;
  t245_n242: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t245_n244;
  t245_n243: return 0.10235729813575745f;
  t245_n244: return 0.036874424666166306f;
  t245_n245: return -0.047470226883888245f;
  t245_n246: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t245_n248;
  t245_n247: return -0.01837390661239624f;
  t245_n248: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t245_n254;
  t245_n249: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t245_n253;
  t245_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t245_n252;
  t245_n251: return 0.07408559322357178f;
  t245_n252: return 0.09646401554346085f;
  t245_n253: return 0.013086427934467793f;
  t245_n254: return -0.011453060433268547f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree246(const Example& E) {
  t246_n0: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t246_n2;
  t246_n1: return -0.0004465508973225951f;
  t246_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t246_n66;
  t246_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t246_n5;
  t246_n4: return -0.008066766895353794f;
  t246_n5: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t246_n37;
  t246_n6: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t246_n18;
  t246_n7: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t246_n15;
  t246_n8: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t246_n10;
  t246_n9: return -0.05204572156071663f;
  t246_n10: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t246_n14;
  t246_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t246_n13;
  t246_n12: return 0.14251406490802765f;
  t246_n13: return 0.040339939296245575f;
  t246_n14: return -0.14480525255203247f;
  t246_n15: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t246_n17;
  t246_n16: return 0.03605418652296066f;
  t246_n17: return 0.10688542574644089f;
  t246_n18: if (E.getNumReferences() >= 3269001216 /*108.5*/) goto t246_n30;
  t246_n19: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t246_n21;
  t246_n20: return 0.015971366316080093f;
  t246_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t246_n25;
  t246_n22: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t246_n24;
  t246_n23: return -0.23622941970825195f;
  t246_n24: return -0.019489280879497528f;
  t246_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t246_n27;
  t246_n26: return -0.2515958547592163f;
  t246_n27: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t246_n29;
  t246_n28: return 0.06981664896011353f;
  t246_n29: return -0.036479149013757706f;
  t246_n30: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t246_n36;
  t246_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t246_n35;
  t246_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t246_n34;
  t246_n33: return -0.1387564241886139f;
  t246_n34: return 0.12085825949907303f;
  t246_n35: return 0.11777298897504807f;
  t246_n36: return 0.02865126170217991f;
  t246_n37: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t246_n53;
  t246_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t246_n40;
  t246_n39: return 0.00996603537350893f;
  t246_n40: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t246_n50;
  t246_n41: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t246_n47;
  t246_n42: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t246_n44;
  t246_n43: return 0.010495811700820923f;
  t246_n44: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t246_n46;
  t246_n45: return 0.11746040731668472f;
  t246_n46: return 0.10433806478977203f;
  t246_n47: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t246_n49;
  t246_n48: return 0.0015538682928308845f;
  t246_n49: return 0.09974376857280731f;
  t246_n50: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t246_n52;
  t246_n51: return -0.1600237637758255f;
  t246_n52: return 0.12696658074855804f;
  t246_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t246_n55;
  t246_n54: return 0.01625117100775242f;
  t246_n55: if (E.getNumReferences() >= 3266838528 /*92.0*/) goto t246_n59;
  t246_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t246_n58;
  t246_n57: return -0.16918134689331055f;
  t246_n58: return 0.29658615589141846f;
  t246_n59: if (E.getNumReferences() >= 3268214784 /*102.5*/) goto t246_n61;
  t246_n60: return 0.12887123227119446f;
  t246_n61: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t246_n63;
  t246_n62: return -0.14676369726657867f;
  t246_n63: if (E.getNumReferences() >= 3269984256 /*116.0*/) goto t246_n65;
  t246_n64: return -0.10090669989585876f;
  t246_n65: return 0.1272565722465515f;
  t246_n66: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t246_n144;
  t246_n67: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t246_n143;
  t246_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t246_n70;
  t246_n69: return -0.012492350302636623f;
  t246_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t246_n72;
  t246_n71: return 0.01272678654640913f;
  t246_n72: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t246_n128;
  t246_n73: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t246_n75;
  t246_n74: return 0.06317462772130966f;
  t246_n75: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t246_n85;
  t246_n76: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t246_n82;
  t246_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t246_n81;
  t246_n78: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t246_n80;
  t246_n79: return 0.2481272965669632f;
  t246_n80: return -0.22455818951129913f;
  t246_n81: return 0.12596268951892853f;
  t246_n82: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t246_n84;
  t246_n83: return 0.11641713976860046f;
  t246_n84: return -0.21080364286899567f;
  t246_n85: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t246_n111;
  t246_n86: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t246_n96;
  t246_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t246_n89;
  t246_n88: return -0.16009162366390228f;
  t246_n89: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t246_n93;
  t246_n90: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t246_n92;
  t246_n91: return 0.0004573935584630817f;
  t246_n92: return 0.10693460702896118f;
  t246_n93: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t246_n95;
  t246_n94: return 0.09488510340452194f;
  t246_n95: return -0.017856618389487267f;
  t246_n96: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t246_n106;
  t246_n97: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t246_n105;
  t246_n98: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t246_n104;
  t246_n99: if (E.getNumReferences() >= 3266576384 /*90.0*/) goto t246_n103;
  t246_n100: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t246_n102;
  t246_n101: return 0.10046664625406265f;
  t246_n102: return 0.11194213479757309f;
  t246_n103: return -0.11454617977142334f;
  t246_n104: return -0.2762186527252197f;
  t246_n105: return 0.09336404502391815f;
  t246_n106: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t246_n108;
  t246_n107: return 0.028553999960422516f;
  t246_n108: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t246_n110;
  t246_n109: return -0.11005621403455734f;
  t246_n110: return 0.1294529289007187f;
  t246_n111: if (E.getNumReferences() >= 3287613440 /*490.0*/) goto t246_n121;
  t246_n112: if (E.getNumReferences() >= 3283894272 /*376.5*/) goto t246_n120;
  t246_n113: if (E.getNumReferences() >= 3282173952 /*324.0*/) goto t246_n119;
  t246_n114: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t246_n116;
  t246_n115: return -0.2604905962944031f;
  t246_n116: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t246_n118;
  t246_n117: return 0.006930687464773655f;
  t246_n118: return 0.08506131917238235f;
  t246_n119: return 0.20152117311954498f;
  t246_n120: return -0.35566169023513794f;
  t246_n121: if (E.getNumReferences() >= 3291611136 /*712.0*/) goto t246_n127;
  t246_n122: if (E.getNumReferences() >= 3289251840 /*568.0*/) goto t246_n124;
  t246_n123: return 0.11731062084436417f;
  t246_n124: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t246_n126;
  t246_n125: return 0.11286357790231705f;
  t246_n126: return 0.07403941452503204f;
  t246_n127: return 0.053109437227249146f;
  t246_n128: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t246_n130;
  t246_n129: return 0.016908859834074974f;
  t246_n130: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t246_n132;
  t246_n131: return 0.045999910682439804f;
  t246_n132: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t246_n134;
  t246_n133: return 0.11871279031038284f;
  t246_n134: if (E.getNumReferences() >= 3297976320 /*1177.0*/) goto t246_n142;
  t246_n135: if (E.getNumReferences() >= 3289726976 /*597.0*/) goto t246_n137;
  t246_n136: return 0.03261341154575348f;
  t246_n137: if (E.getNumReferences() >= 3291373568 /*697.5*/) goto t246_n139;
  t246_n138: return 0.11903676390647888f;
  t246_n139: if (E.getNumReferences() >= 3295526912 /*951.0*/) goto t246_n141;
  t246_n140: return -0.00552723603323102f;
  t246_n141: return 0.10908009111881256f;
  t246_n142: return -0.09605124592781067f;
  t246_n143: return -0.0017297338927164674f;
  t246_n144: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t246_n242;
  t246_n145: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t246_n167;
  t246_n146: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t246_n166;
  t246_n147: if (E.getNumReferences() >= 3309545472 /*3130.5*/) goto t246_n155;
  t246_n148: if (E.getNumReferences() >= 3297005568 /*1058.5*/) goto t246_n152;
  t246_n149: if (E.getNumReferences() >= 3296845824 /*1039.0*/) goto t246_n151;
  t246_n150: return 0.01069692987948656f;
  t246_n151: return 0.0911901667714119f;
  t246_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t246_n154;
  t246_n153: return -0.4045717120170593f;
  t246_n154: return -0.06564751267433167f;
  t246_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t246_n159;
  t246_n156: if (E.getNumReferences() >= 3310942208 /*3471.5*/) goto t246_n158;
  t246_n157: return 0.11679867655038834f;
  t246_n158: return -0.025370851159095764f;
  t246_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t246_n161;
  t246_n160: return 0.0624435618519783f;
  t246_n161: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t246_n163;
  t246_n162: return 0.04414663091301918f;
  t246_n163: if (E.getNumReferences() >= 3322114560 /*8412.5*/) goto t246_n165;
  t246_n164: return 0.12106025218963623f;
  t246_n165: return 0.07838878035545349f;
  t246_n166: return 0.08252237737178802f;
  t246_n167: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t246_n175;
  t246_n168: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t246_n174;
  t246_n169: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t246_n173;
  t246_n170: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t246_n172;
  t246_n171: return -0.5362826585769653f;
  t246_n172: return 0.10890201479196548f;
  t246_n173: return 0.1135982945561409f;
  t246_n174: return 0.028552405536174774f;
  t246_n175: if (E.getNumReferences() >= 3274801152 /*177.5*/) goto t246_n241;
  t246_n176: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t246_n194;
  t246_n177: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t246_n193;
  t246_n178: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t246_n180;
  t246_n179: return 0.056995611637830734f;
  t246_n180: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t246_n186;
  t246_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t246_n185;
  t246_n182: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t246_n184;
  t246_n183: return -0.21747741103172302f;
  t246_n184: return 0.13196638226509094f;
  t246_n185: return 0.14966756105422974f;
  t246_n186: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t246_n192;
  t246_n187: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t246_n189;
  t246_n188: return 0.0035970599856227636f;
  t246_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t246_n191;
  t246_n190: return 0.3091754913330078f;
  t246_n191: return 0.12165240198373795f;
  t246_n192: return 0.0394890122115612f;
  t246_n193: return -0.05750241130590439f;
  t246_n194: if (E.getNumReferences() >= 3270574080 /*120.5*/) goto t246_n210;
  t246_n195: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t246_n205;
  t246_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t246_n198;
  t246_n197: return 0.018125204369425774f;
  t246_n198: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t246_n200;
  t246_n199: return -0.31130215525627136f;
  t246_n200: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t246_n202;
  t246_n201: return 0.707193911075592f;
  t246_n202: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t246_n204;
  t246_n203: return 0.12555478513240814f;
  t246_n204: return 0.11869364231824875f;
  t246_n205: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t246_n207;
  t246_n206: return 0.12312506139278412f;
  t246_n207: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t246_n209;
  t246_n208: return 0.14390763640403748f;
  t246_n209: return -0.10195852071046829f;
  t246_n210: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t246_n234;
  t246_n211: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t246_n223;
  t246_n212: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t246_n214;
  t246_n213: return 0.013306334614753723f;
  t246_n214: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t246_n222;
  t246_n215: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t246_n217;
  t246_n216: return 0.08224139362573624f;
  t246_n217: if (E.getNumReferences() >= 3272114176 /*136.5*/) goto t246_n219;
  t246_n218: return 0.1346428543329239f;
  t246_n219: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t246_n221;
  t246_n220: return 0.08571060001850128f;
  t246_n221: return 0.13696153461933136f;
  t246_n222: return -0.11705050617456436f;
  t246_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t246_n225;
  t246_n224: return -0.13125525414943695f;
  t246_n225: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t246_n233;
  t246_n226: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t246_n228;
  t246_n227: return -0.170371875166893f;
  t246_n228: if (E.getNumReferences() >= 3274473472 /*172.5*/) goto t246_n230;
  t246_n229: return 0.10978538542985916f;
  t246_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t246_n232;
  t246_n231: return -0.11924835294485092f;
  t246_n232: return 0.11922727525234222f;
  t246_n233: return 0.11523757129907608f;
  t246_n234: if (E.getNumReferences() >= 3271360512 /*126.5*/) goto t246_n236;
  t246_n235: return 0.12412884831428528f;
  t246_n236: if (E.getNumReferences() >= 3274145792 /*167.5*/) goto t246_n238;
  t246_n237: return -0.15443235635757446f;
  t246_n238: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t246_n240;
  t246_n239: return 0.1173776164650917f;
  t246_n240: return -0.10095905512571335f;
  t246_n241: return 0.01581299491226673f;
  t246_n242: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t246_n246;
  t246_n243: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t246_n245;
  t246_n244: return 0.1563107669353485f;
  t246_n245: return 0.14308494329452515f;
  t246_n246: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t246_n254;
  t246_n247: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t246_n253;
  t246_n248: if (E.getNumReferences() >= 3288834048 /*542.5*/) goto t246_n250;
  t246_n249: return 0.06411966681480408f;
  t246_n250: if (E.getNumReferences() >= 3305973760 /*2258.5*/) goto t246_n252;
  t246_n251: return 0.13725678622722626f;
  t246_n252: return 0.11433613300323486f;
  t246_n253: return 0.04107775539159775f;
  t246_n254: return 0.03766551613807678f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree247(const Example& E) {
  t247_n0: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t247_n2;
  t247_n1: return -0.0004609566240105778f;
  t247_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t247_n98;
  t247_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t247_n37;
  t247_n4: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t247_n26;
  t247_n5: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t247_n7;
  t247_n6: return -0.15038278698921204f;
  t247_n7: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t247_n15;
  t247_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t247_n12;
  t247_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t247_n11;
  t247_n10: return -0.11093934625387192f;
  t247_n11: return 3.441368818283081f;
  t247_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t247_n14;
  t247_n13: return 0.1367291808128357f;
  t247_n14: return 0.0905541181564331f;
  t247_n15: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t247_n25;
  t247_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t247_n24;
  t247_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t247_n19;
  t247_n18: return -0.10433045774698257f;
  t247_n19: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t247_n23;
  t247_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t247_n22;
  t247_n21: return 0.11377981305122375f;
  t247_n22: return 0.37750130891799927f;
  t247_n23: return -0.1782436966896057f;
  t247_n24: return -0.11134780198335648f;
  t247_n25: return 0.03559546172618866f;
  t247_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t247_n28;
  t247_n27: return 0.0029522664844989777f;
  t247_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t247_n30;
  t247_n29: return 0.01322633121162653f;
  t247_n30: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t247_n32;
  t247_n31: return 0.023565970361232758f;
  t247_n32: if (E.getNumReferences() >= 3266838528 /*92.0*/) goto t247_n34;
  t247_n33: return -0.15580004453659058f;
  t247_n34: if (E.getNumReferences() >= 3286859776 /*467.0*/) goto t247_n36;
  t247_n35: return 0.1228584498167038f;
  t247_n36: return -0.07213427126407623f;
  t247_n37: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t247_n59;
  t247_n38: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t247_n56;
  t247_n39: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t247_n55;
  t247_n40: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t247_n44;
  t247_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t247_n43;
  t247_n42: return -0.009904944337904453f;
  t247_n43: return -0.08967658132314682f;
  t247_n44: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t247_n48;
  t247_n45: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t247_n47;
  t247_n46: return 0.1181681677699089f;
  t247_n47: return -0.11322139203548431f;
  t247_n48: if (E.getNumReferences() >= 3272179712 /*137.5*/) goto t247_n54;
  t247_n49: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t247_n51;
  t247_n50: return 0.0770980641245842f;
  t247_n51: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t247_n53;
  t247_n52: return 0.11538846790790558f;
  t247_n53: return 0.17653606832027435f;
  t247_n54: return 0.01520959660410881f;
  t247_n55: return 0.09722674638032913f;
  t247_n56: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t247_n58;
  t247_n57: return -0.0007148918230086565f;
  t247_n58: return 0.12232260406017303f;
  t247_n59: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t247_n61;
  t247_n60: return 0.09932247549295425f;
  t247_n61: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t247_n73;
  t247_n62: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t247_n72;
  t247_n63: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t247_n65;
  t247_n64: return -0.14770936965942383f;
  t247_n65: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t247_n71;
  t247_n66: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t247_n70;
  t247_n67: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t247_n69;
  t247_n68: return 0.06460385769605637f;
  t247_n69: return 0.10712061822414398f;
  t247_n70: return -0.05419374629855156f;
  t247_n71: return -0.12757202982902527f;
  t247_n72: return 0.12052737921476364f;
  t247_n73: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t247_n89;
  t247_n74: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t247_n88;
  t247_n75: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t247_n77;
  t247_n76: return -0.17626217007637024f;
  t247_n77: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t247_n81;
  t247_n78: if (E.getNumReferences() >= 3271491584 /*127.5*/) goto t247_n80;
  t247_n79: return 0.10152760148048401f;
  t247_n80: return 0.067746601998806f;
  t247_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t247_n83;
  t247_n82: return -0.3741404712200165f;
  t247_n83: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t247_n85;
  t247_n84: return 0.10185196995735168f;
  t247_n85: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t247_n87;
  t247_n86: return -0.13613857328891754f;
  t247_n87: return 0.0918041467666626f;
  t247_n88: return 0.10419107228517532f;
  t247_n89: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t247_n91;
  t247_n90: return -0.48479169607162476f;
  t247_n91: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t247_n97;
  t247_n92: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t247_n96;
  t247_n93: if (E.getNumReferences() >= 3302748160 /*1759.5*/) goto t247_n95;
  t247_n94: return -0.1335850954055786f;
  t247_n95: return 0.05130413919687271f;
  t247_n96: return 0.08725130558013916f;
  t247_n97: return 0.09142334759235382f;
  t247_n98: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t247_n150;
  t247_n99: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t247_n149;
  t247_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t247_n102;
  t247_n101: return -0.010308351367712021f;
  t247_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t247_n104;
  t247_n103: return 0.01211882010102272f;
  t247_n104: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t247_n118;
  t247_n105: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t247_n115;
  t247_n106: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t247_n110;
  t247_n107: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t247_n109;
  t247_n108: return -0.22430811822414398f;
  t247_n109: return 0.6005985140800476f;
  t247_n110: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t247_n114;
  t247_n111: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t247_n113;
  t247_n112: return 0.11243436485528946f;
  t247_n113: return 0.10920856893062592f;
  t247_n114: return -0.21060575544834137f;
  t247_n115: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t247_n117;
  t247_n116: return 0.050915613770484924f;
  t247_n117: return 0.05779392272233963f;
  t247_n118: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t247_n136;
  t247_n119: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t247_n121;
  t247_n120: return 0.010216918773949146f;
  t247_n121: if (E.getNumReferences() >= 3275718656 /*191.5*/) goto t247_n131;
  t247_n122: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t247_n124;
  t247_n123: return 0.11036495864391327f;
  t247_n124: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t247_n126;
  t247_n125: return -0.1178482174873352f;
  t247_n126: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t247_n128;
  t247_n127: return -0.34679633378982544f;
  t247_n128: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t247_n130;
  t247_n129: return 0.1107289046049118f;
  t247_n130: return 0.06664256006479263f;
  t247_n131: if (E.getNumReferences() >= 3281141760 /*292.5*/) goto t247_n135;
  t247_n132: if (E.getNumReferences() >= 3279060992 /*242.5*/) goto t247_n134;
  t247_n133: return 0.08123182505369186f;
  t247_n134: return 0.11026246845722198f;
  t247_n135: return 0.0644403025507927f;
  t247_n136: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t247_n138;
  t247_n137: return 0.047310974448919296f;
  t247_n138: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t247_n140;
  t247_n139: return 0.1166267991065979f;
  t247_n140: if (E.getNumReferences() >= 3297976320 /*1177.0*/) goto t247_n148;
  t247_n141: if (E.getNumReferences() >= 3289726976 /*597.0*/) goto t247_n143;
  t247_n142: return 0.024798251688480377f;
  t247_n143: if (E.getNumReferences() >= 3291373568 /*697.5*/) goto t247_n145;
  t247_n144: return 0.11764465272426605f;
  t247_n145: if (E.getNumReferences() >= 3295526912 /*951.0*/) goto t247_n147;
  t247_n146: return 0.0002911796036642045f;
  t247_n147: return 0.1069846823811531f;
  t247_n148: return -0.09827876836061478f;
  t247_n149: return -0.002628651913255453f;
  t247_n150: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t247_n166;
  t247_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t247_n165;
  t247_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t247_n164;
  t247_n153: if (E.getNumReferences() >= 3298926592 /*1293.0*/) goto t247_n155;
  t247_n154: return -0.04816006124019623f;
  t247_n155: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t247_n157;
  t247_n156: return -0.3169704079627991f;
  t247_n157: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t247_n161;
  t247_n158: if (E.getNumReferences() >= 3337794560 /*31066.0*/) goto t247_n160;
  t247_n159: return -0.022041447460651398f;
  t247_n160: return 0.0876360684633255f;
  t247_n161: if (E.getNumReferences() >= 3342787456 /*48867.5*/) goto t247_n163;
  t247_n162: return 0.07767263799905777f;
  t247_n163: return -0.3461264371871948f;
  t247_n164: return 0.0019008297240361571f;
  t247_n165: return 0.037872765213251114f;
  t247_n166: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t247_n184;
  t247_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t247_n173;
  t247_n168: if (E.getNumReferences() >= 3300868096 /*1530.0*/) goto t247_n170;
  t247_n169: return 0.044736798852682114f;
  t247_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t247_n172;
  t247_n171: return -0.21598611772060394f;
  t247_n172: return 0.10512536019086838f;
  t247_n173: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t247_n179;
  t247_n174: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t247_n176;
  t247_n175: return 0.1878661811351776f;
  t247_n176: if (E.getNumReferences() >= 3281158144 /*293.0*/) goto t247_n178;
  t247_n177: return 0.5371376872062683f;
  t247_n178: return 0.21412897109985352f;
  t247_n179: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t247_n183;
  t247_n180: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t247_n182;
  t247_n181: return -0.007351303473114967f;
  t247_n182: return 0.15461081266403198f;
  t247_n183: return -0.23413294553756714f;
  t247_n184: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t247_n238;
  t247_n185: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t247_n187;
  t247_n186: return 0.02185611054301262f;
  t247_n187: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t247_n189;
  t247_n188: return 0.03892988711595535f;
  t247_n189: if (E.getNumReferences() >= 3270574080 /*120.5*/) goto t247_n205;
  t247_n190: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t247_n198;
  t247_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t247_n193;
  t247_n192: return 0.23350228369235992f;
  t247_n193: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t247_n197;
  t247_n194: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t247_n196;
  t247_n195: return -0.10123856365680695f;
  t247_n196: return 0.12117144465446472f;
  t247_n197: return -0.10568578541278839f;
  t247_n198: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t247_n204;
  t247_n199: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t247_n201;
  t247_n200: return 0.12349008023738861f;
  t247_n201: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t247_n203;
  t247_n202: return -0.42468228936195374f;
  t247_n203: return 0.14545755088329315f;
  t247_n204: return -0.10158908367156982f;
  t247_n205: if (E.getNumReferences() >= 3297632256 /*1135.0*/) goto t247_n237;
  t247_n206: if (E.getNumReferences() >= 3297136640 /*1074.5*/) goto t247_n232;
  t247_n207: if (E.getNumReferences() >= 3273621504 /*159.5*/) goto t247_n209;
  t247_n208: return -0.029878851026296616f;
  t247_n209: if (E.getNumReferences() >= 3274211328 /*168.5*/) goto t247_n215;
  t247_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t247_n212;
  t247_n211: return 0.026383737102150917f;
  t247_n212: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t247_n214;
  t247_n213: return 0.1353038102388382f;
  t247_n214: return -0.4144216477870941f;
  t247_n215: if (E.getNumReferences() >= 3277750272 /*222.5*/) goto t247_n219;
  t247_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t247_n218;
  t247_n217: return -0.20567713677883148f;
  t247_n218: return 0.06286017596721649f;
  t247_n219: if (E.getNumReferences() >= 3277881344 /*224.5*/) goto t247_n223;
  t247_n220: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t247_n222;
  t247_n221: return 0.1963246762752533f;
  t247_n222: return -0.14612703025341034f;
  t247_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t247_n225;
  t247_n224: return -0.027875253930687904f;
  t247_n225: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t247_n227;
  t247_n226: return 0.0680643692612648f;
  t247_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t247_n229;
  t247_n228: return 0.11035647988319397f;
  t247_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t247_n231;
  t247_n230: return -0.21622978150844574f;
  t247_n231: return 0.11673146486282349f;
  t247_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t247_n234;
  t247_n233: return 0.06988973915576935f;
  t247_n234: if (E.getNumReferences() >= 3297320960 /*1097.0*/) goto t247_n236;
  t247_n235: return 0.10213583707809448f;
  t247_n236: return 0.07873786240816116f;
  t247_n237: return 0.010942350141704082f;
  t247_n238: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t247_n242;
  t247_n239: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t247_n241;
  t247_n240: return -0.10754184424877167f;
  t247_n241: return 0.13758045434951782f;
  t247_n242: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t247_n254;
  t247_n243: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t247_n249;
  t247_n244: if (E.getNumReferences() >= 3276931072 /*210.0*/) goto t247_n246;
  t247_n245: return 0.045704953372478485f;
  t247_n246: if (E.getNumReferences() >= 3312265216 /*3794.5*/) goto t247_n248;
  t247_n247: return 0.13741560280323029f;
  t247_n248: return 0.10013829916715622f;
  t247_n249: if (E.getNumReferences() >= 3308357632 /*2840.5*/) goto t247_n251;
  t247_n250: return -0.004155643284320831f;
  t247_n251: if (E.getNumReferences() >= 3319443456 /*6998.0*/) goto t247_n253;
  t247_n252: return 0.1283552050590515f;
  t247_n253: return 0.10008159279823303f;
  t247_n254: return 0.033932726830244064f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree248(const Example& E) {
  t248_n0: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t248_n46;
  t248_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t248_n3;
  t248_n2: return 0.00028378781280480325f;
  t248_n3: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t248_n5;
  t248_n4: return 0.054060399532318115f;
  t248_n5: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t248_n33;
  t248_n6: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t248_n8;
  t248_n7: return -0.04262249916791916f;
  t248_n8: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t248_n10;
  t248_n9: return -0.00434889318421483f;
  t248_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t248_n12;
  t248_n11: return -0.08432484418153763f;
  t248_n12: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t248_n14;
  t248_n13: return 0.013616068288683891f;
  t248_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t248_n16;
  t248_n15: return 0.02619304321706295f;
  t248_n16: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t248_n30;
  t248_n17: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t248_n23;
  t248_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t248_n20;
  t248_n19: return 0.05943945050239563f;
  t248_n20: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t248_n22;
  t248_n21: return 0.07361358404159546f;
  t248_n22: return 0.11165367811918259f;
  t248_n23: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t248_n29;
  t248_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t248_n26;
  t248_n25: return 0.11517544090747833f;
  t248_n26: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t248_n28;
  t248_n27: return 0.04870970547199249f;
  t248_n28: return 0.10800261050462723f;
  t248_n29: return 0.08101015537977219f;
  t248_n30: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t248_n32;
  t248_n31: return -0.08325032144784927f;
  t248_n32: return 0.055076032876968384f;
  t248_n33: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t248_n35;
  t248_n34: return -0.006534134037792683f;
  t248_n35: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t248_n45;
  t248_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t248_n38;
  t248_n37: return -0.006276382133364677f;
  t248_n38: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t248_n42;
  t248_n39: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t248_n41;
  t248_n40: return 0.0479336716234684f;
  t248_n41: return 0.025845885276794434f;
  t248_n42: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t248_n44;
  t248_n43: return 0.10386934131383896f;
  t248_n44: return -0.10852383822202682f;
  t248_n45: return 0.004281277302652597f;
  t248_n46: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t248_n174;
  t248_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t248_n115;
  t248_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t248_n50;
  t248_n49: return -0.007796413265168667f;
  t248_n50: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t248_n60;
  t248_n51: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t248_n57;
  t248_n52: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t248_n54;
  t248_n53: return -0.06140444427728653f;
  t248_n54: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t248_n56;
  t248_n55: return 0.13220445811748505f;
  t248_n56: return 0.08961557596921921f;
  t248_n57: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t248_n59;
  t248_n58: return 0.11443748325109482f;
  t248_n59: return 0.04047856107354164f;
  t248_n60: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t248_n114;
  t248_n61: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t248_n67;
  t248_n62: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t248_n66;
  t248_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t248_n65;
  t248_n64: return -0.02035646326839924f;
  t248_n65: return -0.12201190739870071f;
  t248_n66: return 0.10724468529224396f;
  t248_n67: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t248_n83;
  t248_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t248_n82;
  t248_n69: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t248_n71;
  t248_n70: return 0.05513269081711769f;
  t248_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t248_n73;
  t248_n72: return 0.02795621007680893f;
  t248_n73: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t248_n75;
  t248_n74: return 0.15579061210155487f;
  t248_n75: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t248_n81;
  t248_n76: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t248_n80;
  t248_n77: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t248_n79;
  t248_n78: return 0.06324159353971481f;
  t248_n79: return 0.14505338668823242f;
  t248_n80: return 0.11350532621145248f;
  t248_n81: return -0.13122405111789703f;
  t248_n82: return -0.14229799807071686f;
  t248_n83: if (E.getNumReferences() >= 3277357056 /*216.5*/) goto t248_n91;
  t248_n84: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t248_n86;
  t248_n85: return -0.030358172953128815f;
  t248_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t248_n88;
  t248_n87: return -0.2383558601140976f;
  t248_n88: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t248_n90;
  t248_n89: return 0.11874144524335861f;
  t248_n90: return -0.5024594664573669f;
  t248_n91: if (E.getNumReferences() >= 3277815808 /*223.5*/) goto t248_n93;
  t248_n92: return 0.15596972405910492f;
  t248_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t248_n103;
  t248_n94: if (E.getNumReferences() >= 3280125952 /*261.5*/) goto t248_n98;
  t248_n95: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t248_n97;
  t248_n96: return -0.1569981724023819f;
  t248_n97: return -1.1538379192352295f;
  t248_n98: if (E.getNumReferences() >= 3282059264 /*320.5*/) goto t248_n102;
  t248_n99: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t248_n101;
  t248_n100: return 0.048440080136060715f;
  t248_n101: return 0.10957712680101395f;
  t248_n102: return 0.01202539261430502f;
  t248_n103: if (E.getNumReferences() >= 3279994880 /*257.5*/) goto t248_n109;
  t248_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t248_n108;
  t248_n105: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t248_n107;
  t248_n106: return 0.09878747165203094f;
  t248_n107: return -0.07063421607017517f;
  t248_n108: return 0.13059887290000916f;
  t248_n109: if (E.getNumReferences() >= 3292479488 /*765.0*/) goto t248_n111;
  t248_n110: return -0.011642949655652046f;
  t248_n111: if (E.getNumReferences() >= 3293904896 /*852.0*/) goto t248_n113;
  t248_n112: return 0.1133296936750412f;
  t248_n113: return 0.034514378756284714f;
  t248_n114: return 0.00998024269938469f;
  t248_n115: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t248_n147;
  t248_n116: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t248_n144;
  t248_n117: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t248_n143;
  t248_n118: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t248_n128;
  t248_n119: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t248_n121;
  t248_n120: return -0.007879109121859074f;
  t248_n121: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t248_n125;
  t248_n122: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t248_n124;
  t248_n123: return -0.5268344283103943f;
  t248_n124: return 0.07684344798326492f;
  t248_n125: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t248_n127;
  t248_n126: return -0.1810995638370514f;
  t248_n127: return -0.017461102455854416f;
  t248_n128: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t248_n132;
  t248_n129: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t248_n131;
  t248_n130: return 0.11468289792537689f;
  t248_n131: return -0.11171689629554749f;
  t248_n132: if (E.getNumReferences() >= 3272179712 /*137.5*/) goto t248_n140;
  t248_n133: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t248_n137;
  t248_n134: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t248_n136;
  t248_n135: return 0.11161162704229355f;
  t248_n136: return -0.12253851443529129f;
  t248_n137: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t248_n139;
  t248_n138: return 0.1133110299706459f;
  t248_n139: return 0.13864420354366302f;
  t248_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t248_n142;
  t248_n141: return -0.27450332045555115f;
  t248_n142: return 0.01629233919084072f;
  t248_n143: return 0.09570896625518799f;
  t248_n144: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t248_n146;
  t248_n145: return 0.004782871343195438f;
  t248_n146: return 0.1190045177936554f;
  t248_n147: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t248_n149;
  t248_n148: return 0.09761980921030045f;
  t248_n149: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t248_n161;
  t248_n150: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t248_n160;
  t248_n151: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t248_n159;
  t248_n152: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t248_n156;
  t248_n153: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t248_n155;
  t248_n154: return -0.06977588683366776f;
  t248_n155: return 0.09690948575735092f;
  t248_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t248_n158;
  t248_n157: return 0.10499965399503708f;
  t248_n158: return -0.2963074743747711f;
  t248_n159: return -0.11926085501909256f;
  t248_n160: return 0.11818575114011765f;
  t248_n161: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t248_n169;
  t248_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t248_n168;
  t248_n163: if (E.getNumReferences() >= 3274178560 /*168.0*/) goto t248_n167;
  t248_n164: if (E.getNumReferences() >= 3269001216 /*108.5*/) goto t248_n166;
  t248_n165: return -0.5130957365036011f;
  t248_n166: return 0.10672619938850403f;
  t248_n167: return -0.1830594539642334f;
  t248_n168: return 0.016623420640826225f;
  t248_n169: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t248_n173;
  t248_n170: if (E.getNumReferences() >= 3274047488 /*166.0*/) goto t248_n172;
  t248_n171: return 0.0032357126474380493f;
  t248_n172: return 0.10215093195438385f;
  t248_n173: return -0.0720766931772232f;
  t248_n174: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t248_n176;
  t248_n175: return -0.0014719549799337983f;
  t248_n176: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t248_n180;
  t248_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t248_n179;
  t248_n178: return -0.004403667990118265f;
  t248_n179: return 0.0369252935051918f;
  t248_n180: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t248_n198;
  t248_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t248_n195;
  t248_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t248_n184;
  t248_n183: return 0.04565691575407982f;
  t248_n184: if (E.getNumReferences() >= 3282747392 /*341.5*/) goto t248_n194;
  t248_n185: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t248_n193;
  t248_n186: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t248_n192;
  t248_n187: if (E.getNumReferences() >= 3264479232 /*74.0*/) goto t248_n191;
  t248_n188: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t248_n190;
  t248_n189: return 0.11094583570957184f;
  t248_n190: return -0.12242031842470169f;
  t248_n191: return -0.24618719518184662f;
  t248_n192: return 1.208583116531372f;
  t248_n193: return -0.23771978914737701f;
  t248_n194: return 0.12654827535152435f;
  t248_n195: if (E.getNumReferences() >= 3277717504 /*222.0*/) goto t248_n197;
  t248_n196: return -0.11950838565826416f;
  t248_n197: return 0.1298237144947052f;
  t248_n198: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t248_n238;
  t248_n199: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t248_n201;
  t248_n200: return 0.020631996914744377f;
  t248_n201: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t248_n203;
  t248_n202: return 0.03412002697587013f;
  t248_n203: if (E.getNumReferences() >= 3270574080 /*120.5*/) goto t248_n219;
  t248_n204: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t248_n212;
  t248_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t248_n207;
  t248_n206: return 0.1967143714427948f;
  t248_n207: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t248_n211;
  t248_n208: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t248_n210;
  t248_n209: return -0.10104213654994965f;
  t248_n210: return 0.1187824085354805f;
  t248_n211: return -0.10472463071346283f;
  t248_n212: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t248_n218;
  t248_n213: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t248_n215;
  t248_n214: return 0.12134534120559692f;
  t248_n215: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t248_n217;
  t248_n216: return -0.167813241481781f;
  t248_n217: return 0.13830088078975677f;
  t248_n218: return -0.10138536989688873f;
  t248_n219: if (E.getNumReferences() >= 3297632256 /*1135.0*/) goto t248_n237;
  t248_n220: if (E.getNumReferences() >= 3297136640 /*1074.5*/) goto t248_n232;
  t248_n221: if (E.getNumReferences() >= 3273621504 /*159.5*/) goto t248_n223;
  t248_n222: return -0.023598812520503998f;
  t248_n223: if (E.getNumReferences() >= 3274211328 /*168.5*/) goto t248_n229;
  t248_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t248_n226;
  t248_n225: return 0.025360114872455597f;
  t248_n226: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t248_n228;
  t248_n227: return 0.13167110085487366f;
  t248_n228: return -0.4161844551563263f;
  t248_n229: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t248_n231;
  t248_n230: return 0.017794622108340263f;
  t248_n231: return 0.06894981116056442f;
  t248_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t248_n234;
  t248_n233: return 0.06387826800346375f;
  t248_n234: if (E.getNumReferences() >= 3297320960 /*1097.0*/) goto t248_n236;
  t248_n235: return 0.10156987607479095f;
  t248_n236: return 0.0756220668554306f;
  t248_n237: return 0.012185901403427124f;
  t248_n238: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t248_n242;
  t248_n239: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t248_n241;
  t248_n240: return -0.10658188909292221f;
  t248_n241: return 0.13343310356140137f;
  t248_n242: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t248_n254;
  t248_n243: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t248_n249;
  t248_n244: if (E.getNumReferences() >= 3276931072 /*210.0*/) goto t248_n246;
  t248_n245: return 0.05263087898492813f;
  t248_n246: if (E.getNumReferences() >= 3312265216 /*3794.5*/) goto t248_n248;
  t248_n247: return 0.13323643803596497f;
  t248_n248: return 0.10012524574995041f;
  t248_n249: if (E.getNumReferences() >= 3308357632 /*2840.5*/) goto t248_n251;
  t248_n250: return 0.0002132891968358308f;
  t248_n251: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t248_n253;
  t248_n252: return 0.12346275895833969f;
  t248_n253: return 0.1000736728310585f;
  t248_n254: return 0.03304452449083328f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree249(const Example& E) {
  t249_n0: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t249_n2;
  t249_n1: return -0.0004340603481978178f;
  t249_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t249_n152;
  t249_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t249_n81;
  t249_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t249_n52;
  t249_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t249_n51;
  t249_n6: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t249_n48;
  t249_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t249_n19;
  t249_n8: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t249_n14;
  t249_n9: if (E.getNumReferences() >= 3339097344 /*34453.0*/) goto t249_n11;
  t249_n10: return -0.03941169008612633f;
  t249_n11: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t249_n13;
  t249_n12: return -0.00042429837048985064f;
  t249_n13: return 0.07015544921159744f;
  t249_n14: if (E.getNumReferences() >= 3349315712 /*83201.0*/) goto t249_n16;
  t249_n15: return -0.0848596841096878f;
  t249_n16: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t249_n18;
  t249_n17: return 0.02129465714097023f;
  t249_n18: return -0.17895781993865967f;
  t249_n19: if (E.getNumReferences() >= 3276734464 /*207.0*/) goto t249_n23;
  t249_n20: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t249_n22;
  t249_n21: return 0.09655549377202988f;
  t249_n22: return -0.2230987250804901f;
  t249_n23: if (E.getNumReferences() >= 3332163840 /*20068.5*/) goto t249_n47;
  t249_n24: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t249_n32;
  t249_n25: if (E.getNumReferences() >= 3288186880 /*507.5*/) goto t249_n31;
  t249_n26: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t249_n28;
  t249_n27: return -0.021965408697724342f;
  t249_n28: if (E.getNumReferences() >= 3281666048 /*308.5*/) goto t249_n30;
  t249_n29: return 0.10697142779827118f;
  t249_n30: return 0.06377384066581726f;
  t249_n31: return -0.06914026290178299f;
  t249_n32: if (E.getNumReferences() >= 3310237696 /*3299.5*/) goto t249_n44;
  t249_n33: if (E.getNumReferences() >= 3305103360 /*2047.0*/) goto t249_n43;
  t249_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t249_n42;
  t249_n35: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t249_n37;
  t249_n36: return -0.10804560035467148f;
  t249_n37: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t249_n41;
  t249_n38: if (E.getNumReferences() >= 3292536832 /*768.5*/) goto t249_n40;
  t249_n39: return 0.11825267970561981f;
  t249_n40: return 0.07404395192861557f;
  t249_n41: return -0.07205043733119965f;
  t249_n42: return -0.10423438251018524f;
  t249_n43: return 0.11338012665510178f;
  t249_n44: if (E.getNumReferences() >= 3323808256 /*10066.5*/) goto t249_n46;
  t249_n45: return -0.14235398173332214f;
  t249_n46: return 0.09201763570308685f;
  t249_n47: return -0.03674141690135002f;
  t249_n48: if (E.getNumReferences() >= 3275325440 /*185.5*/) goto t249_n50;
  t249_n49: return 0.14616413414478302f;
  t249_n50: return -0.21344327926635742f;
  t249_n51: return 0.005379298701882362f;
  t249_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t249_n54;
  t249_n53: return -0.05957377701997757f;
  t249_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t249_n58;
  t249_n55: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t249_n57;
  t249_n56: return 0.013686046004295349f;
  t249_n57: return -0.12645716965198517f;
  t249_n58: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t249_n76;
  t249_n59: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t249_n61;
  t249_n60: return -0.0354217104613781f;
  t249_n61: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t249_n75;
  t249_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t249_n74;
  t249_n63: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t249_n65;
  t249_n64: return -0.10068606585264206f;
  t249_n65: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t249_n73;
  t249_n66: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t249_n68;
  t249_n67: return -0.17536714673042297f;
  t249_n68: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t249_n70;
  t249_n69: return -0.07487877458333969f;
  t249_n70: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t249_n72;
  t249_n71: return 0.08025030046701431f;
  t249_n72: return 0.12416517734527588f;
  t249_n73: return 0.09945792704820633f;
  t249_n74: return 0.09726159274578094f;
  t249_n75: return 0.026334967464208603f;
  t249_n76: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t249_n78;
  t249_n77: return -0.1508762389421463f;
  t249_n78: if (E.getNumReferences() >= 3286859776 /*467.0*/) goto t249_n80;
  t249_n79: return 0.11894161999225616f;
  t249_n80: return -0.0686635673046112f;
  t249_n81: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t249_n107;
  t249_n82: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t249_n104;
  t249_n83: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t249_n103;
  t249_n84: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t249_n86;
  t249_n85: return -0.02530755288898945f;
  t249_n86: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t249_n90;
  t249_n87: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t249_n89;
  t249_n88: return 0.11324197798967361f;
  t249_n89: return -0.11037623882293701f;
  t249_n90: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t249_n102;
  t249_n91: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t249_n99;
  t249_n92: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t249_n98;
  t249_n93: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t249_n95;
  t249_n94: return 0.11970030516386032f;
  t249_n95: if (E.getNumReferences() >= 3271229440 /*125.5*/) goto t249_n97;
  t249_n96: return -0.19290970265865326f;
  t249_n97: return 0.4340083599090576f;
  t249_n98: return 0.047671087086200714f;
  t249_n99: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t249_n101;
  t249_n100: return 0.11289473623037338f;
  t249_n101: return 0.055243875831365585f;
  t249_n102: return 0.013449737802147865f;
  t249_n103: return 0.09658174961805344f;
  t249_n104: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t249_n106;
  t249_n105: return -0.017799725756049156f;
  t249_n106: return 0.11446329206228256f;
  t249_n107: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t249_n131;
  t249_n108: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t249_n130;
  t249_n109: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t249_n115;
  t249_n110: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t249_n112;
  t249_n111: return -0.33344215154647827f;
  t249_n112: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t249_n114;
  t249_n113: return 0.09873690456151962f;
  t249_n114: return 0.027316788211464882f;
  t249_n115: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t249_n121;
  t249_n116: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t249_n120;
  t249_n117: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t249_n119;
  t249_n118: return 0.10313525795936584f;
  t249_n119: return 0.10309214144945145f;
  t249_n120: return 0.05303477123379707f;
  t249_n121: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t249_n123;
  t249_n122: return -0.08279391378164291f;
  t249_n123: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t249_n129;
  t249_n124: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t249_n126;
  t249_n125: return 0.0977054238319397f;
  t249_n126: if (E.getNumReferences() >= 3260809216 /*55.0*/) goto t249_n128;
  t249_n127: return 0.11796632409095764f;
  t249_n128: return -0.24189887940883636f;
  t249_n129: return -0.09027464687824249f;
  t249_n130: return 0.11593613773584366f;
  t249_n131: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t249_n139;
  t249_n132: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t249_n138;
  t249_n133: if (E.getNumReferences() >= 3274178560 /*168.0*/) goto t249_n137;
  t249_n134: if (E.getNumReferences() >= 3269001216 /*108.5*/) goto t249_n136;
  t249_n135: return -0.3297380805015564f;
  t249_n136: return 0.10548937320709229f;
  t249_n137: return -0.197080597281456f;
  t249_n138: return 0.013692863285541534f;
  t249_n139: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t249_n151;
  t249_n140: if (E.getNumReferences() >= 3274047488 /*166.0*/) goto t249_n150;
  t249_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t249_n143;
  t249_n142: return -0.20664642751216888f;
  t249_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t249_n145;
  t249_n144: return 0.0881505012512207f;
  t249_n145: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t249_n147;
  t249_n146: return -0.04863353073596954f;
  t249_n147: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t249_n149;
  t249_n148: return 0.014896823093295097f;
  t249_n149: return 0.10662771761417389f;
  t249_n150: return 0.09233442693948746f;
  t249_n151: return -0.06067914515733719f;
  t249_n152: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t249_n230;
  t249_n153: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t249_n165;
  t249_n154: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t249_n156;
  t249_n155: return -0.02660883590579033f;
  t249_n156: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t249_n164;
  t249_n157: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t249_n159;
  t249_n158: return -0.019650384783744812f;
  t249_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t249_n161;
  t249_n160: return 0.017170196399092674f;
  t249_n161: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t249_n163;
  t249_n162: return 0.05839894339442253f;
  t249_n163: return 0.042001690715551376f;
  t249_n164: return 0.005162880290299654f;
  t249_n165: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t249_n167;
  t249_n166: return -0.030798083171248436f;
  t249_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t249_n207;
  t249_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t249_n170;
  t249_n169: return -0.003200497245416045f;
  t249_n170: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t249_n204;
  t249_n171: if (E.getNumReferences() >= 3285516288 /*426.0*/) goto t249_n173;
  t249_n172: return -0.011549372225999832f;
  t249_n173: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t249_n183;
  t249_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t249_n176;
  t249_n175: return 0.06000044569373131f;
  t249_n176: if (E.getNumReferences() >= 3326347776 /*12546.5*/) goto t249_n180;
  t249_n177: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t249_n179;
  t249_n178: return 0.12102532386779785f;
  t249_n179: return -0.1152951791882515f;
  t249_n180: if (E.getNumReferences() >= 3333374720 /*22433.5*/) goto t249_n182;
  t249_n181: return 0.2770821750164032f;
  t249_n182: return -0.03952778875827789f;
  t249_n183: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t249_n185;
  t249_n184: return 0.07281368225812912f;
  t249_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t249_n203;
  t249_n186: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t249_n202;
  t249_n187: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t249_n201;
  t249_n188: if (E.getNumReferences() >= 3290619904 /*651.5*/) goto t249_n190;
  t249_n189: return -0.10410080850124359f;
  t249_n190: if (E.getNumReferences() >= 3291021312 /*676.0*/) goto t249_n192;
  t249_n191: return 0.1268501877784729f;
  t249_n192: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t249_n198;
  t249_n193: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t249_n197;
  t249_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t249_n196;
  t249_n195: return 0.11632902175188065f;
  t249_n196: return 0.08968929201364517f;
  t249_n197: return -0.14158201217651367f;
  t249_n198: if (E.getNumReferences() >= 3308046336 /*2764.5*/) goto t249_n200;
  t249_n199: return 0.10979311913251877f;
  t249_n200: return 0.07061515003442764f;
  t249_n201: return -0.012832462787628174f;
  t249_n202: return -0.12554067373275757f;
  t249_n203: return 0.04063865914940834f;
  t249_n204: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t249_n206;
  t249_n205: return -0.09424977004528046f;
  t249_n206: return 0.1283944845199585f;
  t249_n207: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t249_n211;
  t249_n208: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t249_n210;
  t249_n209: return -0.11822741478681564f;
  t249_n210: return 0.12772338092327118f;
  t249_n211: if (E.getNumReferences() >= 3325630464 /*11846.0*/) goto t249_n213;
  t249_n212: return 0.013928079977631569f;
  t249_n213: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t249_n229;
  t249_n214: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t249_n222;
  t249_n215: if (E.getNumReferences() >= 3348327104 /*75477.5*/) goto t249_n217;
  t249_n216: return 0.034325748682022095f;
  t249_n217: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t249_n221;
  t249_n218: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t249_n220;
  t249_n219: return 0.05646951124072075f;
  t249_n220: return 0.004860611632466316f;
  t249_n221: return 0.039683613926172256f;
  t249_n222: if (E.getNumReferences() >= 3333936384 /*23530.5*/) goto t249_n224;
  t249_n223: return 0.0467170886695385f;
  t249_n224: if (E.getNumReferences() >= 3335077120 /*25758.5*/) goto t249_n226;
  t249_n225: return 0.11048052459955215f;
  t249_n226: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t249_n228;
  t249_n227: return -0.17512422800064087f;
  t249_n228: return 0.12345641106367111f;
  t249_n229: return -0.009149143472313881f;
  t249_n230: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t249_n242;
  t249_n231: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t249_n241;
  t249_n232: if (E.getNumReferences() >= 3301228544 /*1574.0*/) goto t249_n234;
  t249_n233: return -0.050683654844760895f;
  t249_n234: if (E.getNumReferences() >= 3301416960 /*1597.0*/) goto t249_n236;
  t249_n235: return 0.09780242294073105f;
  t249_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t249_n238;
  t249_n237: return 0.009001832455396652f;
  t249_n238: if (E.getNumReferences() >= 3304833024 /*2014.0*/) goto t249_n240;
  t249_n239: return 0.10708367824554443f;
  t249_n240: return 0.04509671404957771f;
  t249_n241: return 0.022580942139029503f;
  t249_n242: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t249_n244;
  t249_n243: return 0.03302409127354622f;
  t249_n244: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t249_n254;
  t249_n245: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t249_n249;
  t249_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t249_n248;
  t249_n247: return -0.08674107491970062f;
  t249_n248: return 0.13062773644924164f;
  t249_n249: if (E.getNumReferences() >= 3288948736 /*549.5*/) goto t249_n251;
  t249_n250: return 0.05711936950683594f;
  t249_n251: if (E.getNumReferences() >= 3291684864 /*716.5*/) goto t249_n253;
  t249_n252: return 0.12734901905059814f;
  t249_n253: return 0.017207736149430275f;
  t249_n254: return 0.03847238048911095f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree250(const Example& E) {
  t250_n0: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t250_n86;
  t250_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t250_n5;
  t250_n2: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t250_n4;
  t250_n3: return -0.07573062181472778f;
  t250_n4: return -0.007578597869724035f;
  t250_n5: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t250_n7;
  t250_n6: return -0.00047731728409416974f;
  t250_n7: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t250_n9;
  t250_n8: return 0.02088080905377865f;
  t250_n9: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t250_n15;
  t250_n10: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t250_n14;
  t250_n11: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t250_n13;
  t250_n12: return 0.03127611428499222f;
  t250_n13: return 0.12149722874164581f;
  t250_n14: return 0.01016273908317089f;
  t250_n15: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t250_n83;
  t250_n16: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t250_n18;
  t250_n17: return -0.0234710443764925f;
  t250_n18: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t250_n64;
  t250_n19: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t250_n57;
  t250_n20: if (E.getNumReferences() >= 3259498496 /*50.0*/) goto t250_n56;
  t250_n21: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t250_n51;
  t250_n22: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t250_n44;
  t250_n23: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t250_n43;
  t250_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t250_n28;
  t250_n25: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t250_n27;
  t250_n26: return 0.027858823537826538f;
  t250_n27: return 0.09296302497386932f;
  t250_n28: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t250_n42;
  t250_n29: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t250_n41;
  t250_n30: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t250_n32;
  t250_n31: return 0.043143436312675476f;
  t250_n32: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t250_n38;
  t250_n33: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t250_n37;
  t250_n34: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t250_n36;
  t250_n35: return -0.12939660251140594f;
  t250_n36: return 0.08814314752817154f;
  t250_n37: return 0.07477985322475433f;
  t250_n38: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t250_n40;
  t250_n39: return -0.38603541254997253f;
  t250_n40: return 0.06655760109424591f;
  t250_n41: return 0.015633031725883484f;
  t250_n42: return 0.019044112414121628f;
  t250_n43: return 0.020483991131186485f;
  t250_n44: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t250_n46;
  t250_n45: return 0.1289733350276947f;
  t250_n46: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t250_n48;
  t250_n47: return -0.10180874913930893f;
  t250_n48: if (E.getNumReferences() >= 3246391296 /*16.0*/) goto t250_n50;
  t250_n49: return 0.03407949581742287f;
  t250_n50: return 0.11056777089834213f;
  t250_n51: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t250_n55;
  t250_n52: if (E.getNumReferences() >= 3256090624 /*37.0*/) goto t250_n54;
  t250_n53: return 0.12991102039813995f;
  t250_n54: return 0.08924510329961777f;
  t250_n55: return 0.012420160695910454f;
  t250_n56: return 0.10276858508586884f;
  t250_n57: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t250_n63;
  t250_n58: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t250_n60;
  t250_n59: return 0.14148454368114471f;
  t250_n60: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t250_n62;
  t250_n61: return 0.10179043561220169f;
  t250_n62: return -0.12127161026000977f;
  t250_n63: return 0.011214923113584518f;
  t250_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t250_n82;
  t250_n65: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t250_n73;
  t250_n66: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t250_n72;
  t250_n67: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t250_n69;
  t250_n68: return 0.08040080964565277f;
  t250_n69: if (E.getNumReferences() >= 3245342720 /*15.0*/) goto t250_n71;
  t250_n70: return 0.10967136919498444f;
  t250_n71: return -0.12931013107299805f;
  t250_n72: return -0.053608719259500504f;
  t250_n73: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t250_n79;
  t250_n74: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t250_n78;
  t250_n75: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t250_n77;
  t250_n76: return 0.032194048166275024f;
  t250_n77: return 0.10593065619468689f;
  t250_n78: return -0.04560554772615433f;
  t250_n79: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t250_n81;
  t250_n80: return 0.10083342343568802f;
  t250_n81: return 0.04121845215559006f;
  t250_n82: return -0.037802428007125854f;
  t250_n83: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t250_n85;
  t250_n84: return -0.02233300171792507f;
  t250_n85: return 0.059258364140987396f;
  t250_n86: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t250_n254;
  t250_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t250_n249;
  t250_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t250_n134;
  t250_n89: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t250_n131;
  t250_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t250_n100;
  t250_n91: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t250_n93;
  t250_n92: return 0.0011782569345086813f;
  t250_n93: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t250_n99;
  t250_n94: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t250_n96;
  t250_n95: return 0.08326181769371033f;
  t250_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t250_n98;
  t250_n97: return 0.1351311355829239f;
  t250_n98: return 0.15589416027069092f;
  t250_n99: return -0.023495834320783615f;
  t250_n100: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t250_n128;
  t250_n101: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t250_n123;
  t250_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n108;
  t250_n103: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t250_n105;
  t250_n104: return -0.023973682895302773f;
  t250_n105: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t250_n107;
  t250_n106: return -0.04260933771729469f;
  t250_n107: return 0.013481304049491882f;
  t250_n108: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t250_n110;
  t250_n109: return 0.017130127176642418f;
  t250_n110: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t250_n118;
  t250_n111: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t250_n115;
  t250_n112: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t250_n114;
  t250_n113: return -0.03404458984732628f;
  t250_n114: return 0.03392718359827995f;
  t250_n115: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t250_n117;
  t250_n116: return -0.03456352651119232f;
  t250_n117: return -0.005347564350813627f;
  t250_n118: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t250_n120;
  t250_n119: return 0.04838518425822258f;
  t250_n120: if (E.getNumReferences() >= 3256352768 /*38.0*/) goto t250_n122;
  t250_n121: return -0.15651898086071014f;
  t250_n122: return 0.023331401869654655f;
  t250_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n127;
  t250_n124: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t250_n126;
  t250_n125: return 0.05275541543960571f;
  t250_n126: return -0.054345861077308655f;
  t250_n127: return -0.020629795268177986f;
  t250_n128: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t250_n130;
  t250_n129: return -0.02754412591457367f;
  t250_n130: return -0.34511348605155945f;
  t250_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t250_n133;
  t250_n132: return -0.03466760739684105f;
  t250_n133: return -0.0258746650069952f;
  t250_n134: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t250_n162;
  t250_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t250_n139;
  t250_n136: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t250_n138;
  t250_n137: return 0.002392733469605446f;
  t250_n138: return -0.007376069203019142f;
  t250_n139: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t250_n141;
  t250_n140: return 0.000376583804609254f;
  t250_n141: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t250_n151;
  t250_n142: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t250_n146;
  t250_n143: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t250_n145;
  t250_n144: return 0.022719500586390495f;
  t250_n145: return -0.0278455913066864f;
  t250_n146: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t250_n150;
  t250_n147: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t250_n149;
  t250_n148: return 0.06878212839365005f;
  t250_n149: return 0.11805698275566101f;
  t250_n150: return 0.03371823951601982f;
  t250_n151: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t250_n159;
  t250_n152: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t250_n158;
  t250_n153: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t250_n157;
  t250_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t250_n156;
  t250_n155: return 0.11517172306776047f;
  t250_n156: return -0.14779546856880188f;
  t250_n157: return 0.016522318124771118f;
  t250_n158: return -0.0018795536598190665f;
  t250_n159: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t250_n161;
  t250_n160: return 0.10000487416982651f;
  t250_n161: return 0.07862933725118637f;
  t250_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t250_n172;
  t250_n163: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t250_n169;
  t250_n164: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t250_n166;
  t250_n165: return 0.03164372220635414f;
  t250_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n168;
  t250_n167: return 0.04520007222890854f;
  t250_n168: return 0.04320826008915901f;
  t250_n169: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t250_n171;
  t250_n170: return 0.03632902726531029f;
  t250_n171: return 0.047829363495111465f;
  t250_n172: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t250_n228;
  t250_n173: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t250_n189;
  t250_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t250_n176;
  t250_n175: return -0.038455042988061905f;
  t250_n176: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t250_n178;
  t250_n177: return 0.042074453085660934f;
  t250_n178: if (E.getNumReferences() >= 3320975360 /*7746.0*/) goto t250_n186;
  t250_n179: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t250_n185;
  t250_n180: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t250_n182;
  t250_n181: return 0.008281557820737362f;
  t250_n182: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t250_n184;
  t250_n183: return 0.0422414094209671f;
  t250_n184: return 0.10449296236038208f;
  t250_n185: return -0.0007647154270671308f;
  t250_n186: if (E.getNumReferences() >= 3323093504 /*9368.5*/) goto t250_n188;
  t250_n187: return 0.13325664401054382f;
  t250_n188: return -0.2344980686903f;
  t250_n189: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t250_n197;
  t250_n190: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n196;
  t250_n191: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t250_n193;
  t250_n192: return -0.16391782462596893f;
  t250_n193: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t250_n195;
  t250_n194: return 0.10247654467821121f;
  t250_n195: return 0.08784588426351547f;
  t250_n196: return 0.0030287466943264008f;
  t250_n197: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t250_n219;
  t250_n198: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t250_n218;
  t250_n199: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t250_n201;
  t250_n200: return 0.02444671094417572f;
  t250_n201: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t250_n209;
  t250_n202: if (E.getNumReferences() >= 3344088704 /*53950.5*/) goto t250_n204;
  t250_n203: return 0.11743149906396866f;
  t250_n204: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t250_n208;
  t250_n205: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t250_n207;
  t250_n206: return -0.013116692192852497f;
  t250_n207: return 0.11731349676847458f;
  t250_n208: return -0.7964848875999451f;
  t250_n209: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t250_n213;
  t250_n210: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t250_n212;
  t250_n211: return 0.11553163081407547f;
  t250_n212: return 0.05040830373764038f;
  t250_n213: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t250_n215;
  t250_n214: return 0.03549725562334061f;
  t250_n215: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t250_n217;
  t250_n216: return 0.12421101331710815f;
  t250_n217: return 0.10001281648874283f;
  t250_n218: return -0.005799827631562948f;
  t250_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n227;
  t250_n220: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t250_n226;
  t250_n221: if (E.getNumReferences() >= 3333923840 /*23506.0*/) goto t250_n225;
  t250_n222: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t250_n224;
  t250_n223: return -0.12803493440151215f;
  t250_n224: return 0.10749463737010956f;
  t250_n225: return 0.022213829681277275f;
  t250_n226: return 0.09946668148040771f;
  t250_n227: return 0.05516577512025833f;
  t250_n228: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t250_n240;
  t250_n229: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n231;
  t250_n230: return 0.06881152838468552f;
  t250_n231: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t250_n233;
  t250_n232: return 0.05202244594693184f;
  t250_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t250_n237;
  t250_n234: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t250_n236;
  t250_n235: return -0.15090809762477875f;
  t250_n236: return 0.12948325276374817f;
  t250_n237: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t250_n239;
  t250_n238: return 0.24948589503765106f;
  t250_n239: return 0.05299833044409752f;
  t250_n240: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t250_n248;
  t250_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t250_n243;
  t250_n242: return -0.039742350578308105f;
  t250_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n245;
  t250_n244: return 0.12656207382678986f;
  t250_n245: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t250_n247;
  t250_n246: return 0.2047608345746994f;
  t250_n247: return 0.09131361544132233f;
  t250_n248: return 0.030073465779423714f;
  t250_n249: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t250_n251;
  t250_n250: return -0.11600925028324127f;
  t250_n251: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t250_n253;
  t250_n252: return 0.009670496918261051f;
  t250_n253: return -0.006590001285076141f;
  t250_n254: return -0.002280907006934285f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree251(const Example& E) {
  t251_n0: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t251_n254;
  t251_n1: if (E.getNumReferences() >= 3294699520 /*900.5*/) goto t251_n253;
  t251_n2: if (E.getNumReferences() >= 3294683136 /*899.5*/) goto t251_n248;
  t251_n3: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t251_n217;
  t251_n4: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t251_n174;
  t251_n5: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t251_n55;
  t251_n6: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t251_n8;
  t251_n7: return 0.0008460190729238093f;
  t251_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t251_n54;
  t251_n9: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t251_n19;
  t251_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t251_n12;
  t251_n11: return -0.058537062257528305f;
  t251_n12: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t251_n14;
  t251_n13: return -0.046792056411504745f;
  t251_n14: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t251_n16;
  t251_n15: return -0.03894174471497536f;
  t251_n16: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t251_n18;
  t251_n17: return 0.1292792111635208f;
  t251_n18: return 0.0413772389292717f;
  t251_n19: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t251_n21;
  t251_n20: return -0.03426407277584076f;
  t251_n21: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t251_n23;
  t251_n22: return 0.008590622805058956f;
  t251_n23: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t251_n53;
  t251_n24: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t251_n42;
  t251_n25: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t251_n41;
  t251_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t251_n28;
  t251_n27: return -0.29045411944389343f;
  t251_n28: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t251_n38;
  t251_n29: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t251_n31;
  t251_n30: return 0.05312122032046318f;
  t251_n31: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n33;
  t251_n32: return 0.09124018996953964f;
  t251_n33: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t251_n37;
  t251_n34: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n36;
  t251_n35: return 0.14626410603523254f;
  t251_n36: return 0.09473678469657898f;
  t251_n37: return 0.12394542992115021f;
  t251_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t251_n40;
  t251_n39: return 0.015380339697003365f;
  t251_n40: return 0.104399673640728f;
  t251_n41: return 0.08841776847839355f;
  t251_n42: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t251_n52;
  t251_n43: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t251_n45;
  t251_n44: return -0.13926951587200165f;
  t251_n45: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t251_n51;
  t251_n46: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t251_n50;
  t251_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t251_n49;
  t251_n48: return 0.05659663677215576f;
  t251_n49: return 0.07671685516834259f;
  t251_n50: return 0.10782863944768906f;
  t251_n51: return -0.030997369438409805f;
  t251_n52: return -0.1777627021074295f;
  t251_n53: return -0.06182757392525673f;
  t251_n54: return 0.023305682465434074f;
  t251_n55: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t251_n131;
  t251_n56: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t251_n66;
  t251_n57: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t251_n63;
  t251_n58: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t251_n60;
  t251_n59: return -0.028497369959950447f;
  t251_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t251_n62;
  t251_n61: return 0.0886923149228096f;
  t251_n62: return 0.10490810871124268f;
  t251_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t251_n65;
  t251_n64: return -0.664527177810669f;
  t251_n65: return -0.006351650692522526f;
  t251_n66: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t251_n130;
  t251_n67: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t251_n75;
  t251_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t251_n72;
  t251_n69: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t251_n71;
  t251_n70: return -0.022141749039292336f;
  t251_n71: return -0.13330256938934326f;
  t251_n72: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t251_n74;
  t251_n73: return 0.023765916004776955f;
  t251_n74: return -0.0052779195830225945f;
  t251_n75: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t251_n123;
  t251_n76: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t251_n122;
  t251_n77: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t251_n79;
  t251_n78: return 0.023402228951454163f;
  t251_n79: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t251_n93;
  t251_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t251_n82;
  t251_n81: return -0.06381210684776306f;
  t251_n82: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n84;
  t251_n83: return -0.05588669702410698f;
  t251_n84: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t251_n86;
  t251_n85: return 0.02125735767185688f;
  t251_n86: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n92;
  t251_n87: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t251_n91;
  t251_n88: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t251_n90;
  t251_n89: return 0.118331179022789f;
  t251_n90: return -0.030166111886501312f;
  t251_n91: return -0.16322004795074463f;
  t251_n92: return 0.36540260910987854f;
  t251_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t251_n95;
  t251_n94: return 0.08047620207071304f;
  t251_n95: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t251_n119;
  t251_n96: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t251_n98;
  t251_n97: return -0.061719827353954315f;
  t251_n98: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n108;
  t251_n99: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t251_n103;
  t251_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t251_n102;
  t251_n101: return -0.1286735087633133f;
  t251_n102: return 0.23879677057266235f;
  t251_n103: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t251_n107;
  t251_n104: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t251_n106;
  t251_n105: return 0.14156855642795563f;
  t251_n106: return 0.12586282193660736f;
  t251_n107: return 0.043722521513700485f;
  t251_n108: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n114;
  t251_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t251_n113;
  t251_n110: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t251_n112;
  t251_n111: return -0.15810100734233856f;
  t251_n112: return 0.11763371527194977f;
  t251_n113: return 0.09545930474996567f;
  t251_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t251_n116;
  t251_n115: return 0.09294086694717407f;
  t251_n116: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t251_n118;
  t251_n117: return 0.12283080816268921f;
  t251_n118: return 0.12704052031040192f;
  t251_n119: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n121;
  t251_n120: return 0.13113564252853394f;
  t251_n121: return 0.16428446769714355f;
  t251_n122: return -0.04689015448093414f;
  t251_n123: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t251_n129;
  t251_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t251_n126;
  t251_n125: return -0.11600060015916824f;
  t251_n126: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t251_n128;
  t251_n127: return 0.19707907736301422f;
  t251_n128: return 0.2890290319919586f;
  t251_n129: return -0.866955578327179f;
  t251_n130: return 0.4444006085395813f;
  t251_n131: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t251_n161;
  t251_n132: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t251_n160;
  t251_n133: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t251_n159;
  t251_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t251_n136;
  t251_n135: return -0.03964156284928322f;
  t251_n136: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t251_n144;
  t251_n137: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t251_n143;
  t251_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n142;
  t251_n139: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t251_n141;
  t251_n140: return 0.10279899090528488f;
  t251_n141: return -1.1287521123886108f;
  t251_n142: return -0.07556550204753876f;
  t251_n143: return -0.0385507196187973f;
  t251_n144: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t251_n154;
  t251_n145: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n151;
  t251_n146: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t251_n150;
  t251_n147: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t251_n149;
  t251_n148: return -0.12610097229480743f;
  t251_n149: return 0.10165658593177795f;
  t251_n150: return 0.14470604062080383f;
  t251_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t251_n153;
  t251_n152: return 0.12639838457107544f;
  t251_n153: return -0.1162201538681984f;
  t251_n154: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t251_n156;
  t251_n155: return -0.15668006241321564f;
  t251_n156: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t251_n158;
  t251_n157: return -0.101308174431324f;
  t251_n158: return 0.14163044095039368f;
  t251_n159: return -0.020135659724473953f;
  t251_n160: return -0.021555837243795395f;
  t251_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t251_n173;
  t251_n162: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t251_n172;
  t251_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t251_n165;
  t251_n164: return 0.03466653451323509f;
  t251_n165: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t251_n167;
  t251_n166: return 0.09830939769744873f;
  t251_n167: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t251_n171;
  t251_n168: if (E.getNumReferences() >= 3235905536 /*7.0*/) goto t251_n170;
  t251_n169: return 0.049078360199928284f;
  t251_n170: return 0.1087256520986557f;
  t251_n171: return -0.10037816315889359f;
  t251_n172: return -0.10514752566814423f;
  t251_n173: return 0.09890104830265045f;
  t251_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t251_n176;
  t251_n175: return -0.1136365607380867f;
  t251_n176: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t251_n216;
  t251_n177: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t251_n215;
  t251_n178: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t251_n180;
  t251_n179: return 0.047249291092157364f;
  t251_n180: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t251_n188;
  t251_n181: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t251_n183;
  t251_n182: return 0.024623528122901917f;
  t251_n183: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t251_n185;
  t251_n184: return 0.0014247403014451265f;
  t251_n185: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t251_n187;
  t251_n186: return 0.10564199090003967f;
  t251_n187: return -0.045549433678388596f;
  t251_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t251_n190;
  t251_n189: return 0.023787586018443108f;
  t251_n190: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t251_n194;
  t251_n191: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t251_n193;
  t251_n192: return -0.02786530740559101f;
  t251_n193: return 0.15959013998508453f;
  t251_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t251_n202;
  t251_n195: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t251_n197;
  t251_n196: return 0.090665303170681f;
  t251_n197: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t251_n201;
  t251_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n200;
  t251_n199: return 0.12297441065311432f;
  t251_n200: return 0.05045964941382408f;
  t251_n201: return 0.10715647786855698f;
  t251_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t251_n214;
  t251_n203: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t251_n213;
  t251_n204: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t251_n210;
  t251_n205: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t251_n207;
  t251_n206: return 0.06850829720497131f;
  t251_n207: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t251_n209;
  t251_n208: return 0.11116161942481995f;
  t251_n209: return 0.11666788905858994f;
  t251_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t251_n212;
  t251_n211: return 0.12468157708644867f;
  t251_n212: return -0.09014154225587845f;
  t251_n213: return -0.3826810121536255f;
  t251_n214: return -0.028742263093590736f;
  t251_n215: return -0.0035868166014552116f;
  t251_n216: return 0.0067685442045331f;
  t251_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t251_n219;
  t251_n218: return 0.009406433440744877f;
  t251_n219: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t251_n243;
  t251_n220: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t251_n224;
  t251_n221: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t251_n223;
  t251_n222: return -0.12459689378738403f;
  t251_n223: return 0.03602784126996994f;
  t251_n224: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t251_n236;
  t251_n225: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t251_n227;
  t251_n226: return -0.06676075607538223f;
  t251_n227: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t251_n235;
  t251_n228: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t251_n230;
  t251_n229: return -0.9702273011207581f;
  t251_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t251_n234;
  t251_n231: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n233;
  t251_n232: return 0.1281798779964447f;
  t251_n233: return 0.1204414889216423f;
  t251_n234: return -0.10590244829654694f;
  t251_n235: return 0.12429303675889969f;
  t251_n236: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t251_n238;
  t251_n237: return -0.025740966200828552f;
  t251_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n240;
  t251_n239: return 0.05019634589552879f;
  t251_n240: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t251_n242;
  t251_n241: return -0.18996018171310425f;
  t251_n242: return 0.11993817985057831f;
  t251_n243: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t251_n247;
  t251_n244: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t251_n246;
  t251_n245: return 0.03862281143665314f;
  t251_n246: return -0.028713682666420937f;
  t251_n247: return -5.621318268822506e-05f;
  t251_n248: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n250;
  t251_n249: return -0.17434997856616974f;
  t251_n250: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n252;
  t251_n251: return -1.1187759637832642f;
  t251_n252: return 0.09991370886564255f;
  t251_n253: return -0.022754816338419914f;
  t251_n254: return -0.0005396142369136214f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree252(const Example& E) {
  t252_n0: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t252_n206;
  t252_n1: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t252_n115;
  t252_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n4;
  t252_n3: return -0.0020793613512068987f;
  t252_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t252_n66;
  t252_n5: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t252_n13;
  t252_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t252_n8;
  t252_n7: return -0.007689312566071749f;
  t252_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Namespace))) goto t252_n10;
  t252_n9: return -0.028877463191747665f;
  t252_n10: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t252_n12;
  t252_n11: return -0.09502160549163818f;
  t252_n12: return 0.04206758365035057f;
  t252_n13: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t252_n57;
  t252_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t252_n30;
  t252_n15: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t252_n27;
  t252_n16: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t252_n26;
  t252_n17: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t252_n23;
  t252_n18: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t252_n20;
  t252_n19: return -0.009944042190909386f;
  t252_n20: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t252_n22;
  t252_n21: return 0.13750946521759033f;
  t252_n22: return 0.03890620917081833f;
  t252_n23: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t252_n25;
  t252_n24: return 0.1106770858168602f;
  t252_n25: return -0.004074375610798597f;
  t252_n26: return -0.030939044430851936f;
  t252_n27: if (E.getNumReferences() >= 3355694624 /*135000.5*/) goto t252_n29;
  t252_n28: return 0.006649407558143139f;
  t252_n29: return -0.08667148649692535f;
  t252_n30: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t252_n32;
  t252_n31: return 0.015317412093281746f;
  t252_n32: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t252_n38;
  t252_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n37;
  t252_n34: if (E.getFileProximityDistance() >= 3251634176 /*26.0*/) goto t252_n36;
  t252_n35: return -0.007866493426263332f;
  t252_n36: return 0.09093550592660904f;
  t252_n37: return 0.01284045446664095f;
  t252_n38: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t252_n56;
  t252_n39: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n41;
  t252_n40: return 0.10535865277051926f;
  t252_n41: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t252_n53;
  t252_n42: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t252_n52;
  t252_n43: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t252_n51;
  t252_n44: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t252_n46;
  t252_n45: return 0.11742610484361649f;
  t252_n46: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t252_n48;
  t252_n47: return -0.1144365444779396f;
  t252_n48: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t252_n50;
  t252_n49: return 0.12139711529016495f;
  t252_n50: return 0.022228216752409935f;
  t252_n51: return -0.047988250851631165f;
  t252_n52: return -0.06512752920389175f;
  t252_n53: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t252_n55;
  t252_n54: return -0.007541762199252844f;
  t252_n55: return 0.1141665130853653f;
  t252_n56: return 0.013401973061263561f;
  t252_n57: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t252_n59;
  t252_n58: return 0.018367625772953033f;
  t252_n59: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t252_n65;
  t252_n60: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t252_n62;
  t252_n61: return -0.05045308172702789f;
  t252_n62: if (E.getNumReferences() >= 3369849520 /*450197.5*/) goto t252_n64;
  t252_n63: return 0.09349492937326431f;
  t252_n64: return 0.0406775139272213f;
  t252_n65: return 0.015857592225074768f;
  t252_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t252_n114;
  t252_n67: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t252_n97;
  t252_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n94;
  t252_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t252_n91;
  t252_n70: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t252_n88;
  t252_n71: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t252_n77;
  t252_n72: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t252_n74;
  t252_n73: return -0.016590436920523643f;
  t252_n74: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t252_n76;
  t252_n75: return -0.13403891026973724f;
  t252_n76: return -0.057892560958862305f;
  t252_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t252_n79;
  t252_n78: return -0.32224786281585693f;
  t252_n79: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t252_n85;
  t252_n80: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t252_n82;
  t252_n81: return 0.04054633155465126f;
  t252_n82: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t252_n84;
  t252_n83: return 0.1010517030954361f;
  t252_n84: return 0.04866061359643936f;
  t252_n85: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t252_n87;
  t252_n86: return 0.08670175075531006f;
  t252_n87: return -0.03791720047593117f;
  t252_n88: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t252_n90;
  t252_n89: return -0.04514126107096672f;
  t252_n90: return -0.019096767529845238f;
  t252_n91: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t252_n93;
  t252_n92: return 0.004176125396043062f;
  t252_n93: return 0.08902600407600403f;
  t252_n94: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t252_n96;
  t252_n95: return 0.035690128803253174f;
  t252_n96: return -0.0002662641345523298f;
  t252_n97: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t252_n99;
  t252_n98: return -0.13693705201148987f;
  t252_n99: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t252_n113;
  t252_n100: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t252_n102;
  t252_n101: return -0.032500479370355606f;
  t252_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n104;
  t252_n103: return -0.011921325698494911f;
  t252_n104: if (E.getNumReferences() >= 3313405952 /*4073.0*/) goto t252_n112;
  t252_n105: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n109;
  t252_n106: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t252_n108;
  t252_n107: return 0.027379313483834267f;
  t252_n108: return 0.11452055722475052f;
  t252_n109: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t252_n111;
  t252_n110: return 0.11580731719732285f;
  t252_n111: return 0.10050761699676514f;
  t252_n112: return -0.020809466019272804f;
  t252_n113: return 0.10220186412334442f;
  t252_n114: return 0.004363608546555042f;
  t252_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t252_n167;
  t252_n116: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t252_n144;
  t252_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n123;
  t252_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t252_n120;
  t252_n119: return 0.007012073416262865f;
  t252_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t252_n122;
  t252_n121: return 0.020526858046650887f;
  t252_n122: return 0.03712324798107147f;
  t252_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n125;
  t252_n124: return -0.0033736161421984434f;
  t252_n125: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t252_n141;
  t252_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t252_n128;
  t252_n127: return -0.132486030459404f;
  t252_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n132;
  t252_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t252_n131;
  t252_n130: return 0.014797191135585308f;
  t252_n131: return 0.07122936844825745f;
  t252_n132: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t252_n134;
  t252_n133: return 0.16767112910747528f;
  t252_n134: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t252_n136;
  t252_n135: return 0.012193274684250355f;
  t252_n136: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t252_n140;
  t252_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t252_n139;
  t252_n138: return -0.074927918612957f;
  t252_n139: return 0.11047631502151489f;
  t252_n140: return 0.021662145853042603f;
  t252_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t252_n143;
  t252_n142: return -0.0015212384751066566f;
  t252_n143: return 0.008665969595313072f;
  t252_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t252_n150;
  t252_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n147;
  t252_n146: return -0.03919480741024017f;
  t252_n147: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t252_n149;
  t252_n148: return -0.0326240248978138f;
  t252_n149: return -0.01839413121342659f;
  t252_n150: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t252_n152;
  t252_n151: return -0.00823840219527483f;
  t252_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t252_n154;
  t252_n153: return -0.10285238176584244f;
  t252_n154: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t252_n156;
  t252_n155: return -0.023180076852440834f;
  t252_n156: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n160;
  t252_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n159;
  t252_n158: return 0.05000671371817589f;
  t252_n159: return -0.005953923333436251f;
  t252_n160: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n162;
  t252_n161: return -0.004941958002746105f;
  t252_n162: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t252_n164;
  t252_n163: return -0.018215050920844078f;
  t252_n164: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t252_n166;
  t252_n165: return 0.04457826539874077f;
  t252_n166: return 0.002713683992624283f;
  t252_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n173;
  t252_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t252_n170;
  t252_n169: return 0.0012707317946478724f;
  t252_n170: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n172;
  t252_n171: return 0.09007865935564041f;
  t252_n172: return -0.01300374697893858f;
  t252_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t252_n199;
  t252_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t252_n194;
  t252_n175: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t252_n183;
  t252_n176: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t252_n178;
  t252_n177: return 0.024470604956150055f;
  t252_n178: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t252_n180;
  t252_n179: return -0.06578332930803299f;
  t252_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t252_n182;
  t252_n181: return 0.008668291382491589f;
  t252_n182: return 0.11700703948736191f;
  t252_n183: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t252_n193;
  t252_n184: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t252_n188;
  t252_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n187;
  t252_n186: return 0.08081656694412231f;
  t252_n187: return 0.0034589567221701145f;
  t252_n188: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n192;
  t252_n189: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n191;
  t252_n190: return 0.08990965038537979f;
  t252_n191: return 0.0903884544968605f;
  t252_n192: return -0.01636631414294243f;
  t252_n193: return 0.026460453867912292f;
  t252_n194: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n198;
  t252_n195: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t252_n197;
  t252_n196: return 0.027539875358343124f;
  t252_n197: return 0.10113009065389633f;
  t252_n198: return 0.06012967973947525f;
  t252_n199: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n205;
  t252_n200: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n204;
  t252_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t252_n203;
  t252_n202: return 0.18870697915554047f;
  t252_n203: return 0.11856451630592346f;
  t252_n204: return 0.17707036435604095f;
  t252_n205: return -0.2312706708908081f;
  t252_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t252_n248;
  t252_n207: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t252_n219;
  t252_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t252_n218;
  t252_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n211;
  t252_n210: return -0.08450503647327423f;
  t252_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t252_n217;
  t252_n212: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t252_n216;
  t252_n213: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t252_n215;
  t252_n214: return -0.26664984226226807f;
  t252_n215: return -0.05236033350229263f;
  t252_n216: return -0.1101333349943161f;
  t252_n217: return -0.06813525408506393f;
  t252_n218: return -0.051707543432712555f;
  t252_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t252_n221;
  t252_n220: return -0.021928058937191963f;
  t252_n221: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n245;
  t252_n222: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t252_n224;
  t252_n223: return -0.00569854024797678f;
  t252_n224: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n236;
  t252_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t252_n231;
  t252_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t252_n230;
  t252_n227: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n229;
  t252_n228: return 0.027001507580280304f;
  t252_n229: return -0.012197542935609818f;
  t252_n230: return 0.07042620331048965f;
  t252_n231: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n235;
  t252_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t252_n234;
  t252_n233: return 0.008464718237519264f;
  t252_n234: return 0.09354447573423386f;
  t252_n235: return 0.05475258454680443f;
  t252_n236: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n238;
  t252_n237: return 0.002088500652462244f;
  t252_n238: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t252_n242;
  t252_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t252_n241;
  t252_n240: return -0.13714982569217682f;
  t252_n241: return 0.034774258732795715f;
  t252_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t252_n244;
  t252_n243: return -0.1078651025891304f;
  t252_n244: return 0.06119586154818535f;
  t252_n245: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t252_n247;
  t252_n246: return 0.01678338088095188f;
  t252_n247: return 0.023935288190841675f;
  t252_n248: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n252;
  t252_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n251;
  t252_n250: return -0.10700736194849014f;
  t252_n251: return 0.061761416494846344f;
  t252_n252: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t252_n254;
  t252_n253: return 0.09740471839904785f;
  t252_n254: return 0.048605289310216904f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree253(const Example& E) {
  t253_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t253_n246;
  t253_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t253_n3;
  t253_n2: return -0.00022941002680454403f;
  t253_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t253_n67;
  t253_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t253_n26;
  t253_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t253_n17;
  t253_n6: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t253_n10;
  t253_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function))) goto t253_n9;
  t253_n8: return -0.0345194935798645f;
  t253_n9: return 0.06490453332662582f;
  t253_n10: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t253_n12;
  t253_n11: return -0.5144620537757874f;
  t253_n12: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t253_n16;
  t253_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t253_n15;
  t253_n14: return 0.021105028688907623f;
  t253_n15: return 0.09700210392475128f;
  t253_n16: return -0.003434708109125495f;
  t253_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n21;
  t253_n18: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n20;
  t253_n19: return -0.6474971771240234f;
  t253_n20: return 0.03680209815502167f;
  t253_n21: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t253_n25;
  t253_n22: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n24;
  t253_n23: return 0.10127002000808716f;
  t253_n24: return 0.05029893293976784f;
  t253_n25: return -0.3924272358417511f;
  t253_n26: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t253_n66;
  t253_n27: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t253_n47;
  t253_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t253_n36;
  t253_n29: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t253_n33;
  t253_n30: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t253_n32;
  t253_n31: return -0.026652932167053223f;
  t253_n32: return -1.0805878639221191f;
  t253_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n35;
  t253_n34: return 0.053597111254930496f;
  t253_n35: return 0.04461684450507164f;
  t253_n36: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t253_n46;
  t253_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n41;
  t253_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t253_n40;
  t253_n39: return 0.1275259256362915f;
  t253_n40: return 0.10083575546741486f;
  t253_n41: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t253_n43;
  t253_n42: return 0.0005967382458038628f;
  t253_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n45;
  t253_n44: return -0.04606667906045914f;
  t253_n45: return 0.1340135782957077f;
  t253_n46: return 0.02141869254410267f;
  t253_n47: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t253_n49;
  t253_n48: return -0.006146968342363834f;
  t253_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t253_n51;
  t253_n50: return -0.015014315024018288f;
  t253_n51: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t253_n63;
  t253_n52: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t253_n54;
  t253_n53: return -0.0011864195112138987f;
  t253_n54: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t253_n60;
  t253_n55: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n57;
  t253_n56: return -0.19390304386615753f;
  t253_n57: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t253_n59;
  t253_n58: return 0.10781136155128479f;
  t253_n59: return -0.007131829857826233f;
  t253_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n62;
  t253_n61: return 0.09316180646419525f;
  t253_n62: return 0.08056730031967163f;
  t253_n63: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n65;
  t253_n64: return -0.11734914034605026f;
  t253_n65: return 0.031635582447052f;
  t253_n66: return -0.009361336007714272f;
  t253_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t253_n127;
  t253_n68: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t253_n100;
  t253_n69: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t253_n93;
  t253_n70: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t253_n78;
  t253_n71: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n75;
  t253_n72: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t253_n74;
  t253_n73: return -0.04177619144320488f;
  t253_n74: return -0.036185938864946365f;
  t253_n75: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t253_n77;
  t253_n76: return -0.031762801110744476f;
  t253_n77: return -0.014706515707075596f;
  t253_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t253_n80;
  t253_n79: return -0.006524031516164541f;
  t253_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t253_n82;
  t253_n81: return -0.10508742928504944f;
  t253_n82: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t253_n84;
  t253_n83: return -0.019789207726716995f;
  t253_n84: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n86;
  t253_n85: return 0.027388274669647217f;
  t253_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n88;
  t253_n87: return -0.015231345780193806f;
  t253_n88: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n92;
  t253_n89: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t253_n91;
  t253_n90: return 0.01575714536011219f;
  t253_n91: return -0.03472084552049637f;
  t253_n92: return 0.029941817745566368f;
  t253_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t253_n95;
  t253_n94: return -0.018803734332323074f;
  t253_n95: if (E.getNumReferences() >= 3361088608 /*219281.5*/) goto t253_n97;
  t253_n96: return 0.0028699992690235376f;
  t253_n97: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t253_n99;
  t253_n98: return 0.006888491101562977f;
  t253_n99: return 0.10821014642715454f;
  t253_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t253_n114;
  t253_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n107;
  t253_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t253_n106;
  t253_n103: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n105;
  t253_n104: return -0.03964724764227867f;
  t253_n105: return -0.06176937744021416f;
  t253_n106: return -0.1012917011976242f;
  t253_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t253_n111;
  t253_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t253_n110;
  t253_n109: return 0.01697051152586937f;
  t253_n110: return 0.06298814713954926f;
  t253_n111: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t253_n113;
  t253_n112: return 0.0596969798207283f;
  t253_n113: return -0.031014055013656616f;
  t253_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t253_n116;
  t253_n115: return 0.0002526360040064901f;
  t253_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n126;
  t253_n117: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t253_n119;
  t253_n118: return -0.1547868847846985f;
  t253_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n121;
  t253_n120: return 0.07519499957561493f;
  t253_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n123;
  t253_n122: return -0.18745195865631104f;
  t253_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n125;
  t253_n124: return 0.035286154597997665f;
  t253_n125: return 0.010588880628347397f;
  t253_n126: return 0.0030008077155798674f;
  t253_n127: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t253_n245;
  t253_n128: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t253_n182;
  t253_n129: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t253_n137;
  t253_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n132;
  t253_n131: return -0.030145123600959778f;
  t253_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t253_n134;
  t253_n133: return 0.01584797538816929f;
  t253_n134: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t253_n136;
  t253_n135: return -0.21088498830795288f;
  t253_n136: return -0.04823673143982887f;
  t253_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t253_n169;
  t253_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n142;
  t253_n139: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t253_n141;
  t253_n140: return 0.019953157752752304f;
  t253_n141: return 0.10585463792085648f;
  t253_n142: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t253_n158;
  t253_n143: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t253_n155;
  t253_n144: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n146;
  t253_n145: return 0.02248941920697689f;
  t253_n146: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t253_n152;
  t253_n147: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t253_n149;
  t253_n148: return 0.025972405448555946f;
  t253_n149: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t253_n151;
  t253_n150: return 0.2083941400051117f;
  t253_n151: return -0.11550460755825043f;
  t253_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n154;
  t253_n153: return -0.24293704330921173f;
  t253_n154: return 0.04245605692267418f;
  t253_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t253_n157;
  t253_n156: return -0.132082000374794f;
  t253_n157: return 0.018476072698831558f;
  t253_n158: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t253_n168;
  t253_n159: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t253_n167;
  t253_n160: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n164;
  t253_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n163;
  t253_n162: return -0.10490292310714722f;
  t253_n163: return 0.07602562755346298f;
  t253_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n166;
  t253_n165: return -0.015774767845869064f;
  t253_n166: return 0.11112193763256073f;
  t253_n167: return -0.0015620560152456164f;
  t253_n168: return 0.06109952926635742f;
  t253_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n179;
  t253_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n172;
  t253_n171: return 0.04266345873475075f;
  t253_n172: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n174;
  t253_n173: return 0.06105751916766167f;
  t253_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n176;
  t253_n175: return -0.0004760785959661007f;
  t253_n176: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t253_n178;
  t253_n177: return 0.09395778179168701f;
  t253_n178: return -0.13091479241847992f;
  t253_n179: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n181;
  t253_n180: return 0.06179629638791084f;
  t253_n181: return -0.008888883516192436f;
  t253_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t253_n216;
  t253_n183: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n185;
  t253_n184: return 0.017468545585870743f;
  t253_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t253_n209;
  t253_n186: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n202;
  t253_n187: if (E.getNumReferences() >= 3266576384 /*90.0*/) goto t253_n201;
  t253_n188: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t253_n198;
  t253_n189: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t253_n193;
  t253_n190: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t253_n192;
  t253_n191: return 0.09522270411252975f;
  t253_n192: return -0.005489036440849304f;
  t253_n193: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t253_n195;
  t253_n194: return 0.08144323527812958f;
  t253_n195: if (E.getNumReferences() >= 3261333504 /*57.0*/) goto t253_n197;
  t253_n196: return 0.1181570291519165f;
  t253_n197: return 0.061721328645944595f;
  t253_n198: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t253_n200;
  t253_n199: return 0.11962874233722687f;
  t253_n200: return 0.09808763116598129f;
  t253_n201: return -0.21556618809700012f;
  t253_n202: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t253_n208;
  t253_n203: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t253_n207;
  t253_n204: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t253_n206;
  t253_n205: return 0.12123316526412964f;
  t253_n206: return 0.17153333127498627f;
  t253_n207: return -0.24991680681705475f;
  t253_n208: return 0.054148733615875244f;
  t253_n209: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t253_n215;
  t253_n210: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t253_n212;
  t253_n211: return 0.03952523693442345f;
  t253_n212: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t253_n214;
  t253_n213: return -0.10977281630039215f;
  t253_n214: return 0.12232045829296112f;
  t253_n215: return 0.08110447973012924f;
  t253_n216: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t253_n242;
  t253_n217: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t253_n241;
  t253_n218: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t253_n232;
  t253_n219: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t253_n221;
  t253_n220: return 0.02167471870779991f;
  t253_n221: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t253_n225;
  t253_n222: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t253_n224;
  t253_n223: return 0.11773620545864105f;
  t253_n224: return 0.10617902129888535f;
  t253_n225: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t253_n231;
  t253_n226: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t253_n230;
  t253_n227: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t253_n229;
  t253_n228: return 0.052987802773714066f;
  t253_n229: return 0.13507574796676636f;
  t253_n230: return 0.010002391412854195f;
  t253_n231: return -0.1964438557624817f;
  t253_n232: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t253_n238;
  t253_n233: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n235;
  t253_n234: return 0.11810562759637833f;
  t253_n235: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t253_n237;
  t253_n236: return 0.02854950726032257f;
  t253_n237: return 0.09650301933288574f;
  t253_n238: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t253_n240;
  t253_n239: return -0.21239346265792847f;
  t253_n240: return 0.0820024237036705f;
  t253_n241: return 0.01731724664568901f;
  t253_n242: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n244;
  t253_n243: return 0.11725085228681564f;
  t253_n244: return -0.11187401413917542f;
  t253_n245: return -0.01225768867880106f;
  t253_n246: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t253_n248;
  t253_n247: return -0.012028241530060768f;
  t253_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t253_n250;
  t253_n249: return -0.030720701441168785f;
  t253_n250: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t253_n252;
  t253_n251: return 0.0378655344247818f;
  t253_n252: if (E.getNumReferences() >= 3280633856 /*277.0*/) goto t253_n254;
  t253_n253: return -0.035682130604982376f;
  t253_n254: return 0.13695786893367767f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree254(const Example& E) {
  t254_n0: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t254_n234;
  t254_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t254_n3;
  t254_n2: return -0.06330560892820358f;
  t254_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t254_n5;
  t254_n4: return -0.0005404078401625156f;
  t254_n5: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t254_n43;
  t254_n6: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t254_n22;
  t254_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t254_n9;
  t254_n8: return -0.0185096375644207f;
  t254_n9: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t254_n17;
  t254_n10: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t254_n16;
  t254_n11: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n13;
  t254_n12: return 0.04795445129275322f;
  t254_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t254_n15;
  t254_n14: return -0.14756964147090912f;
  t254_n15: return 0.040828753262758255f;
  t254_n16: return -0.006196929607540369f;
  t254_n17: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t254_n21;
  t254_n18: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t254_n20;
  t254_n19: return 0.06262266635894775f;
  t254_n20: return 0.12123763561248779f;
  t254_n21: return -0.06623344123363495f;
  t254_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t254_n24;
  t254_n23: return 0.000816730665974319f;
  t254_n24: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t254_n26;
  t254_n25: return 0.0014817174524068832f;
  t254_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t254_n38;
  t254_n27: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n29;
  t254_n28: return 0.03513381630182266f;
  t254_n29: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t254_n35;
  t254_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t254_n34;
  t254_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t254_n33;
  t254_n32: return -0.0011900727404281497f;
  t254_n33: return 0.07451562583446503f;
  t254_n34: return 0.06724726408720016f;
  t254_n35: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t254_n37;
  t254_n36: return 0.10466492176055908f;
  t254_n37: return -0.03547479584813118f;
  t254_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t254_n40;
  t254_n39: return 0.010542323812842369f;
  t254_n40: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n42;
  t254_n41: return 0.008978168480098248f;
  t254_n42: return -0.029770171269774437f;
  t254_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t254_n45;
  t254_n44: return 0.0037405905313789845f;
  t254_n45: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t254_n145;
  t254_n46: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t254_n92;
  t254_n47: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n83;
  t254_n48: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t254_n54;
  t254_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t254_n53;
  t254_n50: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t254_n52;
  t254_n51: return 0.08932241052389145f;
  t254_n52: return 0.08576695621013641f;
  t254_n53: return 0.12128893285989761f;
  t254_n54: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t254_n74;
  t254_n55: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t254_n69;
  t254_n56: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t254_n68;
  t254_n57: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t254_n65;
  t254_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t254_n62;
  t254_n59: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t254_n61;
  t254_n60: return -0.6827035546302795f;
  t254_n61: return 0.09406092017889023f;
  t254_n62: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t254_n64;
  t254_n63: return -0.013304569758474827f;
  t254_n64: return 0.1053013950586319f;
  t254_n65: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t254_n67;
  t254_n66: return 0.1003301590681076f;
  t254_n67: return -0.31519246101379395f;
  t254_n68: return 0.10060533136129379f;
  t254_n69: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t254_n71;
  t254_n70: return -0.46977493166923523f;
  t254_n71: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t254_n73;
  t254_n72: return 0.081718310713768f;
  t254_n73: return -0.5302497148513794f;
  t254_n74: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t254_n80;
  t254_n75: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t254_n77;
  t254_n76: return -0.2751978933811188f;
  t254_n77: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t254_n79;
  t254_n78: return 0.10728456825017929f;
  t254_n79: return 0.10608716309070587f;
  t254_n80: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t254_n82;
  t254_n81: return 0.09392169117927551f;
  t254_n82: return -0.05897641181945801f;
  t254_n83: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t254_n89;
  t254_n84: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t254_n88;
  t254_n85: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t254_n87;
  t254_n86: return -0.042023930698633194f;
  t254_n87: return 0.05869950354099274f;
  t254_n88: return -0.44802945852279663f;
  t254_n89: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t254_n91;
  t254_n90: return 0.09119075536727905f;
  t254_n91: return -2.864040834538173e-05f;
  t254_n92: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t254_n132;
  t254_n93: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t254_n131;
  t254_n94: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t254_n130;
  t254_n95: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t254_n127;
  t254_n96: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t254_n102;
  t254_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t254_n101;
  t254_n98: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t254_n100;
  t254_n99: return -0.04579384997487068f;
  t254_n100: return -0.7947765588760376f;
  t254_n101: return 0.0035281393211334944f;
  t254_n102: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n114;
  t254_n103: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t254_n109;
  t254_n104: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t254_n106;
  t254_n105: return 0.1104634553194046f;
  t254_n106: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t254_n108;
  t254_n107: return -0.13418301939964294f;
  t254_n108: return 0.0760679543018341f;
  t254_n109: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t254_n111;
  t254_n110: return 0.058879364281892776f;
  t254_n111: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t254_n113;
  t254_n112: return -0.1232684999704361f;
  t254_n113: return 0.11072304099798203f;
  t254_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t254_n124;
  t254_n115: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t254_n119;
  t254_n116: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t254_n118;
  t254_n117: return 0.027520939707756042f;
  t254_n118: return -0.3508301377296448f;
  t254_n119: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t254_n121;
  t254_n120: return -0.06461624801158905f;
  t254_n121: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t254_n123;
  t254_n122: return -0.032635465264320374f;
  t254_n123: return 0.10073527693748474f;
  t254_n124: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t254_n126;
  t254_n125: return 0.12117592245340347f;
  t254_n126: return -0.8107118010520935f;
  t254_n127: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t254_n129;
  t254_n128: return 0.1267196536064148f;
  t254_n129: return -0.8808537721633911f;
  t254_n130: return 0.1052454486489296f;
  t254_n131: return -0.13202494382858276f;
  t254_n132: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t254_n134;
  t254_n133: return 0.1094621866941452f;
  t254_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t254_n136;
  t254_n135: return -0.0913144201040268f;
  t254_n136: if (E.getNumReferences() >= 3264348160 /*73.0*/) goto t254_n144;
  t254_n137: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t254_n139;
  t254_n138: return 0.02584495209157467f;
  t254_n139: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t254_n141;
  t254_n140: return -0.385940283536911f;
  t254_n141: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t254_n143;
  t254_n142: return 0.11237253993749619f;
  t254_n143: return 0.10760516673326492f;
  t254_n144: return 0.009179751388728619f;
  t254_n145: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t254_n151;
  t254_n146: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t254_n150;
  t254_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t254_n149;
  t254_n148: return 0.09640238434076309f;
  t254_n149: return -0.08133924007415771f;
  t254_n150: return 0.10711188614368439f;
  t254_n151: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t254_n175;
  t254_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t254_n162;
  t254_n153: if (E.getNumReferences() >= 3301138432 /*1563.0*/) goto t254_n157;
  t254_n154: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t254_n156;
  t254_n155: return 0.0320681668817997f;
  t254_n156: return -0.17654705047607422f;
  t254_n157: if (E.getNumReferences() >= 3303743488 /*1881.0*/) goto t254_n159;
  t254_n158: return 0.10394328832626343f;
  t254_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n161;
  t254_n160: return -0.19030368328094482f;
  t254_n161: return 0.0852402076125145f;
  t254_n162: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t254_n168;
  t254_n163: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t254_n165;
  t254_n164: return 0.08616834133863449f;
  t254_n165: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t254_n167;
  t254_n166: return -0.6656498312950134f;
  t254_n167: return 0.09660597890615463f;
  t254_n168: if (E.getNumReferences() >= 3289096192 /*558.5*/) goto t254_n170;
  t254_n169: return -0.015178145840764046f;
  t254_n170: if (E.getNumReferences() >= 3294158848 /*867.5*/) goto t254_n174;
  t254_n171: if (E.getNumReferences() >= 3292667904 /*776.5*/) goto t254_n173;
  t254_n172: return 0.028067993000149727f;
  t254_n173: return 0.11478810757398605f;
  t254_n174: return 0.008163847960531712f;
  t254_n175: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t254_n197;
  t254_n176: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t254_n194;
  t254_n177: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t254_n189;
  t254_n178: if (E.getNumReferences() >= 3281272832 /*296.5*/) goto t254_n188;
  t254_n179: if (E.getNumReferences() >= 3276472320 /*203.0*/) goto t254_n187;
  t254_n180: if (E.getNumReferences() >= 3271229440 /*125.5*/) goto t254_n184;
  t254_n181: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t254_n183;
  t254_n182: return -0.030436426401138306f;
  t254_n183: return -0.727903425693512f;
  t254_n184: if (E.getNumReferences() >= 3274309632 /*170.0*/) goto t254_n186;
  t254_n185: return 0.12001729756593704f;
  t254_n186: return -0.056537169963121414f;
  t254_n187: return -0.6707778573036194f;
  t254_n188: return 0.06187942251563072f;
  t254_n189: if (E.getNumReferences() >= 3310616576 /*3392.0*/) goto t254_n193;
  t254_n190: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t254_n192;
  t254_n191: return 0.1001463532447815f;
  t254_n192: return 0.06550636142492294f;
  t254_n193: return 0.05463699996471405f;
  t254_n194: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t254_n196;
  t254_n195: return -0.13108596205711365f;
  t254_n196: return 0.08493878692388535f;
  t254_n197: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t254_n211;
  t254_n198: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t254_n208;
  t254_n199: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t254_n201;
  t254_n200: return 0.021126385778188705f;
  t254_n201: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t254_n203;
  t254_n202: return 0.11034499108791351f;
  t254_n203: if (E.getNumReferences() >= 3255828480 /*36.0*/) goto t254_n207;
  t254_n204: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t254_n206;
  t254_n205: return 0.10415960103273392f;
  t254_n206: return -0.006285248789936304f;
  t254_n207: return 0.22015999257564545f;
  t254_n208: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t254_n210;
  t254_n209: return -0.06988973915576935f;
  t254_n210: return 0.08799639344215393f;
  t254_n211: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t254_n213;
  t254_n212: return -0.026994751766324043f;
  t254_n213: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t254_n233;
  t254_n214: if (E.getNumReferences() >= 3321412608 /*7959.5*/) goto t254_n228;
  t254_n215: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n217;
  t254_n216: return 0.04001140967011452f;
  t254_n217: if (E.getNumReferences() >= 3307327488 /*2589.0*/) goto t254_n225;
  t254_n218: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t254_n220;
  t254_n219: return -0.25596871972084045f;
  t254_n220: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t254_n222;
  t254_n221: return 0.08262507617473602f;
  t254_n222: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t254_n224;
  t254_n223: return -0.49374544620513916f;
  t254_n224: return 0.01753547601401806f;
  t254_n225: if (E.getNumReferences() >= 3310909440 /*3463.5*/) goto t254_n227;
  t254_n226: return 0.1035982146859169f;
  t254_n227: return -0.0071105039678514f;
  t254_n228: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t254_n232;
  t254_n229: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t254_n231;
  t254_n230: return 0.07340869307518005f;
  t254_n231: return 0.10286301374435425f;
  t254_n232: return 0.07503686845302582f;
  t254_n233: return 0.0037375465035438538f;
  t254_n234: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t254_n246;
  t254_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t254_n239;
  t254_n236: if (E.getNumReferences() >= 3238002688 /*8.0*/) goto t254_n238;
  t254_n237: return -0.09168242663145065f;
  t254_n238: return 0.09224024415016174f;
  t254_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t254_n245;
  t254_n240: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t254_n242;
  t254_n241: return -0.13441121578216553f;
  t254_n242: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t254_n244;
  t254_n243: return -0.2125571370124817f;
  t254_n244: return -0.1339312642812729f;
  t254_n245: return -0.07662549614906311f;
  t254_n246: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t254_n252;
  t254_n247: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t254_n251;
  t254_n248: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t254_n250;
  t254_n249: return 0.002657294739037752f;
  t254_n250: return 0.0652896910905838f;
  t254_n251: return -0.17741985619068146f;
  t254_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t254_n254;
  t254_n253: return 0.08548223972320557f;
  t254_n254: return -0.06010254845023155f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree255(const Example& E) {
  t255_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t255_n26;
  t255_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t255_n3;
  t255_n2: return -0.0018491409718990326f;
  t255_n3: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t255_n5;
  t255_n4: return 0.003343840828165412f;
  t255_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t255_n7;
  t255_n6: return 0.007678324356675148f;
  t255_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t255_n9;
  t255_n8: return -0.0233792532235384f;
  t255_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t255_n23;
  t255_n10: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t255_n16;
  t255_n11: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t255_n13;
  t255_n12: return -0.059510041028261185f;
  t255_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t255_n15;
  t255_n14: return -0.12867006659507751f;
  t255_n15: return 0.0657811239361763f;
  t255_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t255_n22;
  t255_n17: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t255_n21;
  t255_n18: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t255_n20;
  t255_n19: return -0.10610458999872208f;
  t255_n20: return 0.0951056107878685f;
  t255_n21: return -0.13303391635417938f;
  t255_n22: return -0.005554351024329662f;
  t255_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t255_n25;
  t255_n24: return 0.0276038721203804f;
  t255_n25: return -0.03279587998986244f;
  t255_n26: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t255_n172;
  t255_n27: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t255_n155;
  t255_n28: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t255_n116;
  t255_n29: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t255_n77;
  t255_n30: if (E.getNumReferences() >= 3294724096 /*902.0*/) goto t255_n76;
  t255_n31: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t255_n69;
  t255_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t255_n36;
  t255_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t255_n35;
  t255_n34: return -0.13090580701828003f;
  t255_n35: return 0.021853163838386536f;
  t255_n36: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t255_n68;
  t255_n37: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t255_n59;
  t255_n38: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t255_n58;
  t255_n39: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t255_n53;
  t255_n40: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t255_n52;
  t255_n41: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t255_n51;
  t255_n42: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t255_n48;
  t255_n43: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t255_n47;
  t255_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t255_n46;
  t255_n45: return 0.055859945714473724f;
  t255_n46: return 0.10922630876302719f;
  t255_n47: return -0.09530458599328995f;
  t255_n48: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t255_n50;
  t255_n49: return -0.0553278774023056f;
  t255_n50: return 0.031484268605709076f;
  t255_n51: return 0.10915285348892212f;
  t255_n52: return -0.7335802912712097f;
  t255_n53: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t255_n57;
  t255_n54: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t255_n56;
  t255_n55: return -0.01080633420497179f;
  t255_n56: return 0.10913901031017303f;
  t255_n57: return 0.02816588617861271f;
  t255_n58: return -0.3982486128807068f;
  t255_n59: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t255_n65;
  t255_n60: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t255_n62;
  t255_n61: return 0.12897127866744995f;
  t255_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t255_n64;
  t255_n63: return -0.06871877610683441f;
  t255_n64: return 0.08213836699724197f;
  t255_n65: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t255_n67;
  t255_n66: return -0.15905240178108215f;
  t255_n67: return 0.10593260824680328f;
  t255_n68: return -0.12274354696273804f;
  t255_n69: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t255_n71;
  t255_n70: return 0.11468454450368881f;
  t255_n71: if (E.getNumReferences() >= 3268280320 /*103.0*/) goto t255_n75;
  t255_n72: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t255_n74;
  t255_n73: return -0.056421633809804916f;
  t255_n74: return 0.10110213607549667f;
  t255_n75: return -0.21819841861724854f;
  t255_n76: return 0.08891133219003677f;
  t255_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t255_n79;
  t255_n78: return -0.004468098282814026f;
  t255_n79: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t255_n87;
  t255_n80: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t255_n86;
  t255_n81: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t255_n83;
  t255_n82: return -0.02310977689921856f;
  t255_n83: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t255_n85;
  t255_n84: return -0.17614521086215973f;
  t255_n85: return -0.03665890172123909f;
  t255_n86: return 0.09143585711717606f;
  t255_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t255_n89;
  t255_n88: return -0.0025120878126472235f;
  t255_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t255_n91;
  t255_n90: return -0.0004833569109905511f;
  t255_n91: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t255_n115;
  t255_n92: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t255_n114;
  t255_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t255_n103;
  t255_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t255_n96;
  t255_n95: return 0.0473414808511734f;
  t255_n96: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t255_n102;
  t255_n97: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t255_n99;
  t255_n98: return 0.05302591994404793f;
  t255_n99: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t255_n101;
  t255_n100: return 0.13500060141086578f;
  t255_n101: return 0.06089634820818901f;
  t255_n102: return -0.11379364132881165f;
  t255_n103: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t255_n107;
  t255_n104: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t255_n106;
  t255_n105: return 0.019321003928780556f;
  t255_n106: return -0.0846891850233078f;
  t255_n107: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t255_n113;
  t255_n108: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t255_n112;
  t255_n109: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t255_n111;
  t255_n110: return 0.045501500368118286f;
  t255_n111: return 0.019356975331902504f;
  t255_n112: return -0.014749920926988125f;
  t255_n113: return 0.07387275248765945f;
  t255_n114: return -0.13316014409065247f;
  t255_n115: return -0.09176503866910934f;
  t255_n116: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t255_n118;
  t255_n117: return -0.07729616016149521f;
  t255_n118: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t255_n154;
  t255_n119: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t255_n129;
  t255_n120: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t255_n128;
  t255_n121: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t255_n127;
  t255_n122: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t255_n126;
  t255_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t255_n125;
  t255_n124: return -0.10860514640808105f;
  t255_n125: return 0.12159336358308792f;
  t255_n126: return -0.14240950345993042f;
  t255_n127: return 0.029669957235455513f;
  t255_n128: return -0.0969068855047226f;
  t255_n129: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t255_n131;
  t255_n130: return -0.13729070127010345f;
  t255_n131: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t255_n147;
  t255_n132: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t255_n144;
  t255_n133: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t255_n135;
  t255_n134: return -0.11269166320562363f;
  t255_n135: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t255_n143;
  t255_n136: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t255_n140;
  t255_n137: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t255_n139;
  t255_n138: return 0.08462687581777573f;
  t255_n139: return -0.4226550757884979f;
  t255_n140: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t255_n142;
  t255_n141: return 0.0f;
  t255_n142: return 0.085477314889431f;
  t255_n143: return -0.11699500679969788f;
  t255_n144: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t255_n146;
  t255_n145: return 0.11213864386081696f;
  t255_n146: return 0.10030461847782135f;
  t255_n147: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t255_n149;
  t255_n148: return -0.07115644961595535f;
  t255_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t255_n151;
  t255_n150: return -0.7843937277793884f;
  t255_n151: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t255_n153;
  t255_n152: return 0.11670615524053574f;
  t255_n153: return 0.09361445158720016f;
  t255_n154: return -0.06041456758975983f;
  t255_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t255_n165;
  t255_n156: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t255_n162;
  t255_n157: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t255_n161;
  t255_n158: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t255_n160;
  t255_n159: return -0.010968637652695179f;
  t255_n160: return 0.007505600806325674f;
  t255_n161: return -0.0013412612024694681f;
  t255_n162: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t255_n164;
  t255_n163: return 0.00572931906208396f;
  t255_n164: return 0.014997153542935848f;
  t255_n165: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t255_n171;
  t255_n166: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t255_n168;
  t255_n167: return 0.047753576189279556f;
  t255_n168: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t255_n170;
  t255_n169: return 0.06684277951717377f;
  t255_n170: return 0.12198799103498459f;
  t255_n171: return 0.011835573241114616f;
  t255_n172: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t255_n174;
  t255_n173: return 0.007871419191360474f;
  t255_n174: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t255_n234;
  t255_n175: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t255_n233;
  t255_n176: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t255_n210;
  t255_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t255_n207;
  t255_n178: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t255_n192;
  t255_n179: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t255_n181;
  t255_n180: return -0.025769967585802078f;
  t255_n181: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t255_n185;
  t255_n182: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t255_n184;
  t255_n183: return 0.13628047704696655f;
  t255_n184: return -0.04109989106655121f;
  t255_n185: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t255_n187;
  t255_n186: return -0.026009034365415573f;
  t255_n187: if (E.getNumReferences() >= 3275915264 /*194.5*/) goto t255_n191;
  t255_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t255_n190;
  t255_n189: return 0.070391446352005f;
  t255_n190: return 0.10739361494779587f;
  t255_n191: return 0.03232298791408539f;
  t255_n192: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t255_n198;
  t255_n193: if (E.getNumReferences() >= 3287138304 /*475.5*/) goto t255_n197;
  t255_n194: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t255_n196;
  t255_n195: return 0.006414922885596752f;
  t255_n196: return -0.07199607044458389f;
  t255_n197: return 0.08161401003599167f;
  t255_n198: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t255_n200;
  t255_n199: return -0.010600385256111622f;
  t255_n200: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t255_n206;
  t255_n201: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t255_n205;
  t255_n202: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t255_n204;
  t255_n203: return 0.07473945617675781f;
  t255_n204: return 0.13975076377391815f;
  t255_n205: return 0.048765674233436584f;
  t255_n206: return 0.004976572003215551f;
  t255_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor))) goto t255_n209;
  t255_n208: return -0.010709322057664394f;
  t255_n209: return 0.012053263373672962f;
  t255_n210: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t255_n212;
  t255_n211: return -2.6575333322398365e-05f;
  t255_n212: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t255_n214;
  t255_n213: return -0.008302743546664715f;
  t255_n214: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t255_n232;
  t255_n215: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t255_n221;
  t255_n216: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t255_n220;
  t255_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t255_n219;
  t255_n218: return 0.047695357352495193f;
  t255_n219: return 0.09294446557760239f;
  t255_n220: return 0.05698477104306221f;
  t255_n221: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t255_n231;
  t255_n222: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t255_n224;
  t255_n223: return -0.02441822551190853f;
  t255_n224: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t255_n226;
  t255_n225: return 0.07923030108213425f;
  t255_n226: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t255_n230;
  t255_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t255_n229;
  t255_n228: return -0.12645216286182404f;
  t255_n229: return 0.12092971801757812f;
  t255_n230: return 0.07245223969221115f;
  t255_n231: return -0.09649620205163956f;
  t255_n232: return 0.014157391153275967f;
  t255_n233: return 0.0010279575362801552f;
  t255_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t255_n236;
  t255_n235: return 0.01459662988781929f;
  t255_n236: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t255_n246;
  t255_n237: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t255_n243;
  t255_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t255_n242;
  t255_n239: if (E.getNumReferences() >= 3365247648 /*306389.0*/) goto t255_n241;
  t255_n240: return 0.07803408801555634f;
  t255_n241: return -0.20620740950107574f;
  t255_n242: return 0.10499832779169083f;
  t255_n243: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t255_n245;
  t255_n244: return -0.01569921337068081f;
  t255_n245: return 0.07732664793729782f;
  t255_n246: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t255_n248;
  t255_n247: return -0.0056165531277656555f;
  t255_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t255_n254;
  t255_n249: if (E.getNumReferences() >= 3368194704 /*398484.5*/) goto t255_n251;
  t255_n250: return -0.031952500343322754f;
  t255_n251: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t255_n253;
  t255_n252: return 0.0944083109498024f;
  t255_n253: return 0.09153558313846588f;
  t255_n254: return -0.055179279297590256f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree256(const Example& E) {
  t256_n0: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t256_n254;
  t256_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t256_n145;
  t256_n2: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t256_n72;
  t256_n3: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t256_n71;
  t256_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t256_n28;
  t256_n5: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t256_n25;
  t256_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t256_n8;
  t256_n7: return 0.004443442914634943f;
  t256_n8: if (E.getNumReferences() >= 3277979648 /*226.0*/) goto t256_n12;
  t256_n9: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t256_n11;
  t256_n10: return -0.018310632556676865f;
  t256_n11: return 0.011634891852736473f;
  t256_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t256_n18;
  t256_n13: if (E.getNumReferences() >= 3278569472 /*235.0*/) goto t256_n15;
  t256_n14: return 0.09666075557470322f;
  t256_n15: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t256_n17;
  t256_n16: return -0.1747322976589203f;
  t256_n17: return 0.06214071810245514f;
  t256_n18: if (E.getNumReferences() >= 3280453632 /*271.5*/) goto t256_n20;
  t256_n19: return 0.12097789347171783f;
  t256_n20: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t256_n22;
  t256_n21: return -0.22827713191509247f;
  t256_n22: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t256_n24;
  t256_n23: return 0.12872864305973053f;
  t256_n24: return 0.09805088490247726f;
  t256_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t256_n27;
  t256_n26: return -0.02881845273077488f;
  t256_n27: return -0.007622479926794767f;
  t256_n28: if (E.getNumReferences() >= 3264610304 /*75.0*/) goto t256_n68;
  t256_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t256_n31;
  t256_n30: return -0.042101044207811356f;
  t256_n31: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t256_n33;
  t256_n32: return 0.010361921973526478f;
  t256_n33: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t256_n57;
  t256_n34: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t256_n46;
  t256_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t256_n39;
  t256_n36: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t256_n38;
  t256_n37: return 0.049389470368623734f;
  t256_n38: return 0.0924396738409996f;
  t256_n39: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t256_n43;
  t256_n40: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t256_n42;
  t256_n41: return -0.48471927642822266f;
  t256_n42: return 0.22349633276462555f;
  t256_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n45;
  t256_n44: return 0.07312899082899094f;
  t256_n45: return 0.11462800204753876f;
  t256_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t256_n48;
  t256_n47: return -0.0888548493385315f;
  t256_n48: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n56;
  t256_n49: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t256_n55;
  t256_n50: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t256_n54;
  t256_n51: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t256_n53;
  t256_n52: return 0.1357232928276062f;
  t256_n53: return 0.097050242125988f;
  t256_n54: return 0.030134523287415504f;
  t256_n55: return 0.0654887929558754f;
  t256_n56: return 0.046565573662519455f;
  t256_n57: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t256_n61;
  t256_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t256_n60;
  t256_n59: return -1.4516109228134155f;
  t256_n60: return -0.4057711362838745f;
  t256_n61: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t256_n63;
  t256_n62: return -0.06579741835594177f;
  t256_n63: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t256_n67;
  t256_n64: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t256_n66;
  t256_n65: return 0.11048150062561035f;
  t256_n66: return 0.11095511168241501f;
  t256_n67: return 0.020845472812652588f;
  t256_n68: if (E.getNumReferences() >= 3265396736 /*81.0*/) goto t256_n70;
  t256_n69: return 0.11559563130140305f;
  t256_n70: return -0.002653174102306366f;
  t256_n71: return 0.00751916691660881f;
  t256_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t256_n122;
  t256_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t256_n75;
  t256_n74: return 0.007638154085725546f;
  t256_n75: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t256_n77;
  t256_n76: return 0.13674059510231018f;
  t256_n77: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t256_n105;
  t256_n78: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t256_n84;
  t256_n79: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t256_n83;
  t256_n80: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t256_n82;
  t256_n81: return -0.018903132528066635f;
  t256_n82: return 0.0765618234872818f;
  t256_n83: return 0.08092204481363297f;
  t256_n84: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t256_n100;
  t256_n85: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t256_n87;
  t256_n86: return 0.10371749848127365f;
  t256_n87: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t256_n99;
  t256_n88: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t256_n94;
  t256_n89: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t256_n93;
  t256_n90: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n92;
  t256_n91: return 0.11975718289613724f;
  t256_n92: return 0.13034173846244812f;
  t256_n93: return -0.14466078579425812f;
  t256_n94: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t256_n96;
  t256_n95: return -0.0006749294698238373f;
  t256_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t256_n98;
  t256_n97: return -0.5009667873382568f;
  t256_n98: return 0.11761674284934998f;
  t256_n99: return 0.06134583428502083f;
  t256_n100: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t256_n102;
  t256_n101: return -0.0037815000396221876f;
  t256_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t256_n104;
  t256_n103: return 0.06818380206823349f;
  t256_n104: return 0.10655096173286438f;
  t256_n105: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t256_n119;
  t256_n106: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t256_n118;
  t256_n107: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n115;
  t256_n108: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t256_n110;
  t256_n109: return 0.14291241765022278f;
  t256_n110: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t256_n112;
  t256_n111: return 0.12900736927986145f;
  t256_n112: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t256_n114;
  t256_n113: return 0.12175451219081879f;
  t256_n114: return -0.10515440255403519f;
  t256_n115: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t256_n117;
  t256_n116: return 0.17687374353408813f;
  t256_n117: return -0.29417234659194946f;
  t256_n118: return -0.01425214298069477f;
  t256_n119: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t256_n121;
  t256_n120: return 0.12656421959400177f;
  t256_n121: return -0.3121412992477417f;
  t256_n122: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t256_n124;
  t256_n123: return 0.16214226186275482f;
  t256_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t256_n126;
  t256_n125: return 0.10638118535280228f;
  t256_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t256_n128;
  t256_n127: return 0.031701020896434784f;
  t256_n128: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n138;
  t256_n129: if (E.getNumReferences() >= 3284434944 /*393.0*/) goto t256_n137;
  t256_n130: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t256_n134;
  t256_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t256_n133;
  t256_n132: return -0.19380560517311096f;
  t256_n133: return 0.07236587256193161f;
  t256_n134: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t256_n136;
  t256_n135: return 0.11991619318723679f;
  t256_n136: return 0.14446179568767548f;
  t256_n137: return 0.10055378824472427f;
  t256_n138: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t256_n144;
  t256_n139: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t256_n141;
  t256_n140: return 0.1905146837234497f;
  t256_n141: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t256_n143;
  t256_n142: return 0.1327289640903473f;
  t256_n143: return 0.24683961272239685f;
  t256_n144: return 0.03056390769779682f;
  t256_n145: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t256_n179;
  t256_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t256_n164;
  t256_n147: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n149;
  t256_n148: return 0.012416910380125046f;
  t256_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t256_n151;
  t256_n150: return 0.006539677735418081f;
  t256_n151: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t256_n153;
  t256_n152: return -0.020294660702347755f;
  t256_n153: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t256_n159;
  t256_n154: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t256_n158;
  t256_n155: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t256_n157;
  t256_n156: return 0.10378621518611908f;
  t256_n157: return -0.21414905786514282f;
  t256_n158: return 0.019484711810946465f;
  t256_n159: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t256_n161;
  t256_n160: return 0.00882426742464304f;
  t256_n161: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t256_n163;
  t256_n162: return 0.10504695028066635f;
  t256_n163: return 0.05091595649719238f;
  t256_n164: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t256_n178;
  t256_n165: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t256_n175;
  t256_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t256_n168;
  t256_n167: return -0.21708887815475464f;
  t256_n168: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t256_n174;
  t256_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n173;
  t256_n170: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t256_n172;
  t256_n171: return 0.10762742161750793f;
  t256_n172: return 0.14079706370830536f;
  t256_n173: return 0.0033703241497278214f;
  t256_n174: return -0.0033679683692753315f;
  t256_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t256_n177;
  t256_n176: return -0.13630296289920807f;
  t256_n177: return 0.0703202411532402f;
  t256_n178: return 0.016731664538383484f;
  t256_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t256_n187;
  t256_n180: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t256_n186;
  t256_n181: if (E.getNumReferences() >= 3262382080 /*61.0*/) goto t256_n185;
  t256_n182: if (E.getNumReferences() >= 3256614912 /*39.0*/) goto t256_n184;
  t256_n183: return -0.03834613040089607f;
  t256_n184: return -0.8270891904830933f;
  t256_n185: return 0.05079155042767525f;
  t256_n186: return 0.044642046093940735f;
  t256_n187: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t256_n223;
  t256_n188: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n208;
  t256_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t256_n199;
  t256_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t256_n196;
  t256_n191: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t256_n193;
  t256_n192: return -0.061083946377038956f;
  t256_n193: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t256_n195;
  t256_n194: return 0.08812187612056732f;
  t256_n195: return -0.03883935511112213f;
  t256_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t256_n198;
  t256_n197: return 0.06644700467586517f;
  t256_n198: return 0.04794720560312271f;
  t256_n199: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t256_n205;
  t256_n200: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t256_n202;
  t256_n201: return 0.050941433757543564f;
  t256_n202: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t256_n204;
  t256_n203: return 0.10987933725118637f;
  t256_n204: return 0.12384413927793503f;
  t256_n205: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t256_n207;
  t256_n206: return -0.2528441548347473f;
  t256_n207: return 0.07852162420749664f;
  t256_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t256_n220;
  t256_n209: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t256_n219;
  t256_n210: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t256_n218;
  t256_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t256_n213;
  t256_n212: return -0.18447759747505188f;
  t256_n213: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t256_n217;
  t256_n214: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t256_n216;
  t256_n215: return 0.028115270659327507f;
  t256_n216: return 0.14342723786830902f;
  t256_n217: return -0.037210822105407715f;
  t256_n218: return 0.09298119693994522f;
  t256_n219: return -0.39613139629364014f;
  t256_n220: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t256_n222;
  t256_n221: return 0.05259379744529724f;
  t256_n222: return 0.0847054049372673f;
  t256_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t256_n233;
  t256_n224: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t256_n230;
  t256_n225: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t256_n229;
  t256_n226: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t256_n228;
  t256_n227: return -0.13043390214443207f;
  t256_n228: return 0.020395681262016296f;
  t256_n229: return -0.5890836715698242f;
  t256_n230: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n232;
  t256_n231: return -0.23293966054916382f;
  t256_n232: return 0.1115301176905632f;
  t256_n233: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t256_n237;
  t256_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t256_n236;
  t256_n235: return 0.012410130351781845f;
  t256_n236: return -0.4990866482257843f;
  t256_n237: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t256_n251;
  t256_n238: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t256_n250;
  t256_n239: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t256_n249;
  t256_n240: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t256_n242;
  t256_n241: return -2.4860033988952637f;
  t256_n242: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t256_n248;
  t256_n243: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t256_n247;
  t256_n244: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t256_n246;
  t256_n245: return 0.07271730154752731f;
  t256_n246: return 0.12016892433166504f;
  t256_n247: return -0.06396150588989258f;
  t256_n248: return 0.04077741503715515f;
  t256_n249: return 0.07140224426984787f;
  t256_n250: return 0.09785646945238113f;
  t256_n251: if (E.getNumReferences() >= 3280453632 /*271.5*/) goto t256_n253;
  t256_n252: return -0.5534387826919556f;
  t256_n253: return 0.06296020746231079f;
  t256_n254: return -0.0002683565835468471f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree257(const Example& E) {
  t257_n0: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t257_n2;
  t257_n1: return -0.0016287690959870815f;
  t257_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t257_n36;
  t257_n3: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t257_n5;
  t257_n4: return -0.00044426051317714155f;
  t257_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t257_n7;
  t257_n6: return 0.0025014053098857403f;
  t257_n7: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t257_n35;
  t257_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t257_n34;
  t257_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t257_n33;
  t257_n10: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t257_n14;
  t257_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t257_n13;
  t257_n12: return 0.08243444561958313f;
  t257_n13: return 0.1171947717666626f;
  t257_n14: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t257_n24;
  t257_n15: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t257_n23;
  t257_n16: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t257_n22;
  t257_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t257_n19;
  t257_n18: return 0.030933784320950508f;
  t257_n19: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t257_n21;
  t257_n20: return -0.05372015759348869f;
  t257_n21: return 0.09807556867599487f;
  t257_n22: return 0.09738100320100784f;
  t257_n23: return -0.0782788023352623f;
  t257_n24: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t257_n30;
  t257_n25: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t257_n27;
  t257_n26: return -0.19330443441867828f;
  t257_n27: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t257_n29;
  t257_n28: return 0.1012674868106842f;
  t257_n29: return 0.10258499532938004f;
  t257_n30: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t257_n32;
  t257_n31: return 0.09292490035295486f;
  t257_n32: return -0.06065515801310539f;
  t257_n33: return 0.0068273479118943214f;
  t257_n34: return 0.009964913129806519f;
  t257_n35: return 0.01089983806014061f;
  t257_n36: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t257_n48;
  t257_n37: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t257_n39;
  t257_n38: return -0.0003577354073058814f;
  t257_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t257_n41;
  t257_n40: return 0.006864032242447138f;
  t257_n41: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t257_n47;
  t257_n42: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t257_n46;
  t257_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t257_n45;
  t257_n44: return 0.07275212556123734f;
  t257_n45: return 0.07623990625143051f;
  t257_n46: return 0.05819672718644142f;
  t257_n47: return -0.02323675900697708f;
  t257_n48: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t257_n204;
  t257_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t257_n51;
  t257_n50: return -0.003734227502718568f;
  t257_n51: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t257_n65;
  t257_n52: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t257_n54;
  t257_n53: return 0.09326878190040588f;
  t257_n54: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t257_n62;
  t257_n55: if (E.getNumReferences() >= 3264348160 /*73.0*/) goto t257_n61;
  t257_n56: if (E.getNumReferences() >= 3245342720 /*15.0*/) goto t257_n58;
  t257_n57: return 0.128458172082901f;
  t257_n58: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t257_n60;
  t257_n59: return 0.1014808714389801f;
  t257_n60: return 0.1997881978750229f;
  t257_n61: return -0.7573672533035278f;
  t257_n62: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t257_n64;
  t257_n63: return -0.045899346470832825f;
  t257_n64: return 0.05153566971421242f;
  t257_n65: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t257_n183;
  t257_n66: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t257_n182;
  t257_n67: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t257_n181;
  t257_n68: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t257_n168;
  t257_n69: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t257_n123;
  t257_n70: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t257_n80;
  t257_n71: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t257_n79;
  t257_n72: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t257_n74;
  t257_n73: return 0.01429225504398346f;
  t257_n74: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t257_n76;
  t257_n75: return 0.059700872749090195f;
  t257_n76: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t257_n78;
  t257_n77: return 0.14542536437511444f;
  t257_n78: return 0.10193628072738647f;
  t257_n79: return -0.11618370562791824f;
  t257_n80: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t257_n98;
  t257_n81: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t257_n89;
  t257_n82: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t257_n88;
  t257_n83: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t257_n87;
  t257_n84: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t257_n86;
  t257_n85: return -0.10968868434429169f;
  t257_n86: return 0.099345363676548f;
  t257_n87: return 0.10542808473110199f;
  t257_n88: return 0.10396572947502136f;
  t257_n89: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t257_n91;
  t257_n90: return 0.040482137352228165f;
  t257_n91: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t257_n95;
  t257_n92: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t257_n94;
  t257_n93: return 0.11019545048475266f;
  t257_n94: return -0.07934966683387756f;
  t257_n95: if (E.getNumReferences() >= 3241148416 /*11.0*/) goto t257_n97;
  t257_n96: return 0.1194223091006279f;
  t257_n97: return -1.7536739110946655f;
  t257_n98: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t257_n106;
  t257_n99: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t257_n101;
  t257_n100: return -0.11126550287008286f;
  t257_n101: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t257_n105;
  t257_n102: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t257_n104;
  t257_n103: return 0.10134780406951904f;
  t257_n104: return 0.10890646278858185f;
  t257_n105: return -0.032007794827222824f;
  t257_n106: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t257_n120;
  t257_n107: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t257_n117;
  t257_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t257_n114;
  t257_n109: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t257_n113;
  t257_n110: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t257_n112;
  t257_n111: return 0.15357562899589539f;
  t257_n112: return 0.07666414231061935f;
  t257_n113: return -0.11589454114437103f;
  t257_n114: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t257_n116;
  t257_n115: return 0.05350785702466965f;
  t257_n116: return 0.13342362642288208f;
  t257_n117: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t257_n119;
  t257_n118: return 0.009069526568055153f;
  t257_n119: return 0.2061184048652649f;
  t257_n120: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t257_n122;
  t257_n121: return 0.017671363428235054f;
  t257_n122: return 0.12004760652780533f;
  t257_n123: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t257_n165;
  t257_n124: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t257_n126;
  t257_n125: return -0.007393680978566408f;
  t257_n126: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t257_n128;
  t257_n127: return 0.014997257851064205f;
  t257_n128: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t257_n154;
  t257_n129: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t257_n145;
  t257_n130: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t257_n140;
  t257_n131: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t257_n133;
  t257_n132: return 0.07390877604484558f;
  t257_n133: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t257_n139;
  t257_n134: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t257_n136;
  t257_n135: return -0.3628704249858856f;
  t257_n136: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t257_n138;
  t257_n137: return 0.10863613337278366f;
  t257_n138: return -0.3150383532047272f;
  t257_n139: return -0.9054198861122131f;
  t257_n140: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t257_n144;
  t257_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t257_n143;
  t257_n142: return 0.09287860244512558f;
  t257_n143: return 0.013147737830877304f;
  t257_n144: return -0.5347589254379272f;
  t257_n145: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t257_n149;
  t257_n146: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t257_n148;
  t257_n147: return 0.11597798019647598f;
  t257_n148: return 0.07218155264854431f;
  t257_n149: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t257_n151;
  t257_n150: return -0.20014412701129913f;
  t257_n151: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t257_n153;
  t257_n152: return 0.09967402368783951f;
  t257_n153: return -0.19114470481872559f;
  t257_n154: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t257_n158;
  t257_n155: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t257_n157;
  t257_n156: return -0.14198380708694458f;
  t257_n157: return 0.047482941299676895f;
  t257_n158: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t257_n164;
  t257_n159: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t257_n161;
  t257_n160: return 0.03644233196973801f;
  t257_n161: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t257_n163;
  t257_n162: return 0.1186511442065239f;
  t257_n163: return 0.11303875595331192f;
  t257_n164: return -0.10059300065040588f;
  t257_n165: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t257_n167;
  t257_n166: return 0.12025423347949982f;
  t257_n167: return -0.11284638941287994f;
  t257_n168: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t257_n170;
  t257_n169: return -0.06631079316139221f;
  t257_n170: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t257_n172;
  t257_n171: return -0.023575056344270706f;
  t257_n172: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t257_n176;
  t257_n173: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t257_n175;
  t257_n174: return 0.035705629736185074f;
  t257_n175: return -0.2540794014930725f;
  t257_n176: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t257_n178;
  t257_n177: return -0.02815195545554161f;
  t257_n178: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t257_n180;
  t257_n179: return -0.2583119869232178f;
  t257_n180: return 0.11069516837596893f;
  t257_n181: return 0.013625369407236576f;
  t257_n182: return -0.19932031631469727f;
  t257_n183: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t257_n203;
  t257_n184: if (E.getNumReferences() >= 3267493888 /*97.0*/) goto t257_n202;
  t257_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t257_n189;
  t257_n186: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t257_n188;
  t257_n187: return -0.12037988007068634f;
  t257_n188: return 0.11061451584100723f;
  t257_n189: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t257_n191;
  t257_n190: return 0.10346711426973343f;
  t257_n191: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t257_n199;
  t257_n192: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t257_n198;
  t257_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t257_n195;
  t257_n194: return -0.13321299850940704f;
  t257_n195: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t257_n197;
  t257_n196: return 0.0f;
  t257_n197: return 0.09550625085830688f;
  t257_n198: return -0.10796575993299484f;
  t257_n199: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t257_n201;
  t257_n200: return 0.08870815485715866f;
  t257_n201: return 0.12042589485645294f;
  t257_n202: return 0.13892778754234314f;
  t257_n203: return -0.011554007418453693f;
  t257_n204: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t257_n206;
  t257_n205: return 0.04972703754901886f;
  t257_n206: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t257_n226;
  t257_n207: if (E.getNumReferences() >= 3271950336 /*134.0*/) goto t257_n219;
  t257_n208: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t257_n210;
  t257_n209: return 0.012728845700621605f;
  t257_n210: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t257_n218;
  t257_n211: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t257_n213;
  t257_n212: return -0.26123517751693726f;
  t257_n213: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t257_n215;
  t257_n214: return -0.05660562217235565f;
  t257_n215: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t257_n217;
  t257_n216: return 0.13443930447101593f;
  t257_n217: return 0.002671597758308053f;
  t257_n218: return 0.029152989387512207f;
  t257_n219: if (E.getNumReferences() >= 3272278016 /*139.0*/) goto t257_n221;
  t257_n220: return 0.11857405304908752f;
  t257_n221: if (E.getNumReferences() >= 3276472320 /*203.0*/) goto t257_n225;
  t257_n222: if (E.getNumReferences() >= 3276013568 /*196.0*/) goto t257_n224;
  t257_n223: return 0.06402623653411865f;
  t257_n224: return 0.15960821509361267f;
  t257_n225: return 0.009088468737900257f;
  t257_n226: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t257_n250;
  t257_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t257_n235;
  t257_n228: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t257_n230;
  t257_n229: return -0.15187227725982666f;
  t257_n230: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t257_n232;
  t257_n231: return 0.11188036948442459f;
  t257_n232: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t257_n234;
  t257_n233: return 0.08071994036436081f;
  t257_n234: return -0.24283309280872345f;
  t257_n235: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t257_n243;
  t257_n236: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t257_n242;
  t257_n237: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t257_n239;
  t257_n238: return -0.02585117146372795f;
  t257_n239: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t257_n241;
  t257_n240: return -0.5592742562294006f;
  t257_n241: return -0.042681314051151276f;
  t257_n242: return -0.08128079026937485f;
  t257_n243: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t257_n247;
  t257_n244: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t257_n246;
  t257_n245: return -0.06239766255021095f;
  t257_n246: return -0.2133937031030655f;
  t257_n247: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t257_n249;
  t257_n248: return -0.04260475933551788f;
  t257_n249: return 0.010566821321845055f;
  t257_n250: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t257_n252;
  t257_n251: return -0.02841494418680668f;
  t257_n252: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t257_n254;
  t257_n253: return 0.08804379403591156f;
  t257_n254: return 0.02794104814529419f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree258(const Example& E) {
  t258_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t258_n2;
  t258_n1: return -0.0009104986675083637f;
  t258_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t258_n182;
  t258_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t258_n103;
  t258_n4: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t258_n34;
  t258_n5: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t258_n7;
  t258_n6: return -0.00705066230148077f;
  t258_n7: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t258_n23;
  t258_n8: if (E.getNumReferences() >= 3315371008 /*5009.5*/) goto t258_n22;
  t258_n9: if (E.getNumReferences() >= 3314935808 /*4797.0*/) goto t258_n11;
  t258_n10: return 0.004524436313658953f;
  t258_n11: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t258_n17;
  t258_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n14;
  t258_n13: return -0.4609035551548004f;
  t258_n14: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t258_n16;
  t258_n15: return 0.10512568801641464f;
  t258_n16: return 0.06930702179670334f;
  t258_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n19;
  t258_n18: return 0.1124892607331276f;
  t258_n19: if (E.getNumReferences() >= 3315329024 /*4989.0*/) goto t258_n21;
  t258_n20: return 0.029450321570038795f;
  t258_n21: return 0.1082991436123848f;
  t258_n22: return -0.011225493624806404f;
  t258_n23: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t258_n29;
  t258_n24: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t258_n26;
  t258_n25: return 0.026878343895077705f;
  t258_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n28;
  t258_n27: return 0.07801968604326248f;
  t258_n28: return 0.048903003334999084f;
  t258_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n33;
  t258_n30: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t258_n32;
  t258_n31: return -0.43802717328071594f;
  t258_n32: return 0.003569947788491845f;
  t258_n33: return 0.038003213703632355f;
  t258_n34: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t258_n58;
  t258_n35: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t258_n37;
  t258_n36: return -0.014186330139636993f;
  t258_n37: if (E.getNumReferences() >= 3332287488 /*20310.0*/) goto t258_n41;
  t258_n38: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t258_n40;
  t258_n39: return 0.09648146480321884f;
  t258_n40: return 0.07469874620437622f;
  t258_n41: if (E.getNumReferences() >= 3336505344 /*28548.0*/) goto t258_n53;
  t258_n42: if (E.getNumReferences() >= 3334726400 /*25073.5*/) goto t258_n44;
  t258_n43: return 0.01699345000088215f;
  t258_n44: if (E.getNumReferences() >= 3334882048 /*25377.5*/) goto t258_n46;
  t258_n45: return 0.10363569110631943f;
  t258_n46: if (E.getNumReferences() >= 3336322560 /*28191.0*/) goto t258_n52;
  t258_n47: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t258_n49;
  t258_n48: return -0.01871970109641552f;
  t258_n49: if (E.getNumReferences() >= 3335284480 /*26163.5*/) goto t258_n51;
  t258_n50: return 0.015306600369513035f;
  t258_n51: return 0.10862948000431061f;
  t258_n52: return 0.11011920869350433f;
  t258_n53: if (E.getNumReferences() >= 3337070336 /*29651.5*/) goto t258_n55;
  t258_n54: return -0.36921006441116333f;
  t258_n55: if (E.getNumReferences() >= 3337668864 /*30820.5*/) goto t258_n57;
  t258_n56: return 0.08955628424882889f;
  t258_n57: return -0.002799262525513768f;
  t258_n58: if (E.getNumReferences() >= 3317607424 /*6101.5*/) goto t258_n92;
  t258_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t258_n61;
  t258_n60: return -0.05218547210097313f;
  t258_n61: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t258_n91;
  t258_n62: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t258_n64;
  t258_n63: return -0.011230498552322388f;
  t258_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t258_n74;
  t258_n65: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t258_n73;
  t258_n66: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t258_n70;
  t258_n67: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t258_n69;
  t258_n68: return 0.12557923793792725f;
  t258_n69: return -0.10757795721292496f;
  t258_n70: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n72;
  t258_n71: return 0.12423530966043472f;
  t258_n72: return 0.1578325480222702f;
  t258_n73: return 0.022183259949088097f;
  t258_n74: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t258_n76;
  t258_n75: return -0.014683994464576244f;
  t258_n76: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t258_n84;
  t258_n77: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t258_n79;
  t258_n78: return 0.006998992525041103f;
  t258_n79: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t258_n83;
  t258_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_DotMemberAccess))) goto t258_n82;
  t258_n81: return 0.03847995027899742f;
  t258_n82: return 0.10605543106794357f;
  t258_n83: return 0.017759639769792557f;
  t258_n84: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t258_n86;
  t258_n85: return 0.05390617623925209f;
  t258_n86: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t258_n88;
  t258_n87: return 0.3725389540195465f;
  t258_n88: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t258_n90;
  t258_n89: return 0.09160343557596207f;
  t258_n90: return 0.08148679882287979f;
  t258_n91: return 0.004619884770363569f;
  t258_n92: if (E.getNumReferences() >= 3318311936 /*6445.5*/) goto t258_n94;
  t258_n93: return 0.11462986469268799f;
  t258_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t258_n96;
  t258_n95: return -0.02701181173324585f;
  t258_n96: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t258_n102;
  t258_n97: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n101;
  t258_n98: if (E.getNumReferences() >= 3332080128 /*19905.0*/) goto t258_n100;
  t258_n99: return 0.020172331482172012f;
  t258_n100: return 0.09979776293039322f;
  t258_n101: return 0.025011226534843445f;
  t258_n102: return 0.01568802446126938f;
  t258_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t258_n105;
  t258_n104: return -0.01658683829009533f;
  t258_n105: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t258_n123;
  t258_n106: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n122;
  t258_n107: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t258_n111;
  t258_n108: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t258_n110;
  t258_n109: return 0.01664280891418457f;
  t258_n110: return 0.029367132112383842f;
  t258_n111: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t258_n117;
  t258_n112: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t258_n114;
  t258_n113: return -0.10780029743909836f;
  t258_n114: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t258_n116;
  t258_n115: return 0.11326734721660614f;
  t258_n116: return -0.06876543164253235f;
  t258_n117: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t258_n121;
  t258_n118: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t258_n120;
  t258_n119: return -0.10590440779924393f;
  t258_n120: return 0.08378516137599945f;
  t258_n121: return -0.13496273756027222f;
  t258_n122: return 0.008697066456079483f;
  t258_n123: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t258_n125;
  t258_n124: return -0.00011296905722701922f;
  t258_n125: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t258_n181;
  t258_n126: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t258_n150;
  t258_n127: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t258_n139;
  t258_n128: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t258_n136;
  t258_n129: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t258_n133;
  t258_n130: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t258_n132;
  t258_n131: return 0.041292861104011536f;
  t258_n132: return -0.0500897578895092f;
  t258_n133: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t258_n135;
  t258_n134: return 0.11729192733764648f;
  t258_n135: return 0.1010386198759079f;
  t258_n136: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t258_n138;
  t258_n137: return 0.09161143004894257f;
  t258_n138: return 0.05027703940868378f;
  t258_n139: if (E.getNumReferences() >= 3292536832 /*768.5*/) goto t258_n149;
  t258_n140: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t258_n142;
  t258_n141: return 0.026092182844877243f;
  t258_n142: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t258_n148;
  t258_n143: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t258_n147;
  t258_n144: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t258_n146;
  t258_n145: return -0.41823625564575195f;
  t258_n146: return 0.10874812304973602f;
  t258_n147: return 0.11600740253925323f;
  t258_n148: return 0.010169805958867073f;
  t258_n149: return -0.13512861728668213f;
  t258_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n158;
  t258_n151: if (E.getNumReferences() >= 3244294144 /*14.0*/) goto t258_n157;
  t258_n152: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t258_n156;
  t258_n153: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t258_n155;
  t258_n154: return 0.17307740449905396f;
  t258_n155: return -0.14843492209911346f;
  t258_n156: return 0.09684508293867111f;
  t258_n157: return 0.04122474044561386f;
  t258_n158: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t258_n174;
  t258_n159: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t258_n171;
  t258_n160: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t258_n170;
  t258_n161: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t258_n163;
  t258_n162: return 0.06570427864789963f;
  t258_n163: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t258_n165;
  t258_n164: return 0.12687897682189941f;
  t258_n165: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t258_n169;
  t258_n166: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t258_n168;
  t258_n167: return -0.11345770210027695f;
  t258_n168: return 0.11100168526172638f;
  t258_n169: return -0.10201060771942139f;
  t258_n170: return 0.0859074592590332f;
  t258_n171: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t258_n173;
  t258_n172: return -0.10185927152633667f;
  t258_n173: return 0.11453662067651749f;
  t258_n174: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t258_n176;
  t258_n175: return 0.0006386296590790153f;
  t258_n176: if (E.getNumReferences() >= 3285565440 /*427.5*/) goto t258_n180;
  t258_n177: if (E.getNumReferences() >= 3283468288 /*363.5*/) goto t258_n179;
  t258_n178: return 0.08298048377037048f;
  t258_n179: return 0.12000449001789093f;
  t258_n180: return -0.04036038741469383f;
  t258_n181: return -0.0596906915307045f;
  t258_n182: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t258_n206;
  t258_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t258_n195;
  t258_n184: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t258_n190;
  t258_n185: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t258_n189;
  t258_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t258_n188;
  t258_n187: return -0.02279304340481758f;
  t258_n188: return 0.04711790755391121f;
  t258_n189: return -0.09789274632930756f;
  t258_n190: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t258_n192;
  t258_n191: return -0.023219455033540726f;
  t258_n192: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t258_n194;
  t258_n193: return 0.0023725659120827913f;
  t258_n194: return 0.09417658299207687f;
  t258_n195: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t258_n205;
  t258_n196: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t258_n198;
  t258_n197: return -0.03432849794626236f;
  t258_n198: if (E.getSymbolScopeDistance() >= 3246391296 /*16.0*/) goto t258_n204;
  t258_n199: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t258_n201;
  t258_n200: return 0.02418237365782261f;
  t258_n201: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t258_n203;
  t258_n202: return -0.003299869829788804f;
  t258_n203: return 0.03458271920681f;
  t258_n204: return -0.0331701934337616f;
  t258_n205: return -0.00013975761248730123f;
  t258_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t258_n236;
  t258_n207: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t258_n235;
  t258_n208: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t258_n214;
  t258_n209: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t258_n213;
  t258_n210: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t258_n212;
  t258_n211: return -0.007483676075935364f;
  t258_n212: return -0.02392210252583027f;
  t258_n213: return 0.03552043437957764f;
  t258_n214: if (E.getNumReferences() >= 3264872448 /*77.0*/) goto t258_n230;
  t258_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t258_n217;
  t258_n216: return -0.026168236508965492f;
  t258_n217: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t258_n219;
  t258_n218: return 0.0233133714646101f;
  t258_n219: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t258_n223;
  t258_n220: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t258_n222;
  t258_n221: return -0.004624144174158573f;
  t258_n222: return 0.10818703472614288f;
  t258_n223: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t258_n229;
  t258_n224: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t258_n226;
  t258_n225: return 0.002361482009291649f;
  t258_n226: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t258_n228;
  t258_n227: return 0.12014059722423553f;
  t258_n228: return 0.065745510160923f;
  t258_n229: return -0.14980584383010864f;
  t258_n230: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t258_n232;
  t258_n231: return 0.10755881667137146f;
  t258_n232: if (E.getNumReferences() >= 3294724096 /*902.0*/) goto t258_n234;
  t258_n233: return -0.0019662503618746996f;
  t258_n234: return 0.08232202380895615f;
  t258_n235: return 0.008556588552892208f;
  t258_n236: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t258_n238;
  t258_n237: return 0.011426661163568497f;
  t258_n238: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t258_n248;
  t258_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t258_n247;
  t258_n240: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t258_n246;
  t258_n241: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t258_n245;
  t258_n242: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t258_n244;
  t258_n243: return 0.02004663459956646f;
  t258_n244: return 0.09857156127691269f;
  t258_n245: return -0.13631998002529144f;
  t258_n246: return 0.06285052746534348f;
  t258_n247: return 0.0439436174929142f;
  t258_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t258_n250;
  t258_n249: return 0.003855382790789008f;
  t258_n250: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t258_n252;
  t258_n251: return -0.025713136419653893f;
  t258_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n254;
  t258_n253: return 0.06845982372760773f;
  t258_n254: return -0.07878891378641129f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree259(const Example& E) {
  t259_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t259_n236;
  t259_n1: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t259_n3;
  t259_n2: return -0.0013495102757588029f;
  t259_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t259_n107;
  t259_n4: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t259_n58;
  t259_n5: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t259_n13;
  t259_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t259_n10;
  t259_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t259_n9;
  t259_n8: return -0.023197496309876442f;
  t259_n9: return -0.01661246083676815f;
  t259_n10: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t259_n12;
  t259_n11: return 0.023770833387970924f;
  t259_n12: return 0.07112263888120651f;
  t259_n13: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t259_n29;
  t259_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t259_n16;
  t259_n15: return -0.0071070315316319466f;
  t259_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t259_n26;
  t259_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t259_n19;
  t259_n18: return 0.00041180316475220025f;
  t259_n19: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t259_n23;
  t259_n20: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n22;
  t259_n21: return -0.3962693512439728f;
  t259_n22: return 0.10617373883724213f;
  t259_n23: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t259_n25;
  t259_n24: return 0.016110491007566452f;
  t259_n25: return 0.08550921827554703f;
  t259_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t259_n28;
  t259_n27: return -0.030321968719363213f;
  t259_n28: return 0.03155462071299553f;
  t259_n29: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t259_n57;
  t259_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t259_n42;
  t259_n31: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n35;
  t259_n32: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t259_n34;
  t259_n33: return -0.1257329285144806f;
  t259_n34: return -0.016627566888928413f;
  t259_n35: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t259_n41;
  t259_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n38;
  t259_n37: return -0.0768725648522377f;
  t259_n38: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t259_n40;
  t259_n39: return -0.0019382763421162963f;
  t259_n40: return -0.07265356183052063f;
  t259_n41: return 0.05605451762676239f;
  t259_n42: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t259_n56;
  t259_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n45;
  t259_n44: return -0.05659635365009308f;
  t259_n45: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t259_n55;
  t259_n46: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t259_n48;
  t259_n47: return 0.04850909113883972f;
  t259_n48: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t259_n54;
  t259_n49: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t259_n51;
  t259_n50: return 0.0347701720893383f;
  t259_n51: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t259_n53;
  t259_n52: return 0.12732799351215363f;
  t259_n53: return 0.11658623069524765f;
  t259_n54: return 0.00016350123041775078f;
  t259_n55: return -0.22706261277198792f;
  t259_n56: return -0.004397178068757057f;
  t259_n57: return 6.70454028295353e-05f;
  t259_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t259_n60;
  t259_n59: return 0.0022219480015337467f;
  t259_n60: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t259_n100;
  t259_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n99;
  t259_n62: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n90;
  t259_n63: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t259_n67;
  t259_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t259_n66;
  t259_n65: return 0.08436589688062668f;
  t259_n66: return 0.1149919331073761f;
  t259_n67: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t259_n81;
  t259_n68: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t259_n80;
  t259_n69: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t259_n79;
  t259_n70: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t259_n78;
  t259_n71: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t259_n77;
  t259_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t259_n74;
  t259_n73: return 0.002064220141619444f;
  t259_n74: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t259_n76;
  t259_n75: return -0.280791699886322f;
  t259_n76: return 0.10882671922445297f;
  t259_n77: return -0.3609050512313843f;
  t259_n78: return 0.0955595150589943f;
  t259_n79: return -0.05254359915852547f;
  t259_n80: return 0.09808595478534698f;
  t259_n81: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t259_n87;
  t259_n82: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t259_n84;
  t259_n83: return -0.18506252765655518f;
  t259_n84: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t259_n86;
  t259_n85: return 0.09944383054971695f;
  t259_n86: return 0.09806524962186813f;
  t259_n87: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t259_n89;
  t259_n88: return 0.09211984276771545f;
  t259_n89: return -0.06212412193417549f;
  t259_n90: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t259_n96;
  t259_n91: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t259_n93;
  t259_n92: return -0.018345775082707405f;
  t259_n93: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t259_n95;
  t259_n94: return 0.08790688961744308f;
  t259_n95: return 0.014654295518994331f;
  t259_n96: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t259_n98;
  t259_n97: return -0.6628628373146057f;
  t259_n98: return -0.14770051836967468f;
  t259_n99: return 0.009544874541461468f;
  t259_n100: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t259_n106;
  t259_n101: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t259_n105;
  t259_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n104;
  t259_n103: return 0.09389178454875946f;
  t259_n104: return -0.07286907732486725f;
  t259_n105: return 0.10561415553092957f;
  t259_n106: return 0.0070419772528111935f;
  t259_n107: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t259_n123;
  t259_n108: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t259_n114;
  t259_n109: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t259_n113;
  t259_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t259_n112;
  t259_n111: return -0.10616511851549149f;
  t259_n112: return 0.0019781175069510937f;
  t259_n113: return -0.056155867874622345f;
  t259_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t259_n116;
  t259_n115: return 0.006573302671313286f;
  t259_n116: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t259_n122;
  t259_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n121;
  t259_n118: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n120;
  t259_n119: return 0.06883208453655243f;
  t259_n120: return 0.07598504424095154f;
  t259_n121: return 0.05139072239398956f;
  t259_n122: return -0.024896366521716118f;
  t259_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t259_n185;
  t259_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t259_n126;
  t259_n125: return -0.0010373103432357311f;
  t259_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n144;
  t259_n127: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n129;
  t259_n128: return 0.07980985939502716f;
  t259_n129: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t259_n137;
  t259_n130: if (E.getNumReferences() >= 3264348160 /*73.0*/) goto t259_n136;
  t259_n131: if (E.getNumReferences() >= 3245342720 /*15.0*/) goto t259_n133;
  t259_n132: return 0.12287650257349014f;
  t259_n133: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t259_n135;
  t259_n134: return 0.10130491107702255f;
  t259_n135: return 0.14952422678470612f;
  t259_n136: return -0.44764867424964905f;
  t259_n137: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t259_n139;
  t259_n138: return -0.04323297366499901f;
  t259_n139: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t259_n143;
  t259_n140: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t259_n142;
  t259_n141: return 0.05023467168211937f;
  t259_n142: return -0.21412234008312225f;
  t259_n143: return 0.1435607671737671f;
  t259_n144: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t259_n146;
  t259_n145: return 0.015261368826031685f;
  t259_n146: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t259_n168;
  t259_n147: if (E.getNumReferences() >= 3267493888 /*97.0*/) goto t259_n167;
  t259_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n152;
  t259_n149: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t259_n151;
  t259_n150: return -0.09903544187545776f;
  t259_n151: return 0.10904479026794434f;
  t259_n152: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t259_n154;
  t259_n153: return 0.10060470551252365f;
  t259_n154: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t259_n164;
  t259_n155: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t259_n163;
  t259_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t259_n158;
  t259_n157: return -0.12531781196594238f;
  t259_n158: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t259_n160;
  t259_n159: return 0.09227506071329117f;
  t259_n160: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t259_n162;
  t259_n161: return -0.2723976969718933f;
  t259_n162: return 0.10764598101377487f;
  t259_n163: return -0.30289411544799805f;
  t259_n164: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t259_n166;
  t259_n165: return 0.0748811885714531f;
  t259_n166: return 0.11876484006643295f;
  t259_n167: return 0.13504458963871002f;
  t259_n168: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t259_n178;
  t259_n169: if (E.getNumReferences() >= 3314298880 /*4486.0*/) goto t259_n177;
  t259_n170: if (E.getNumReferences() >= 3304935424 /*2026.5*/) goto t259_n176;
  t259_n171: if (E.getNumReferences() >= 3286532096 /*457.0*/) goto t259_n173;
  t259_n172: return -0.19567078351974487f;
  t259_n173: if (E.getNumReferences() >= 3288170496 /*507.0*/) goto t259_n175;
  t259_n174: return 0.11995924264192581f;
  t259_n175: return 0.007836327888071537f;
  t259_n176: return 0.11255156993865967f;
  t259_n177: return -0.3885272741317749f;
  t259_n178: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t259_n180;
  t259_n179: return -0.021064024418592453f;
  t259_n180: if (E.getNumReferences() >= 3283124224 /*353.0*/) goto t259_n182;
  t259_n181: return -0.09104592353105545f;
  t259_n182: if (E.getNumReferences() >= 3302817792 /*1768.0*/) goto t259_n184;
  t259_n183: return 0.10725328326225281f;
  t259_n184: return 0.0675315260887146f;
  t259_n185: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n189;
  t259_n186: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t259_n188;
  t259_n187: return 0.09091772884130478f;
  t259_n188: return -0.016157058998942375f;
  t259_n189: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t259_n235;
  t259_n190: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n222;
  t259_n191: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t259_n205;
  t259_n192: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t259_n194;
  t259_n193: return 0.00010852632840396836f;
  t259_n194: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t259_n196;
  t259_n195: return 0.02900925651192665f;
  t259_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t259_n204;
  t259_n197: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t259_n203;
  t259_n198: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t259_n200;
  t259_n199: return 0.056959107518196106f;
  t259_n200: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t259_n202;
  t259_n201: return 0.09116728603839874f;
  t259_n202: return 0.0689435601234436f;
  t259_n203: return 0.05507558584213257f;
  t259_n204: return 0.005595774855464697f;
  t259_n205: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t259_n213;
  t259_n206: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t259_n212;
  t259_n207: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t259_n211;
  t259_n208: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t259_n210;
  t259_n209: return -0.23708786070346832f;
  t259_n210: return -0.6461445689201355f;
  t259_n211: return -0.09098239243030548f;
  t259_n212: return 0.017460709437727928f;
  t259_n213: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t259_n217;
  t259_n214: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t259_n216;
  t259_n215: return 0.14215713739395142f;
  t259_n216: return -0.002076047472655773f;
  t259_n217: if (E.getNumReferences() >= 3281453056 /*302.0*/) goto t259_n221;
  t259_n218: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t259_n220;
  t259_n219: return -0.014970095828175545f;
  t259_n220: return 0.10288294404745102f;
  t259_n221: return -0.13385945558547974f;
  t259_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t259_n230;
  t259_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t259_n225;
  t259_n224: return -0.2256964147090912f;
  t259_n225: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t259_n229;
  t259_n226: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t259_n228;
  t259_n227: return -0.024365171790122986f;
  t259_n228: return -0.1719551533460617f;
  t259_n229: return -0.07360262423753738f;
  t259_n230: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t259_n232;
  t259_n231: return -0.03725667670369148f;
  t259_n232: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t259_n234;
  t259_n233: return -0.021199239417910576f;
  t259_n234: return 0.019323257729411125f;
  t259_n235: return 0.014981926418840885f;
  t259_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t259_n252;
  t259_n237: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t259_n251;
  t259_n238: if (E.getNumReferences() >= 3284877312 /*406.5*/) goto t259_n240;
  t259_n239: return -0.05201007425785065f;
  t259_n240: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t259_n250;
  t259_n241: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t259_n249;
  t259_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t259_n244;
  t259_n243: return -0.1241447851061821f;
  t259_n244: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t259_n246;
  t259_n245: return 0.3729100823402405f;
  t259_n246: if (E.getNumReferences() >= 3302293504 /*1704.0*/) goto t259_n248;
  t259_n247: return 0.08573751151561737f;
  t259_n248: return 0.16097795963287354f;
  t259_n249: return 0.27522552013397217f;
  t259_n250: return -0.1016203761100769f;
  t259_n251: return -0.08947356790304184f;
  t259_n252: if (E.getNumReferences() >= 3294519296 /*889.5*/) goto t259_n254;
  t259_n253: return -0.013496224768459797f;
  t259_n254: return 0.09609353542327881f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree260(const Example& E) {
  t260_n0: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t260_n254;
  t260_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t260_n111;
  t260_n2: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t260_n38;
  t260_n3: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t260_n35;
  t260_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t260_n6;
  t260_n5: return -0.009155933745205402f;
  t260_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n8;
  t260_n7: return -0.002265893155708909f;
  t260_n8: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t260_n30;
  t260_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t260_n11;
  t260_n10: return -0.012080885469913483f;
  t260_n11: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t260_n29;
  t260_n12: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t260_n16;
  t260_n13: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t260_n15;
  t260_n14: return 0.013926873914897442f;
  t260_n15: return 0.08810165524482727f;
  t260_n16: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t260_n20;
  t260_n17: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t260_n19;
  t260_n18: return 0.0018232539296150208f;
  t260_n19: return 0.107339046895504f;
  t260_n20: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t260_n22;
  t260_n21: return -0.00868942029774189f;
  t260_n22: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t260_n24;
  t260_n23: return -0.031155047938227654f;
  t260_n24: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t260_n26;
  t260_n25: return 0.1034289002418518f;
  t260_n26: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t260_n28;
  t260_n27: return 0.11486957967281342f;
  t260_n28: return -0.20868636667728424f;
  t260_n29: return -0.11726655811071396f;
  t260_n30: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t260_n32;
  t260_n31: return 0.10459373146295547f;
  t260_n32: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t260_n34;
  t260_n33: return 0.09623853117227554f;
  t260_n34: return -0.009244185872375965f;
  t260_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t260_n37;
  t260_n36: return -0.11759842187166214f;
  t260_n37: return 0.009409592486917973f;
  t260_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t260_n90;
  t260_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t260_n41;
  t260_n40: return 0.00946089532226324f;
  t260_n41: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n43;
  t260_n42: return 0.09609241038560867f;
  t260_n43: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t260_n73;
  t260_n44: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t260_n50;
  t260_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t260_n49;
  t260_n46: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t260_n48;
  t260_n47: return -0.022746577858924866f;
  t260_n48: return 0.07427014410495758f;
  t260_n49: return 0.07595571875572205f;
  t260_n50: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t260_n62;
  t260_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t260_n53;
  t260_n52: return -0.12108895927667618f;
  t260_n53: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t260_n55;
  t260_n54: return 0.11023548990488052f;
  t260_n55: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t260_n61;
  t260_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n58;
  t260_n57: return 0.11530744284391403f;
  t260_n58: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t260_n60;
  t260_n59: return -0.10186176002025604f;
  t260_n60: return 0.1095009297132492f;
  t260_n61: return 0.0512995570898056f;
  t260_n62: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t260_n64;
  t260_n63: return 0.0045605795457959175f;
  t260_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t260_n70;
  t260_n65: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t260_n67;
  t260_n66: return 0.06177366524934769f;
  t260_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t260_n69;
  t260_n68: return 0.06549949198961258f;
  t260_n69: return 0.10673180222511292f;
  t260_n70: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t260_n72;
  t260_n71: return 0.11431064456701279f;
  t260_n72: return -0.10401105135679245f;
  t260_n73: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t260_n87;
  t260_n74: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t260_n86;
  t260_n75: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t260_n85;
  t260_n76: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n84;
  t260_n77: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t260_n79;
  t260_n78: return 0.1479116678237915f;
  t260_n79: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t260_n83;
  t260_n80: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t260_n82;
  t260_n81: return -0.10527046024799347f;
  t260_n82: return 0.1034703478217125f;
  t260_n83: return 0.11785993725061417f;
  t260_n84: return 0.16108763217926025f;
  t260_n85: return -0.39504843950271606f;
  t260_n86: return -0.008443833328783512f;
  t260_n87: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t260_n89;
  t260_n88: return 0.12305029481649399f;
  t260_n89: return -0.23226803541183472f;
  t260_n90: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n94;
  t260_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t260_n93;
  t260_n92: return 0.08384886384010315f;
  t260_n93: return 0.5084651708602905f;
  t260_n94: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t260_n96;
  t260_n95: return 0.10043323785066605f;
  t260_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t260_n98;
  t260_n97: return 0.038028500974178314f;
  t260_n98: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n104;
  t260_n99: if (E.getNumReferences() >= 3284434944 /*393.0*/) goto t260_n103;
  t260_n100: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t260_n102;
  t260_n101: return -0.13871626555919647f;
  t260_n102: return 0.11152050644159317f;
  t260_n103: return 0.09879007190465927f;
  t260_n104: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t260_n110;
  t260_n105: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t260_n107;
  t260_n106: return 0.19649945199489594f;
  t260_n107: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t260_n109;
  t260_n108: return 0.1291174739599228f;
  t260_n109: return 0.24732717871665955f;
  t260_n110: return 0.013858456164598465f;
  t260_n111: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t260_n175;
  t260_n112: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t260_n154;
  t260_n113: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t260_n131;
  t260_n114: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n116;
  t260_n115: return 0.01649019867181778f;
  t260_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t260_n118;
  t260_n117: return 0.0129423001781106f;
  t260_n118: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t260_n120;
  t260_n119: return -0.025441855192184448f;
  t260_n120: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t260_n126;
  t260_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t260_n125;
  t260_n122: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t260_n124;
  t260_n123: return 0.09992820024490356f;
  t260_n124: return -0.1401832401752472f;
  t260_n125: return 0.03603190556168556f;
  t260_n126: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t260_n128;
  t260_n127: return 0.0100418571382761f;
  t260_n128: if (E.getNumReferences() >= 3244294144 /*14.0*/) goto t260_n130;
  t260_n129: return 0.11537738144397736f;
  t260_n130: return -0.38762691617012024f;
  t260_n131: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t260_n147;
  t260_n132: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t260_n134;
  t260_n133: return -0.02630370669066906f;
  t260_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t260_n136;
  t260_n135: return -0.07634644955396652f;
  t260_n136: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t260_n140;
  t260_n137: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n139;
  t260_n138: return 0.04676845669746399f;
  t260_n139: return -0.05964115634560585f;
  t260_n140: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t260_n146;
  t260_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t260_n143;
  t260_n142: return 0.09236165136098862f;
  t260_n143: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t260_n145;
  t260_n144: return 0.16264384984970093f;
  t260_n145: return 0.10304409265518188f;
  t260_n146: return 0.06834578514099121f;
  t260_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t260_n149;
  t260_n148: return -0.10086800158023834f;
  t260_n149: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t260_n151;
  t260_n150: return 0.016132406890392303f;
  t260_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t260_n153;
  t260_n152: return -0.12353039532899857f;
  t260_n153: return 0.0296370517462492f;
  t260_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t260_n164;
  t260_n155: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t260_n163;
  t260_n156: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t260_n158;
  t260_n157: return -0.04491422325372696f;
  t260_n158: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t260_n162;
  t260_n159: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t260_n161;
  t260_n160: return 0.09963290393352509f;
  t260_n161: return 0.057429611682891846f;
  t260_n162: return -0.12641610205173492f;
  t260_n163: return 0.0508728101849556f;
  t260_n164: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t260_n174;
  t260_n165: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t260_n173;
  t260_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n172;
  t260_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n171;
  t260_n168: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t260_n170;
  t260_n169: return 0.10752884298563004f;
  t260_n170: return 0.1258438378572464f;
  t260_n171: return 0.018242422491312027f;
  t260_n172: return 0.0818495973944664f;
  t260_n173: return 0.02291700430214405f;
  t260_n174: return 0.01651429943740368f;
  t260_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t260_n179;
  t260_n176: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t260_n178;
  t260_n177: return -0.024942470714449883f;
  t260_n178: return 0.04356852173805237f;
  t260_n179: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t260_n247;
  t260_n180: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t260_n200;
  t260_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t260_n197;
  t260_n182: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t260_n194;
  t260_n183: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t260_n191;
  t260_n184: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n186;
  t260_n185: return -0.10074158757925034f;
  t260_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t260_n190;
  t260_n187: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t260_n189;
  t260_n188: return 0.021279674023389816f;
  t260_n189: return -0.12594595551490784f;
  t260_n190: return 0.02231616899371147f;
  t260_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t260_n193;
  t260_n192: return 0.10371946543455124f;
  t260_n193: return -0.11421779543161392f;
  t260_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n196;
  t260_n195: return 0.10006225109100342f;
  t260_n196: return -0.08317945897579193f;
  t260_n197: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n199;
  t260_n198: return 0.08206052333116531f;
  t260_n199: return 0.014657232910394669f;
  t260_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t260_n232;
  t260_n201: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t260_n213;
  t260_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t260_n210;
  t260_n203: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t260_n209;
  t260_n204: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t260_n208;
  t260_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n207;
  t260_n206: return -0.1961740404367447f;
  t260_n207: return 0.10549812018871307f;
  t260_n208: return -0.04188656434416771f;
  t260_n209: return 0.09591767936944962f;
  t260_n210: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t260_n212;
  t260_n211: return 0.05288943648338318f;
  t260_n212: return -0.3338080644607544f;
  t260_n213: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t260_n227;
  t260_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t260_n226;
  t260_n215: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n219;
  t260_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n218;
  t260_n217: return 0.07328318059444427f;
  t260_n218: return -0.7142096161842346f;
  t260_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t260_n223;
  t260_n220: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t260_n222;
  t260_n221: return 0.10392993688583374f;
  t260_n222: return 0.02809332124888897f;
  t260_n223: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t260_n225;
  t260_n224: return 0.04712136089801788f;
  t260_n225: return 0.10448069125413895f;
  t260_n226: return 0.018492601811885834f;
  t260_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t260_n229;
  t260_n228: return -0.012396492063999176f;
  t260_n229: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t260_n231;
  t260_n230: return 0.08879254758358002f;
  t260_n231: return -0.029904775321483612f;
  t260_n232: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n242;
  t260_n233: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t260_n237;
  t260_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n236;
  t260_n235: return 0.11205079406499863f;
  t260_n236: return -1.640018105506897f;
  t260_n237: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t260_n241;
  t260_n238: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t260_n240;
  t260_n239: return -0.3688066303730011f;
  t260_n240: return 0.0982869490981102f;
  t260_n241: return -0.18600863218307495f;
  t260_n242: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t260_n244;
  t260_n243: return -0.06938444823026657f;
  t260_n244: if (E.getNumReferences() >= 3252682752 /*28.0*/) goto t260_n246;
  t260_n245: return 0.10887053608894348f;
  t260_n246: return -0.2346607893705368f;
  t260_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t260_n253;
  t260_n248: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t260_n252;
  t260_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n251;
  t260_n250: return -0.21467049419879913f;
  t260_n251: return 0.10241910815238953f;
  t260_n252: return -0.41272592544555664f;
  t260_n253: return 0.11462979018688202f;
  t260_n254: return -0.00025769066996872425f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree261(const Example& E) {
  t261_n0: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t261_n2;
  t261_n1: return 0.0024534454569220543f;
  t261_n2: if (E.getNumReferences() >= 3297832960 /*1159.5*/) goto t261_n240;
  t261_n3: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t261_n5;
  t261_n4: return -0.00015061514568515122f;
  t261_n5: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t261_n157;
  t261_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t261_n8;
  t261_n7: return -0.0046946513466537f;
  t261_n8: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t261_n10;
  t261_n9: return 0.006105051841586828f;
  t261_n10: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t261_n12;
  t261_n11: return -0.11832858622074127f;
  t261_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t261_n14;
  t261_n13: return 0.019386881962418556f;
  t261_n14: if (E.getNumReferences() >= 3297464320 /*1114.5*/) goto t261_n156;
  t261_n15: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t261_n67;
  t261_n16: if (E.getNumReferences() >= 3273097216 /*151.5*/) goto t261_n58;
  t261_n17: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t261_n47;
  t261_n18: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t261_n20;
  t261_n19: return 0.032492898404598236f;
  t261_n20: if (E.getNumReferences() >= 3266379776 /*88.5*/) goto t261_n24;
  t261_n21: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t261_n23;
  t261_n22: return 0.059991102665662766f;
  t261_n23: return 0.11858442425727844f;
  t261_n24: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t261_n26;
  t261_n25: return 0.00311466446146369f;
  t261_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t261_n42;
  t261_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t261_n33;
  t261_n28: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t261_n30;
  t261_n29: return -0.0061901044100522995f;
  t261_n30: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t261_n32;
  t261_n31: return 0.15590910613536835f;
  t261_n32: return 0.11246275156736374f;
  t261_n33: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t261_n41;
  t261_n34: if (E.getNumReferences() >= 3271294976 /*126.0*/) goto t261_n40;
  t261_n35: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t261_n37;
  t261_n36: return -0.11243713647127151f;
  t261_n37: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t261_n39;
  t261_n38: return 0.18153882026672363f;
  t261_n39: return 0.14918984472751617f;
  t261_n40: return 0.008277310989797115f;
  t261_n41: return -0.12030947208404541f;
  t261_n42: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t261_n46;
  t261_n43: if (E.getNumReferences() >= 3268870144 /*107.5*/) goto t261_n45;
  t261_n44: return 0.24956609308719635f;
  t261_n45: return 0.10176955163478851f;
  t261_n46: return -0.2537081241607666f;
  t261_n47: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t261_n57;
  t261_n48: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t261_n52;
  t261_n49: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t261_n51;
  t261_n50: return -0.18512648344039917f;
  t261_n51: return 0.12475273758172989f;
  t261_n52: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t261_n56;
  t261_n53: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t261_n55;
  t261_n54: return 0.10719791799783707f;
  t261_n55: return 0.1025756448507309f;
  t261_n56: return -0.020898040384054184f;
  t261_n57: return -0.0727899894118309f;
  t261_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t261_n62;
  t261_n59: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t261_n61;
  t261_n60: return -0.02778657339513302f;
  t261_n61: return -0.1154232919216156f;
  t261_n62: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t261_n64;
  t261_n63: return -0.014425419270992279f;
  t261_n64: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t261_n66;
  t261_n65: return 0.12265966832637787f;
  t261_n66: return 0.0710642859339714f;
  t261_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t261_n149;
  t261_n68: if (E.getNumReferences() >= 3271720960 /*130.5*/) goto t261_n94;
  t261_n69: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t261_n89;
  t261_n70: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t261_n88;
  t261_n71: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t261_n73;
  t261_n72: return 0.04254743084311485f;
  t261_n73: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t261_n87;
  t261_n74: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t261_n86;
  t261_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t261_n77;
  t261_n76: return -0.012106589041650295f;
  t261_n77: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t261_n85;
  t261_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t261_n80;
  t261_n79: return 0.024951154366135597f;
  t261_n80: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t261_n84;
  t261_n81: if (E.getNumReferences() >= 3266576384 /*90.0*/) goto t261_n83;
  t261_n82: return 0.10995656251907349f;
  t261_n83: return 0.12788335978984833f;
  t261_n84: return 0.8514944314956665f;
  t261_n85: return 0.10541963577270508f;
  t261_n86: return -0.0355105921626091f;
  t261_n87: return -0.1419798880815506f;
  t261_n88: return -0.006621848326176405f;
  t261_n89: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t261_n91;
  t261_n90: return 0.009836188517510891f;
  t261_n91: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t261_n93;
  t261_n92: return 0.13483816385269165f;
  t261_n93: return -0.14183375239372253f;
  t261_n94: if (E.getNumReferences() >= 3273621504 /*159.5*/) goto t261_n104;
  t261_n95: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t261_n103;
  t261_n96: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t261_n100;
  t261_n97: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t261_n99;
  t261_n98: return 0.1632845252752304f;
  t261_n99: return 0.09469707310199738f;
  t261_n100: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t261_n102;
  t261_n101: return -0.08782467246055603f;
  t261_n102: return 0.08484413474798203f;
  t261_n103: return 0.12989096343517303f;
  t261_n104: if (E.getNumReferences() >= 3287318528 /*481.0*/) goto t261_n124;
  t261_n105: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t261_n111;
  t261_n106: if (E.getNumReferences() >= 3274735616 /*176.5*/) goto t261_n110;
  t261_n107: if (E.getNumReferences() >= 3274342400 /*170.5*/) goto t261_n109;
  t261_n108: return -0.0072292182594537735f;
  t261_n109: return 0.10209226608276367f;
  t261_n110: return -0.07748360931873322f;
  t261_n111: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t261_n123;
  t261_n112: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t261_n120;
  t261_n113: if (E.getNumReferences() >= 3283386368 /*361.0*/) goto t261_n119;
  t261_n114: if (E.getNumReferences() >= 3281780736 /*312.0*/) goto t261_n118;
  t261_n115: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t261_n117;
  t261_n116: return 0.10555781424045563f;
  t261_n117: return -0.10216421633958817f;
  t261_n118: return 0.22189638018608093f;
  t261_n119: return -0.15419267117977142f;
  t261_n120: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t261_n122;
  t261_n121: return -0.11057237535715103f;
  t261_n122: return 0.10950304567813873f;
  t261_n123: return -0.03429615497589111f;
  t261_n124: if (E.getNumReferences() >= 3287859200 /*497.5*/) goto t261_n126;
  t261_n125: return 0.11088074743747711f;
  t261_n126: if (E.getNumReferences() >= 3295395840 /*943.0*/) goto t261_n146;
  t261_n127: if (E.getNumReferences() >= 3293257728 /*812.5*/) goto t261_n143;
  t261_n128: if (E.getNumReferences() >= 3290841088 /*665.0*/) goto t261_n142;
  t261_n129: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t261_n137;
  t261_n130: if (E.getNumReferences() >= 3290292224 /*631.5*/) goto t261_n136;
  t261_n131: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t261_n133;
  t261_n132: return -0.09172262251377106f;
  t261_n133: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t261_n135;
  t261_n134: return 0.13357321918010712f;
  t261_n135: return 0.03861953690648079f;
  t261_n136: return -1.9739550352096558f;
  t261_n137: if (E.getNumReferences() >= 3290144768 /*622.5*/) goto t261_n141;
  t261_n138: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t261_n140;
  t261_n139: return 0.11566611379384995f;
  t261_n140: return -0.008127523586153984f;
  t261_n141: return 0.11869083344936371f;
  t261_n142: return -0.1491771787405014f;
  t261_n143: if (E.getNumReferences() >= 3293855744 /*849.0*/) goto t261_n145;
  t261_n144: return 0.11944328993558884f;
  t261_n145: return 0.140952467918396f;
  t261_n146: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t261_n148;
  t261_n147: return -0.6025333404541016f;
  t261_n148: return 0.11833794414997101f;
  t261_n149: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t261_n153;
  t261_n150: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t261_n152;
  t261_n151: return 0.12230399250984192f;
  t261_n152: return -0.10698050260543823f;
  t261_n153: if (E.getNumReferences() >= 3283681280 /*370.0*/) goto t261_n155;
  t261_n154: return 0.04814609885215759f;
  t261_n155: return 0.15145422518253326f;
  t261_n156: return 0.1091514378786087f;
  t261_n157: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t261_n159;
  t261_n158: return -0.033069808036088943f;
  t261_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t261_n229;
  t261_n160: if (E.getNumReferences() >= 3280797696 /*282.0*/) goto t261_n180;
  t261_n161: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t261_n163;
  t261_n162: return -0.0069010015577077866f;
  t261_n163: if (E.getNumReferences() >= 3280224256 /*264.5*/) goto t261_n173;
  t261_n164: if (E.getNumReferences() >= 3279781888 /*253.5*/) goto t261_n172;
  t261_n165: if (E.getNumReferences() >= 3278929920 /*240.5*/) goto t261_n167;
  t261_n166: return 0.023632634431123734f;
  t261_n167: if (E.getNumReferences() >= 3278995456 /*241.5*/) goto t261_n169;
  t261_n168: return 0.13613127171993256f;
  t261_n169: if (E.getNumReferences() >= 3279618048 /*251.0*/) goto t261_n171;
  t261_n170: return 0.06613736599683762f;
  t261_n171: return 0.141680046916008f;
  t261_n172: return -0.2067154496908188f;
  t261_n173: if (E.getNumReferences() >= 3280502784 /*273.0*/) goto t261_n179;
  t261_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t261_n176;
  t261_n175: return 0.09916649013757706f;
  t261_n176: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t261_n178;
  t261_n177: return 0.15112599730491638f;
  t261_n178: return 0.12060169130563736f;
  t261_n179: return 0.011274680495262146f;
  t261_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t261_n182;
  t261_n181: return -0.12587764859199524f;
  t261_n182: if (E.getNumReferences() >= 3286974464 /*470.5*/) goto t261_n184;
  t261_n183: return -0.0724993422627449f;
  t261_n184: if (E.getNumReferences() >= 3287040000 /*472.5*/) goto t261_n188;
  t261_n185: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t261_n187;
  t261_n186: return 0.10882899165153503f;
  t261_n187: return -0.3903099000453949f;
  t261_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t261_n212;
  t261_n189: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t261_n191;
  t261_n190: return -0.05770701542496681f;
  t261_n191: if (E.getNumReferences() >= 3296731136 /*1025.0*/) goto t261_n205;
  t261_n192: if (E.getNumReferences() >= 3293413376 /*822.0*/) goto t261_n204;
  t261_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t261_n195;
  t261_n194: return -0.20186083018779755f;
  t261_n195: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t261_n199;
  t261_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t261_n198;
  t261_n197: return 0.10083174705505371f;
  t261_n198: return 0.032033395022153854f;
  t261_n199: if (E.getNumReferences() >= 3290390528 /*637.5*/) goto t261_n201;
  t261_n200: return 0.008841014467179775f;
  t261_n201: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t261_n203;
  t261_n202: return 0.15551824867725372f;
  t261_n203: return 0.08168961107730865f;
  t261_n204: return -0.3375546932220459f;
  t261_n205: if (E.getNumReferences() >= 3297198080 /*1082.0*/) goto t261_n211;
  t261_n206: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t261_n208;
  t261_n207: return 0.11701745539903641f;
  t261_n208: if (E.getNumReferences() >= 3296980992 /*1055.5*/) goto t261_n210;
  t261_n209: return 0.22787946462631226f;
  t261_n210: return 0.12326952815055847f;
  t261_n211: return -0.03834453597664833f;
  t261_n212: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t261_n224;
  t261_n213: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t261_n215;
  t261_n214: return -0.044505055993795395f;
  t261_n215: if (E.getNumReferences() >= 3289071616 /*557.0*/) goto t261_n219;
  t261_n216: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t261_n218;
  t261_n217: return -0.06125618889927864f;
  t261_n218: return 0.1488644927740097f;
  t261_n219: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t261_n223;
  t261_n220: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t261_n222;
  t261_n221: return 0.08970051258802414f;
  t261_n222: return -0.013417400419712067f;
  t261_n223: return -0.3869909942150116f;
  t261_n224: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t261_n228;
  t261_n225: if (E.getNumReferences() >= 3290988544 /*674.0*/) goto t261_n227;
  t261_n226: return 0.08278180658817291f;
  t261_n227: return 0.10269227623939514f;
  t261_n228: return 0.06456772983074188f;
  t261_n229: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t261_n233;
  t261_n230: if (E.getNumReferences() >= 3276472320 /*203.0*/) goto t261_n232;
  t261_n231: return -0.1690768152475357f;
  t261_n232: return 0.058852244168519974f;
  t261_n233: if (E.getNumReferences() >= 3282370560 /*330.0*/) goto t261_n239;
  t261_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t261_n238;
  t261_n235: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t261_n237;
  t261_n236: return 0.056551743298769f;
  t261_n237: return 0.10424909740686417f;
  t261_n238: return 0.05930929258465767f;
  t261_n239: return -0.025294866412878036f;
  t261_n240: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t261_n254;
  t261_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t261_n247;
  t261_n242: if (E.getNumReferences() >= 3297878016 /*1165.0*/) goto t261_n246;
  t261_n243: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t261_n245;
  t261_n244: return -0.04907950386404991f;
  t261_n245: return 0.5231308937072754f;
  t261_n246: return 0.009046928025782108f;
  t261_n247: if (E.getNumReferences() >= 3307966464 /*2745.0*/) goto t261_n253;
  t261_n248: if (E.getNumReferences() >= 3303108608 /*1803.5*/) goto t261_n252;
  t261_n249: if (E.getNumReferences() >= 3299176448 /*1323.5*/) goto t261_n251;
  t261_n250: return 0.10868077725172043f;
  t261_n251: return -0.3056700825691223f;
  t261_n252: return 0.09728150814771652f;
  t261_n253: return 0.006666501984000206f;
  t261_n254: return 0.0020920021925121546f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree262(const Example& E) {
  t262_n0: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t262_n108;
  t262_n1: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t262_n35;
  t262_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n22;
  t262_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t262_n21;
  t262_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n6;
  t262_n5: return -0.008244043216109276f;
  t262_n6: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t262_n18;
  t262_n7: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t262_n15;
  t262_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n10;
  t262_n9: return -0.02149556577205658f;
  t262_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t262_n14;
  t262_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Namespace))) goto t262_n13;
  t262_n12: return -0.1600462794303894f;
  t262_n13: return 0.0041241771541535854f;
  t262_n14: return 0.04647732153534889f;
  t262_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t262_n17;
  t262_n16: return -0.20638687908649445f;
  t262_n17: return 0.09097184240818024f;
  t262_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t262_n20;
  t262_n19: return -0.010074760764837265f;
  t262_n20: return 0.03026833012700081f;
  t262_n21: return -0.012935210950672626f;
  t262_n22: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t262_n32;
  t262_n23: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t262_n27;
  t262_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t262_n26;
  t262_n25: return -0.026317942887544632f;
  t262_n26: return -0.00905661378055811f;
  t262_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n29;
  t262_n28: return -0.007073251996189356f;
  t262_n29: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t262_n31;
  t262_n30: return 0.013970187865197659f;
  t262_n31: return -0.02045024186372757f;
  t262_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t262_n34;
  t262_n33: return 0.0012968543451279402f;
  t262_n34: return 0.061587631702423096f;
  t262_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t262_n107;
  t262_n36: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t262_n106;
  t262_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t262_n81;
  t262_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t262_n44;
  t262_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n43;
  t262_n40: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n42;
  t262_n41: return 0.009859366342425346f;
  t262_n42: return -0.04682939127087593f;
  t262_n43: return -0.003101843409240246f;
  t262_n44: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t262_n64;
  t262_n45: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t262_n63;
  t262_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n50;
  t262_n47: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t262_n49;
  t262_n48: return -0.037456195801496506f;
  t262_n49: return 0.016073863953351974f;
  t262_n50: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t262_n60;
  t262_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Namespace))) goto t262_n55;
  t262_n52: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t262_n54;
  t262_n53: return -0.10780937969684601f;
  t262_n54: return -0.0009442463051527739f;
  t262_n55: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t262_n59;
  t262_n56: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t262_n58;
  t262_n57: return 0.004181920550763607f;
  t262_n58: return 0.017900830134749413f;
  t262_n59: return -0.013249770738184452f;
  t262_n60: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n62;
  t262_n61: return -0.07156478613615036f;
  t262_n62: return -0.4588032066822052f;
  t262_n63: return -0.4149528443813324f;
  t262_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t262_n76;
  t262_n65: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t262_n73;
  t262_n66: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t262_n68;
  t262_n67: return 0.012518598698079586f;
  t262_n68: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t262_n70;
  t262_n69: return 0.003971195314079523f;
  t262_n70: if (E.getFilterLength() >= 3239051264 /*9.0*/) goto t262_n72;
  t262_n71: return 0.09001348912715912f;
  t262_n72: return 0.10780789703130722f;
  t262_n73: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n75;
  t262_n74: return 0.1001659408211708f;
  t262_n75: return -0.007081310730427504f;
  t262_n76: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n80;
  t262_n77: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t262_n79;
  t262_n78: return 0.0030867040622979403f;
  t262_n79: return 0.13598109781742096f;
  t262_n80: return 0.03604250028729439f;
  t262_n81: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t262_n103;
  t262_n82: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n98;
  t262_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t262_n95;
  t262_n84: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t262_n86;
  t262_n85: return -0.004191744141280651f;
  t262_n86: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t262_n90;
  t262_n87: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t262_n89;
  t262_n88: return 0.019402794539928436f;
  t262_n89: return 0.7818167805671692f;
  t262_n90: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t262_n92;
  t262_n91: return -0.010768801905214787f;
  t262_n92: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t262_n94;
  t262_n93: return 0.026381682604551315f;
  t262_n94: return -0.011222007684409618f;
  t262_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t262_n97;
  t262_n96: return 0.10062766075134277f;
  t262_n97: return -0.044089436531066895f;
  t262_n98: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t262_n100;
  t262_n99: return 0.01853042282164097f;
  t262_n100: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t262_n102;
  t262_n101: return -0.006167309358716011f;
  t262_n102: return 0.011526966467499733f;
  t262_n103: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t262_n105;
  t262_n104: return 0.08259996026754379f;
  t262_n105: return 0.006063962355256081f;
  t262_n106: return 0.021013807505369186f;
  t262_n107: return 0.06946537643671036f;
  t262_n108: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t262_n110;
  t262_n109: return -0.0013524553505703807f;
  t262_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t262_n112;
  t262_n111: return 0.00012157700257375836f;
  t262_n112: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t262_n172;
  t262_n113: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t262_n115;
  t262_n114: return 0.0032739804591983557f;
  t262_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n117;
  t262_n116: return -0.011486383154988289f;
  t262_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n119;
  t262_n118: return 0.06497560441493988f;
  t262_n119: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t262_n163;
  t262_n120: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t262_n158;
  t262_n121: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t262_n149;
  t262_n122: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t262_n142;
  t262_n123: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t262_n125;
  t262_n124: return 0.01418117806315422f;
  t262_n125: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t262_n141;
  t262_n126: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t262_n130;
  t262_n127: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t262_n129;
  t262_n128: return 0.11792461574077606f;
  t262_n129: return -0.07444991171360016f;
  t262_n130: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t262_n134;
  t262_n131: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t262_n133;
  t262_n132: return 0.10827227681875229f;
  t262_n133: return 0.07019975781440735f;
  t262_n134: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t262_n140;
  t262_n135: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t262_n137;
  t262_n136: return -1.3608899116516113f;
  t262_n137: if (E.getNumReferences() >= 3247964160 /*19.0*/) goto t262_n139;
  t262_n138: return 0.08352747559547424f;
  t262_n139: return -0.4437861740589142f;
  t262_n140: return 0.13337227702140808f;
  t262_n141: return -0.04905097559094429f;
  t262_n142: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t262_n144;
  t262_n143: return 0.2948704659938812f;
  t262_n144: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t262_n146;
  t262_n145: return 0.06763731688261032f;
  t262_n146: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t262_n148;
  t262_n147: return 0.143254816532135f;
  t262_n148: return -0.10781954973936081f;
  t262_n149: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t262_n153;
  t262_n150: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t262_n152;
  t262_n151: return -0.0354510098695755f;
  t262_n152: return 0.06758815795183182f;
  t262_n153: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t262_n157;
  t262_n154: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t262_n156;
  t262_n155: return -0.03359582647681236f;
  t262_n156: return 0.0997525230050087f;
  t262_n157: return 0.10845855623483658f;
  t262_n158: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t262_n160;
  t262_n159: return -0.08159051835536957f;
  t262_n160: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t262_n162;
  t262_n161: return 0.0986877977848053f;
  t262_n162: return 0.06630610674619675f;
  t262_n163: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t262_n171;
  t262_n164: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t262_n166;
  t262_n165: return 0.0516473725438118f;
  t262_n166: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t262_n170;
  t262_n167: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t262_n169;
  t262_n168: return 0.1761477291584015f;
  t262_n169: return -0.37156572937965393f;
  t262_n170: return 0.049808863550424576f;
  t262_n171: return -0.032898854464292526f;
  t262_n172: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t262_n244;
  t262_n173: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t262_n211;
  t262_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n176;
  t262_n175: return -0.0007557005155831575f;
  t262_n176: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t262_n190;
  t262_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n179;
  t262_n178: return -0.024989569559693336f;
  t262_n179: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t262_n189;
  t262_n180: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t262_n182;
  t262_n181: return -0.10352250188589096f;
  t262_n182: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t262_n184;
  t262_n183: return -0.0650520920753479f;
  t262_n184: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t262_n186;
  t262_n185: return -0.005746627692133188f;
  t262_n186: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t262_n188;
  t262_n187: return 0.054718438535928726f;
  t262_n188: return -0.003524956526234746f;
  t262_n189: return 0.133326455950737f;
  t262_n190: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t262_n196;
  t262_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n193;
  t262_n192: return -0.0631726086139679f;
  t262_n193: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t262_n195;
  t262_n194: return 0.0031788838095963f;
  t262_n195: return -0.03442783281207085f;
  t262_n196: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t262_n198;
  t262_n197: return -0.04407269135117531f;
  t262_n198: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t262_n210;
  t262_n199: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t262_n201;
  t262_n200: return 0.02272173762321472f;
  t262_n201: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t262_n207;
  t262_n202: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t262_n204;
  t262_n203: return -0.10382838547229767f;
  t262_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n206;
  t262_n205: return -0.13317474722862244f;
  t262_n206: return 0.14660070836544037f;
  t262_n207: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t262_n209;
  t262_n208: return -0.004277427680790424f;
  t262_n209: return 0.08221179991960526f;
  t262_n210: return 0.013942623510956764f;
  t262_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t262_n213;
  t262_n212: return 0.004638136830180883f;
  t262_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n243;
  t262_n214: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t262_n218;
  t262_n215: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t262_n217;
  t262_n216: return -0.011436648666858673f;
  t262_n217: return 0.09871672093868256f;
  t262_n218: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t262_n242;
  t262_n219: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t262_n241;
  t262_n220: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t262_n234;
  t262_n221: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t262_n225;
  t262_n222: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t262_n224;
  t262_n223: return 0.12032372504472733f;
  t262_n224: return -0.12491938471794128f;
  t262_n225: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t262_n229;
  t262_n226: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t262_n228;
  t262_n227: return 0.019345544278621674f;
  t262_n228: return 0.1059982180595398f;
  t262_n229: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t262_n233;
  t262_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t262_n232;
  t262_n231: return 0.10284197330474854f;
  t262_n232: return -0.11303997039794922f;
  t262_n233: return 0.07389620691537857f;
  t262_n234: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t262_n236;
  t262_n235: return 0.1569535881280899f;
  t262_n236: if (E.getNumReferences() >= 3299532800 /*1367.0*/) goto t262_n240;
  t262_n237: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t262_n239;
  t262_n238: return 0.14008520543575287f;
  t262_n239: return 0.09713130444288254f;
  t262_n240: return 0.11039789021015167f;
  t262_n241: return 0.04188837856054306f;
  t262_n242: return -0.0005387468263506889f;
  t262_n243: return -0.0002354362659389153f;
  t262_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t262_n248;
  t262_n245: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t262_n247;
  t262_n246: return 0.005492060910910368f;
  t262_n247: return 0.11397143453359604f;
  t262_n248: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t262_n254;
  t262_n249: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t262_n253;
  t262_n250: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t262_n252;
  t262_n251: return 0.08401627838611603f;
  t262_n252: return 0.04258376732468605f;
  t262_n253: return 0.040218353271484375f;
  t262_n254: return -0.040595464408397675f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree263(const Example& E) {
  t263_n0: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t263_n2;
  t263_n1: return 0.0023874929174780846f;
  t263_n2: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t263_n44;
  t263_n3: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t263_n7;
  t263_n4: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t263_n6;
  t263_n5: return -0.0006029728683643043f;
  t263_n6: return 0.00908026471734047f;
  t263_n7: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n9;
  t263_n8: return -0.020663456991314888f;
  t263_n9: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t263_n25;
  t263_n10: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t263_n24;
  t263_n11: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t263_n15;
  t263_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t263_n14;
  t263_n13: return -0.08763932436704636f;
  t263_n14: return 0.019318927079439163f;
  t263_n15: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t263_n23;
  t263_n16: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t263_n22;
  t263_n17: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t263_n21;
  t263_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t263_n20;
  t263_n19: return -0.9319264888763428f;
  t263_n20: return -0.44293856620788574f;
  t263_n21: return -0.14834250509738922f;
  t263_n22: return -0.02159433253109455f;
  t263_n23: return -0.07170332968235016f;
  t263_n24: return 0.037735603749752045f;
  t263_n25: if (E.getNumReferences() >= 3368194704 /*398484.5*/) goto t263_n41;
  t263_n26: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t263_n28;
  t263_n27: return -0.059274982661008835f;
  t263_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t263_n38;
  t263_n29: if (E.getNumReferences() >= 3247964160 /*19.0*/) goto t263_n33;
  t263_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t263_n32;
  t263_n31: return -0.42289865016937256f;
  t263_n32: return -0.02180936373770237f;
  t263_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t263_n37;
  t263_n34: if (E.getNumReferences() >= 3255828480 /*36.0*/) goto t263_n36;
  t263_n35: return 0.1185101717710495f;
  t263_n36: return -0.0030759975779801607f;
  t263_n37: return 0.11435981839895248f;
  t263_n38: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t263_n40;
  t263_n39: return 0.09520106762647629f;
  t263_n40: return 0.08800731599330902f;
  t263_n41: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n43;
  t263_n42: return 0.0101467315107584f;
  t263_n43: return 0.07417891174554825f;
  t263_n44: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t263_n254;
  t263_n45: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t263_n47;
  t263_n46: return -0.003154890378937125f;
  t263_n47: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t263_n55;
  t263_n48: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t263_n50;
  t263_n49: return 3.358894173288718e-05f;
  t263_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t263_n52;
  t263_n51: return 0.007783149369060993f;
  t263_n52: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t263_n54;
  t263_n53: return 0.025493767112493515f;
  t263_n54: return -0.15646100044250488f;
  t263_n55: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t263_n225;
  t263_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t263_n110;
  t263_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t263_n77;
  t263_n58: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t263_n68;
  t263_n59: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t263_n67;
  t263_n60: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t263_n66;
  t263_n61: if (E.getSymbolScopeDistance() >= 3245342720 /*15.0*/) goto t263_n65;
  t263_n62: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t263_n64;
  t263_n63: return 0.07139299809932709f;
  t263_n64: return 0.0995524600148201f;
  t263_n65: return 0.01742180809378624f;
  t263_n66: return -0.052290625870227814f;
  t263_n67: return -0.03632097318768501f;
  t263_n68: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n72;
  t263_n69: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t263_n71;
  t263_n70: return 0.07969311624765396f;
  t263_n71: return -1.3787411451339722f;
  t263_n72: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t263_n74;
  t263_n73: return 0.12549297511577606f;
  t263_n74: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t263_n76;
  t263_n75: return -0.04612200707197189f;
  t263_n76: return 0.10691125690937042f;
  t263_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t263_n99;
  t263_n78: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t263_n80;
  t263_n79: return 0.02395429089665413f;
  t263_n80: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t263_n90;
  t263_n81: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t263_n83;
  t263_n82: return 0.055335212498903275f;
  t263_n83: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t263_n89;
  t263_n84: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t263_n88;
  t263_n85: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t263_n87;
  t263_n86: return 0.09459211677312851f;
  t263_n87: return 0.07227978855371475f;
  t263_n88: return 0.03057156316936016f;
  t263_n89: return -0.11144591122865677f;
  t263_n90: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t263_n98;
  t263_n91: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n97;
  t263_n92: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n94;
  t263_n93: return -0.12411695718765259f;
  t263_n94: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t263_n96;
  t263_n95: return 0.09789913892745972f;
  t263_n96: return -0.10013438016176224f;
  t263_n97: return 0.1287747621536255f;
  t263_n98: return 0.06479192525148392f;
  t263_n99: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t263_n109;
  t263_n100: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n102;
  t263_n101: return 0.17948542535305023f;
  t263_n102: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t263_n104;
  t263_n103: return 0.005848924163728952f;
  t263_n104: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n108;
  t263_n105: if (E.getNumReferences() >= 3314549760 /*4608.5*/) goto t263_n107;
  t263_n106: return 0.13462834060192108f;
  t263_n107: return 0.032756831496953964f;
  t263_n108: return 0.056799959391355515f;
  t263_n109: return 0.04895709827542305f;
  t263_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t263_n124;
  t263_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t263_n113;
  t263_n112: return -0.060876429080963135f;
  t263_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t263_n115;
  t263_n114: return -0.10031954944133759f;
  t263_n115: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t263_n123;
  t263_n116: if (E.getNumReferences() >= 3267756032 /*99.0*/) goto t263_n122;
  t263_n117: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t263_n119;
  t263_n118: return 0.05266343057155609f;
  t263_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n121;
  t263_n120: return 0.11586331576108932f;
  t263_n121: return 0.08814885467290878f;
  t263_n122: return 0.10560549795627594f;
  t263_n123: return -0.035084839910268784f;
  t263_n124: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t263_n220;
  t263_n125: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t263_n169;
  t263_n126: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t263_n128;
  t263_n127: return 0.03357893228530884f;
  t263_n128: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t263_n168;
  t263_n129: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t263_n167;
  t263_n130: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n160;
  t263_n131: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t263_n143;
  t263_n132: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t263_n142;
  t263_n133: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n137;
  t263_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t263_n136;
  t263_n135: return 0.04440688714385033f;
  t263_n136: return 0.06986689567565918f;
  t263_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t263_n141;
  t263_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t263_n140;
  t263_n139: return 0.02680877223610878f;
  t263_n140: return 0.07680447399616241f;
  t263_n141: return 0.11841564625501633f;
  t263_n142: return -0.049320418387651443f;
  t263_n143: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t263_n159;
  t263_n144: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t263_n152;
  t263_n145: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t263_n151;
  t263_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t263_n148;
  t263_n147: return 0.07256726920604706f;
  t263_n148: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n150;
  t263_n149: return 0.11025198549032211f;
  t263_n150: return 0.04731715843081474f;
  t263_n151: return -0.053121596574783325f;
  t263_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t263_n158;
  t263_n153: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n155;
  t263_n154: return 0.012446449138224125f;
  t263_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t263_n157;
  t263_n156: return 0.046073392033576965f;
  t263_n157: return 0.10717301815748215f;
  t263_n158: return 0.14640453457832336f;
  t263_n159: return -0.006157289259135723f;
  t263_n160: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t263_n164;
  t263_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t263_n163;
  t263_n162: return -0.009171332232654095f;
  t263_n163: return 0.09098635613918304f;
  t263_n164: if (E.getFileProximityDistance() >= 3254910976 /*32.5*/) goto t263_n166;
  t263_n165: return -0.028231782838702202f;
  t263_n166: return -0.1655210554599762f;
  t263_n167: return -0.10084109753370285f;
  t263_n168: return 0.013560670427978039f;
  t263_n169: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t263_n193;
  t263_n170: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t263_n176;
  t263_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t263_n175;
  t263_n172: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t263_n174;
  t263_n173: return 0.042580246925354004f;
  t263_n174: return 0.08142878115177155f;
  t263_n175: return 0.07321755588054657f;
  t263_n176: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t263_n192;
  t263_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n191;
  t263_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t263_n180;
  t263_n179: return 0.04339143633842468f;
  t263_n180: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t263_n190;
  t263_n181: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t263_n185;
  t263_n182: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t263_n184;
  t263_n183: return -0.10641635209321976f;
  t263_n184: return 0.09505301713943481f;
  t263_n185: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t263_n187;
  t263_n186: return -0.04946257546544075f;
  t263_n187: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t263_n189;
  t263_n188: return 0.09611184149980545f;
  t263_n189: return -0.1288149058818817f;
  t263_n190: return -0.10059801489114761f;
  t263_n191: return 0.041399359703063965f;
  t263_n192: return 0.00016177556244656444f;
  t263_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t263_n211;
  t263_n194: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t263_n210;
  t263_n195: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t263_n209;
  t263_n196: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t263_n202;
  t263_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t263_n201;
  t263_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n200;
  t263_n199: return 0.051173366606235504f;
  t263_n200: return 0.14252786338329315f;
  t263_n201: return 0.11402884870767593f;
  t263_n202: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t263_n204;
  t263_n203: return -0.08729677647352219f;
  t263_n204: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t263_n208;
  t263_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t263_n207;
  t263_n206: return 0.10076185315847397f;
  t263_n207: return 0.10704468190670013f;
  t263_n208: return 0.20125707983970642f;
  t263_n209: return -0.1006065085530281f;
  t263_n210: return 0.04129302129149437f;
  t263_n211: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t263_n219;
  t263_n212: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t263_n218;
  t263_n213: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t263_n217;
  t263_n214: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t263_n216;
  t263_n215: return 0.10954506695270538f;
  t263_n216: return -0.13016921281814575f;
  t263_n217: return -0.10079646110534668f;
  t263_n218: return 0.12466908246278763f;
  t263_n219: return -0.14461757242679596f;
  t263_n220: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t263_n222;
  t263_n221: return -0.010812586173415184f;
  t263_n222: if (E.getSymbolScopeDistance() >= 3247964160 /*19.0*/) goto t263_n224;
  t263_n223: return 0.18467138707637787f;
  t263_n224: return 0.05715601146221161f;
  t263_n225: if (E.getNumReferences() >= 3282452480 /*332.5*/) goto t263_n227;
  t263_n226: return 0.004416801035404205f;
  t263_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t263_n229;
  t263_n228: return 0.029225073754787445f;
  t263_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t263_n253;
  t263_n230: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n240;
  t263_n231: if (E.getNumReferences() >= 3291054080 /*678.0*/) goto t263_n233;
  t263_n232: return -0.11192569136619568f;
  t263_n233: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t263_n239;
  t263_n234: if (E.getNumReferences() >= 3302932480 /*1782.0*/) goto t263_n236;
  t263_n235: return 0.1872205138206482f;
  t263_n236: if (E.getNumReferences() >= 3325197824 /*11423.5*/) goto t263_n238;
  t263_n237: return -0.1027078926563263f;
  t263_n238: return 0.08710148185491562f;
  t263_n239: return 0.09813757240772247f;
  t263_n240: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t263_n242;
  t263_n241: return -0.16304519772529602f;
  t263_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t263_n244;
  t263_n243: return -0.1162911206483841f;
  t263_n244: if (E.getNumReferences() >= 3321980928 /*8282.0*/) goto t263_n252;
  t263_n245: if (E.getNumReferences() >= 3292160000 /*745.5*/) goto t263_n249;
  t263_n246: if (E.getNumReferences() >= 3283419136 /*362.0*/) goto t263_n248;
  t263_n247: return 0.11921671032905579f;
  t263_n248: return -0.28737935423851013f;
  t263_n249: if (E.getNumReferences() >= 3306002432 /*2265.5*/) goto t263_n251;
  t263_n250: return 0.10718824714422226f;
  t263_n251: return 0.10752546042203903f;
  t263_n252: return -0.11077603697776794f;
  t263_n253: return 0.023544572293758392f;
  t263_n254: return -0.04673806205391884f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree264(const Example& E) {
  t264_n0: if (E.getNumReferences() >= 3320122368 /*7329.5*/) goto t264_n2;
  t264_n1: return -0.0002530912170186639f;
  t264_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t264_n56;
  t264_n3: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t264_n27;
  t264_n4: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t264_n6;
  t264_n5: return 0.10707733780145645f;
  t264_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t264_n26;
  t264_n7: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t264_n25;
  t264_n8: if (E.getNumReferences() >= 3327672832 /*13840.5*/) goto t264_n16;
  t264_n9: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t264_n11;
  t264_n10: return -0.09797956049442291f;
  t264_n11: if (E.getNumReferences() >= 3324626432 /*10865.5*/) goto t264_n15;
  t264_n12: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t264_n14;
  t264_n13: return -0.14917878806591034f;
  t264_n14: return 0.1046484187245369f;
  t264_n15: return -0.014194603078067303f;
  t264_n16: if (E.getNumReferences() >= 3328148480 /*14305.0*/) goto t264_n20;
  t264_n17: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t264_n19;
  t264_n18: return 0.1365695595741272f;
  t264_n19: return 0.10056792199611664f;
  t264_n20: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t264_n24;
  t264_n21: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t264_n23;
  t264_n22: return -0.13153555989265442f;
  t264_n23: return 0.07514497637748718f;
  t264_n24: return 0.01702863909304142f;
  t264_n25: return -0.1416569948196411f;
  t264_n26: return 0.012360326945781708f;
  t264_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t264_n39;
  t264_n28: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t264_n30;
  t264_n29: return -0.003986636642366648f;
  t264_n30: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t264_n38;
  t264_n31: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t264_n35;
  t264_n32: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t264_n34;
  t264_n33: return -0.18023322522640228f;
  t264_n34: return -0.6340731978416443f;
  t264_n35: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t264_n37;
  t264_n36: return 0.08171653747558594f;
  t264_n37: return -0.1100151538848877f;
  t264_n38: return 0.014440600760281086f;
  t264_n39: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t264_n55;
  t264_n40: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t264_n46;
  t264_n41: if (E.getNumReferences() >= 3321499648 /*8002.0*/) goto t264_n45;
  t264_n42: if (E.getNumReferences() >= 3320885248 /*7702.0*/) goto t264_n44;
  t264_n43: return -0.18418440222740173f;
  t264_n44: return 0.4016737937927246f;
  t264_n45: return 0.06517153978347778f;
  t264_n46: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t264_n48;
  t264_n47: return 0.03501906618475914f;
  t264_n48: if (E.getNumReferences() >= 3321825280 /*8161.0*/) goto t264_n54;
  t264_n49: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t264_n53;
  t264_n50: if (E.getNumReferences() >= 3321156608 /*7834.5*/) goto t264_n52;
  t264_n51: return 0.3053189218044281f;
  t264_n52: return 0.3541563153266907f;
  t264_n53: return 0.04062018170952797f;
  t264_n54: return 0.03988879546523094f;
  t264_n55: return 0.008027967065572739f;
  t264_n56: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t264_n60;
  t264_n57: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t264_n59;
  t264_n58: return -0.02905375324189663f;
  t264_n59: return -0.07338821142911911f;
  t264_n60: if (E.getNumReferences() >= 3322934784 /*9213.5*/) goto t264_n240;
  t264_n61: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t264_n219;
  t264_n62: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t264_n184;
  t264_n63: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t264_n65;
  t264_n64: return 0.02275303192436695f;
  t264_n65: if (E.getNumReferences() >= 3320185856 /*7360.5*/) goto t264_n73;
  t264_n66: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t264_n68;
  t264_n67: return 0.11685184389352798f;
  t264_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t264_n70;
  t264_n69: return -0.2639961540699005f;
  t264_n70: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t264_n72;
  t264_n71: return 0.11449114978313446f;
  t264_n72: return -0.10700280219316483f;
  t264_n73: if (E.getNumReferences() >= 3322624512 /*8910.5*/) goto t264_n163;
  t264_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t264_n76;
  t264_n75: return -0.10703901201486588f;
  t264_n76: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t264_n112;
  t264_n77: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t264_n87;
  t264_n78: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t264_n80;
  t264_n79: return -0.15353578329086304f;
  t264_n80: if (E.getNumReferences() >= 3321541632 /*8022.5*/) goto t264_n82;
  t264_n81: return -0.021576842293143272f;
  t264_n82: if (E.getNumReferences() >= 3321819136 /*8158.0*/) goto t264_n86;
  t264_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t264_n85;
  t264_n84: return -0.14196035265922546f;
  t264_n85: return 0.13572247326374054f;
  t264_n86: return -0.11049371212720871f;
  t264_n87: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t264_n105;
  t264_n88: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t264_n104;
  t264_n89: if (E.getNumReferences() >= 3322036736 /*8336.5*/) goto t264_n103;
  t264_n90: if (E.getNumReferences() >= 3321878528 /*8187.0*/) goto t264_n102;
  t264_n91: if (E.getNumReferences() >= 3321586688 /*8044.5*/) goto t264_n101;
  t264_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t264_n94;
  t264_n93: return 0.1761539876461029f;
  t264_n94: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t264_n98;
  t264_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t264_n97;
  t264_n96: return -0.13397538661956787f;
  t264_n97: return 0.6902667880058289f;
  t264_n98: if (E.getNumReferences() >= 3320489984 /*7509.0*/) goto t264_n100;
  t264_n99: return 0.14737914502620697f;
  t264_n100: return -0.11158844828605652f;
  t264_n101: return 0.11582455784082413f;
  t264_n102: return 0.12325620651245117f;
  t264_n103: return -0.04956893250346184f;
  t264_n104: return -0.1410479098558426f;
  t264_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t264_n107;
  t264_n106: return 0.012413193471729755f;
  t264_n107: if (E.getNumReferences() >= 3321601024 /*8051.5*/) goto t264_n109;
  t264_n108: return 0.04255624860525131f;
  t264_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t264_n111;
  t264_n110: return -0.10109062492847443f;
  t264_n111: return 0.1134641021490097f;
  t264_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t264_n130;
  t264_n113: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t264_n115;
  t264_n114: return -0.0497509129345417f;
  t264_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t264_n123;
  t264_n116: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t264_n120;
  t264_n117: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t264_n119;
  t264_n118: return -1.1469184160232544f;
  t264_n119: return 0.047611434012651443f;
  t264_n120: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t264_n122;
  t264_n121: return 0.052352942526340485f;
  t264_n122: return 0.1138836219906807f;
  t264_n123: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t264_n129;
  t264_n124: if (E.getNumReferences() >= 3321240576 /*7875.5*/) goto t264_n128;
  t264_n125: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t264_n127;
  t264_n126: return 0.13063210248947144f;
  t264_n127: return -0.04264707490801811f;
  t264_n128: return 0.11449922621250153f;
  t264_n129: return 0.0407857671380043f;
  t264_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t264_n162;
  t264_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t264_n133;
  t264_n132: return -0.7286947965621948f;
  t264_n133: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t264_n145;
  t264_n134: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t264_n136;
  t264_n135: return -0.10237197577953339f;
  t264_n136: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t264_n144;
  t264_n137: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t264_n139;
  t264_n138: return 0.07714354991912842f;
  t264_n139: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t264_n143;
  t264_n140: if (E.getNumReferences() >= 3321156608 /*7834.5*/) goto t264_n142;
  t264_n141: return 0.07630033046007156f;
  t264_n142: return 0.10620920360088348f;
  t264_n143: return 0.06719394028186798f;
  t264_n144: return 0.10172060877084732f;
  t264_n145: if (E.getNumReferences() >= 3321964032 /*8265.5*/) goto t264_n161;
  t264_n146: if (E.getNumReferences() >= 3320403968 /*7467.0*/) goto t264_n150;
  t264_n147: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t264_n149;
  t264_n148: return -0.11138954013586044f;
  t264_n149: return 0.11571714282035828f;
  t264_n150: if (E.getNumReferences() >= 3320655872 /*7590.0*/) goto t264_n152;
  t264_n151: return -0.109327532351017f;
  t264_n152: if (E.getNumReferences() >= 3321151488 /*7832.0*/) goto t264_n158;
  t264_n153: if (E.getNumReferences() >= 3320945664 /*7731.5*/) goto t264_n155;
  t264_n154: return 0.08197680115699768f;
  t264_n155: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t264_n157;
  t264_n156: return 0.10938876122236252f;
  t264_n157: return 0.0851588100194931f;
  t264_n158: if (E.getNumReferences() >= 3321802752 /*8150.0*/) goto t264_n160;
  t264_n159: return 0.04696061834692955f;
  t264_n160: return 0.10493941605091095f;
  t264_n161: return -0.12212970107793808f;
  t264_n162: return 0.10132923722267151f;
  t264_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t264_n183;
  t264_n164: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t264_n180;
  t264_n165: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t264_n179;
  t264_n166: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t264_n168;
  t264_n167: return -0.4876014292240143f;
  t264_n168: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t264_n170;
  t264_n169: return 0.12054920941591263f;
  t264_n170: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t264_n174;
  t264_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t264_n173;
  t264_n172: return -0.37670332193374634f;
  t264_n173: return 0.10709338635206223f;
  t264_n174: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t264_n178;
  t264_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t264_n177;
  t264_n176: return -0.24214619398117065f;
  t264_n177: return 0.10638914257287979f;
  t264_n178: return 0.15195167064666748f;
  t264_n179: return -0.3174605965614319f;
  t264_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t264_n182;
  t264_n181: return -0.28234386444091797f;
  t264_n182: return 0.11073284596204758f;
  t264_n183: return 0.09919124096632004f;
  t264_n184: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t264_n214;
  t264_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t264_n205;
  t264_n186: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t264_n196;
  t264_n187: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t264_n191;
  t264_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t264_n190;
  t264_n189: return -0.542084276676178f;
  t264_n190: return -0.04978398233652115f;
  t264_n191: if (E.getNumReferences() >= 3321995264 /*8296.0*/) goto t264_n193;
  t264_n192: return 0.0983557254076004f;
  t264_n193: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t264_n195;
  t264_n194: return 0.06299242377281189f;
  t264_n195: return -0.1440954953432083f;
  t264_n196: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t264_n204;
  t264_n197: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t264_n201;
  t264_n198: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t264_n200;
  t264_n199: return -0.7193828225135803f;
  t264_n200: return 0.08207804709672928f;
  t264_n201: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t264_n203;
  t264_n202: return 0.09743236750364304f;
  t264_n203: return 0.11266063153743744f;
  t264_n204: return 0.025277288630604744f;
  t264_n205: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t264_n213;
  t264_n206: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t264_n212;
  t264_n207: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t264_n209;
  t264_n208: return 0.09317463636398315f;
  t264_n209: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t264_n211;
  t264_n210: return 0.10488531738519669f;
  t264_n211: return 0.10686041414737701f;
  t264_n212: return 0.006027278024703264f;
  t264_n213: return -0.02859637327492237f;
  t264_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t264_n218;
  t264_n215: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t264_n217;
  t264_n216: return -0.023889193311333656f;
  t264_n217: return 0.10965083539485931f;
  t264_n218: return 0.13644054532051086f;
  t264_n219: if (E.getNumReferences() >= 3322603520 /*8890.0*/) goto t264_n227;
  t264_n220: if (E.getNumReferences() >= 3320516608 /*7522.0*/) goto t264_n226;
  t264_n221: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t264_n223;
  t264_n222: return -0.2607899010181427f;
  t264_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t264_n225;
  t264_n224: return 0.11279025673866272f;
  t264_n225: return 0.14243820309638977f;
  t264_n226: return -0.06580764055252075f;
  t264_n227: if (E.getNumReferences() >= 3322671104 /*8956.0*/) goto t264_n229;
  t264_n228: return 0.11113855987787247f;
  t264_n229: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t264_n231;
  t264_n230: return -0.1581154614686966f;
  t264_n231: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t264_n233;
  t264_n232: return 0.07029625028371811f;
  t264_n233: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t264_n239;
  t264_n234: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t264_n238;
  t264_n235: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t264_n237;
  t264_n236: return -0.10431382805109024f;
  t264_n237: return 0.10504720360040665f;
  t264_n238: return 0.10906069725751877f;
  t264_n239: return -0.10196453332901001f;
  t264_n240: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t264_n246;
  t264_n241: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t264_n245;
  t264_n242: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t264_n244;
  t264_n243: return -0.01334524154663086f;
  t264_n244: return 0.11777745187282562f;
  t264_n245: return -0.00971667468547821f;
  t264_n246: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t264_n248;
  t264_n247: return 0.010011685080826283f;
  t264_n248: if (E.getNumReferences() >= 3331489536 /*18751.5*/) goto t264_n252;
  t264_n249: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t264_n251;
  t264_n250: return 0.11273820698261261f;
  t264_n251: return -0.06519660353660583f;
  t264_n252: if (E.getNumReferences() >= 3333341184 /*22368.0*/) goto t264_n254;
  t264_n253: return 0.024314939975738525f;
  t264_n254: return -0.006078618578612804f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree265(const Example& E) {
  t265_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t265_n232;
  t265_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t265_n3;
  t265_n2: return -0.0001371461694361642f;
  t265_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t265_n43;
  t265_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t265_n24;
  t265_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t265_n7;
  t265_n6: return -0.05689384043216705f;
  t265_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n11;
  t265_n8: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t265_n10;
  t265_n9: return -0.011340834200382233f;
  t265_n10: return 0.01351480558514595f;
  t265_n11: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t265_n19;
  t265_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t265_n18;
  t265_n13: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t265_n17;
  t265_n14: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t265_n16;
  t265_n15: return -0.06802206486463547f;
  t265_n16: return -1.1481515169143677f;
  t265_n17: return -0.0010421437909826636f;
  t265_n18: return -0.019771572202444077f;
  t265_n19: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t265_n23;
  t265_n20: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t265_n22;
  t265_n21: return 0.0042795455083251f;
  t265_n22: return 0.07770003378391266f;
  t265_n23: return -0.017406756058335304f;
  t265_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n26;
  t265_n25: return -0.01997656747698784f;
  t265_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t265_n28;
  t265_n27: return 0.01847931742668152f;
  t265_n28: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t265_n42;
  t265_n29: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t265_n41;
  t265_n30: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n36;
  t265_n31: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t265_n33;
  t265_n32: return -0.2328079789876938f;
  t265_n33: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t265_n35;
  t265_n34: return 0.0899992287158966f;
  t265_n35: return 0.01858898624777794f;
  t265_n36: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t265_n40;
  t265_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t265_n39;
  t265_n38: return 0.11347991973161697f;
  t265_n39: return -0.3291932940483093f;
  t265_n40: return 0.011169728823006153f;
  t265_n41: return -0.024112431332468987f;
  t265_n42: return 0.06490448117256165f;
  t265_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t265_n135;
  t265_n44: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t265_n48;
  t265_n45: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t265_n47;
  t265_n46: return 0.003509857691824436f;
  t265_n47: return 0.015494339168071747f;
  t265_n48: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t265_n96;
  t265_n49: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t265_n63;
  t265_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n60;
  t265_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t265_n53;
  t265_n52: return -0.00696588447317481f;
  t265_n53: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t265_n55;
  t265_n54: return -0.03294484689831734f;
  t265_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t265_n57;
  t265_n56: return 0.04851873591542244f;
  t265_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t265_n59;
  t265_n58: return -0.1001054123044014f;
  t265_n59: return 0.041041478514671326f;
  t265_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t265_n62;
  t265_n61: return -0.026277143508195877f;
  t265_n62: return 0.004450688604265451f;
  t265_n63: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n73;
  t265_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t265_n66;
  t265_n65: return 0.007965834811329842f;
  t265_n66: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t265_n68;
  t265_n67: return 0.005791411269456148f;
  t265_n68: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t265_n70;
  t265_n69: return 0.0656772181391716f;
  t265_n70: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t265_n72;
  t265_n71: return -0.03358175605535507f;
  t265_n72: return 0.11125696450471878f;
  t265_n73: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t265_n95;
  t265_n74: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t265_n76;
  t265_n75: return -0.018549256026744843f;
  t265_n76: if (E.getNumReferences() >= 3324770304 /*11006.0*/) goto t265_n94;
  t265_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t265_n83;
  t265_n78: if (E.getNumReferences() >= 3298770944 /*1274.0*/) goto t265_n80;
  t265_n79: return -0.03080056793987751f;
  t265_n80: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n82;
  t265_n81: return 0.09984475374221802f;
  t265_n82: return -0.399953693151474f;
  t265_n83: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t265_n89;
  t265_n84: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t265_n86;
  t265_n85: return -0.7000288963317871f;
  t265_n86: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t265_n88;
  t265_n87: return 0.09750567376613617f;
  t265_n88: return 0.11200466752052307f;
  t265_n89: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t265_n91;
  t265_n90: return 0.08423177897930145f;
  t265_n91: if (E.getSymbolScopeDistance() >= 3246391296 /*16.0*/) goto t265_n93;
  t265_n92: return -0.2014145851135254f;
  t265_n93: return 0.05421341210603714f;
  t265_n94: return -0.019702879711985588f;
  t265_n95: return 0.4224223792552948f;
  t265_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t265_n132;
  t265_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t265_n99;
  t265_n98: return -0.024037685245275497f;
  t265_n99: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t265_n101;
  t265_n100: return -0.00846597459167242f;
  t265_n101: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t265_n103;
  t265_n102: return -0.011128704063594341f;
  t265_n103: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t265_n127;
  t265_n104: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t265_n126;
  t265_n105: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t265_n115;
  t265_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t265_n114;
  t265_n107: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t265_n111;
  t265_n108: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t265_n110;
  t265_n109: return 0.08834553509950638f;
  t265_n110: return -0.0371847003698349f;
  t265_n111: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t265_n113;
  t265_n112: return 0.13235172629356384f;
  t265_n113: return 0.01626795157790184f;
  t265_n114: return -0.12506616115570068f;
  t265_n115: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t265_n119;
  t265_n116: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t265_n118;
  t265_n117: return 0.06157601997256279f;
  t265_n118: return 0.09177961945533752f;
  t265_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t265_n121;
  t265_n120: return -0.13045144081115723f;
  t265_n121: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t265_n125;
  t265_n122: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t265_n124;
  t265_n123: return 0.07351258397102356f;
  t265_n124: return 0.11638680845499039f;
  t265_n125: return 0.08588734269142151f;
  t265_n126: return -0.005817297380417585f;
  t265_n127: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t265_n129;
  t265_n128: return -0.05092532932758331f;
  t265_n129: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t265_n131;
  t265_n130: return 0.15725819766521454f;
  t265_n131: return 0.031086064875125885f;
  t265_n132: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t265_n134;
  t265_n133: return 0.0060227252542972565f;
  t265_n134: return 0.010161848738789558f;
  t265_n135: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t265_n225;
  t265_n136: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t265_n200;
  t265_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t265_n163;
  t265_n138: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n140;
  t265_n139: return 0.00890728086233139f;
  t265_n140: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t265_n162;
  t265_n141: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t265_n151;
  t265_n142: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t265_n144;
  t265_n143: return -0.5232328772544861f;
  t265_n144: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t265_n150;
  t265_n145: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t265_n149;
  t265_n146: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t265_n148;
  t265_n147: return 0.10144828259944916f;
  t265_n148: return -0.08403301984071732f;
  t265_n149: return 0.10875600576400757f;
  t265_n150: return -0.036639340221881866f;
  t265_n151: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t265_n161;
  t265_n152: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t265_n158;
  t265_n153: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t265_n155;
  t265_n154: return -0.16690154373645782f;
  t265_n155: if (E.getNumReferences() >= 3238002688 /*8.0*/) goto t265_n157;
  t265_n156: return 0.11948603391647339f;
  t265_n157: return 0.1140751764178276f;
  t265_n158: if (E.getNumReferences() >= 3265396736 /*81.0*/) goto t265_n160;
  t265_n159: return -0.1453748643398285f;
  t265_n160: return 0.09653052687644958f;
  t265_n161: return 0.07052335888147354f;
  t265_n162: return 0.0512433722615242f;
  t265_n163: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t265_n195;
  t265_n164: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t265_n192;
  t265_n165: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t265_n181;
  t265_n166: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t265_n180;
  t265_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t265_n173;
  t265_n168: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n172;
  t265_n169: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t265_n171;
  t265_n170: return 0.04456391930580139f;
  t265_n171: return 0.14676479995250702f;
  t265_n172: return -0.037125542759895325f;
  t265_n173: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t265_n179;
  t265_n174: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n176;
  t265_n175: return -0.11660099774599075f;
  t265_n176: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t265_n178;
  t265_n177: return 0.13377757370471954f;
  t265_n178: return 0.11255265772342682f;
  t265_n179: return 0.07860633730888367f;
  t265_n180: return 0.016493454575538635f;
  t265_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n187;
  t265_n182: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t265_n186;
  t265_n183: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t265_n185;
  t265_n184: return 0.11140128970146179f;
  t265_n185: return 0.10175486654043198f;
  t265_n186: return -0.14002302289009094f;
  t265_n187: if (E.getNumReferences() >= 3233808384 /*6.0*/) goto t265_n189;
  t265_n188: return -0.05833810940384865f;
  t265_n189: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t265_n191;
  t265_n190: return 0.1188209280371666f;
  t265_n191: return 0.04657655954360962f;
  t265_n192: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t265_n194;
  t265_n193: return 0.15614017844200134f;
  t265_n194: return -0.015060569159686565f;
  t265_n195: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t265_n199;
  t265_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t265_n198;
  t265_n197: return 0.10530136525630951f;
  t265_n198: return 0.11089877784252167f;
  t265_n199: return -0.03684954345226288f;
  t265_n200: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t265_n206;
  t265_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t265_n203;
  t265_n202: return -0.019737042486667633f;
  t265_n203: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t265_n205;
  t265_n204: return 0.016320914030075073f;
  t265_n205: return -0.057907834649086f;
  t265_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t265_n216;
  t265_n207: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n209;
  t265_n208: return 0.006648062262684107f;
  t265_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t265_n211;
  t265_n210: return 0.03154253214597702f;
  t265_n211: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t265_n213;
  t265_n212: return -0.024540802463889122f;
  t265_n213: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t265_n215;
  t265_n214: return 0.09710372984409332f;
  t265_n215: return 0.004924481268972158f;
  t265_n216: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n224;
  t265_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t265_n221;
  t265_n218: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n220;
  t265_n219: return 0.047543179243803024f;
  t265_n220: return 0.06132834777235985f;
  t265_n221: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n223;
  t265_n222: return 0.05143539980053902f;
  t265_n223: return 0.012972933240234852f;
  t265_n224: return -0.026353677734732628f;
  t265_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t265_n227;
  t265_n226: return -0.011894289404153824f;
  t265_n227: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n231;
  t265_n228: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t265_n230;
  t265_n229: return 0.051690101623535156f;
  t265_n230: return 0.1032603308558464f;
  t265_n231: return 0.0018094974802806973f;
  t265_n232: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t265_n246;
  t265_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t265_n245;
  t265_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t265_n236;
  t265_n235: return -0.07042880356311798f;
  t265_n236: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n238;
  t265_n237: return -0.09875551611185074f;
  t265_n238: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t265_n242;
  t265_n239: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t265_n241;
  t265_n240: return -0.13491088151931763f;
  t265_n241: return -0.07997286319732666f;
  t265_n242: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t265_n244;
  t265_n243: return 0.010814371518790722f;
  t265_n244: return -0.2477635145187378f;
  t265_n245: return -0.00606003450229764f;
  t265_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t265_n248;
  t265_n247: return -0.024556171149015427f;
  t265_n248: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t265_n252;
  t265_n249: if (E.getNumReferences() >= 3346496384 /*63355.5*/) goto t265_n251;
  t265_n250: return 0.03391391411423683f;
  t265_n251: return 0.0730263814330101f;
  t265_n252: if (E.getNumReferences() >= 3280633856 /*277.0*/) goto t265_n254;
  t265_n253: return -0.02888600528240204f;
  t265_n254: return 0.1347033828496933f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree266(const Example& E) {
  t266_n0: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t266_n210;
  t266_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t266_n209;
  t266_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t266_n84;
  t266_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t266_n83;
  t266_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t266_n32;
  t266_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t266_n17;
  t266_n6: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t266_n14;
  t266_n7: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t266_n13;
  t266_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t266_n10;
  t266_n9: return -0.14294709265232086f;
  t266_n10: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n12;
  t266_n11: return 0.10088977962732315f;
  t266_n12: return 0.013427432626485825f;
  t266_n13: return 0.02961147204041481f;
  t266_n14: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t266_n16;
  t266_n15: return -0.029730452224612236f;
  t266_n16: return 0.11302733421325684f;
  t266_n17: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t266_n31;
  t266_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t266_n22;
  t266_n19: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t266_n21;
  t266_n20: return -0.08688316494226456f;
  t266_n21: return -0.1637892872095108f;
  t266_n22: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t266_n24;
  t266_n23: return -0.016927268356084824f;
  t266_n24: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t266_n26;
  t266_n25: return 0.01928785815834999f;
  t266_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t266_n30;
  t266_n27: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t266_n29;
  t266_n28: return 0.10991144925355911f;
  t266_n29: return 0.09388848394155502f;
  t266_n30: return 0.11938928812742233f;
  t266_n31: return 0.0020454612094908953f;
  t266_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t266_n60;
  t266_n33: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t266_n57;
  t266_n34: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t266_n36;
  t266_n35: return -0.11465691775083542f;
  t266_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n42;
  t266_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t266_n39;
  t266_n38: return 0.01716517098248005f;
  t266_n39: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t266_n41;
  t266_n40: return 0.5093629360198975f;
  t266_n41: return -0.061838164925575256f;
  t266_n42: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t266_n56;
  t266_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t266_n47;
  t266_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t266_n46;
  t266_n45: return 0.10999688506126404f;
  t266_n46: return 0.1058567464351654f;
  t266_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t266_n55;
  t266_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t266_n50;
  t266_n49: return -0.15749487280845642f;
  t266_n50: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t266_n54;
  t266_n51: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t266_n53;
  t266_n52: return 0.14928261935710907f;
  t266_n53: return 0.09312749654054642f;
  t266_n54: return 0.23075444996356964f;
  t266_n55: return 0.11347155272960663f;
  t266_n56: return -0.07885421812534332f;
  t266_n57: if (E.getSymbolScopeDistance() >= 3245342720 /*15.0*/) goto t266_n59;
  t266_n58: return 0.007039055228233337f;
  t266_n59: return -0.03522808477282524f;
  t266_n60: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t266_n78;
  t266_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t266_n63;
  t266_n62: return -0.034878090023994446f;
  t266_n63: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t266_n77;
  t266_n64: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t266_n66;
  t266_n65: return 0.05575264245271683f;
  t266_n66: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t266_n76;
  t266_n67: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t266_n75;
  t266_n68: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t266_n72;
  t266_n69: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t266_n71;
  t266_n70: return 0.10779924690723419f;
  t266_n71: return 0.100611612200737f;
  t266_n72: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t266_n74;
  t266_n73: return 0.07133070379495621f;
  t266_n74: return 0.08837002515792847f;
  t266_n75: return -0.11478453129529953f;
  t266_n76: return 0.04260038584470749f;
  t266_n77: return -0.017040370032191277f;
  t266_n78: if (E.getNumReferences() >= 3310286848 /*3311.5*/) goto t266_n80;
  t266_n79: return -0.025617072358727455f;
  t266_n80: if (E.getNumReferences() >= 3311058944 /*3500.0*/) goto t266_n82;
  t266_n81: return 0.12177680432796478f;
  t266_n82: return 0.033024322241544724f;
  t266_n83: return -0.03929354250431061f;
  t266_n84: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t266_n86;
  t266_n85: return -0.011878753080964088f;
  t266_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t266_n208;
  t266_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t266_n153;
  t266_n88: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t266_n90;
  t266_n89: return -0.01302577555179596f;
  t266_n90: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t266_n136;
  t266_n91: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t266_n135;
  t266_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t266_n110;
  t266_n93: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t266_n109;
  t266_n94: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n108;
  t266_n95: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t266_n99;
  t266_n96: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t266_n98;
  t266_n97: return 0.012964945286512375f;
  t266_n98: return 0.07942113280296326f;
  t266_n99: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t266_n103;
  t266_n100: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t266_n102;
  t266_n101: return 0.12192396074533463f;
  t266_n102: return 0.10331454128026962f;
  t266_n103: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t266_n105;
  t266_n104: return 0.11020481586456299f;
  t266_n105: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t266_n107;
  t266_n106: return 0.01262042298913002f;
  t266_n107: return 0.08793377876281738f;
  t266_n108: return 0.005661584436893463f;
  t266_n109: return -0.1490388810634613f;
  t266_n110: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t266_n126;
  t266_n111: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t266_n125;
  t266_n112: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n124;
  t266_n113: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t266_n117;
  t266_n114: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t266_n116;
  t266_n115: return 0.104563869535923f;
  t266_n116: return 0.060001689940690994f;
  t266_n117: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t266_n119;
  t266_n118: return 0.02975262887775898f;
  t266_n119: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t266_n121;
  t266_n120: return 0.12490660697221756f;
  t266_n121: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t266_n123;
  t266_n122: return 0.12677742540836334f;
  t266_n123: return 0.060475364327430725f;
  t266_n124: return -0.021840736269950867f;
  t266_n125: return 0.006797381676733494f;
  t266_n126: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t266_n134;
  t266_n127: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t266_n129;
  t266_n128: return 0.09077988564968109f;
  t266_n129: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n131;
  t266_n130: return -0.37304773926734924f;
  t266_n131: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t266_n133;
  t266_n132: return 0.12652993202209473f;
  t266_n133: return -0.10135935246944427f;
  t266_n134: return -0.21244792640209198f;
  t266_n135: return -0.0031839795410633087f;
  t266_n136: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t266_n144;
  t266_n137: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t266_n139;
  t266_n138: return -0.0005539284902624786f;
  t266_n139: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t266_n141;
  t266_n140: return 0.0371597483754158f;
  t266_n141: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t266_n143;
  t266_n142: return 0.1230822205543518f;
  t266_n143: return 0.1046779602766037f;
  t266_n144: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t266_n152;
  t266_n145: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t266_n147;
  t266_n146: return -0.0601884201169014f;
  t266_n147: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t266_n151;
  t266_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n150;
  t266_n149: return 0.11954007297754288f;
  t266_n150: return -0.10030949860811234f;
  t266_n151: return -0.655197024345398f;
  t266_n152: return 0.005224030464887619f;
  t266_n153: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t266_n187;
  t266_n154: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t266_n176;
  t266_n155: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t266_n165;
  t266_n156: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t266_n164;
  t266_n157: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t266_n159;
  t266_n158: return -0.49875301122665405f;
  t266_n159: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t266_n161;
  t266_n160: return 0.14243264496326447f;
  t266_n161: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t266_n163;
  t266_n162: return 0.09521451592445374f;
  t266_n163: return 0.08396031707525253f;
  t266_n164: return -0.0022505908273160458f;
  t266_n165: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t266_n167;
  t266_n166: return 0.0945003554224968f;
  t266_n167: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t266_n169;
  t266_n168: return -0.04641703888773918f;
  t266_n169: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t266_n175;
  t266_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t266_n172;
  t266_n171: return 0.09380719065666199f;
  t266_n172: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n174;
  t266_n173: return 0.0831466093659401f;
  t266_n174: return -0.31045278906822205f;
  t266_n175: return 0.16744115948677063f;
  t266_n176: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t266_n178;
  t266_n177: return -0.0011936655500903726f;
  t266_n178: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n186;
  t266_n179: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t266_n185;
  t266_n180: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t266_n184;
  t266_n181: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t266_n183;
  t266_n182: return 0.01591135561466217f;
  t266_n183: return 0.031789518892765045f;
  t266_n184: return 0.07216043025255203f;
  t266_n185: return -0.05311813950538635f;
  t266_n186: return 0.007313149981200695f;
  t266_n187: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t266_n191;
  t266_n188: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t266_n190;
  t266_n189: return -0.57929527759552f;
  t266_n190: return -0.12149791419506073f;
  t266_n191: if (E.getNumReferences() >= 3333794048 /*23252.5*/) goto t266_n193;
  t266_n192: return -0.004645606502890587f;
  t266_n193: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t266_n199;
  t266_n194: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t266_n196;
  t266_n195: return 0.09142494946718216f;
  t266_n196: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n198;
  t266_n197: return -0.04152899980545044f;
  t266_n198: return 0.1133054792881012f;
  t266_n199: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t266_n201;
  t266_n200: return -0.004853356163948774f;
  t266_n201: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t266_n205;
  t266_n202: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t266_n204;
  t266_n203: return 0.08177496492862701f;
  t266_n204: return -0.05945603922009468f;
  t266_n205: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t266_n207;
  t266_n206: return 0.08852601051330566f;
  t266_n207: return 0.03886756673455238f;
  t266_n208: return 0.06297758966684341f;
  t266_n209: return 0.0008832048624753952f;
  t266_n210: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t266_n212;
  t266_n211: return -0.0005072267958894372f;
  t266_n212: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t266_n216;
  t266_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t266_n215;
  t266_n214: return -0.10533810406923294f;
  t266_n215: return 0.003187097841873765f;
  t266_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t266_n248;
  t266_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n221;
  t266_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t266_n220;
  t266_n219: return -0.015085973776876926f;
  t266_n220: return 0.02133808098733425f;
  t266_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t266_n235;
  t266_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t266_n228;
  t266_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t266_n227;
  t266_n224: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t266_n226;
  t266_n225: return -0.018900888040661812f;
  t266_n226: return 0.03615214303135872f;
  t266_n227: return -0.0067928205244243145f;
  t266_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t266_n230;
  t266_n229: return 0.002777441870421171f;
  t266_n230: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t266_n232;
  t266_n231: return 0.00033731688745319843f;
  t266_n232: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t266_n234;
  t266_n233: return 0.02908875234425068f;
  t266_n234: return -0.0044554173946380615f;
  t266_n235: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t266_n247;
  t266_n236: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t266_n242;
  t266_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t266_n241;
  t266_n238: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t266_n240;
  t266_n239: return -0.3054511547088623f;
  t266_n240: return 0.03397975116968155f;
  t266_n241: return 0.029757961630821228f;
  t266_n242: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t266_n244;
  t266_n243: return -0.001966611947864294f;
  t266_n244: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t266_n246;
  t266_n245: return 0.03163072094321251f;
  t266_n246: return 0.05684802681207657f;
  t266_n247: return 0.020146099850535393f;
  t266_n248: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t266_n254;
  t266_n249: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t266_n253;
  t266_n250: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t266_n252;
  t266_n251: return 0.0755566880106926f;
  t266_n252: return 0.0409579761326313f;
  t266_n253: return 0.044757578521966934f;
  t266_n254: return -0.007000420242547989f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree267(const Example& E) {
  t267_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t267_n24;
  t267_n1: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t267_n3;
  t267_n2: return -0.002730569802224636f;
  t267_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t267_n13;
  t267_n4: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t267_n12;
  t267_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t267_n9;
  t267_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t267_n8;
  t267_n7: return 0.006117536686360836f;
  t267_n8: return -0.003720036707818508f;
  t267_n9: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t267_n11;
  t267_n10: return 0.024979455396533012f;
  t267_n11: return 0.0031269621104002f;
  t267_n12: return -0.014078921638429165f;
  t267_n13: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t267_n23;
  t267_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t267_n16;
  t267_n15: return 0.011423279531300068f;
  t267_n16: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t267_n22;
  t267_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t267_n19;
  t267_n18: return 0.026948057115077972f;
  t267_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n21;
  t267_n20: return 0.09575028717517853f;
  t267_n21: return -0.012823281809687614f;
  t267_n22: return 0.04519057273864746f;
  t267_n23: return -0.05055035278201103f;
  t267_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t267_n124;
  t267_n25: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t267_n123;
  t267_n26: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t267_n70;
  t267_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown))) goto t267_n49;
  t267_n28: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t267_n30;
  t267_n29: return -0.00751735782250762f;
  t267_n30: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t267_n48;
  t267_n31: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n45;
  t267_n32: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t267_n36;
  t267_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t267_n35;
  t267_n34: return -0.18042980134487152f;
  t267_n35: return 0.09404150396585464f;
  t267_n36: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t267_n38;
  t267_n37: return 0.10694333910942078f;
  t267_n38: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t267_n40;
  t267_n39: return -0.030170345678925514f;
  t267_n40: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t267_n42;
  t267_n41: return 0.09568189084529877f;
  t267_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t267_n44;
  t267_n43: return -1.5909855365753174f;
  t267_n44: return 0.11153572052717209f;
  t267_n45: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t267_n47;
  t267_n46: return 0.007441780064254999f;
  t267_n47: return 0.10804763436317444f;
  t267_n48: return 0.0026016782503575087f;
  t267_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t267_n55;
  t267_n50: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t267_n52;
  t267_n51: return -0.09421028196811676f;
  t267_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t267_n54;
  t267_n53: return -0.03473619744181633f;
  t267_n54: return 0.0020302394405007362f;
  t267_n55: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n69;
  t267_n56: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t267_n62;
  t267_n57: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t267_n61;
  t267_n58: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t267_n60;
  t267_n59: return -0.739951491355896f;
  t267_n60: return -0.0025486210361123085f;
  t267_n61: return 0.022778989747166634f;
  t267_n62: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t267_n64;
  t267_n63: return 0.017482386901974678f;
  t267_n64: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t267_n66;
  t267_n65: return -0.10475537180900574f;
  t267_n66: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t267_n68;
  t267_n67: return 0.07093636691570282f;
  t267_n68: return -0.12669728696346283f;
  t267_n69: return 0.004511814098805189f;
  t267_n70: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t267_n72;
  t267_n71: return -0.06121326982975006f;
  t267_n72: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t267_n80;
  t267_n73: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t267_n75;
  t267_n74: return -0.00648330757394433f;
  t267_n75: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t267_n77;
  t267_n76: return 0.0012188851833343506f;
  t267_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t267_n79;
  t267_n78: return -0.07786449790000916f;
  t267_n79: return -0.005256766453385353f;
  t267_n80: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t267_n110;
  t267_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t267_n83;
  t267_n82: return -0.015454304404556751f;
  t267_n83: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t267_n95;
  t267_n84: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t267_n94;
  t267_n85: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t267_n93;
  t267_n86: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t267_n92;
  t267_n87: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t267_n89;
  t267_n88: return -0.10166620463132858f;
  t267_n89: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t267_n91;
  t267_n90: return 0.14712435007095337f;
  t267_n91: return 0.08367172628641129f;
  t267_n92: return -0.09763524681329727f;
  t267_n93: return 0.12748391926288605f;
  t267_n94: return 0.04270947352051735f;
  t267_n95: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t267_n97;
  t267_n96: return 0.0139304893091321f;
  t267_n97: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t267_n105;
  t267_n98: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t267_n100;
  t267_n99: return 0.01747273840010166f;
  t267_n100: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t267_n104;
  t267_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_DotMemberAccess))) goto t267_n103;
  t267_n102: return 0.01913519576191902f;
  t267_n103: return 0.11421047151088715f;
  t267_n104: return 0.00743847107514739f;
  t267_n105: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t267_n109;
  t267_n106: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t267_n108;
  t267_n107: return 0.06141616031527519f;
  t267_n108: return 0.137796550989151f;
  t267_n109: return 0.07819042354822159f;
  t267_n110: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t267_n112;
  t267_n111: return 0.001149671385064721f;
  t267_n112: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t267_n114;
  t267_n113: return -0.008888984099030495f;
  t267_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t267_n122;
  t267_n115: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t267_n117;
  t267_n116: return -0.005340272095054388f;
  t267_n117: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t267_n119;
  t267_n118: return 0.06973452121019363f;
  t267_n119: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t267_n121;
  t267_n120: return 0.1168174296617508f;
  t267_n121: return 0.12623755633831024f;
  t267_n122: return 0.012326105497777462f;
  t267_n123: return 0.0059222010895609856f;
  t267_n124: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t267_n192;
  t267_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t267_n127;
  t267_n126: return 0.0014059861423447728f;
  t267_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t267_n191;
  t267_n128: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t267_n144;
  t267_n129: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t267_n143;
  t267_n130: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t267_n132;
  t267_n131: return 0.015766004100441933f;
  t267_n132: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t267_n142;
  t267_n133: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t267_n139;
  t267_n134: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n138;
  t267_n135: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t267_n137;
  t267_n136: return 0.05822988599538803f;
  t267_n137: return 0.008067110553383827f;
  t267_n138: return -0.0133872851729393f;
  t267_n139: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t267_n141;
  t267_n140: return 0.10918322205543518f;
  t267_n141: return 0.018655380234122276f;
  t267_n142: return -0.009402510710060596f;
  t267_n143: return 0.007118739653378725f;
  t267_n144: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t267_n182;
  t267_n145: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t267_n181;
  t267_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n154;
  t267_n147: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t267_n153;
  t267_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t267_n150;
  t267_n149: return 0.006014605052769184f;
  t267_n150: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t267_n152;
  t267_n151: return 0.025602729991078377f;
  t267_n152: return -0.10169610381126404f;
  t267_n153: return -0.2112884372472763f;
  t267_n154: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t267_n172;
  t267_n155: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t267_n171;
  t267_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t267_n160;
  t267_n157: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t267_n159;
  t267_n158: return 0.13524498045444489f;
  t267_n159: return 0.0389166995882988f;
  t267_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t267_n162;
  t267_n161: return -0.010335388593375683f;
  t267_n162: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t267_n170;
  t267_n163: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t267_n169;
  t267_n164: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t267_n168;
  t267_n165: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t267_n167;
  t267_n166: return 0.1227855309844017f;
  t267_n167: return 0.1252421736717224f;
  t267_n168: return 0.07460103929042816f;
  t267_n169: return 0.04826226085424423f;
  t267_n170: return 0.00745236175134778f;
  t267_n171: return 0.11819060146808624f;
  t267_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t267_n180;
  t267_n173: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t267_n179;
  t267_n174: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t267_n176;
  t267_n175: return -0.022660044953227043f;
  t267_n176: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t267_n178;
  t267_n177: return -0.19346536695957184f;
  t267_n178: return -0.2893243730068207f;
  t267_n179: return -0.02203275077044964f;
  t267_n180: return -0.005770217161625624f;
  t267_n181: return -0.03246968984603882f;
  t267_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t267_n188;
  t267_n183: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n185;
  t267_n184: return 0.0516987070441246f;
  t267_n185: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t267_n187;
  t267_n186: return -0.040929120033979416f;
  t267_n187: return 0.04275303706526756f;
  t267_n188: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n190;
  t267_n189: return 0.04152324050664902f;
  t267_n190: return 0.014024495147168636f;
  t267_n191: return 0.02364920638501644f;
  t267_n192: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t267_n246;
  t267_n193: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t267_n243;
  t267_n194: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t267_n214;
  t267_n195: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t267_n213;
  t267_n196: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t267_n210;
  t267_n197: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t267_n203;
  t267_n198: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t267_n200;
  t267_n199: return -0.01013268157839775f;
  t267_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n202;
  t267_n201: return -0.08562622964382172f;
  t267_n202: return -0.010732363909482956f;
  t267_n203: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t267_n209;
  t267_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t267_n208;
  t267_n205: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t267_n207;
  t267_n206: return -0.05327858775854111f;
  t267_n207: return -0.19704501330852509f;
  t267_n208: return 0.011282887309789658f;
  t267_n209: return 0.028765013441443443f;
  t267_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t267_n212;
  t267_n211: return 0.03440432250499725f;
  t267_n212: return 0.11004232615232468f;
  t267_n213: return -0.02932683378458023f;
  t267_n214: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t267_n216;
  t267_n215: return 0.04292680695652962f;
  t267_n216: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t267_n242;
  t267_n217: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t267_n225;
  t267_n218: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t267_n224;
  t267_n219: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t267_n221;
  t267_n220: return -0.10767380148172379f;
  t267_n221: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t267_n223;
  t267_n222: return 0.1373744159936905f;
  t267_n223: return -0.10859548300504684f;
  t267_n224: return 0.15752655267715454f;
  t267_n225: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t267_n241;
  t267_n226: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t267_n236;
  t267_n227: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t267_n229;
  t267_n228: return -0.2525063753128052f;
  t267_n229: if (E.getNumReferences() >= 3294322688 /*877.5*/) goto t267_n235;
  t267_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t267_n232;
  t267_n231: return 0.05846020206809044f;
  t267_n232: if (E.getNumReferences() >= 3276865536 /*209.0*/) goto t267_n234;
  t267_n233: return 0.05861712992191315f;
  t267_n234: return 0.09737909585237503f;
  t267_n235: return 0.19841724634170532f;
  t267_n236: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t267_n238;
  t267_n237: return 0.09201841801404953f;
  t267_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t267_n240;
  t267_n239: return -0.6524826288223267f;
  t267_n240: return 0.08837790787220001f;
  t267_n241: return 0.02202451415359974f;
  t267_n242: return 0.11856492608785629f;
  t267_n243: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t267_n245;
  t267_n244: return 0.008546704426407814f;
  t267_n245: return -0.01784767396748066f;
  t267_n246: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t267_n248;
  t267_n247: return -0.013879799284040928f;
  t267_n248: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t267_n250;
  t267_n249: return 0.03150663524866104f;
  t267_n250: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t267_n252;
  t267_n251: return -0.013382741250097752f;
  t267_n252: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t267_n254;
  t267_n253: return 0.22632654011249542f;
  t267_n254: return 0.16827067732810974f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree268(const Example& E) {
  t268_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t268_n2;
  t268_n1: return -0.00032464246032759547f;
  t268_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t268_n70;
  t268_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t268_n41;
  t268_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t268_n6;
  t268_n5: return 0.0031567257829010487f;
  t268_n6: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t268_n28;
  t268_n7: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t268_n17;
  t268_n8: if (E.getNumReferences() >= 3284926464 /*408.0*/) goto t268_n10;
  t268_n9: return -0.6578812003135681f;
  t268_n10: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t268_n12;
  t268_n11: return -0.03878534585237503f;
  t268_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t268_n16;
  t268_n13: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t268_n15;
  t268_n14: return 0.07608432322740555f;
  t268_n15: return -0.027123969048261642f;
  t268_n16: return 0.09240173548460007f;
  t268_n17: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t268_n25;
  t268_n18: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t268_n20;
  t268_n19: return 0.019269365817308426f;
  t268_n20: if (E.getNumReferences() >= 3288489984 /*521.5*/) goto t268_n22;
  t268_n21: return 0.11535605043172836f;
  t268_n22: if (E.getNumReferences() >= 3295059968 /*922.5*/) goto t268_n24;
  t268_n23: return -0.22041882574558258f;
  t268_n24: return 0.09410280734300613f;
  t268_n25: if (E.getNumReferences() >= 3291029504 /*676.5*/) goto t268_n27;
  t268_n26: return 0.12250266224145889f;
  t268_n27: return 0.28383252024650574f;
  t268_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t268_n32;
  t268_n29: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t268_n31;
  t268_n30: return 0.014463038183748722f;
  t268_n31: return -0.14452964067459106f;
  t268_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t268_n38;
  t268_n33: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t268_n35;
  t268_n34: return -0.23244693875312805f;
  t268_n35: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t268_n37;
  t268_n36: return 0.011674950830638409f;
  t268_n37: return 0.07604878395795822f;
  t268_n38: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t268_n40;
  t268_n39: return 0.09336821734905243f;
  t268_n40: return 0.0707482174038887f;
  t268_n41: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t268_n69;
  t268_n42: if (E.getNumReferences() >= 3297431552 /*1110.5*/) goto t268_n68;
  t268_n43: if (E.getNumReferences() >= 3297333248 /*1098.5*/) goto t268_n67;
  t268_n44: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t268_n60;
  t268_n45: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t268_n47;
  t268_n46: return 0.01179643627256155f;
  t268_n47: if (E.getNumReferences() >= 3285057536 /*412.0*/) goto t268_n49;
  t268_n48: return -0.19174805283546448f;
  t268_n49: if (E.getNumReferences() >= 3286433792 /*454.0*/) goto t268_n53;
  t268_n50: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t268_n52;
  t268_n51: return 0.11552780866622925f;
  t268_n52: return 0.08842921257019043f;
  t268_n53: if (E.getNumReferences() >= 3292299264 /*754.0*/) goto t268_n55;
  t268_n54: return 0.03138609975576401f;
  t268_n55: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t268_n59;
  t268_n56: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t268_n58;
  t268_n57: return 0.10328803956508636f;
  t268_n58: return 0.12684151530265808f;
  t268_n59: return -0.008324316702783108f;
  t268_n60: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t268_n64;
  t268_n61: if (E.getNumReferences() >= 3285794816 /*434.5*/) goto t268_n63;
  t268_n62: return 0.09802622348070145f;
  t268_n63: return -0.04859844595193863f;
  t268_n64: if (E.getNumReferences() >= 3292962816 /*794.5*/) goto t268_n66;
  t268_n65: return 0.10428232699632645f;
  t268_n66: return 0.056869298219680786f;
  t268_n67: return 0.10201174765825272f;
  t268_n68: return -0.035544198006391525f;
  t268_n69: return 0.09714686125516891f;
  t268_n70: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t268_n124;
  t268_n71: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t268_n75;
  t268_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t268_n74;
  t268_n73: return -0.06509137898683548f;
  t268_n74: return -0.011312219314277172f;
  t268_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t268_n77;
  t268_n76: return 0.0018927183700725436f;
  t268_n77: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t268_n87;
  t268_n78: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t268_n80;
  t268_n79: return 0.13695821166038513f;
  t268_n80: if (E.getNumReferences() >= 3287154688 /*476.0*/) goto t268_n82;
  t268_n81: return 0.13538393378257751f;
  t268_n82: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t268_n84;
  t268_n83: return 0.1187051311135292f;
  t268_n84: if (E.getNumReferences() >= 3304493056 /*1972.5*/) goto t268_n86;
  t268_n85: return -0.143084317445755f;
  t268_n86: return 0.10483860969543457f;
  t268_n87: if (E.getNumReferences() >= 3325700096 /*11914.0*/) goto t268_n105;
  t268_n88: if (E.getNumReferences() >= 3315857408 /*5247.0*/) goto t268_n104;
  t268_n89: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t268_n91;
  t268_n90: return 0.005088873207569122f;
  t268_n91: if (E.getNumReferences() >= 3307923456 /*2734.5*/) goto t268_n95;
  t268_n92: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t268_n94;
  t268_n93: return 0.030952295288443565f;
  t268_n94: return 0.08931917697191238f;
  t268_n95: if (E.getNumReferences() >= 3308326912 /*2833.0*/) goto t268_n97;
  t268_n96: return 0.10859324038028717f;
  t268_n97: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t268_n103;
  t268_n98: if (E.getNumReferences() >= 3313381376 /*4067.0*/) goto t268_n102;
  t268_n99: if (E.getNumReferences() >= 3310929920 /*3468.5*/) goto t268_n101;
  t268_n100: return 0.10300324857234955f;
  t268_n101: return 0.11049765348434448f;
  t268_n102: return 0.08218292146921158f;
  t268_n103: return 0.05913146957755089f;
  t268_n104: return -0.03755826875567436f;
  t268_n105: if (E.getNumReferences() >= 3327105024 /*13286.0*/) goto t268_n121;
  t268_n106: if (E.getNumReferences() >= 3327053312 /*13235.5*/) goto t268_n116;
  t268_n107: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t268_n111;
  t268_n108: if (E.getNumReferences() >= 3325825536 /*12036.5*/) goto t268_n110;
  t268_n109: return 0.31848445534706116f;
  t268_n110: return 0.010723716579377651f;
  t268_n111: if (E.getNumReferences() >= 3326541312 /*12735.5*/) goto t268_n113;
  t268_n112: return -0.08969324082136154f;
  t268_n113: if (E.getNumReferences() >= 3326876672 /*13063.0*/) goto t268_n115;
  t268_n114: return 0.09309361129999161f;
  t268_n115: return 0.047620609402656555f;
  t268_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t268_n118;
  t268_n117: return 0.37172871828079224f;
  t268_n118: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t268_n120;
  t268_n119: return 0.11438488215208054f;
  t268_n120: return 0.009297979064285755f;
  t268_n121: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t268_n123;
  t268_n122: return 0.018634820356965065f;
  t268_n123: return 0.10009732842445374f;
  t268_n124: if (E.getNumReferences() >= 3284516864 /*395.5*/) goto t268_n128;
  t268_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t268_n127;
  t268_n126: return -0.20185315608978271f;
  t268_n127: return 0.10417396575212479f;
  t268_n128: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t268_n130;
  t268_n129: return 0.005523754749447107f;
  t268_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t268_n254;
  t268_n131: if (E.getNumReferences() >= 3286646784 /*460.5*/) goto t268_n145;
  t268_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t268_n136;
  t268_n133: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t268_n135;
  t268_n134: return -0.29011911153793335f;
  t268_n135: return -0.10366718471050262f;
  t268_n136: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t268_n144;
  t268_n137: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t268_n139;
  t268_n138: return 0.12702856957912445f;
  t268_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t268_n143;
  t268_n140: if (E.getNumReferences() >= 3285663744 /*430.5*/) goto t268_n142;
  t268_n141: return 0.08045675605535507f;
  t268_n142: return -0.6512492299079895f;
  t268_n143: return 0.07674819231033325f;
  t268_n144: return -0.4537450671195984f;
  t268_n145: if (E.getNumReferences() >= 3286712320 /*462.5*/) goto t268_n147;
  t268_n146: return 0.10219712555408478f;
  t268_n147: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t268_n237;
  t268_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t268_n208;
  t268_n149: if (E.getNumReferences() >= 3300311040 /*1462.0*/) goto t268_n207;
  t268_n150: if (E.getNumReferences() >= 3299819520 /*1402.0*/) goto t268_n204;
  t268_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t268_n175;
  t268_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t268_n166;
  t268_n153: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t268_n161;
  t268_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t268_n156;
  t268_n155: return -1.0112189054489136f;
  t268_n156: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t268_n158;
  t268_n157: return 0.04783685877919197f;
  t268_n158: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t268_n160;
  t268_n159: return -0.7479925155639648f;
  t268_n160: return -0.12785771489143372f;
  t268_n161: if (E.getNumReferences() >= 3288473600 /*520.5*/) goto t268_n163;
  t268_n162: return 0.10037891566753387f;
  t268_n163: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t268_n165;
  t268_n164: return -0.09889526665210724f;
  t268_n165: return 0.08101922273635864f;
  t268_n166: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t268_n168;
  t268_n167: return -0.1054157093167305f;
  t268_n168: if (E.getNumReferences() >= 3291308032 /*693.5*/) goto t268_n170;
  t268_n169: return -0.31096163392066956f;
  t268_n170: if (E.getNumReferences() >= 3294150656 /*867.0*/) goto t268_n172;
  t268_n171: return 0.11556235700845718f;
  t268_n172: if (E.getNumReferences() >= 3297222656 /*1085.0*/) goto t268_n174;
  t268_n173: return -0.0024039228446781635f;
  t268_n174: return 0.13142022490501404f;
  t268_n175: if (E.getNumReferences() >= 3294748672 /*903.5*/) goto t268_n191;
  t268_n176: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t268_n188;
  t268_n177: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t268_n179;
  t268_n178: return 0.09385652840137482f;
  t268_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t268_n187;
  t268_n180: if (E.getNumReferences() >= 3290759168 /*660.0*/) goto t268_n184;
  t268_n181: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t268_n183;
  t268_n182: return -1.4555426836013794f;
  t268_n183: return -0.5778682231903076f;
  t268_n184: if (E.getNumReferences() >= 3292045312 /*738.5*/) goto t268_n186;
  t268_n185: return 0.11436174064874649f;
  t268_n186: return -0.09089936316013336f;
  t268_n187: return 0.06500755250453949f;
  t268_n188: if (E.getNumReferences() >= 3289456640 /*580.5*/) goto t268_n190;
  t268_n189: return 0.0861348956823349f;
  t268_n190: return 0.04384274780750275f;
  t268_n191: if (E.getNumReferences() >= 3296256000 /*995.5*/) goto t268_n195;
  t268_n192: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t268_n194;
  t268_n193: return 0.14407701790332794f;
  t268_n194: return -0.06092308461666107f;
  t268_n195: if (E.getNumReferences() >= 3299012608 /*1303.5*/) goto t268_n203;
  t268_n196: if (E.getNumReferences() >= 3298086912 /*1190.5*/) goto t268_n200;
  t268_n197: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t268_n199;
  t268_n198: return -0.08434034883975983f;
  t268_n199: return 0.07405632734298706f;
  t268_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t268_n202;
  t268_n201: return 0.060237180441617966f;
  t268_n202: return 0.11272060126066208f;
  t268_n203: return -0.8447687029838562f;
  t268_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t268_n206;
  t268_n205: return -0.18846282362937927f;
  t268_n206: return 0.11502334475517273f;
  t268_n207: return 0.027011973783373833f;
  t268_n208: if (E.getNumReferences() >= 3287056384 /*473.0*/) goto t268_n212;
  t268_n209: if (E.getNumReferences() >= 3286990848 /*471.0*/) goto t268_n211;
  t268_n210: return -0.28904688358306885f;
  t268_n211: return 0.12228931486606598f;
  t268_n212: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t268_n218;
  t268_n213: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t268_n217;
  t268_n214: if (E.getNumReferences() >= 3293315072 /*816.0*/) goto t268_n216;
  t268_n215: return 0.07909034192562103f;
  t268_n216: return 0.00168310955632478f;
  t268_n217: return 0.009982336312532425f;
  t268_n218: if (E.getNumReferences() >= 3365715136 /*320998.0*/) goto t268_n236;
  t268_n219: if (E.getNumReferences() >= 3319939072 /*7240.0*/) goto t268_n235;
  t268_n220: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t268_n224;
  t268_n221: if (E.getNumReferences() >= 3316105216 /*5368.0*/) goto t268_n223;
  t268_n222: return -0.055297333747148514f;
  t268_n223: return -0.36092275381088257f;
  t268_n224: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t268_n232;
  t268_n225: if (E.getNumReferences() >= 3309293568 /*3069.0*/) goto t268_n227;
  t268_n226: return -0.08625443279743195f;
  t268_n227: if (E.getNumReferences() >= 3311069184 /*3502.5*/) goto t268_n229;
  t268_n228: return 0.1162247285246849f;
  t268_n229: if (E.getNumReferences() >= 3315866624 /*5251.5*/) goto t268_n231;
  t268_n230: return -0.10190063714981079f;
  t268_n231: return 0.07531154155731201f;
  t268_n232: if (E.getNumReferences() >= 3290120192 /*621.0*/) goto t268_n234;
  t268_n233: return 0.07162890583276749f;
  t268_n234: return 0.0017244991613551974f;
  t268_n235: return 0.00568772666156292f;
  t268_n236: return 0.09786694496870041f;
  t268_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t268_n249;
  t268_n238: if (E.getNumReferences() >= 3297067008 /*1066.0*/) goto t268_n246;
  t268_n239: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t268_n243;
  t268_n240: if (E.getNumReferences() >= 3294601216 /*894.5*/) goto t268_n242;
  t268_n241: return -0.24455250799655914f;
  t268_n242: return -3.696253538131714f;
  t268_n243: if (E.getNumReferences() >= 3296575488 /*1015.0*/) goto t268_n245;
  t268_n244: return -0.07872742414474487f;
  t268_n245: return -1.4604294300079346f;
  t268_n246: if (E.getNumReferences() >= 3297263616 /*1090.0*/) goto t268_n248;
  t268_n247: return 0.09459394961595535f;
  t268_n248: return 0.0019574682228267193f;
  t268_n249: if (E.getNumReferences() >= 3289088000 /*558.0*/) goto t268_n253;
  t268_n250: if (E.getNumReferences() >= 3288530944 /*524.0*/) goto t268_n252;
  t268_n251: return 0.0973275750875473f;
  t268_n252: return 0.1468123346567154f;
  t268_n253: return 0.022298011928796768f;
  t268_n254: return 0.10968631505966187f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree269(const Example& E) {
  t269_n0: if (E.getNumReferences() >= 3320122368 /*7329.5*/) goto t269_n2;
  t269_n1: return -0.00024920282885432243f;
  t269_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t269_n20;
  t269_n3: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t269_n7;
  t269_n4: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t269_n6;
  t269_n5: return 0.10481611639261246f;
  t269_n6: return 0.01041041873395443f;
  t269_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t269_n9;
  t269_n8: return -0.0057387156412005424f;
  t269_n9: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t269_n19;
  t269_n10: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t269_n18;
  t269_n11: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t269_n13;
  t269_n12: return -0.202397882938385f;
  t269_n13: if (E.getNumReferences() >= 3338025472 /*31517.0*/) goto t269_n17;
  t269_n14: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n16;
  t269_n15: return 0.14676102995872498f;
  t269_n16: return -0.04379652440547943f;
  t269_n17: return -0.06081049516797066f;
  t269_n18: return 0.037269238382577896f;
  t269_n19: return 0.008097292855381966f;
  t269_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t269_n32;
  t269_n21: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t269_n23;
  t269_n22: return -0.032231781631708145f;
  t269_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t269_n25;
  t269_n24: return 0.08527535945177078f;
  t269_n25: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t269_n31;
  t269_n26: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t269_n30;
  t269_n27: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t269_n29;
  t269_n28: return 0.0669204592704773f;
  t269_n29: return 0.02943088486790657f;
  t269_n30: return 0.08245760947465897f;
  t269_n31: return 0.01469360664486885f;
  t269_n32: if (E.getNumReferences() >= 3322934784 /*9213.5*/) goto t269_n180;
  t269_n33: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t269_n159;
  t269_n34: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t269_n120;
  t269_n35: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t269_n37;
  t269_n36: return 0.02016156166791916f;
  t269_n37: if (E.getNumReferences() >= 3320185856 /*7360.5*/) goto t269_n45;
  t269_n38: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t269_n40;
  t269_n39: return 0.11493047326803207f;
  t269_n40: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n42;
  t269_n41: return -0.25572407245635986f;
  t269_n42: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t269_n44;
  t269_n43: return 0.11299459636211395f;
  t269_n44: return -0.10653692483901978f;
  t269_n45: if (E.getNumReferences() >= 3322624512 /*8910.5*/) goto t269_n99;
  t269_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t269_n48;
  t269_n47: return -0.08077273517847061f;
  t269_n48: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t269_n74;
  t269_n49: if (E.getNumReferences() >= 3321606144 /*8054.0*/) goto t269_n51;
  t269_n50: return -0.00395452044904232f;
  t269_n51: if (E.getNumReferences() >= 3321819136 /*8158.0*/) goto t269_n63;
  t269_n52: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n58;
  t269_n53: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t269_n55;
  t269_n54: return 0.03612349554896355f;
  t269_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t269_n57;
  t269_n56: return -0.525761067867279f;
  t269_n57: return 0.11624304950237274f;
  t269_n58: if (E.getNumReferences() >= 3321802752 /*8150.0*/) goto t269_n60;
  t269_n59: return 0.10944489389657974f;
  t269_n60: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t269_n62;
  t269_n61: return 0.08546657860279083f;
  t269_n62: return 0.12477309256792068f;
  t269_n63: if (E.getNumReferences() >= 3322180096 /*8476.5*/) goto t269_n73;
  t269_n64: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t269_n66;
  t269_n65: return -0.16081589460372925f;
  t269_n66: if (E.getNumReferences() >= 3322118656 /*8416.5*/) goto t269_n70;
  t269_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t269_n69;
  t269_n68: return 0.07359102368354797f;
  t269_n69: return 0.1104322150349617f;
  t269_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t269_n72;
  t269_n71: return -0.4267744719982147f;
  t269_n72: return 0.1087404116988182f;
  t269_n73: return -0.12682819366455078f;
  t269_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t269_n86;
  t269_n75: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n77;
  t269_n76: return -0.04390530288219452f;
  t269_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t269_n79;
  t269_n78: return 0.044691264629364014f;
  t269_n79: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t269_n85;
  t269_n80: if (E.getNumReferences() >= 3321240576 /*7875.5*/) goto t269_n84;
  t269_n81: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t269_n83;
  t269_n82: return 0.12561248242855072f;
  t269_n83: return -0.03623289242386818f;
  t269_n84: return 0.11312159895896912f;
  t269_n85: return 0.04247593507170677f;
  t269_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t269_n98;
  t269_n87: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t269_n95;
  t269_n88: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t269_n90;
  t269_n89: return -0.10210646688938141f;
  t269_n90: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t269_n92;
  t269_n91: return 0.08063752204179764f;
  t269_n92: if (E.getNumReferences() >= 3321615360 /*8058.5*/) goto t269_n94;
  t269_n93: return 0.10834277421236038f;
  t269_n94: return 0.05417369678616524f;
  t269_n95: if (E.getNumReferences() >= 3321964032 /*8265.5*/) goto t269_n97;
  t269_n96: return 0.06986264884471893f;
  t269_n97: return -0.14314283430576324f;
  t269_n98: return 0.09467247873544693f;
  t269_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t269_n119;
  t269_n100: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n118;
  t269_n101: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t269_n115;
  t269_n102: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t269_n104;
  t269_n103: return -0.3125990331172943f;
  t269_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t269_n106;
  t269_n105: return 0.10873671621084213f;
  t269_n106: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t269_n110;
  t269_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t269_n109;
  t269_n108: return -0.10377661138772964f;
  t269_n109: return 0.10464361310005188f;
  t269_n110: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t269_n114;
  t269_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t269_n113;
  t269_n112: return -0.23176667094230652f;
  t269_n113: return 0.10742440819740295f;
  t269_n114: return 0.15072087943553925f;
  t269_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t269_n117;
  t269_n116: return -0.00396140618249774f;
  t269_n117: return 0.11009763181209564f;
  t269_n118: return -0.35631972551345825f;
  t269_n119: return 0.09747283160686493f;
  t269_n120: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t269_n154;
  t269_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t269_n145;
  t269_n122: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t269_n136;
  t269_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n131;
  t269_n124: if (E.getNumReferences() >= 3322376704 /*8668.5*/) goto t269_n126;
  t269_n125: return -0.1053377240896225f;
  t269_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t269_n128;
  t269_n127: return -0.36983662843704224f;
  t269_n128: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t269_n130;
  t269_n129: return 0.058038871735334396f;
  t269_n130: return 0.10688057541847229f;
  t269_n131: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t269_n133;
  t269_n132: return 0.038481418043375015f;
  t269_n133: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t269_n135;
  t269_n134: return -0.015877947211265564f;
  t269_n135: return 0.10999692231416702f;
  t269_n136: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t269_n144;
  t269_n137: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t269_n141;
  t269_n138: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t269_n140;
  t269_n139: return -0.4432945251464844f;
  t269_n140: return 0.07914714515209198f;
  t269_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t269_n143;
  t269_n142: return 0.0949820801615715f;
  t269_n143: return 0.11157681047916412f;
  t269_n144: return 0.01961546018719673f;
  t269_n145: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t269_n153;
  t269_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t269_n152;
  t269_n147: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t269_n149;
  t269_n148: return 0.09566408395767212f;
  t269_n149: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t269_n151;
  t269_n150: return 0.10343826562166214f;
  t269_n151: return 0.10265152156352997f;
  t269_n152: return 0.005065077915787697f;
  t269_n153: return -0.02814542129635811f;
  t269_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t269_n158;
  t269_n155: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t269_n157;
  t269_n156: return -0.026470046490430832f;
  t269_n157: return 0.10772862285375595f;
  t269_n158: return 0.12811419367790222f;
  t269_n159: if (E.getNumReferences() >= 3322603520 /*8890.0*/) goto t269_n167;
  t269_n160: if (E.getNumReferences() >= 3320516608 /*7522.0*/) goto t269_n166;
  t269_n161: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t269_n163;
  t269_n162: return -0.17477181553840637f;
  t269_n163: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t269_n165;
  t269_n164: return 0.11135481297969818f;
  t269_n165: return 0.1415833979845047f;
  t269_n166: return -0.06036657467484474f;
  t269_n167: if (E.getNumReferences() >= 3322671104 /*8956.0*/) goto t269_n169;
  t269_n168: return 0.10980775952339172f;
  t269_n169: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t269_n171;
  t269_n170: return -0.15356415510177612f;
  t269_n171: if (E.getNumReferences() >= 3322782208 /*9064.5*/) goto t269_n173;
  t269_n172: return 0.0700712725520134f;
  t269_n173: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t269_n179;
  t269_n174: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t269_n178;
  t269_n175: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t269_n177;
  t269_n176: return -0.1036488264799118f;
  t269_n177: return 0.09195108711719513f;
  t269_n178: return 0.10711608827114105f;
  t269_n179: return -0.10181281715631485f;
  t269_n180: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t269_n182;
  t269_n181: return -0.00810197088867426f;
  t269_n182: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t269_n184;
  t269_n183: return 0.00878005288541317f;
  t269_n184: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t269_n192;
  t269_n185: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t269_n191;
  t269_n186: if (E.getNumReferences() >= 3331489536 /*18751.5*/) goto t269_n190;
  t269_n187: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t269_n189;
  t269_n188: return 0.11074569076299667f;
  t269_n189: return -0.060026995837688446f;
  t269_n190: return -0.0044226557947695255f;
  t269_n191: return 0.13109977543354034f;
  t269_n192: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t269_n196;
  t269_n193: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t269_n195;
  t269_n194: return -0.008088726550340652f;
  t269_n195: return 0.13435347378253937f;
  t269_n196: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t269_n198;
  t269_n197: return 0.0372607596218586f;
  t269_n198: if (E.getNumReferences() >= 3333877760 /*23416.0*/) goto t269_n214;
  t269_n199: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t269_n207;
  t269_n200: if (E.getNumReferences() >= 3332307456 /*20349.0*/) goto t269_n206;
  t269_n201: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t269_n205;
  t269_n202: if (E.getNumReferences() >= 3332209408 /*20157.5*/) goto t269_n204;
  t269_n203: return 0.06293146312236786f;
  t269_n204: return 0.11953003704547882f;
  t269_n205: return -0.05634760484099388f;
  t269_n206: return -0.1885685920715332f;
  t269_n207: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t269_n213;
  t269_n208: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t269_n212;
  t269_n209: if (E.getNumReferences() >= 3333234688 /*22160.0*/) goto t269_n211;
  t269_n210: return 0.08840467035770416f;
  t269_n211: return 0.10878154635429382f;
  t269_n212: return 0.013067732565104961f;
  t269_n213: return 0.10403764247894287f;
  t269_n214: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t269_n248;
  t269_n215: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t269_n239;
  t269_n216: if (E.getNumReferences() >= 3372373568 /*533860.0*/) goto t269_n238;
  t269_n217: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t269_n231;
  t269_n218: if (E.getNumReferences() >= 3367337376 /*371693.0*/) goto t269_n226;
  t269_n219: if (E.getNumReferences() >= 3364664960 /*288180.0*/) goto t269_n221;
  t269_n220: return -0.010720081627368927f;
  t269_n221: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t269_n223;
  t269_n222: return -0.2019246518611908f;
  t269_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t269_n225;
  t269_n224: return -0.11611029505729675f;
  t269_n225: return 0.06602200120687485f;
  t269_n226: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t269_n228;
  t269_n227: return 0.1074037104845047f;
  t269_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t269_n230;
  t269_n229: return -0.5038248896598816f;
  t269_n230: return 0.044653672724962234f;
  t269_n231: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t269_n233;
  t269_n232: return 0.06555846333503723f;
  t269_n233: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t269_n237;
  t269_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n236;
  t269_n235: return -0.20008179545402527f;
  t269_n236: return -1.8823069334030151f;
  t269_n237: return -0.11609134078025818f;
  t269_n238: return 0.0663256049156189f;
  t269_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t269_n241;
  t269_n240: return 0.022385617718100548f;
  t269_n241: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t269_n247;
  t269_n242: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t269_n244;
  t269_n243: return -0.04980979487299919f;
  t269_n244: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t269_n246;
  t269_n245: return 0.11086565256118774f;
  t269_n246: return 0.10347672551870346f;
  t269_n247: return 0.020071007311344147f;
  t269_n248: if (E.getNumReferences() >= 3336586496 /*28706.5*/) goto t269_n250;
  t269_n249: return -0.056564874947071075f;
  t269_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t269_n254;
  t269_n251: if (E.getNumReferences() >= 3336821248 /*29165.0*/) goto t269_n253;
  t269_n252: return 0.07213837653398514f;
  t269_n253: return 0.022259263321757317f;
  t269_n254: return 0.09045996516942978f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree270(const Example& E) {
  t270_n0: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t270_n2;
  t270_n1: return -0.0004046738613396883f;
  t270_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t270_n226;
  t270_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t270_n109;
  t270_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t270_n6;
  t270_n5: return 0.003015809925273061f;
  t270_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t270_n24;
  t270_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Namespace))) goto t270_n9;
  t270_n8: return -0.04511398822069168f;
  t270_n9: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t270_n19;
  t270_n10: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t270_n18;
  t270_n11: if (E.getNumReferences() >= 3275390976 /*186.5*/) goto t270_n17;
  t270_n12: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t270_n14;
  t270_n13: return -0.13820281624794006f;
  t270_n14: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t270_n16;
  t270_n15: return 0.10864213854074478f;
  t270_n16: return -0.23625360429286957f;
  t270_n17: return -0.11304944008588791f;
  t270_n18: return 0.09218358248472214f;
  t270_n19: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t270_n21;
  t270_n20: return -0.27923649549484253f;
  t270_n21: if (E.getNumReferences() >= 3277389824 /*217.0*/) goto t270_n23;
  t270_n22: return -0.1776786744594574f;
  t270_n23: return 0.11759188771247864f;
  t270_n24: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t270_n100;
  t270_n25: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t270_n31;
  t270_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t270_n28;
  t270_n27: return -0.10995344072580338f;
  t270_n28: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t270_n30;
  t270_n29: return 0.14099016785621643f;
  t270_n30: return 0.08231177181005478f;
  t270_n31: if (E.getNumReferences() >= 3281698816 /*309.5*/) goto t270_n85;
  t270_n32: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t270_n50;
  t270_n33: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t270_n49;
  t270_n34: if (E.getNumReferences() >= 3265986560 /*85.5*/) goto t270_n44;
  t270_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t270_n39;
  t270_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t270_n38;
  t270_n37: return -0.4792892634868622f;
  t270_n38: return -0.02726178988814354f;
  t270_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t270_n41;
  t270_n40: return 0.04722153767943382f;
  t270_n41: if (E.getNumReferences() >= 3262382080 /*61.0*/) goto t270_n43;
  t270_n42: return -0.15613850951194763f;
  t270_n43: return 0.1820254772901535f;
  t270_n44: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t270_n46;
  t270_n45: return 0.12833741307258606f;
  t270_n46: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t270_n48;
  t270_n47: return -0.17518490552902222f;
  t270_n48: return 0.10784265398979187f;
  t270_n49: return -0.07202153652906418f;
  t270_n50: if (E.getNumReferences() >= 3272966144 /*149.5*/) goto t270_n76;
  t270_n51: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t270_n65;
  t270_n52: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t270_n60;
  t270_n53: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t270_n55;
  t270_n54: return -0.12553906440734863f;
  t270_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t270_n57;
  t270_n56: return -0.13464371860027313f;
  t270_n57: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t270_n59;
  t270_n58: return 0.10403859615325928f;
  t270_n59: return 0.06020870432257652f;
  t270_n60: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t270_n62;
  t270_n61: return -0.1692117601633072f;
  t270_n62: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t270_n64;
  t270_n63: return 0.1358531266450882f;
  t270_n64: return 0.12117015570402145f;
  t270_n65: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t270_n71;
  t270_n66: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t270_n70;
  t270_n67: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t270_n69;
  t270_n68: return -0.02611038275063038f;
  t270_n69: return -0.6828874349594116f;
  t270_n70: return 0.07252669334411621f;
  t270_n71: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t270_n73;
  t270_n72: return -0.3332127332687378f;
  t270_n73: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t270_n75;
  t270_n74: return -0.0586981475353241f;
  t270_n75: return 0.09524156153202057f;
  t270_n76: if (E.getNumReferences() >= 3274735616 /*176.5*/) goto t270_n84;
  t270_n77: if (E.getNumReferences() >= 3274604544 /*174.5*/) goto t270_n83;
  t270_n78: if (E.getNumReferences() >= 3273097216 /*151.5*/) goto t270_n80;
  t270_n79: return 0.09223390370607376f;
  t270_n80: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t270_n82;
  t270_n81: return 0.004982424434274435f;
  t270_n82: return 0.11562962830066681f;
  t270_n83: return 0.11603476107120514f;
  t270_n84: return -0.01571737229824066f;
  t270_n85: if (E.getNumReferences() >= 3281813504 /*313.0*/) goto t270_n87;
  t270_n86: return 0.1172361969947815f;
  t270_n87: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t270_n89;
  t270_n88: return 0.020488504320383072f;
  t270_n89: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t270_n91;
  t270_n90: return 0.03133267164230347f;
  t270_n91: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t270_n97;
  t270_n92: if (E.getNumReferences() >= 3288088576 /*504.5*/) goto t270_n94;
  t270_n93: return 0.10360242426395416f;
  t270_n94: if (E.getNumReferences() >= 3295690752 /*961.0*/) goto t270_n96;
  t270_n95: return -0.2264346033334732f;
  t270_n96: return 0.09886380285024643f;
  t270_n97: if (E.getNumReferences() >= 3291029504 /*676.5*/) goto t270_n99;
  t270_n98: return 0.12029504776000977f;
  t270_n99: return 0.08500952273607254f;
  t270_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t270_n102;
  t270_n101: return 0.012239346280694008f;
  t270_n102: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t270_n104;
  t270_n103: return 0.024848802015185356f;
  t270_n104: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t270_n106;
  t270_n105: return -0.14521068334579468f;
  t270_n106: if (E.getNumReferences() >= 3286859776 /*467.0*/) goto t270_n108;
  t270_n107: return 0.11565160006284714f;
  t270_n108: return -0.06428588181734085f;
  t270_n109: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t270_n189;
  t270_n110: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t270_n186;
  t270_n111: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t270_n185;
  t270_n112: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t270_n126;
  t270_n113: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t270_n125;
  t270_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t270_n116;
  t270_n115: return -0.0009360757539980114f;
  t270_n116: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t270_n122;
  t270_n117: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t270_n121;
  t270_n118: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t270_n120;
  t270_n119: return -0.036090027540922165f;
  t270_n120: return 0.11503175646066666f;
  t270_n121: return 0.13476347923278809f;
  t270_n122: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t270_n124;
  t270_n123: return -0.20946455001831055f;
  t270_n124: return 0.09393060952425003f;
  t270_n125: return -0.03329605609178543f;
  t270_n126: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t270_n130;
  t270_n127: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t270_n129;
  t270_n128: return 0.11234263330698013f;
  t270_n129: return -0.10818123072385788f;
  t270_n130: if (E.getNumReferences() >= 3272179712 /*137.5*/) goto t270_n142;
  t270_n131: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t270_n139;
  t270_n132: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t270_n138;
  t270_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t270_n135;
  t270_n134: return 0.020960431545972824f;
  t270_n135: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t270_n137;
  t270_n136: return 0.13259878754615784f;
  t270_n137: return -0.04893101006746292f;
  t270_n138: return 0.10998613387346268f;
  t270_n139: if (E.getNumReferences() >= 3272114176 /*136.5*/) goto t270_n141;
  t270_n140: return 0.01591462641954422f;
  t270_n141: return 0.3234180212020874f;
  t270_n142: if (E.getNumReferences() >= 3281534976 /*304.5*/) goto t270_n148;
  t270_n143: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t270_n145;
  t270_n144: return -0.008069631643593311f;
  t270_n145: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t270_n147;
  t270_n146: return -0.12139546871185303f;
  t270_n147: return 0.08886607736349106f;
  t270_n148: if (E.getNumReferences() >= 3281600512 /*306.5*/) goto t270_n150;
  t270_n149: return 0.12036052346229553f;
  t270_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t270_n152;
  t270_n151: return -0.005602053366601467f;
  t270_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t270_n154;
  t270_n153: return -0.24207821488380432f;
  t270_n154: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t270_n184;
  t270_n155: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t270_n157;
  t270_n156: return -0.08008144795894623f;
  t270_n157: if (E.getNumReferences() >= 3302694912 /*1753.0*/) goto t270_n183;
  t270_n158: if (E.getNumReferences() >= 3292364800 /*758.0*/) goto t270_n172;
  t270_n159: if (E.getNumReferences() >= 3286761472 /*464.0*/) goto t270_n171;
  t270_n160: if (E.getNumReferences() >= 3285139456 /*414.5*/) goto t270_n168;
  t270_n161: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t270_n163;
  t270_n162: return -0.023201214149594307f;
  t270_n163: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t270_n167;
  t270_n164: if (E.getNumReferences() >= 3283501056 /*364.5*/) goto t270_n166;
  t270_n165: return 0.22820498049259186f;
  t270_n166: return 0.031228404492139816f;
  t270_n167: return -0.018946249037981033f;
  t270_n168: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t270_n170;
  t270_n169: return 0.09646381437778473f;
  t270_n170: return -0.12511998414993286f;
  t270_n171: return -0.016144651919603348f;
  t270_n172: if (E.getNumReferences() >= 3294167040 /*868.0*/) goto t270_n176;
  t270_n173: if (E.getNumReferences() >= 3293421568 /*822.5*/) goto t270_n175;
  t270_n174: return 0.1069672554731369f;
  t270_n175: return 0.1251228153705597f;
  t270_n176: if (E.getNumReferences() >= 3297796096 /*1155.0*/) goto t270_n180;
  t270_n177: if (E.getNumReferences() >= 3295977472 /*978.5*/) goto t270_n179;
  t270_n178: return 0.019251257181167603f;
  t270_n179: return 0.1092950701713562f;
  t270_n180: if (E.getNumReferences() >= 3301625856 /*1622.5*/) goto t270_n182;
  t270_n181: return -0.0867585688829422f;
  t270_n182: return 0.105888232588768f;
  t270_n183: return 0.0016553750028833747f;
  t270_n184: return -0.12800295650959015f;
  t270_n185: return 0.09490302205085754f;
  t270_n186: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t270_n188;
  t270_n187: return -0.020859787240624428f;
  t270_n188: return 0.1066020205616951f;
  t270_n189: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t270_n211;
  t270_n190: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t270_n210;
  t270_n191: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t270_n195;
  t270_n192: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t270_n194;
  t270_n193: return -0.20338734984397888f;
  t270_n194: return 0.10844169557094574f;
  t270_n195: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t270_n197;
  t270_n196: return -0.038223668932914734f;
  t270_n197: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t270_n209;
  t270_n198: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t270_n200;
  t270_n199: return -0.020992251113057137f;
  t270_n200: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t270_n204;
  t270_n201: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t270_n203;
  t270_n202: return 0.09082090854644775f;
  t270_n203: return 0.11485632508993149f;
  t270_n204: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t270_n206;
  t270_n205: return 0.003642786294221878f;
  t270_n206: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t270_n208;
  t270_n207: return 0.08905868232250214f;
  t270_n208: return -0.2617889642715454f;
  t270_n209: return -0.08042021840810776f;
  t270_n210: return 0.10845710337162018f;
  t270_n211: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t270_n221;
  t270_n212: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t270_n220;
  t270_n213: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t270_n215;
  t270_n214: return -0.09670703858137131f;
  t270_n215: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t270_n219;
  t270_n216: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t270_n218;
  t270_n217: return 0.09614437818527222f;
  t270_n218: return 0.062202099710702896f;
  t270_n219: return -0.009076130576431751f;
  t270_n220: return 0.0968737006187439f;
  t270_n221: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t270_n223;
  t270_n222: return -0.06830690801143646f;
  t270_n223: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t270_n225;
  t270_n224: return -0.033064406365156174f;
  t270_n225: return 0.10236728936433792f;
  t270_n226: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t270_n228;
  t270_n227: return -0.0016605686396360397f;
  t270_n228: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t270_n250;
  t270_n229: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t270_n249;
  t270_n230: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t270_n246;
  t270_n231: if (E.getNumReferences() >= 3264872448 /*77.0*/) goto t270_n233;
  t270_n232: return -0.08682970702648163f;
  t270_n233: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t270_n235;
  t270_n234: return 0.14423689246177673f;
  t270_n235: if (E.getNumReferences() >= 3272998912 /*150.0*/) goto t270_n241;
  t270_n236: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t270_n240;
  t270_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t270_n239;
  t270_n238: return -0.4302901029586792f;
  t270_n239: return 0.23725222051143646f;
  t270_n240: return -0.2888478934764862f;
  t270_n241: if (E.getNumReferences() >= 3273490432 /*157.5*/) goto t270_n243;
  t270_n242: return 0.10343969613313675f;
  t270_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t270_n245;
  t270_n244: return -1.0634597539901733f;
  t270_n245: return 0.08870965987443924f;
  t270_n246: if (E.getNumReferences() >= 3264741376 /*76.0*/) goto t270_n248;
  t270_n247: return 0.10372588783502579f;
  t270_n248: return 0.0634690597653389f;
  t270_n249: return 0.015296237543225288f;
  t270_n250: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t270_n254;
  t270_n251: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t270_n253;
  t270_n252: return -0.18874359130859375f;
  t270_n253: return 0.006398837082087994f;
  t270_n254: return 0.028705457225441933f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree271(const Example& E) {
  t271_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t271_n254;
  t271_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t271_n3;
  t271_n2: return -0.00017012325406540185f;
  t271_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t271_n59;
  t271_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t271_n14;
  t271_n5: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n13;
  t271_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n12;
  t271_n7: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t271_n11;
  t271_n8: if (E.getNumReferences() >= 3212836864 /*1.0*/) goto t271_n10;
  t271_n9: return 0.09321700781583786f;
  t271_n10: return -0.0266172643750906f;
  t271_n11: return -0.018331680446863174f;
  t271_n12: return 0.009801347739994526f;
  t271_n13: return -0.021170098334550858f;
  t271_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n34;
  t271_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t271_n17;
  t271_n16: return -0.0459512397646904f;
  t271_n17: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t271_n33;
  t271_n18: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t271_n20;
  t271_n19: return 0.00806854385882616f;
  t271_n20: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t271_n32;
  t271_n21: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t271_n25;
  t271_n22: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t271_n24;
  t271_n23: return 0.1011657863855362f;
  t271_n24: return -0.07490447908639908f;
  t271_n25: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t271_n29;
  t271_n26: if (E.getNumReferences() >= 3271229440 /*125.5*/) goto t271_n28;
  t271_n27: return -0.05587886646389961f;
  t271_n28: return 0.07133892178535461f;
  t271_n29: if (E.getNumReferences() >= 3260284928 /*53.0*/) goto t271_n31;
  t271_n30: return 0.10513119399547577f;
  t271_n31: return -0.01041154470294714f;
  t271_n32: return -0.21573716402053833f;
  t271_n33: return -0.030110886320471764f;
  t271_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t271_n36;
  t271_n35: return 0.01246523018926382f;
  t271_n36: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t271_n38;
  t271_n37: return 0.008403596468269825f;
  t271_n38: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n58;
  t271_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n49;
  t271_n40: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t271_n48;
  t271_n41: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t271_n45;
  t271_n42: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t271_n44;
  t271_n43: return 0.10852646827697754f;
  t271_n44: return -0.5230382680892944f;
  t271_n45: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t271_n47;
  t271_n46: return 0.1168011948466301f;
  t271_n47: return 0.10766423493623734f;
  t271_n48: return -0.007373692933470011f;
  t271_n49: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t271_n53;
  t271_n50: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t271_n52;
  t271_n51: return 0.07584003359079361f;
  t271_n52: return 0.10776817053556442f;
  t271_n53: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t271_n55;
  t271_n54: return -0.6404602527618408f;
  t271_n55: if (E.getNumReferences() >= 3326113792 /*12318.0*/) goto t271_n57;
  t271_n56: return 0.05327229201793671f;
  t271_n57: return -1.2747036218643188f;
  t271_n58: return 0.04051947966217995f;
  t271_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t271_n137;
  t271_n60: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t271_n108;
  t271_n61: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t271_n69;
  t271_n62: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t271_n64;
  t271_n63: return -0.003014660906046629f;
  t271_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t271_n68;
  t271_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n67;
  t271_n66: return -0.02957906946539879f;
  t271_n67: return -0.005468500312417746f;
  t271_n68: return 0.009462008252739906f;
  t271_n69: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n91;
  t271_n70: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t271_n72;
  t271_n71: return -0.013818695209920406f;
  t271_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n74;
  t271_n73: return 0.03225648030638695f;
  t271_n74: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t271_n84;
  t271_n75: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t271_n77;
  t271_n76: return -0.032105572521686554f;
  t271_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t271_n79;
  t271_n78: return 0.08889096975326538f;
  t271_n79: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t271_n81;
  t271_n80: return 0.021256355568766594f;
  t271_n81: if (E.getNumReferences() >= 3259236352 /*49.0*/) goto t271_n83;
  t271_n82: return 0.10790538787841797f;
  t271_n83: return 0.12137055397033691f;
  t271_n84: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t271_n86;
  t271_n85: return 0.026929106563329697f;
  t271_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n88;
  t271_n87: return -0.020562658086419106f;
  t271_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t271_n90;
  t271_n89: return -0.24703416228294373f;
  t271_n90: return 0.06372739374637604f;
  t271_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t271_n97;
  t271_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n96;
  t271_n93: if (E.getNumReferences() >= 3361088608 /*219281.5*/) goto t271_n95;
  t271_n94: return -0.020339567214250565f;
  t271_n95: return 0.07612890750169754f;
  t271_n96: return -0.0014395592734217644f;
  t271_n97: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t271_n99;
  t271_n98: return 0.0030240293126553297f;
  t271_n99: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n105;
  t271_n100: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t271_n104;
  t271_n101: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t271_n103;
  t271_n102: return 0.2594850957393646f;
  t271_n103: return 0.13763058185577393f;
  t271_n104: return 0.060969822108745575f;
  t271_n105: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t271_n107;
  t271_n106: return 0.026929957792162895f;
  t271_n107: return -1.2733756303787231f;
  t271_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t271_n124;
  t271_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t271_n117;
  t271_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n116;
  t271_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t271_n115;
  t271_n112: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n114;
  t271_n113: return -0.03318848833441734f;
  t271_n114: return -0.06991801410913467f;
  t271_n115: return -0.10133962333202362f;
  t271_n116: return 0.019674312323331833f;
  t271_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t271_n119;
  t271_n118: return 0.011312730610370636f;
  t271_n119: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n123;
  t271_n120: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t271_n122;
  t271_n121: return -0.0788494199514389f;
  t271_n122: return 0.04209822043776512f;
  t271_n123: return 0.0005073270876891911f;
  t271_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t271_n126;
  t271_n125: return -0.0165246594697237f;
  t271_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t271_n128;
  t271_n127: return -0.027478624135255814f;
  t271_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n136;
  t271_n129: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n135;
  t271_n130: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t271_n134;
  t271_n131: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t271_n133;
  t271_n132: return -0.10512267798185349f;
  t271_n133: return 0.0955759659409523f;
  t271_n134: return -0.12774740159511566f;
  t271_n135: return -0.13359639048576355f;
  t271_n136: return 0.024121101945638657f;
  t271_n137: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t271_n247;
  t271_n138: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t271_n216;
  t271_n139: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t271_n215;
  t271_n140: if (E.getNumReferences() >= 3268739072 /*106.5*/) goto t271_n210;
  t271_n141: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t271_n161;
  t271_n142: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t271_n160;
  t271_n143: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n145;
  t271_n144: return 0.06358561664819717f;
  t271_n145: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t271_n157;
  t271_n146: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t271_n150;
  t271_n147: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t271_n149;
  t271_n148: return 0.1518419235944748f;
  t271_n149: return -0.012959827668964863f;
  t271_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n152;
  t271_n151: return 0.06602144986391068f;
  t271_n152: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t271_n156;
  t271_n153: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t271_n155;
  t271_n154: return 0.39014506340026855f;
  t271_n155: return 0.11429958790540695f;
  t271_n156: return 0.09869582951068878f;
  t271_n157: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t271_n159;
  t271_n158: return 0.10843289643526077f;
  t271_n159: return -0.08479895442724228f;
  t271_n160: return 0.0037141749635338783f;
  t271_n161: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t271_n185;
  t271_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t271_n178;
  t271_n163: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t271_n173;
  t271_n164: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t271_n166;
  t271_n165: return -0.11448338627815247f;
  t271_n166: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t271_n170;
  t271_n167: if (E.getNumReferences() >= 3229614080 /*4.0*/) goto t271_n169;
  t271_n168: return 0.17104984819889069f;
  t271_n169: return 0.1260748654603958f;
  t271_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n172;
  t271_n171: return -0.7378110885620117f;
  t271_n172: return 0.07541455328464508f;
  t271_n173: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t271_n175;
  t271_n174: return 0.028019307181239128f;
  t271_n175: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t271_n177;
  t271_n176: return 0.11483011394739151f;
  t271_n177: return 0.12591588497161865f;
  t271_n178: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t271_n184;
  t271_n179: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n181;
  t271_n180: return 0.11509500443935394f;
  t271_n181: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t271_n183;
  t271_n182: return 0.0030251541174948215f;
  t271_n183: return 0.11088072508573532f;
  t271_n184: return 0.05240800976753235f;
  t271_n185: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t271_n189;
  t271_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t271_n188;
  t271_n187: return -0.01442849449813366f;
  t271_n188: return 0.15494567155838013f;
  t271_n189: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n199;
  t271_n190: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t271_n192;
  t271_n191: return 0.04683058708906174f;
  t271_n192: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t271_n198;
  t271_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n195;
  t271_n194: return 0.1156356930732727f;
  t271_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t271_n197;
  t271_n196: return 0.09068930894136429f;
  t271_n197: return 0.09962036460638046f;
  t271_n198: return 0.10284503549337387f;
  t271_n199: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t271_n209;
  t271_n200: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t271_n202;
  t271_n201: return -0.12473326176404953f;
  t271_n202: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t271_n206;
  t271_n203: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t271_n205;
  t271_n204: return 0.12025943398475647f;
  t271_n205: return 0.1385803371667862f;
  t271_n206: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t271_n208;
  t271_n207: return -0.45377781987190247f;
  t271_n208: return 0.0537690706551075f;
  t271_n209: return 0.1075885072350502f;
  t271_n210: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t271_n212;
  t271_n211: return -0.07522863894701004f;
  t271_n212: if (E.getNumReferences() >= 3290939392 /*671.0*/) goto t271_n214;
  t271_n213: return 0.13549020886421204f;
  t271_n214: return -0.0817590057849884f;
  t271_n215: return 0.04107268899679184f;
  t271_n216: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t271_n218;
  t271_n217: return -0.003804483450949192f;
  t271_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t271_n240;
  t271_n219: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t271_n223;
  t271_n220: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n222;
  t271_n221: return 0.008519905619323254f;
  t271_n222: return 0.020435338839888573f;
  t271_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n225;
  t271_n224: return 0.02407318353652954f;
  t271_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t271_n239;
  t271_n226: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t271_n238;
  t271_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t271_n229;
  t271_n228: return 0.016266725957393646f;
  t271_n229: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n231;
  t271_n230: return 0.06902388483285904f;
  t271_n231: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n233;
  t271_n232: return -0.07212293893098831f;
  t271_n233: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t271_n237;
  t271_n234: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t271_n236;
  t271_n235: return 0.06465831398963928f;
  t271_n236: return 0.11881187558174133f;
  t271_n237: return 0.08546748012304306f;
  t271_n238: return 0.012839671224355698f;
  t271_n239: return 0.04562067240476608f;
  t271_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n246;
  t271_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n245;
  t271_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n244;
  t271_n243: return 0.032606206834316254f;
  t271_n244: return 0.057841334491968155f;
  t271_n245: return 0.03673667833209038f;
  t271_n246: return -0.01348403561860323f;
  t271_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n249;
  t271_n248: return -0.011111805215477943f;
  t271_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n253;
  t271_n250: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t271_n252;
  t271_n251: return 0.05979118123650551f;
  t271_n252: return 0.09970255941152573f;
  t271_n253: return 0.0013206922449171543f;
  t271_n254: return -0.009460430592298508f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree272(const Example& E) {
  t272_n0: if (E.getNumReferences() >= 3320122368 /*7329.5*/) goto t272_n210;
  t272_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t272_n3;
  t272_n2: return 0.0022675246000289917f;
  t272_n3: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t272_n173;
  t272_n4: if (E.getSymbolScopeDistance() >= 3246915584 /*17.0*/) goto t272_n30;
  t272_n5: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t272_n29;
  t272_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t272_n8;
  t272_n7: return -0.01264221128076315f;
  t272_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t272_n10;
  t272_n9: return 0.023399455472826958f;
  t272_n10: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t272_n22;
  t272_n11: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t272_n13;
  t272_n12: return 0.008639214560389519f;
  t272_n13: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n15;
  t272_n14: return 0.03609349951148033f;
  t272_n15: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t272_n17;
  t272_n16: return 0.06596704572439194f;
  t272_n17: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t272_n21;
  t272_n18: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t272_n20;
  t272_n19: return 0.12582221627235413f;
  t272_n20: return 0.1351318657398224f;
  t272_n21: return 0.08391793072223663f;
  t272_n22: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t272_n28;
  t272_n23: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t272_n27;
  t272_n24: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n26;
  t272_n25: return 0.10804705321788788f;
  t272_n26: return 0.1397029608488083f;
  t272_n27: return 0.056800372898578644f;
  t272_n28: return 0.036074113100767136f;
  t272_n29: return 0.00018523613107390702f;
  t272_n30: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t272_n32;
  t272_n31: return -0.0063846176490187645f;
  t272_n32: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t272_n34;
  t272_n33: return 0.0029971993062645197f;
  t272_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t272_n36;
  t272_n35: return -0.006992395967245102f;
  t272_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t272_n84;
  t272_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t272_n43;
  t272_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n42;
  t272_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t272_n41;
  t272_n40: return -0.01625852845609188f;
  t272_n41: return 0.04437035694718361f;
  t272_n42: return -0.04257486015558243f;
  t272_n43: if (E.getSymbolScopeDistance() >= 3249012736 /*21.0*/) goto t272_n47;
  t272_n44: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t272_n46;
  t272_n45: return 0.12433672696352005f;
  t272_n46: return -0.3053397536277771f;
  t272_n47: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t272_n69;
  t272_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t272_n58;
  t272_n49: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n51;
  t272_n50: return 0.01774229109287262f;
  t272_n51: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t272_n53;
  t272_n52: return 0.1329420953989029f;
  t272_n53: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t272_n57;
  t272_n54: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t272_n56;
  t272_n55: return 0.061699219048023224f;
  t272_n56: return 0.0864289402961731f;
  t272_n57: return -0.11282815039157867f;
  t272_n58: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t272_n68;
  t272_n59: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t272_n61;
  t272_n60: return 0.20743407309055328f;
  t272_n61: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t272_n63;
  t272_n62: return -0.075736865401268f;
  t272_n63: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t272_n65;
  t272_n64: return -0.10013201832771301f;
  t272_n65: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t272_n67;
  t272_n66: return 0.13145746290683746f;
  t272_n67: return 0.057311076670885086f;
  t272_n68: return 0.08735332638025284f;
  t272_n69: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t272_n81;
  t272_n70: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t272_n72;
  t272_n71: return 0.008989043533802032f;
  t272_n72: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t272_n80;
  t272_n73: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n79;
  t272_n74: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t272_n78;
  t272_n75: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t272_n77;
  t272_n76: return 0.14250285923480988f;
  t272_n77: return 0.19262754917144775f;
  t272_n78: return 0.08999203145503998f;
  t272_n79: return 0.12706084549427032f;
  t272_n80: return 0.03326508030295372f;
  t272_n81: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t272_n83;
  t272_n82: return 0.036719389259815216f;
  t272_n83: return -0.004660372156649828f;
  t272_n84: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t272_n88;
  t272_n85: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t272_n87;
  t272_n86: return -0.031645823270082474f;
  t272_n87: return -0.22924166917800903f;
  t272_n88: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t272_n98;
  t272_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t272_n91;
  t272_n90: return 0.025602800771594048f;
  t272_n91: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t272_n93;
  t272_n92: return 0.036635711789131165f;
  t272_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t272_n95;
  t272_n94: return -0.04914555698633194f;
  t272_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t272_n97;
  t272_n96: return -0.10148368030786514f;
  t272_n97: return 0.10571535676717758f;
  t272_n98: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t272_n172;
  t272_n99: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t272_n169;
  t272_n100: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t272_n122;
  t272_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t272_n115;
  t272_n102: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t272_n108;
  t272_n103: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t272_n105;
  t272_n104: return 0.06827963143587112f;
  t272_n105: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t272_n107;
  t272_n106: return -0.045165229588747025f;
  t272_n107: return 0.052785418927669525f;
  t272_n108: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t272_n114;
  t272_n109: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t272_n111;
  t272_n110: return 0.13310931622982025f;
  t272_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t272_n113;
  t272_n112: return 0.06289325654506683f;
  t272_n113: return 0.14745934307575226f;
  t272_n114: return -0.04093904048204422f;
  t272_n115: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t272_n119;
  t272_n116: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t272_n118;
  t272_n117: return 0.07634971290826797f;
  t272_n118: return -0.038101449608802795f;
  t272_n119: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t272_n121;
  t272_n120: return 0.08268275856971741f;
  t272_n121: return 0.07121023535728455f;
  t272_n122: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t272_n168;
  t272_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t272_n141;
  t272_n124: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t272_n128;
  t272_n125: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t272_n127;
  t272_n126: return 0.056837018579244614f;
  t272_n127: return -0.022822683677077293f;
  t272_n128: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t272_n132;
  t272_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t272_n131;
  t272_n130: return 0.026860956102609634f;
  t272_n131: return 0.08495038002729416f;
  t272_n132: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t272_n134;
  t272_n133: return 0.05027230083942413f;
  t272_n134: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t272_n140;
  t272_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t272_n139;
  t272_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t272_n138;
  t272_n137: return 0.04109268635511398f;
  t272_n138: return 0.11782949417829514f;
  t272_n139: return 0.10621823370456696f;
  t272_n140: return 0.04116327315568924f;
  t272_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t272_n143;
  t272_n142: return 0.05266723409295082f;
  t272_n143: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t272_n167;
  t272_n144: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t272_n164;
  t272_n145: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t272_n155;
  t272_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t272_n148;
  t272_n147: return 0.0541829951107502f;
  t272_n148: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t272_n150;
  t272_n149: return 0.08839435130357742f;
  t272_n150: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t272_n152;
  t272_n151: return -0.02570757456123829f;
  t272_n152: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t272_n154;
  t272_n153: return 0.09228207170963287f;
  t272_n154: return -0.12831901013851166f;
  t272_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t272_n161;
  t272_n156: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t272_n160;
  t272_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t272_n159;
  t272_n158: return 0.07459262013435364f;
  t272_n159: return 0.10575567185878754f;
  t272_n160: return -0.1336333006620407f;
  t272_n161: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t272_n163;
  t272_n162: return 0.10894696414470673f;
  t272_n163: return -0.13209538161754608f;
  t272_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t272_n166;
  t272_n165: return 0.09108821302652359f;
  t272_n166: return 0.11980102956295013f;
  t272_n167: return -0.07895655930042267f;
  t272_n168: return 0.020851654931902885f;
  t272_n169: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t272_n171;
  t272_n170: return 0.029215797781944275f;
  t272_n171: return -0.08014735579490662f;
  t272_n172: return -0.10199395567178726f;
  t272_n173: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t272_n175;
  t272_n174: return 0.008589616045355797f;
  t272_n175: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t272_n177;
  t272_n176: return -0.0277081448584795f;
  t272_n177: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n203;
  t272_n178: if (E.getNumReferences() >= 3316691968 /*5654.5*/) goto t272_n192;
  t272_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t272_n181;
  t272_n180: return 0.01531133521348238f;
  t272_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t272_n183;
  t272_n182: return -0.03430768474936485f;
  t272_n183: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t272_n191;
  t272_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t272_n190;
  t272_n185: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t272_n189;
  t272_n186: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t272_n188;
  t272_n187: return 0.1541374921798706f;
  t272_n188: return -0.025971582159399986f;
  t272_n189: return 0.15017573535442352f;
  t272_n190: return -0.05994337424635887f;
  t272_n191: return 0.04028250277042389f;
  t272_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t272_n194;
  t272_n193: return -0.24702033400535583f;
  t272_n194: if (E.getNumReferences() >= 3319669760 /*7108.5*/) goto t272_n202;
  t272_n195: if (E.getNumReferences() >= 3319385088 /*6969.5*/) goto t272_n201;
  t272_n196: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t272_n198;
  t272_n197: return 0.13455452024936676f;
  t272_n198: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t272_n200;
  t272_n199: return -0.05629127845168114f;
  t272_n200: return 0.09050492942333221f;
  t272_n201: return 0.12765946984291077f;
  t272_n202: return -0.21160122752189636f;
  t272_n203: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t272_n205;
  t272_n204: return -0.059765323996543884f;
  t272_n205: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t272_n207;
  t272_n206: return -0.015415072441101074f;
  t272_n207: if (E.getNumReferences() >= 3276865536 /*209.0*/) goto t272_n209;
  t272_n208: return 0.16754034161567688f;
  t272_n209: return 0.0672769844532013f;
  t272_n210: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t272_n252;
  t272_n211: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t272_n245;
  t272_n212: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t272_n214;
  t272_n213: return 0.10251887887716293f;
  t272_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t272_n244;
  t272_n215: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t272_n229;
  t272_n216: if (E.getNumReferences() >= 3339097344 /*34453.0*/) goto t272_n218;
  t272_n217: return -0.02022102102637291f;
  t272_n218: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t272_n228;
  t272_n219: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t272_n221;
  t272_n220: return -0.2741563022136688f;
  t272_n221: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n227;
  t272_n222: if (E.getNumReferences() >= 3345471616 /*59352.5*/) goto t272_n224;
  t272_n223: return 0.025091204792261124f;
  t272_n224: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t272_n226;
  t272_n225: return 0.03773108497262001f;
  t272_n226: return 0.08976670354604721f;
  t272_n227: return 0.0988512709736824f;
  t272_n228: return -0.06011049821972847f;
  t272_n229: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t272_n243;
  t272_n230: if (E.getNumReferences() >= 3349315712 /*83201.0*/) goto t272_n236;
  t272_n231: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t272_n233;
  t272_n232: return -2.759380578994751f;
  t272_n233: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t272_n235;
  t272_n234: return -0.008589637465775013f;
  t272_n235: return -0.13245181739330292f;
  t272_n236: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t272_n238;
  t272_n237: return 0.01883835531771183f;
  t272_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t272_n242;
  t272_n239: if (E.getNumReferences() >= 3359666304 /*197058.0*/) goto t272_n241;
  t272_n240: return -0.2317870408296585f;
  t272_n241: return -0.11055287718772888f;
  t272_n242: return 0.0435432605445385f;
  t272_n243: return 0.08752705901861191f;
  t272_n244: return 0.011080209165811539f;
  t272_n245: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t272_n247;
  t272_n246: return 0.0009819614933803678f;
  t272_n247: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t272_n249;
  t272_n248: return 0.016466841101646423f;
  t272_n249: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t272_n251;
  t272_n250: return 0.0981258824467659f;
  t272_n251: return -0.044042594730854034f;
  t272_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t272_n254;
  t272_n253: return -0.026343777775764465f;
  t272_n254: return 0.0046780845150351524f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree273(const Example& E) {
  t273_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t273_n2;
  t273_n1: return -0.00031622109236195683f;
  t273_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t273_n86;
  t273_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t273_n7;
  t273_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t273_n6;
  t273_n5: return -0.21177783608436584f;
  t273_n6: return 0.003154624719172716f;
  t273_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t273_n31;
  t273_n8: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t273_n30;
  t273_n9: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t273_n11;
  t273_n10: return 0.000418495706981048f;
  t273_n11: if (E.getNumReferences() >= 3290529792 /*646.0*/) goto t273_n21;
  t273_n12: if (E.getNumReferences() >= 3289440256 /*579.5*/) goto t273_n20;
  t273_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t273_n15;
  t273_n14: return -0.18330809473991394f;
  t273_n15: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t273_n17;
  t273_n16: return -0.34679844975471497f;
  t273_n17: if (E.getNumReferences() >= 3288375296 /*514.5*/) goto t273_n19;
  t273_n18: return 0.10578006505966187f;
  t273_n19: return -0.20934343338012695f;
  t273_n20: return 0.13260087370872498f;
  t273_n21: if (E.getNumReferences() >= 3295690752 /*961.0*/) goto t273_n23;
  t273_n22: return -0.36665117740631104f;
  t273_n23: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t273_n29;
  t273_n24: if (E.getNumReferences() >= 3302469632 /*1725.5*/) goto t273_n28;
  t273_n25: if (E.getNumReferences() >= 3298672640 /*1262.0*/) goto t273_n27;
  t273_n26: return 0.10687698423862457f;
  t273_n27: return 0.12787170708179474f;
  t273_n28: return -0.7502469420433044f;
  t273_n29: return -0.004112012684345245f;
  t273_n30: return 0.012726353481411934f;
  t273_n31: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t273_n83;
  t273_n32: if (E.getNumReferences() >= 3314761728 /*4712.0*/) goto t273_n68;
  t273_n33: if (E.getNumReferences() >= 3289620480 /*590.5*/) goto t273_n67;
  t273_n34: if (E.getNumReferences() >= 3289538560 /*585.5*/) goto t273_n66;
  t273_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t273_n57;
  t273_n36: if (E.getNumReferences() >= 3286384640 /*452.5*/) goto t273_n48;
  t273_n37: if (E.getNumReferences() >= 3286089728 /*443.5*/) goto t273_n45;
  t273_n38: if (E.getNumReferences() >= 3285598208 /*428.5*/) goto t273_n44;
  t273_n39: if (E.getNumReferences() >= 3285467136 /*424.5*/) goto t273_n41;
  t273_n40: return 0.052434779703617096f;
  t273_n41: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t273_n43;
  t273_n42: return 0.11015193164348602f;
  t273_n43: return -0.1614500731229782f;
  t273_n44: return -0.20996235311031342f;
  t273_n45: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t273_n47;
  t273_n46: return 0.04369568079710007f;
  t273_n47: return 0.11223895102739334f;
  t273_n48: if (E.getNumReferences() >= 3288580096 /*527.0*/) goto t273_n50;
  t273_n49: return -0.07223992049694061f;
  t273_n50: if (E.getNumReferences() >= 3288678400 /*533.0*/) goto t273_n52;
  t273_n51: return 0.10755637288093567f;
  t273_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t273_n54;
  t273_n53: return -0.39761948585510254f;
  t273_n54: if (E.getNumReferences() >= 3289128960 /*560.5*/) goto t273_n56;
  t273_n55: return -0.003162436420097947f;
  t273_n56: return 0.11339423805475235f;
  t273_n57: if (E.getNumReferences() >= 3286024192 /*441.5*/) goto t273_n59;
  t273_n58: return -0.09724900871515274f;
  t273_n59: if (E.getNumReferences() >= 3286368256 /*452.0*/) goto t273_n61;
  t273_n60: return 0.0985201969742775f;
  t273_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t273_n63;
  t273_n62: return -0.11641903966665268f;
  t273_n63: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t273_n65;
  t273_n64: return 0.167011559009552f;
  t273_n65: return -0.11663062125444412f;
  t273_n66: return 0.1486562341451645f;
  t273_n67: return 0.00871626939624548f;
  t273_n68: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t273_n82;
  t273_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t273_n77;
  t273_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t273_n72;
  t273_n71: return -0.27521684765815735f;
  t273_n72: if (E.getNumReferences() >= 3317001216 /*5805.5*/) goto t273_n74;
  t273_n73: return 0.03631414473056793f;
  t273_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t273_n76;
  t273_n75: return 0.10276547074317932f;
  t273_n76: return 0.13469047844409943f;
  t273_n77: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t273_n79;
  t273_n78: return 0.08939363062381744f;
  t273_n79: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t273_n81;
  t273_n80: return 0.12987728416919708f;
  t273_n81: return 0.1398271769285202f;
  t273_n82: return -0.001562589081004262f;
  t273_n83: if (E.getNumReferences() >= 3298271232 /*1213.0*/) goto t273_n85;
  t273_n84: return 0.11373718827962875f;
  t273_n85: return -1.4637610912322998f;
  t273_n86: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t273_n88;
  t273_n87: return -0.00046386371832340956f;
  t273_n88: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t273_n90;
  t273_n89: return 0.00560372369363904f;
  t273_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t273_n254;
  t273_n91: if (E.getNumReferences() >= 3286646784 /*460.5*/) goto t273_n101;
  t273_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t273_n98;
  t273_n93: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t273_n95;
  t273_n94: return -0.45036134123802185f;
  t273_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t273_n97;
  t273_n96: return -0.17215275764465332f;
  t273_n97: return -0.008461110293865204f;
  t273_n98: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t273_n100;
  t273_n99: return -0.18822382390499115f;
  t273_n100: return 0.12325061112642288f;
  t273_n101: if (E.getNumReferences() >= 3286761472 /*464.0*/) goto t273_n103;
  t273_n102: return 0.09653985500335693f;
  t273_n103: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t273_n217;
  t273_n104: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t273_n148;
  t273_n105: if (E.getNumReferences() >= 3300311040 /*1462.0*/) goto t273_n147;
  t273_n106: if (E.getNumReferences() >= 3300237312 /*1453.0*/) goto t273_n146;
  t273_n107: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t273_n129;
  t273_n108: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t273_n116;
  t273_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t273_n113;
  t273_n110: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t273_n112;
  t273_n111: return -0.46035632491111755f;
  t273_n112: return 0.14869174361228943f;
  t273_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t273_n115;
  t273_n114: return 0.02425779215991497f;
  t273_n115: return 0.12286421656608582f;
  t273_n116: if (E.getNumReferences() >= 3299237888 /*1331.0*/) goto t273_n128;
  t273_n117: if (E.getNumReferences() >= 3294543872 /*891.0*/) goto t273_n121;
  t273_n118: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t273_n120;
  t273_n119: return -0.1590830385684967f;
  t273_n120: return 0.05591215193271637f;
  t273_n121: if (E.getNumReferences() >= 3295584256 /*954.5*/) goto t273_n123;
  t273_n122: return 0.10527046769857407f;
  t273_n123: if (E.getNumReferences() >= 3298086912 /*1190.5*/) goto t273_n125;
  t273_n124: return -0.10650062561035156f;
  t273_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t273_n127;
  t273_n126: return 0.0028732072096318007f;
  t273_n127: return 0.09726721793413162f;
  t273_n128: return -1.2171803712844849f;
  t273_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t273_n137;
  t273_n130: if (E.getNumReferences() >= 3299737600 /*1392.0*/) goto t273_n136;
  t273_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t273_n135;
  t273_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t273_n134;
  t273_n133: return -0.2631862163543701f;
  t273_n134: return 0.08062144368886948f;
  t273_n135: return 0.08895644545555115f;
  t273_n136: return 0.09462673962116241f;
  t273_n137: if (E.getNumReferences() >= 3291422720 /*700.5*/) goto t273_n139;
  t273_n138: return -0.4278988540172577f;
  t273_n139: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t273_n143;
  t273_n140: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t273_n142;
  t273_n141: return 0.12373102456331253f;
  t273_n142: return 0.059694379568099976f;
  t273_n143: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t273_n145;
  t273_n144: return -0.1169477105140686f;
  t273_n145: return 0.12536601722240448f;
  t273_n146: return 0.11783809959888458f;
  t273_n147: return 0.02349073812365532f;
  t273_n148: if (E.getNumReferences() >= 3287089152 /*474.0*/) goto t273_n152;
  t273_n149: if (E.getNumReferences() >= 3286990848 /*471.0*/) goto t273_n151;
  t273_n150: return -0.2524101436138153f;
  t273_n151: return 0.10783607512712479f;
  t273_n152: if (E.getNumReferences() >= 3289980928 /*612.5*/) goto t273_n156;
  t273_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t273_n155;
  t273_n154: return -0.15750941634178162f;
  t273_n155: return 0.12324083596467972f;
  t273_n156: if (E.getNumReferences() >= 3290718208 /*657.5*/) goto t273_n168;
  t273_n157: if (E.getNumReferences() >= 3290267648 /*630.0*/) goto t273_n165;
  t273_n158: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t273_n164;
  t273_n159: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t273_n163;
  t273_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t273_n162;
  t273_n161: return -0.27426910400390625f;
  t273_n162: return 0.060777463018894196f;
  t273_n163: return 0.07307519763708115f;
  t273_n164: return 0.11683496832847595f;
  t273_n165: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t273_n167;
  t273_n166: return 0.1133643388748169f;
  t273_n167: return -0.09855208545923233f;
  t273_n168: if (E.getNumReferences() >= 3312013312 /*3733.0*/) goto t273_n202;
  t273_n169: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t273_n189;
  t273_n170: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t273_n172;
  t273_n171: return 0.08516591787338257f;
  t273_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t273_n176;
  t273_n173: if (E.getNumReferences() >= 3294429184 /*884.0*/) goto t273_n175;
  t273_n174: return -0.8568227291107178f;
  t273_n175: return -0.10086403042078018f;
  t273_n176: if (E.getNumReferences() >= 3291193344 /*686.5*/) goto t273_n180;
  t273_n177: if (E.getNumReferences() >= 3290963968 /*672.5*/) goto t273_n179;
  t273_n178: return -0.010616296902298927f;
  t273_n179: return -0.5300487279891968f;
  t273_n180: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t273_n186;
  t273_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t273_n185;
  t273_n182: if (E.getNumReferences() >= 3310272512 /*3308.0*/) goto t273_n184;
  t273_n183: return -0.014238185249269009f;
  t273_n184: return 0.10111494362354279f;
  t273_n185: return 0.09259900450706482f;
  t273_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t273_n188;
  t273_n187: return -0.2239830642938614f;
  t273_n188: return -0.06312979757785797f;
  t273_n189: if (E.getNumReferences() >= 3307843584 /*2715.0*/) goto t273_n201;
  t273_n190: if (E.getNumReferences() >= 3296665600 /*1020.5*/) goto t273_n192;
  t273_n191: return -0.08804783225059509f;
  t273_n192: if (E.getNumReferences() >= 3296931840 /*1049.5*/) goto t273_n194;
  t273_n193: return 0.10611032694578171f;
  t273_n194: if (E.getNumReferences() >= 3303219200 /*1817.0*/) goto t273_n196;
  t273_n195: return 0.0010310913203284144f;
  t273_n196: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t273_n198;
  t273_n197: return 0.12382940202951431f;
  t273_n198: if (E.getNumReferences() >= 3305670656 /*2184.5*/) goto t273_n200;
  t273_n199: return -0.02572430670261383f;
  t273_n200: return 0.1302795559167862f;
  t273_n201: return -0.48674771189689636f;
  t273_n202: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t273_n204;
  t273_n203: return -0.19084139168262482f;
  t273_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t273_n208;
  t273_n205: if (E.getNumReferences() >= 3313082368 /*3994.0*/) goto t273_n207;
  t273_n206: return 0.061208467930555344f;
  t273_n207: return 0.00582013139501214f;
  t273_n208: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t273_n210;
  t273_n209: return 0.10530727356672287f;
  t273_n210: if (E.getNumReferences() >= 3319742464 /*7144.0*/) goto t273_n214;
  t273_n211: if (E.getNumReferences() >= 3315684352 /*5162.5*/) goto t273_n213;
  t273_n212: return -0.028774376958608627f;
  t273_n213: return 0.11124803870916367f;
  t273_n214: if (E.getNumReferences() >= 3364045296 /*268815.5*/) goto t273_n216;
  t273_n215: return -0.025387294590473175f;
  t273_n216: return 0.07468394935131073f;
  t273_n217: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t273_n219;
  t273_n218: return -0.011669783852994442f;
  t273_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t273_n237;
  t273_n220: if (E.getNumReferences() >= 3289956352 /*611.0*/) goto t273_n224;
  t273_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t273_n223;
  t273_n222: return -0.34453830122947693f;
  t273_n223: return 0.08636423945426941f;
  t273_n224: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t273_n232;
  t273_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t273_n229;
  t273_n226: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t273_n228;
  t273_n227: return -0.4054372310638428f;
  t273_n228: return 0.032595645636320114f;
  t273_n229: if (E.getNumReferences() >= 3290333184 /*634.0*/) goto t273_n231;
  t273_n230: return 0.1747329980134964f;
  t273_n231: return 0.010365399532020092f;
  t273_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t273_n234;
  t273_n233: return 0.10018978267908096f;
  t273_n234: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t273_n236;
  t273_n235: return 0.08112356811761856f;
  t273_n236: return 0.009757503867149353f;
  t273_n237: if (E.getNumReferences() >= 3289088000 /*558.0*/) goto t273_n239;
  t273_n238: return 0.09777652472257614f;
  t273_n239: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t273_n253;
  t273_n240: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t273_n250;
  t273_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t273_n243;
  t273_n242: return -0.004836652893573046f;
  t273_n243: if (E.getNumReferences() >= 3347567040 /*69539.5*/) goto t273_n249;
  t273_n244: if (E.getNumReferences() >= 3319671808 /*7109.5*/) goto t273_n246;
  t273_n245: return 0.06208343803882599f;
  t273_n246: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t273_n248;
  t273_n247: return 0.11411050707101822f;
  t273_n248: return 0.10144314914941788f;
  t273_n249: return -0.02167423814535141f;
  t273_n250: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t273_n252;
  t273_n251: return 0.0943528264760971f;
  t273_n252: return 0.11468975245952606f;
  t273_n253: return -0.004111388232558966f;
  t273_n254: return 0.10833494365215302f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree274(const Example& E) {
  t274_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t274_n2;
  t274_n1: return -0.00031513572321273386f;
  t274_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t274_n178;
  t274_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t274_n157;
  t274_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t274_n28;
  t274_n5: if (E.getNumReferences() >= 3310407680 /*3341.0*/) goto t274_n7;
  t274_n6: return -0.012307364493608475f;
  t274_n7: if (E.getNumReferences() >= 3311495168 /*3606.5*/) goto t274_n27;
  t274_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t274_n24;
  t274_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t274_n19;
  t274_n10: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t274_n18;
  t274_n11: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t274_n13;
  t274_n12: return 0.1462482362985611f;
  t274_n13: if (E.getNumReferences() >= 3311011840 /*3488.5*/) goto t274_n15;
  t274_n14: return -0.10254786908626556f;
  t274_n15: if (E.getNumReferences() >= 3311206400 /*3536.0*/) goto t274_n17;
  t274_n16: return 0.20058684051036835f;
  t274_n17: return -0.10313844680786133f;
  t274_n18: return -0.10591036826372147f;
  t274_n19: if (E.getNumReferences() >= 3310528512 /*3370.5*/) goto t274_n21;
  t274_n20: return 0.17454001307487488f;
  t274_n21: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t274_n23;
  t274_n22: return 0.08369076997041702f;
  t274_n23: return -0.2896454930305481f;
  t274_n24: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t274_n26;
  t274_n25: return 0.09843171387910843f;
  t274_n26: return -0.10676586627960205f;
  t274_n27: return 0.005820554215461016f;
  t274_n28: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t274_n58;
  t274_n29: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t274_n43;
  t274_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t274_n34;
  t274_n31: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t274_n33;
  t274_n32: return 0.05782734230160713f;
  t274_n33: return -0.144953653216362f;
  t274_n34: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t274_n38;
  t274_n35: if (E.getNumReferences() >= 3318000640 /*6293.5*/) goto t274_n37;
  t274_n36: return -0.08002349734306335f;
  t274_n37: return 0.12429457157850266f;
  t274_n38: if (E.getNumReferences() >= 3291176960 /*685.5*/) goto t274_n40;
  t274_n39: return -0.28907883167266846f;
  t274_n40: if (E.getNumReferences() >= 3294339072 /*878.5*/) goto t274_n42;
  t274_n41: return 0.10457852482795715f;
  t274_n42: return 0.07050852477550507f;
  t274_n43: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t274_n55;
  t274_n44: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t274_n54;
  t274_n45: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t274_n47;
  t274_n46: return -0.1060740202665329f;
  t274_n47: if (E.getNumReferences() >= 3289227264 /*566.5*/) goto t274_n49;
  t274_n48: return 0.11460157483816147f;
  t274_n49: if (E.getNumReferences() >= 3295690752 /*961.0*/) goto t274_n51;
  t274_n50: return -0.1405637264251709f;
  t274_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t274_n53;
  t274_n52: return 0.107828289270401f;
  t274_n53: return 0.09103654325008392f;
  t274_n54: return -0.25040504336357117f;
  t274_n55: if (E.getNumReferences() >= 3291029504 /*676.5*/) goto t274_n57;
  t274_n56: return 0.1155184656381607f;
  t274_n57: return 0.07387030869722366f;
  t274_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t274_n152;
  t274_n59: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t274_n151;
  t274_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t274_n136;
  t274_n61: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t274_n117;
  t274_n62: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t274_n86;
  t274_n63: if (E.getNumReferences() >= 3288662016 /*532.0*/) goto t274_n67;
  t274_n64: if (E.getNumReferences() >= 3288432640 /*518.0*/) goto t274_n66;
  t274_n65: return -0.039172712713479996f;
  t274_n66: return 0.1097930446267128f;
  t274_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t274_n85;
  t274_n68: if (E.getNumReferences() >= 3314260992 /*4467.5*/) goto t274_n84;
  t274_n69: if (E.getNumReferences() >= 3302797312 /*1765.5*/) goto t274_n79;
  t274_n70: if (E.getNumReferences() >= 3291463680 /*703.0*/) goto t274_n74;
  t274_n71: if (E.getNumReferences() >= 3290890240 /*668.0*/) goto t274_n73;
  t274_n72: return -0.038761384785175323f;
  t274_n73: return 0.10047018527984619f;
  t274_n74: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t274_n78;
  t274_n75: if (E.getNumReferences() >= 3292356608 /*757.5*/) goto t274_n77;
  t274_n76: return -0.8249486684799194f;
  t274_n77: return -0.10975154489278793f;
  t274_n78: return 0.07384754717350006f;
  t274_n79: if (E.getNumReferences() >= 3303575552 /*1860.5*/) goto t274_n81;
  t274_n80: return 0.10796822607517242f;
  t274_n81: if (E.getNumReferences() >= 3310970880 /*3478.5*/) goto t274_n83;
  t274_n82: return -0.09591950476169586f;
  t274_n83: return 0.10681251436471939f;
  t274_n84: return -0.15707632899284363f;
  t274_n85: return -0.35336020588874817f;
  t274_n86: if (E.getNumReferences() >= 3317244928 /*5924.5*/) goto t274_n114;
  t274_n87: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t274_n105;
  t274_n88: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t274_n100;
  t274_n89: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t274_n95;
  t274_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t274_n94;
  t274_n91: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t274_n93;
  t274_n92: return -0.16465380787849426f;
  t274_n93: return -0.6644179224967957f;
  t274_n94: return -0.0456058643758297f;
  t274_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t274_n97;
  t274_n96: return -0.5159109830856323f;
  t274_n97: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t274_n99;
  t274_n98: return -0.5195292830467224f;
  t274_n99: return -0.050112638622522354f;
  t274_n100: if (E.getNumReferences() >= 3284992000 /*410.0*/) goto t274_n104;
  t274_n101: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t274_n103;
  t274_n102: return -0.26288366317749023f;
  t274_n103: return 0.12123597413301468f;
  t274_n104: return -0.02834898792207241f;
  t274_n105: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t274_n107;
  t274_n106: return -0.043857622891664505f;
  t274_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t274_n109;
  t274_n108: return 0.005949351005256176f;
  t274_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t274_n113;
  t274_n110: if (E.getNumReferences() >= 3289448448 /*580.0*/) goto t274_n112;
  t274_n111: return 0.18747399747371674f;
  t274_n112: return -0.08202183246612549f;
  t274_n113: return 0.10791762918233871f;
  t274_n114: if (E.getNumReferences() >= 3321911808 /*8214.5*/) goto t274_n116;
  t274_n115: return 0.09593097865581512f;
  t274_n116: return -0.2397880256175995f;
  t274_n117: if (E.getNumReferences() >= 3291791360 /*723.0*/) goto t274_n131;
  t274_n118: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t274_n126;
  t274_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t274_n123;
  t274_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t274_n122;
  t274_n121: return -0.1340940296649933f;
  t274_n122: return 0.08379355072975159f;
  t274_n123: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t274_n125;
  t274_n124: return 0.11072813719511032f;
  t274_n125: return 0.045977529138326645f;
  t274_n126: if (E.getNumReferences() >= 3286204416 /*447.0*/) goto t274_n130;
  t274_n127: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t274_n129;
  t274_n128: return -3.1444900035858154f;
  t274_n129: return -0.15584196150302887f;
  t274_n130: return -0.07107935100793839f;
  t274_n131: if (E.getNumReferences() >= 3292323840 /*755.5*/) goto t274_n133;
  t274_n132: return -0.9795028567314148f;
  t274_n133: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t274_n135;
  t274_n134: return -0.10861244052648544f;
  t274_n135: return 0.046681102365255356f;
  t274_n136: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t274_n148;
  t274_n137: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t274_n139;
  t274_n138: return 0.01917448081076145f;
  t274_n139: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t274_n147;
  t274_n140: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t274_n142;
  t274_n141: return -0.13273443281650543f;
  t274_n142: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t274_n144;
  t274_n143: return 0.3092496693134308f;
  t274_n144: if (E.getNumReferences() >= 3302293504 /*1704.0*/) goto t274_n146;
  t274_n145: return 0.06781362742185593f;
  t274_n146: return 0.1431487649679184f;
  t274_n147: return 0.155690535902977f;
  t274_n148: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t274_n150;
  t274_n149: return 0.003256283700466156f;
  t274_n150: return 0.05846068635582924f;
  t274_n151: return -0.13849978148937225f;
  t274_n152: if (E.getNumReferences() >= 3286122496 /*444.5*/) goto t274_n156;
  t274_n153: if (E.getNumReferences() >= 3285368832 /*421.5*/) goto t274_n155;
  t274_n154: return 0.02675841562449932f;
  t274_n155: return 0.10389867424964905f;
  t274_n156: return 0.009261944331228733f;
  t274_n157: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t274_n177;
  t274_n158: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t274_n162;
  t274_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t274_n161;
  t274_n160: return -0.03821224346756935f;
  t274_n161: return 0.065894715487957f;
  t274_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t274_n164;
  t274_n163: return -0.07305784523487091f;
  t274_n164: if (E.getNumReferences() >= 3286761472 /*464.0*/) goto t274_n172;
  t274_n165: if (E.getNumReferences() >= 3286269952 /*449.0*/) goto t274_n171;
  t274_n166: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t274_n168;
  t274_n167: return 0.015135345980525017f;
  t274_n168: if (E.getNumReferences() >= 3285696512 /*431.5*/) goto t274_n170;
  t274_n169: return 0.09394926577806473f;
  t274_n170: return -0.12014550715684891f;
  t274_n171: return 0.08132800459861755f;
  t274_n172: if (E.getNumReferences() >= 3288186880 /*507.5*/) goto t274_n174;
  t274_n173: return -0.4069157540798187f;
  t274_n174: if (E.getNumReferences() >= 3288334336 /*512.0*/) goto t274_n176;
  t274_n175: return 0.09508407115936279f;
  t274_n176: return 0.04415477439761162f;
  t274_n177: return 0.08685418963432312f;
  t274_n178: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t274_n208;
  t274_n179: if (E.getNumReferences() >= 3284516864 /*395.5*/) goto t274_n183;
  t274_n180: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t274_n182;
  t274_n181: return -0.10590801388025284f;
  t274_n182: return 0.09796811640262604f;
  t274_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t274_n185;
  t274_n184: return 0.021726883947849274f;
  t274_n185: if (E.getNumReferences() >= 3289849856 /*604.5*/) goto t274_n195;
  t274_n186: if (E.getNumReferences() >= 3289677824 /*594.0*/) goto t274_n194;
  t274_n187: if (E.getNumReferences() >= 3288891392 /*546.0*/) goto t274_n193;
  t274_n188: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t274_n190;
  t274_n189: return -0.15515990555286407f;
  t274_n190: if (E.getNumReferences() >= 3285975040 /*440.0*/) goto t274_n192;
  t274_n191: return 0.10188545286655426f;
  t274_n192: return 0.02985912188887596f;
  t274_n193: return 0.11490967869758606f;
  t274_n194: return 0.10546955466270447f;
  t274_n195: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t274_n205;
  t274_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t274_n198;
  t274_n197: return -0.06709950417280197f;
  t274_n198: if (E.getNumReferences() >= 3297423360 /*1109.5*/) goto t274_n202;
  t274_n199: if (E.getNumReferences() >= 3292889088 /*790.0*/) goto t274_n201;
  t274_n200: return 0.06956489384174347f;
  t274_n201: return 0.10668207705020905f;
  t274_n202: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t274_n204;
  t274_n203: return -0.4154883325099945f;
  t274_n204: return 0.07684171199798584f;
  t274_n205: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t274_n207;
  t274_n206: return 0.08683925867080688f;
  t274_n207: return 0.016123943030834198f;
  t274_n208: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t274_n210;
  t274_n209: return -0.0007037675241008401f;
  t274_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t274_n212;
  t274_n211: return 0.004664168227463961f;
  t274_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t274_n254;
  t274_n213: if (E.getNumReferences() >= 3286646784 /*460.5*/) goto t274_n219;
  t274_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t274_n216;
  t274_n215: return -0.09436514228582382f;
  t274_n216: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t274_n218;
  t274_n217: return -0.1510152518749237f;
  t274_n218: return 0.12522973120212555f;
  t274_n219: if (E.getNumReferences() >= 3286712320 /*462.5*/) goto t274_n221;
  t274_n220: return 0.09039585292339325f;
  t274_n221: if (E.getNumReferences() >= 3287056384 /*473.0*/) goto t274_n225;
  t274_n222: if (E.getNumReferences() >= 3286990848 /*471.0*/) goto t274_n224;
  t274_n223: return 0.014905460178852081f;
  t274_n224: return 0.08665014803409576f;
  t274_n225: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t274_n253;
  t274_n226: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t274_n252;
  t274_n227: if (E.getNumReferences() >= 3300311040 /*1462.0*/) goto t274_n251;
  t274_n228: if (E.getNumReferences() >= 3299819520 /*1402.0*/) goto t274_n248;
  t274_n229: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t274_n231;
  t274_n230: return -0.053078893572092056f;
  t274_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t274_n233;
  t274_n232: return 0.04102148488163948f;
  t274_n233: if (E.getNumReferences() >= 3291422720 /*700.5*/) goto t274_n235;
  t274_n234: return 0.0114559605717659f;
  t274_n235: if (E.getNumReferences() >= 3292069888 /*740.0*/) goto t274_n237;
  t274_n236: return 0.10972021520137787f;
  t274_n237: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t274_n247;
  t274_n238: if (E.getNumReferences() >= 3292553216 /*769.5*/) goto t274_n240;
  t274_n239: return 0.006627675611525774f;
  t274_n240: if (E.getNumReferences() >= 3296256000 /*995.5*/) goto t274_n244;
  t274_n241: if (E.getNumReferences() >= 3293970432 /*856.0*/) goto t274_n243;
  t274_n242: return 0.12347692251205444f;
  t274_n243: return 0.1762036234140396f;
  t274_n244: if (E.getNumReferences() >= 3298041856 /*1185.0*/) goto t274_n246;
  t274_n245: return -0.07242642343044281f;
  t274_n246: return 0.09745687246322632f;
  t274_n247: return 0.047273870557546616f;
  t274_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t274_n250;
  t274_n249: return -0.09569644927978516f;
  t274_n250: return 0.11578826606273651f;
  t274_n251: return 0.022681105881929398f;
  t274_n252: return 0.003968062344938517f;
  t274_n253: return 0.005084900185465813f;
  t274_n254: return 0.1065460592508316f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree275(const Example& E) {
  t275_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t275_n2;
  t275_n1: return -0.0008722601924091578f;
  t275_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t275_n254;
  t275_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t275_n101;
  t275_n4: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t275_n58;
  t275_n5: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t275_n29;
  t275_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t275_n10;
  t275_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t275_n9;
  t275_n8: return -0.008663583546876907f;
  t275_n9: return -0.047370120882987976f;
  t275_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t275_n12;
  t275_n11: return -0.0020269076339900494f;
  t275_n12: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t275_n28;
  t275_n13: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t275_n15;
  t275_n14: return 0.03154369816184044f;
  t275_n15: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t275_n17;
  t275_n16: return -0.016758600249886513f;
  t275_n17: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t275_n19;
  t275_n18: return 0.10127152502536774f;
  t275_n19: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t275_n23;
  t275_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t275_n22;
  t275_n21: return 0.08830726891756058f;
  t275_n22: return 0.09962349385023117f;
  t275_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t275_n25;
  t275_n24: return 0.04499959200620651f;
  t275_n25: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t275_n27;
  t275_n26: return 0.045987486839294434f;
  t275_n27: return 0.146021768450737f;
  t275_n28: return -0.006261436268687248f;
  t275_n29: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t275_n31;
  t275_n30: return -0.05167798697948456f;
  t275_n31: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t275_n33;
  t275_n32: return -0.013474998064339161f;
  t275_n33: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t275_n55;
  t275_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Function))) goto t275_n36;
  t275_n35: return -0.018524151295423508f;
  t275_n36: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t275_n52;
  t275_n37: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t275_n47;
  t275_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t275_n46;
  t275_n39: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t275_n41;
  t275_n40: return 0.14523963630199432f;
  t275_n41: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t275_n45;
  t275_n42: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n44;
  t275_n43: return -0.2835027873516083f;
  t275_n44: return 0.0943041443824768f;
  t275_n45: return -0.05267103761434555f;
  t275_n46: return -0.0029191740322858095f;
  t275_n47: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t275_n51;
  t275_n48: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n50;
  t275_n49: return 0.11555762588977814f;
  t275_n50: return 0.17253223061561584f;
  t275_n51: return 0.08421199768781662f;
  t275_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t275_n54;
  t275_n53: return 0.037993814796209335f;
  t275_n54: return -0.0008709885296411812f;
  t275_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t275_n57;
  t275_n56: return -0.07846345007419586f;
  t275_n57: return 0.004556549247354269f;
  t275_n58: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t275_n86;
  t275_n59: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n61;
  t275_n60: return -0.005107522010803223f;
  t275_n61: if (E.getNumReferences() >= 3363951184 /*265874.5*/) goto t275_n85;
  t275_n62: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t275_n84;
  t275_n63: if (E.getNumReferences() >= 3278602240 /*235.5*/) goto t275_n81;
  t275_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t275_n80;
  t275_n65: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t275_n79;
  t275_n66: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t275_n76;
  t275_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t275_n75;
  t275_n68: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t275_n74;
  t275_n69: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t275_n73;
  t275_n70: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t275_n72;
  t275_n71: return 0.07645659893751144f;
  t275_n72: return 0.09063903987407684f;
  t275_n73: return -0.010063815861940384f;
  t275_n74: return 0.0400347039103508f;
  t275_n75: return -0.0687028244137764f;
  t275_n76: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t275_n78;
  t275_n77: return 0.08716040849685669f;
  t275_n78: return -0.12668852508068085f;
  t275_n79: return -0.019646788015961647f;
  t275_n80: return 0.005008689593523741f;
  t275_n81: if (E.getNumReferences() >= 3280486400 /*272.5*/) goto t275_n83;
  t275_n82: return 0.12059945613145828f;
  t275_n83: return 0.034664954990148544f;
  t275_n84: return 0.0056219156831502914f;
  t275_n85: return 0.04521685093641281f;
  t275_n86: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t275_n100;
  t275_n87: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t275_n89;
  t275_n88: return 0.09012136608362198f;
  t275_n89: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t275_n91;
  t275_n90: return -0.0058025033213198185f;
  t275_n91: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t275_n99;
  t275_n92: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t275_n98;
  t275_n93: if (E.getNumReferences() >= 3328268288 /*14422.0*/) goto t275_n97;
  t275_n94: if (E.getNumReferences() >= 3286122496 /*444.5*/) goto t275_n96;
  t275_n95: return 0.09408626705408096f;
  t275_n96: return -0.09007740765810013f;
  t275_n97: return 0.09637477248907089f;
  t275_n98: return 0.008084351196885109f;
  t275_n99: return 0.018687045201659203f;
  t275_n100: return 0.10605646669864655f;
  t275_n101: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t275_n107;
  t275_n102: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t275_n106;
  t275_n103: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n105;
  t275_n104: return 0.11599228531122208f;
  t275_n105: return -0.005865557584911585f;
  t275_n106: return -0.11258076876401901f;
  t275_n107: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t275_n253;
  t275_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t275_n110;
  t275_n109: return -0.09162381291389465f;
  t275_n110: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t275_n132;
  t275_n111: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t275_n131;
  t275_n112: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t275_n116;
  t275_n113: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t275_n115;
  t275_n114: return 0.02536049671471119f;
  t275_n115: return -0.7156781554222107f;
  t275_n116: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t275_n122;
  t275_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t275_n121;
  t275_n118: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t275_n120;
  t275_n119: return 0.09407306462526321f;
  t275_n120: return -0.09522237628698349f;
  t275_n121: return 0.037848662585020065f;
  t275_n122: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t275_n128;
  t275_n123: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t275_n125;
  t275_n124: return -0.031044354662299156f;
  t275_n125: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t275_n127;
  t275_n126: return 0.04601030796766281f;
  t275_n127: return -0.13223804533481598f;
  t275_n128: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t275_n130;
  t275_n129: return 0.10476183146238327f;
  t275_n130: return 0.003144137328490615f;
  t275_n131: return -0.07529082149267197f;
  t275_n132: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t275_n142;
  t275_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n141;
  t275_n134: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t275_n136;
  t275_n135: return 0.02270866185426712f;
  t275_n136: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t275_n138;
  t275_n137: return -0.1012941300868988f;
  t275_n138: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t275_n140;
  t275_n139: return 0.06824079155921936f;
  t275_n140: return -0.07915277034044266f;
  t275_n141: return 0.0035976364742964506f;
  t275_n142: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t275_n144;
  t275_n143: return -0.0017296049045398831f;
  t275_n144: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t275_n232;
  t275_n145: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t275_n231;
  t275_n146: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t275_n228;
  t275_n147: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t275_n205;
  t275_n148: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t275_n176;
  t275_n149: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t275_n175;
  t275_n150: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t275_n160;
  t275_n151: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n157;
  t275_n152: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t275_n156;
  t275_n153: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t275_n155;
  t275_n154: return 0.10862696170806885f;
  t275_n155: return 0.11138025671243668f;
  t275_n156: return -0.15992499887943268f;
  t275_n157: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t275_n159;
  t275_n158: return 0.01820412091910839f;
  t275_n159: return 0.4351242482662201f;
  t275_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t275_n170;
  t275_n161: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t275_n163;
  t275_n162: return 0.06381212919950485f;
  t275_n163: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t275_n169;
  t275_n164: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t275_n168;
  t275_n165: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t275_n167;
  t275_n166: return 0.06443388015031815f;
  t275_n167: return 0.11222435534000397f;
  t275_n168: return 0.10452774167060852f;
  t275_n169: return -0.07500752061605453f;
  t275_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n172;
  t275_n171: return 0.08865290135145187f;
  t275_n172: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t275_n174;
  t275_n173: return 0.11314556747674942f;
  t275_n174: return -0.06215394660830498f;
  t275_n175: return 0.02374875918030739f;
  t275_n176: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t275_n182;
  t275_n177: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t275_n179;
  t275_n178: return -0.0434330478310585f;
  t275_n179: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t275_n181;
  t275_n180: return 0.13269400596618652f;
  t275_n181: return -0.0015244574751704931f;
  t275_n182: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t275_n188;
  t275_n183: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t275_n187;
  t275_n184: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t275_n186;
  t275_n185: return -0.30553948879241943f;
  t275_n186: return 0.10670294612646103f;
  t275_n187: return 0.11332403868436813f;
  t275_n188: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t275_n190;
  t275_n189: return -0.060239527374506f;
  t275_n190: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t275_n204;
  t275_n191: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t275_n193;
  t275_n192: return -0.19659768044948578f;
  t275_n193: if (E.getNumReferences() >= 3278209024 /*229.5*/) goto t275_n201;
  t275_n194: if (E.getNumReferences() >= 3277324288 /*216.0*/) goto t275_n200;
  t275_n195: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t275_n199;
  t275_n196: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t275_n198;
  t275_n197: return 0.1160767674446106f;
  t275_n198: return 0.03374063968658447f;
  t275_n199: return 0.040521398186683655f;
  t275_n200: return 0.12691707909107208f;
  t275_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t275_n203;
  t275_n202: return 0.09311804920434952f;
  t275_n203: return 0.013689029030501842f;
  t275_n204: return -0.7233436107635498f;
  t275_n205: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t275_n225;
  t275_n206: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t275_n218;
  t275_n207: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t275_n217;
  t275_n208: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t275_n216;
  t275_n209: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t275_n215;
  t275_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t275_n214;
  t275_n211: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t275_n213;
  t275_n212: return 0.4249661862850189f;
  t275_n213: return 0.15138623118400574f;
  t275_n214: return -0.10099916905164719f;
  t275_n215: return -0.10516338795423508f;
  t275_n216: return 0.11067048460245132f;
  t275_n217: return -0.11863266676664352f;
  t275_n218: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t275_n220;
  t275_n219: return 0.10855823010206223f;
  t275_n220: if (E.getNumReferences() >= 3259760640 /*51.0*/) goto t275_n222;
  t275_n221: return 0.047502052038908005f;
  t275_n222: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t275_n224;
  t275_n223: return -0.6311695575714111f;
  t275_n224: return 0.11465905606746674f;
  t275_n225: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t275_n227;
  t275_n226: return -0.0040567428804934025f;
  t275_n227: return -0.9014007449150085f;
  t275_n228: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t275_n230;
  t275_n229: return -0.11935442686080933f;
  t275_n230: return 0.11028289794921875f;
  t275_n231: return -0.07176971435546875f;
  t275_n232: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t275_n242;
  t275_n233: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t275_n241;
  t275_n234: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t275_n240;
  t275_n235: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t275_n237;
  t275_n236: return -0.06745336204767227f;
  t275_n237: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t275_n239;
  t275_n238: return 0.16501787304878235f;
  t275_n239: return 0.09229850769042969f;
  t275_n240: return -0.36736860871315f;
  t275_n241: return -0.1700281798839569f;
  t275_n242: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t275_n252;
  t275_n243: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t275_n247;
  t275_n244: if (E.getNumReferences() >= 3261595648 /*58.0*/) goto t275_n246;
  t275_n245: return -0.2984693944454193f;
  t275_n246: return 0.08501418679952621f;
  t275_n247: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t275_n249;
  t275_n248: return 0.11048675328493118f;
  t275_n249: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t275_n251;
  t275_n250: return 0.11604470014572144f;
  t275_n251: return -0.21796652674674988f;
  t275_n252: return -0.14478494226932526f;
  t275_n253: return 0.02250482514500618f;
  t275_n254: return 0.002231793710961938f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree276(const Example& E) {
  t276_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t276_n2;
  t276_n1: return -0.0008145553874783218f;
  t276_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t276_n254;
  t276_n3: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t276_n97;
  t276_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t276_n32;
  t276_n5: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t276_n17;
  t276_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t276_n10;
  t276_n7: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t276_n9;
  t276_n8: return 0.09254157543182373f;
  t276_n9: return -0.568488597869873f;
  t276_n10: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n14;
  t276_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t276_n13;
  t276_n12: return -0.13387079536914825f;
  t276_n13: return 0.06771028786897659f;
  t276_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t276_n16;
  t276_n15: return -0.08661295473575592f;
  t276_n16: return 0.05034294351935387f;
  t276_n17: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t276_n27;
  t276_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t276_n22;
  t276_n19: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t276_n21;
  t276_n20: return -0.022226279601454735f;
  t276_n21: return -0.44313979148864746f;
  t276_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t276_n26;
  t276_n23: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t276_n25;
  t276_n24: return -0.3222096264362335f;
  t276_n25: return 0.11247611790895462f;
  t276_n26: return -0.11332527548074722f;
  t276_n27: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t276_n31;
  t276_n28: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t276_n30;
  t276_n29: return 0.1595979630947113f;
  t276_n30: return 0.03062356449663639f;
  t276_n31: return -0.0018395435763522983f;
  t276_n32: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t276_n34;
  t276_n33: return 0.000948573462665081f;
  t276_n34: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t276_n78;
  t276_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t276_n45;
  t276_n36: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t276_n38;
  t276_n37: return 0.0002136744005838409f;
  t276_n38: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t276_n44;
  t276_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t276_n43;
  t276_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n42;
  t276_n41: return -0.9506571292877197f;
  t276_n42: return -0.33095210790634155f;
  t276_n43: return 0.1633283942937851f;
  t276_n44: return -0.06493102759122849f;
  t276_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t276_n47;
  t276_n46: return -0.0844401940703392f;
  t276_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t276_n77;
  t276_n48: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t276_n50;
  t276_n49: return -0.011761737987399101f;
  t276_n50: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t276_n72;
  t276_n51: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t276_n55;
  t276_n52: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n54;
  t276_n53: return 0.07154294103384018f;
  t276_n54: return 0.009901142679154873f;
  t276_n55: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t276_n65;
  t276_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t276_n58;
  t276_n57: return 0.016924137249588966f;
  t276_n58: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t276_n64;
  t276_n59: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t276_n61;
  t276_n60: return 0.13333268463611603f;
  t276_n61: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t276_n63;
  t276_n62: return -0.5302838087081909f;
  t276_n63: return 0.047753434628248215f;
  t276_n64: return 0.13352929055690765f;
  t276_n65: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t276_n69;
  t276_n66: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t276_n68;
  t276_n67: return 0.12388481944799423f;
  t276_n68: return 0.11050965636968613f;
  t276_n69: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t276_n71;
  t276_n70: return 0.11945166438817978f;
  t276_n71: return 0.04941356182098389f;
  t276_n72: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t276_n74;
  t276_n73: return -0.009173017926514149f;
  t276_n74: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t276_n76;
  t276_n75: return -0.025244932621717453f;
  t276_n76: return 0.045596279203891754f;
  t276_n77: return -0.00632650637999177f;
  t276_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t276_n82;
  t276_n79: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t276_n81;
  t276_n80: return -0.0034023935440927744f;
  t276_n81: return -0.10912660509347916f;
  t276_n82: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t276_n96;
  t276_n83: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t276_n85;
  t276_n84: return 0.009951922111213207f;
  t276_n85: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t276_n95;
  t276_n86: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t276_n94;
  t276_n87: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t276_n91;
  t276_n88: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t276_n90;
  t276_n89: return 0.09377508610486984f;
  t276_n90: return 0.08194159716367722f;
  t276_n91: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t276_n93;
  t276_n92: return 0.12663032114505768f;
  t276_n93: return -0.017725767567753792f;
  t276_n94: return 0.05299096181988716f;
  t276_n95: return 0.06244586035609245f;
  t276_n96: return 0.004561457317322493f;
  t276_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t276_n173;
  t276_n98: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t276_n160;
  t276_n99: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t276_n139;
  t276_n100: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t276_n102;
  t276_n101: return -0.0014812814770266414f;
  t276_n102: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t276_n110;
  t276_n103: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t276_n105;
  t276_n104: return -0.04611366614699364f;
  t276_n105: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t276_n109;
  t276_n106: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t276_n108;
  t276_n107: return 0.10052650421857834f;
  t276_n108: return -0.10134756565093994f;
  t276_n109: return 0.004307464696466923f;
  t276_n110: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t276_n114;
  t276_n111: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t276_n113;
  t276_n112: return -0.004769459832459688f;
  t276_n113: return -0.08493735641241074f;
  t276_n114: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t276_n122;
  t276_n115: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t276_n117;
  t276_n116: return -0.2744795083999634f;
  t276_n117: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t276_n119;
  t276_n118: return -0.04199528321623802f;
  t276_n119: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t276_n121;
  t276_n120: return 0.13132813572883606f;
  t276_n121: return -0.21182721853256226f;
  t276_n122: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t276_n126;
  t276_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t276_n125;
  t276_n124: return 0.10543529689311981f;
  t276_n125: return -0.037685416638851166f;
  t276_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t276_n136;
  t276_n127: if (E.getNumReferences() >= 3259760640 /*51.0*/) goto t276_n133;
  t276_n128: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t276_n132;
  t276_n129: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t276_n131;
  t276_n130: return 0.010238615795969963f;
  t276_n131: return 0.11535916477441788f;
  t276_n132: return -0.041779737919569016f;
  t276_n133: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t276_n135;
  t276_n134: return 0.1129855290055275f;
  t276_n135: return 0.045268114656209946f;
  t276_n136: if (E.getNumReferences() >= 3283222528 /*356.0*/) goto t276_n138;
  t276_n137: return 0.09476260840892792f;
  t276_n138: return -0.04411202669143677f;
  t276_n139: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t276_n149;
  t276_n140: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t276_n148;
  t276_n141: if (E.getNumReferences() >= 3298136064 /*1196.5*/) goto t276_n147;
  t276_n142: if (E.getNumReferences() >= 3298004992 /*1180.5*/) goto t276_n144;
  t276_n143: return 0.014901559799909592f;
  t276_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t276_n146;
  t276_n145: return 0.05071108788251877f;
  t276_n146: return 0.21760733425617218f;
  t276_n147: return -0.020383575931191444f;
  t276_n148: return 0.020402662456035614f;
  t276_n149: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t276_n153;
  t276_n150: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t276_n152;
  t276_n151: return -0.009219027124345303f;
  t276_n152: return 0.11266562342643738f;
  t276_n153: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t276_n155;
  t276_n154: return -0.11545895040035248f;
  t276_n155: if (E.getNumReferences() >= 3303305216 /*1827.5*/) goto t276_n157;
  t276_n156: return -0.025262773036956787f;
  t276_n157: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t276_n159;
  t276_n158: return -0.47082167863845825f;
  t276_n159: return 0.10628953576087952f;
  t276_n160: if (E.getNumReferences() >= 3364952880 /*297177.5*/) goto t276_n170;
  t276_n161: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n167;
  t276_n162: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t276_n164;
  t276_n163: return 0.009217003360390663f;
  t276_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t276_n166;
  t276_n165: return 0.09093209356069565f;
  t276_n166: return 0.05771917849779129f;
  t276_n167: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t276_n169;
  t276_n168: return -0.08506546169519424f;
  t276_n169: return 0.035114310681819916f;
  t276_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t276_n172;
  t276_n171: return -0.03034280054271221f;
  t276_n172: return 0.06167708337306976f;
  t276_n173: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t276_n231;
  t276_n174: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t276_n204;
  t276_n175: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t276_n183;
  t276_n176: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t276_n178;
  t276_n177: return 0.022505803033709526f;
  t276_n178: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t276_n180;
  t276_n179: return -0.23944847285747528f;
  t276_n180: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t276_n182;
  t276_n181: return -0.0400911383330822f;
  t276_n182: return 0.03421967476606369f;
  t276_n183: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t276_n185;
  t276_n184: return -0.00870082713663578f;
  t276_n185: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n203;
  t276_n186: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t276_n202;
  t276_n187: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t276_n201;
  t276_n188: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t276_n196;
  t276_n189: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t276_n191;
  t276_n190: return 0.11486293375492096f;
  t276_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t276_n193;
  t276_n192: return -0.10487306118011475f;
  t276_n193: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t276_n195;
  t276_n194: return 0.025673897936940193f;
  t276_n195: return 0.11352366954088211f;
  t276_n196: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t276_n198;
  t276_n197: return -0.26029884815216064f;
  t276_n198: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t276_n200;
  t276_n199: return 0.11694282293319702f;
  t276_n200: return 0.22467753291130066f;
  t276_n201: return -0.1283019632101059f;
  t276_n202: return -0.08124514669179916f;
  t276_n203: return 0.03596383333206177f;
  t276_n204: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t276_n224;
  t276_n205: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t276_n215;
  t276_n206: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t276_n214;
  t276_n207: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t276_n209;
  t276_n208: return -0.08327562361955643f;
  t276_n209: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t276_n211;
  t276_n210: return -0.27566131949424744f;
  t276_n211: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t276_n213;
  t276_n212: return 0.10910122096538544f;
  t276_n213: return -0.36417892575263977f;
  t276_n214: return -0.01623273268342018f;
  t276_n215: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t276_n217;
  t276_n216: return 0.009580983780324459f;
  t276_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n223;
  t276_n218: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t276_n222;
  t276_n219: if (E.getNumReferences() >= 3255828480 /*36.0*/) goto t276_n221;
  t276_n220: return -0.4561728239059448f;
  t276_n221: return 0.11236035078763962f;
  t276_n222: return 0.10166065394878387f;
  t276_n223: return -0.0763779729604721f;
  t276_n224: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t276_n230;
  t276_n225: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t276_n227;
  t276_n226: return -0.17645609378814697f;
  t276_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t276_n229;
  t276_n228: return 0.1155596524477005f;
  t276_n229: return -0.13412757217884064f;
  t276_n230: return 0.010755171068012714f;
  t276_n231: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t276_n235;
  t276_n232: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t276_n234;
  t276_n233: return -0.007967577315866947f;
  t276_n234: return 0.011455468833446503f;
  t276_n235: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t276_n253;
  t276_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t276_n238;
  t276_n237: return 0.10206539928913116f;
  t276_n238: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t276_n250;
  t276_n239: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t276_n249;
  t276_n240: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t276_n246;
  t276_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n245;
  t276_n242: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t276_n244;
  t276_n243: return -0.2014504224061966f;
  t276_n244: return 0.10624305158853531f;
  t276_n245: return -0.07621145993471146f;
  t276_n246: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t276_n248;
  t276_n247: return 0.11326075345277786f;
  t276_n248: return 0.07792454212903976f;
  t276_n249: return -0.0626896545290947f;
  t276_n250: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t276_n252;
  t276_n251: return -0.026279151439666748f;
  t276_n252: return 0.10984189063310623f;
  t276_n253: return 0.012021641246974468f;
  t276_n254: return 0.0023225729819387197f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree277(const Example& E) {
  t277_n0: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t277_n252;
  t277_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t277_n3;
  t277_n2: return -2.4026456230785698e-05f;
  t277_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t277_n29;
  t277_n4: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t277_n20;
  t277_n5: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t277_n13;
  t277_n6: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t277_n10;
  t277_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t277_n9;
  t277_n8: return -0.019127285107970238f;
  t277_n9: return 0.08167087286710739f;
  t277_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t277_n12;
  t277_n11: return -0.0859576016664505f;
  t277_n12: return 0.04395516961812973f;
  t277_n13: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t277_n15;
  t277_n14: return -0.18170765042304993f;
  t277_n15: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t277_n19;
  t277_n16: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t277_n18;
  t277_n17: return -0.12895174324512482f;
  t277_n18: return -0.11364448070526123f;
  t277_n19: return -0.001933826133608818f;
  t277_n20: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t277_n22;
  t277_n21: return 0.10331084579229355f;
  t277_n22: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t277_n24;
  t277_n23: return -0.0007746167830191553f;
  t277_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t277_n26;
  t277_n25: return -0.07154730707406998f;
  t277_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t277_n28;
  t277_n27: return 0.0631183311343193f;
  t277_n28: return -0.07234769314527512f;
  t277_n29: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t277_n251;
  t277_n30: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t277_n248;
  t277_n31: if (E.getNumReferences() >= 3323708928 /*9969.5*/) goto t277_n241;
  t277_n32: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t277_n124;
  t277_n33: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t277_n35;
  t277_n34: return 0.020581314340233803f;
  t277_n35: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t277_n109;
  t277_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t277_n62;
  t277_n37: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t277_n41;
  t277_n38: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t277_n40;
  t277_n39: return -0.007858586497604847f;
  t277_n40: return -0.05109884962439537f;
  t277_n41: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t277_n53;
  t277_n42: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t277_n48;
  t277_n43: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t277_n45;
  t277_n44: return -0.004184836987406015f;
  t277_n45: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t277_n47;
  t277_n46: return 0.14172956347465515f;
  t277_n47: return 0.029200134798884392f;
  t277_n48: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t277_n52;
  t277_n49: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t277_n51;
  t277_n50: return -0.3230268359184265f;
  t277_n51: return 0.1367480605840683f;
  t277_n52: return -0.016394976526498795f;
  t277_n53: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t277_n57;
  t277_n54: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t277_n56;
  t277_n55: return 0.11156845092773438f;
  t277_n56: return 0.0889589935541153f;
  t277_n57: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t277_n61;
  t277_n58: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t277_n60;
  t277_n59: return 0.10703549534082413f;
  t277_n60: return -0.12077067792415619f;
  t277_n61: return -0.07284963876008987f;
  t277_n62: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t277_n80;
  t277_n63: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t277_n75;
  t277_n64: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t277_n66;
  t277_n65: return 0.03496309369802475f;
  t277_n66: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t277_n68;
  t277_n67: return -0.0965641513466835f;
  t277_n68: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t277_n74;
  t277_n69: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t277_n71;
  t277_n70: return 0.0179100651293993f;
  t277_n71: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t277_n73;
  t277_n72: return 0.010525195859372616f;
  t277_n73: return 0.18215247988700867f;
  t277_n74: return 0.08789321035146713f;
  t277_n75: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t277_n79;
  t277_n76: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t277_n78;
  t277_n77: return 0.15267761051654816f;
  t277_n78: return 0.14861907064914703f;
  t277_n79: return 0.0065987748093903065f;
  t277_n80: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t277_n82;
  t277_n81: return -0.15007257461547852f;
  t277_n82: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t277_n108;
  t277_n83: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t277_n105;
  t277_n84: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t277_n92;
  t277_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t277_n87;
  t277_n86: return 0.0015976623399183154f;
  t277_n87: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t277_n89;
  t277_n88: return -0.10795020312070847f;
  t277_n89: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t277_n91;
  t277_n90: return 0.12019115686416626f;
  t277_n91: return -0.4050194025039673f;
  t277_n92: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t277_n104;
  t277_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t277_n101;
  t277_n94: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t277_n98;
  t277_n95: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t277_n97;
  t277_n96: return -0.6340553760528564f;
  t277_n97: return 0.08949548751115799f;
  t277_n98: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t277_n100;
  t277_n99: return 0.1402163803577423f;
  t277_n100: return 0.016808252781629562f;
  t277_n101: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t277_n103;
  t277_n102: return 0.07903818786144257f;
  t277_n103: return -0.12486311048269272f;
  t277_n104: return -0.020631110295653343f;
  t277_n105: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t277_n107;
  t277_n106: return -0.19403177499771118f;
  t277_n107: return 0.04772607609629631f;
  t277_n108: return 0.053861103951931f;
  t277_n109: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t277_n113;
  t277_n110: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t277_n112;
  t277_n111: return -0.30428245663642883f;
  t277_n112: return 0.11050862073898315f;
  t277_n113: if (E.getNumReferences() >= 3293675520 /*838.0*/) goto t277_n119;
  t277_n114: if (E.getNumReferences() >= 3291987968 /*735.0*/) goto t277_n118;
  t277_n115: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t277_n117;
  t277_n116: return -0.05789916589856148f;
  t277_n117: return 0.028061265125870705f;
  t277_n118: return 0.08889203518629074f;
  t277_n119: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t277_n123;
  t277_n120: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t277_n122;
  t277_n121: return -0.33596494793891907f;
  t277_n122: return 0.05269069969654083f;
  t277_n123: return -0.013300331309437752f;
  t277_n124: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t277_n136;
  t277_n125: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t277_n133;
  t277_n126: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t277_n132;
  t277_n127: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t277_n131;
  t277_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t277_n130;
  t277_n129: return -0.05812111124396324f;
  t277_n130: return 0.009404129348695278f;
  t277_n131: return 0.023849720135331154f;
  t277_n132: return 0.1409132033586502f;
  t277_n133: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t277_n135;
  t277_n134: return -0.03519997000694275f;
  t277_n135: return -0.29445481300354004f;
  t277_n136: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t277_n186;
  t277_n137: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t277_n147;
  t277_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t277_n144;
  t277_n139: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t277_n143;
  t277_n140: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t277_n142;
  t277_n141: return -0.0281053576618433f;
  t277_n142: return -0.08390699326992035f;
  t277_n143: return 0.006180633790791035f;
  t277_n144: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t277_n146;
  t277_n145: return 0.0026562537532299757f;
  t277_n146: return -0.10415098816156387f;
  t277_n147: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t277_n153;
  t277_n148: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t277_n152;
  t277_n149: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t277_n151;
  t277_n150: return 0.10429756343364716f;
  t277_n151: return -0.11956058442592621f;
  t277_n152: return -0.15207135677337646f;
  t277_n153: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t277_n179;
  t277_n154: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t277_n166;
  t277_n155: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t277_n159;
  t277_n156: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t277_n158;
  t277_n157: return -0.10130380094051361f;
  t277_n158: return -0.46254271268844604f;
  t277_n159: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t277_n165;
  t277_n160: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t277_n162;
  t277_n161: return 0.0f;
  t277_n162: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t277_n164;
  t277_n163: return 0.0973525419831276f;
  t277_n164: return -0.05910249799489975f;
  t277_n165: return 0.024800816550850868f;
  t277_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t277_n170;
  t277_n167: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t277_n169;
  t277_n168: return 0.06696678698062897f;
  t277_n169: return 0.3085139989852905f;
  t277_n170: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t277_n176;
  t277_n171: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t277_n175;
  t277_n172: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t277_n174;
  t277_n173: return -0.10121184587478638f;
  t277_n174: return 0.10034927725791931f;
  t277_n175: return 0.11460010707378387f;
  t277_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t277_n178;
  t277_n177: return -0.505709707736969f;
  t277_n178: return 0.1666792780160904f;
  t277_n179: if (E.getNumReferences() >= 3301568512 /*1615.5*/) goto t277_n181;
  t277_n180: return -0.04031198099255562f;
  t277_n181: if (E.getNumReferences() >= 3301761024 /*1639.0*/) goto t277_n185;
  t277_n182: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t277_n184;
  t277_n183: return 0.19545257091522217f;
  t277_n184: return -0.03496947139501572f;
  t277_n185: return 0.0356200747191906f;
  t277_n186: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t277_n192;
  t277_n187: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t277_n189;
  t277_n188: return 0.005557127296924591f;
  t277_n189: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t277_n191;
  t277_n190: return -0.031324855983257294f;
  t277_n191: return 0.1300443708896637f;
  t277_n192: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t277_n204;
  t277_n193: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t277_n197;
  t277_n194: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t277_n196;
  t277_n195: return -0.3596130907535553f;
  t277_n196: return -0.4932118058204651f;
  t277_n197: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t277_n199;
  t277_n198: return 0.05478818342089653f;
  t277_n199: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t277_n201;
  t277_n200: return 0.021915633231401443f;
  t277_n201: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t277_n203;
  t277_n202: return -0.114412322640419f;
  t277_n203: return 0.08576854318380356f;
  t277_n204: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t277_n230;
  t277_n205: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t277_n229;
  t277_n206: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t277_n216;
  t277_n207: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t277_n215;
  t277_n208: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t277_n214;
  t277_n209: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t277_n213;
  t277_n210: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t277_n212;
  t277_n211: return -0.3590363562107086f;
  t277_n212: return -0.9596304893493652f;
  t277_n213: return -0.06697729974985123f;
  t277_n214: return 0.010264805518090725f;
  t277_n215: return -0.056049346923828125f;
  t277_n216: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t277_n218;
  t277_n217: return -0.060561783611774445f;
  t277_n218: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t277_n224;
  t277_n219: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t277_n221;
  t277_n220: return -0.047572407871484756f;
  t277_n221: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t277_n223;
  t277_n222: return -0.11462529748678207f;
  t277_n223: return 0.10930949449539185f;
  t277_n224: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t277_n226;
  t277_n225: return 0.10212986916303635f;
  t277_n226: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t277_n228;
  t277_n227: return -0.2931008040904999f;
  t277_n228: return 0.0916864201426506f;
  t277_n229: return -0.6947469711303711f;
  t277_n230: if (E.getNumReferences() >= 3282960384 /*348.0*/) goto t277_n240;
  t277_n231: if (E.getNumReferences() >= 3281829888 /*313.5*/) goto t277_n239;
  t277_n232: if (E.getNumReferences() >= 3278209024 /*229.5*/) goto t277_n238;
  t277_n233: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t277_n237;
  t277_n234: if (E.getNumReferences() >= 3272114176 /*136.5*/) goto t277_n236;
  t277_n235: return 0.09538327902555466f;
  t277_n236: return -0.15063126385211945f;
  t277_n237: return 0.11651613563299179f;
  t277_n238: return -0.02316010184586048f;
  t277_n239: return 0.09407202899456024f;
  t277_n240: return -0.018603401258587837f;
  t277_n241: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t277_n247;
  t277_n242: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t277_n244;
  t277_n243: return 0.04633164778351784f;
  t277_n244: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t277_n246;
  t277_n245: return 0.10419701784849167f;
  t277_n246: return -0.20093318819999695f;
  t277_n247: return 0.012158913537859917f;
  t277_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t277_n250;
  t277_n249: return -0.10573960840702057f;
  t277_n250: return 0.007717037573456764f;
  t277_n251: return -0.00010794147237902507f;
  t277_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t277_n254;
  t277_n253: return -0.11297336220741272f;
  t277_n254: return -0.06378210335969925f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree278(const Example& E) {
  t278_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t278_n250;
  t278_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t278_n95;
  t278_n2: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t278_n94;
  t278_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t278_n39;
  t278_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t278_n6;
  t278_n5: return 0.006579677574336529f;
  t278_n6: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t278_n36;
  t278_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t278_n11;
  t278_n8: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t278_n10;
  t278_n9: return 0.026580005884170532f;
  t278_n10: return -0.07025980949401855f;
  t278_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n23;
  t278_n12: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t278_n22;
  t278_n13: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t278_n17;
  t278_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n16;
  t278_n15: return -0.0066936686635017395f;
  t278_n16: return 0.07400637120008469f;
  t278_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t278_n19;
  t278_n18: return 0.05557025969028473f;
  t278_n19: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t278_n21;
  t278_n20: return 0.10778338462114334f;
  t278_n21: return 0.09238967299461365f;
  t278_n22: return 0.023426571860909462f;
  t278_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n29;
  t278_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t278_n28;
  t278_n25: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t278_n27;
  t278_n26: return -0.003556353272870183f;
  t278_n27: return 0.08835957944393158f;
  t278_n28: return -0.21954023838043213f;
  t278_n29: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t278_n31;
  t278_n30: return 0.015202966518700123f;
  t278_n31: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t278_n35;
  t278_n32: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t278_n34;
  t278_n33: return 0.05423160269856453f;
  t278_n34: return 0.1366138607263565f;
  t278_n35: return -0.30136480927467346f;
  t278_n36: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t278_n38;
  t278_n37: return -0.25438231229782104f;
  t278_n38: return 0.11763054877519608f;
  t278_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t278_n83;
  t278_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n44;
  t278_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t278_n43;
  t278_n42: return -0.06391981989145279f;
  t278_n43: return 0.06255032867193222f;
  t278_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t278_n70;
  t278_n45: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t278_n51;
  t278_n46: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t278_n50;
  t278_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t278_n49;
  t278_n48: return -0.40926867723464966f;
  t278_n49: return 0.012848610989749432f;
  t278_n50: return -0.2588683068752289f;
  t278_n51: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t278_n57;
  t278_n52: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t278_n56;
  t278_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n55;
  t278_n54: return -0.3274013102054596f;
  t278_n55: return 0.09739644080400467f;
  t278_n56: return 0.1255979686975479f;
  t278_n57: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t278_n61;
  t278_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t278_n60;
  t278_n59: return -0.26963353157043457f;
  t278_n60: return 0.08280761539936066f;
  t278_n61: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t278_n67;
  t278_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n64;
  t278_n63: return -0.033642515540122986f;
  t278_n64: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t278_n66;
  t278_n65: return 0.08967249095439911f;
  t278_n66: return 0.016386142000555992f;
  t278_n67: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t278_n69;
  t278_n68: return -0.18699730932712555f;
  t278_n69: return 0.04037795588374138f;
  t278_n70: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t278_n78;
  t278_n71: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t278_n73;
  t278_n72: return 0.03705926612019539f;
  t278_n73: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t278_n75;
  t278_n74: return 0.07424243539571762f;
  t278_n75: if (E.getNumReferences() >= 3251634176 /*26.0*/) goto t278_n77;
  t278_n76: return 0.11924582719802856f;
  t278_n77: return -0.1063745990395546f;
  t278_n78: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t278_n82;
  t278_n79: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t278_n81;
  t278_n80: return 0.11862460523843765f;
  t278_n81: return 0.0825238972902298f;
  t278_n82: return 0.034361060708761215f;
  t278_n83: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n93;
  t278_n84: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t278_n92;
  t278_n85: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t278_n91;
  t278_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n88;
  t278_n87: return -0.10239730030298233f;
  t278_n88: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t278_n90;
  t278_n89: return 0.09877005964517593f;
  t278_n90: return 0.10707342624664307f;
  t278_n91: return 0.0399295836687088f;
  t278_n92: return 0.05084504559636116f;
  t278_n93: return 0.04461078345775604f;
  t278_n94: return -0.002275702776387334f;
  t278_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t278_n175;
  t278_n96: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t278_n166;
  t278_n97: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t278_n107;
  t278_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t278_n102;
  t278_n99: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t278_n101;
  t278_n100: return 0.05478822439908981f;
  t278_n101: return -0.21616092324256897f;
  t278_n102: if (E.getNumReferences() >= 3243245568 /*13.0*/) goto t278_n106;
  t278_n103: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n105;
  t278_n104: return 0.10778061300516129f;
  t278_n105: return 0.03317462280392647f;
  t278_n106: return 0.01501523982733488f;
  t278_n107: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t278_n155;
  t278_n108: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t278_n148;
  t278_n109: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t278_n125;
  t278_n110: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t278_n118;
  t278_n111: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t278_n113;
  t278_n112: return -0.004975901450961828f;
  t278_n113: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t278_n117;
  t278_n114: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t278_n116;
  t278_n115: return -0.23428353667259216f;
  t278_n116: return 0.2123987227678299f;
  t278_n117: return 0.085941843688488f;
  t278_n118: if (E.getNumReferences() >= 3309711360 /*3171.0*/) goto t278_n124;
  t278_n119: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t278_n123;
  t278_n120: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t278_n122;
  t278_n121: return -0.12498242408037186f;
  t278_n122: return -0.39826324582099915f;
  t278_n123: return -0.022720549255609512f;
  t278_n124: return 0.02799614891409874f;
  t278_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t278_n131;
  t278_n126: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t278_n128;
  t278_n127: return 0.0629810318350792f;
  t278_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n130;
  t278_n129: return 0.10797899961471558f;
  t278_n130: return 0.08317450433969498f;
  t278_n131: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t278_n137;
  t278_n132: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t278_n134;
  t278_n133: return 0.024648120626807213f;
  t278_n134: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t278_n136;
  t278_n135: return -0.5210446715354919f;
  t278_n136: return -0.01677219569683075f;
  t278_n137: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t278_n141;
  t278_n138: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t278_n140;
  t278_n139: return -0.3233487010002136f;
  t278_n140: return 0.0438089482486248f;
  t278_n141: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t278_n143;
  t278_n142: return 0.119831882417202f;
  t278_n143: if (E.getNumReferences() >= 3281666048 /*308.5*/) goto t278_n145;
  t278_n144: return -0.14588484168052673f;
  t278_n145: if (E.getNumReferences() >= 3332881408 /*21470.0*/) goto t278_n147;
  t278_n146: return 0.11355443298816681f;
  t278_n147: return 0.05040978640317917f;
  t278_n148: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t278_n150;
  t278_n149: return -0.05858014151453972f;
  t278_n150: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t278_n154;
  t278_n151: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t278_n153;
  t278_n152: return -1.5396077632904053f;
  t278_n153: return -0.19381938874721527f;
  t278_n154: return -0.2044840157032013f;
  t278_n155: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t278_n157;
  t278_n156: return -0.038913603872060776f;
  t278_n157: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t278_n165;
  t278_n158: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t278_n164;
  t278_n159: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n161;
  t278_n160: return -0.13123507797718048f;
  t278_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t278_n163;
  t278_n162: return 0.09906835108995438f;
  t278_n163: return 0.018838685005903244f;
  t278_n164: return 0.08557764440774918f;
  t278_n165: return 0.022593140602111816f;
  t278_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n174;
  t278_n167: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t278_n173;
  t278_n168: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t278_n172;
  t278_n169: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t278_n171;
  t278_n170: return -0.14938940107822418f;
  t278_n171: return -0.10148649662733078f;
  t278_n172: return 0.008581782691180706f;
  t278_n173: return -0.018482277169823647f;
  t278_n174: return -0.0204616691917181f;
  t278_n175: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t278_n235;
  t278_n176: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t278_n234;
  t278_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t278_n179;
  t278_n178: return -0.012829042971134186f;
  t278_n179: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t278_n233;
  t278_n180: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t278_n182;
  t278_n181: return 0.00037265062564983964f;
  t278_n182: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t278_n200;
  t278_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t278_n185;
  t278_n184: return 0.0033682279754430056f;
  t278_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t278_n197;
  t278_n186: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n188;
  t278_n187: return 0.04880242422223091f;
  t278_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t278_n196;
  t278_n189: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t278_n195;
  t278_n190: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t278_n194;
  t278_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t278_n193;
  t278_n192: return 0.01110877189785242f;
  t278_n193: return 0.1136757954955101f;
  t278_n194: return 0.13795356452465057f;
  t278_n195: return 0.0382830873131752f;
  t278_n196: return 0.04444018006324768f;
  t278_n197: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t278_n199;
  t278_n198: return 0.007782378233969212f;
  t278_n199: return 0.05431767925620079f;
  t278_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t278_n216;
  t278_n201: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t278_n215;
  t278_n202: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t278_n208;
  t278_n203: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t278_n207;
  t278_n204: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t278_n206;
  t278_n205: return -0.12641742825508118f;
  t278_n206: return 0.019299160689115524f;
  t278_n207: return 0.09784293919801712f;
  t278_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t278_n210;
  t278_n209: return -0.07543954998254776f;
  t278_n210: if (E.getNumReferences() >= 3327834624 /*13998.5*/) goto t278_n214;
  t278_n211: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t278_n213;
  t278_n212: return 0.11744139343500137f;
  t278_n213: return 0.09751220047473907f;
  t278_n214: return 0.03399742767214775f;
  t278_n215: return -0.0005937851965427399f;
  t278_n216: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t278_n232;
  t278_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t278_n219;
  t278_n218: return 0.012826112098991871f;
  t278_n219: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t278_n229;
  t278_n220: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t278_n224;
  t278_n221: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t278_n223;
  t278_n222: return 0.1238420382142067f;
  t278_n223: return -0.01052157487720251f;
  t278_n224: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t278_n228;
  t278_n225: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t278_n227;
  t278_n226: return 0.08712541311979294f;
  t278_n227: return 0.20407168567180634f;
  t278_n228: return 0.11198756843805313f;
  t278_n229: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t278_n231;
  t278_n230: return 0.07680962979793549f;
  t278_n231: return 0.10109599679708481f;
  t278_n232: return -0.2204572707414627f;
  t278_n233: return -0.021252118051052094f;
  t278_n234: return -0.007489602081477642f;
  t278_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t278_n237;
  t278_n236: return 0.011025740765035152f;
  t278_n237: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t278_n241;
  t278_n238: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t278_n240;
  t278_n239: return 0.06772234290838242f;
  t278_n240: return -0.06750716269016266f;
  t278_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t278_n243;
  t278_n242: return -0.06930069625377655f;
  t278_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n249;
  t278_n244: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t278_n248;
  t278_n245: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t278_n247;
  t278_n246: return -0.10480455309152603f;
  t278_n247: return 0.09536249935626984f;
  t278_n248: return -0.12427201867103577f;
  t278_n249: return 0.0048832339234650135f;
  t278_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n254;
  t278_n251: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t278_n253;
  t278_n252: return -0.007099279668182135f;
  t278_n253: return 0.005538186524063349f;
  t278_n254: return 0.0018399425316601992f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree279(const Example& E) {
  t279_n0: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t279_n2;
  t279_n1: return -0.00041070388397201896f;
  t279_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t279_n120;
  t279_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t279_n45;
  t279_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t279_n6;
  t279_n5: return 0.0028706334996968508f;
  t279_n6: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t279_n32;
  t279_n7: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t279_n25;
  t279_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t279_n18;
  t279_n9: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t279_n11;
  t279_n10: return -0.025562645867466927f;
  t279_n11: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t279_n13;
  t279_n12: return -0.12811101973056793f;
  t279_n13: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t279_n17;
  t279_n14: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t279_n16;
  t279_n15: return 0.12120804190635681f;
  t279_n16: return 0.13811521232128143f;
  t279_n17: return 0.11940986663103104f;
  t279_n18: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t279_n24;
  t279_n19: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t279_n21;
  t279_n20: return 0.13516798615455627f;
  t279_n21: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t279_n23;
  t279_n22: return 0.11546877026557922f;
  t279_n23: return -0.4414885640144348f;
  t279_n24: return -0.2296466827392578f;
  t279_n25: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t279_n27;
  t279_n26: return -0.08911667764186859f;
  t279_n27: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t279_n29;
  t279_n28: return 0.04086155816912651f;
  t279_n29: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t279_n31;
  t279_n30: return 0.11291202902793884f;
  t279_n31: return -0.007698480971157551f;
  t279_n32: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t279_n40;
  t279_n33: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t279_n35;
  t279_n34: return 0.011158653534948826f;
  t279_n35: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t279_n37;
  t279_n36: return 0.018469203263521194f;
  t279_n37: if (E.getNumReferences() >= 3266838528 /*92.0*/) goto t279_n39;
  t279_n38: return -0.1370045244693756f;
  t279_n39: return 0.11472474783658981f;
  t279_n40: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t279_n44;
  t279_n41: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t279_n43;
  t279_n42: return -0.07399626076221466f;
  t279_n43: return 0.11813758313655853f;
  t279_n44: return -0.15220382809638977f;
  t279_n45: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t279_n83;
  t279_n46: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t279_n80;
  t279_n47: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t279_n59;
  t279_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t279_n50;
  t279_n49: return 0.0059743463061749935f;
  t279_n50: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t279_n56;
  t279_n51: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t279_n55;
  t279_n52: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t279_n54;
  t279_n53: return -0.02957492507994175f;
  t279_n54: return 0.11931413412094116f;
  t279_n55: return 0.12704749405384064f;
  t279_n56: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t279_n58;
  t279_n57: return -0.20117832720279694f;
  t279_n58: return 0.09224028140306473f;
  t279_n59: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t279_n61;
  t279_n60: return -0.031893737614154816f;
  t279_n61: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t279_n65;
  t279_n62: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t279_n64;
  t279_n63: return 0.10965141654014587f;
  t279_n64: return -0.10571538656949997f;
  t279_n65: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t279_n77;
  t279_n66: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t279_n74;
  t279_n67: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t279_n73;
  t279_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t279_n70;
  t279_n69: return 0.014163524843752384f;
  t279_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t279_n72;
  t279_n71: return 0.11986090242862701f;
  t279_n72: return -0.02234531007707119f;
  t279_n73: return 0.020692288875579834f;
  t279_n74: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t279_n76;
  t279_n75: return 0.10612775385379791f;
  t279_n76: return 0.056885603815317154f;
  t279_n77: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t279_n79;
  t279_n78: return 0.009515030309557915f;
  t279_n79: return 0.09516891837120056f;
  t279_n80: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t279_n82;
  t279_n81: return -0.012966156005859375f;
  t279_n82: return 0.10312318801879883f;
  t279_n83: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t279_n107;
  t279_n84: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t279_n106;
  t279_n85: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t279_n89;
  t279_n86: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t279_n88;
  t279_n87: return -0.16940733790397644f;
  t279_n88: return 0.10689855366945267f;
  t279_n89: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t279_n91;
  t279_n90: return -0.036611005663871765f;
  t279_n91: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t279_n105;
  t279_n92: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t279_n98;
  t279_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t279_n95;
  t279_n94: return -0.2737055718898773f;
  t279_n95: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t279_n97;
  t279_n96: return -0.3950292766094208f;
  t279_n97: return 0.10915199667215347f;
  t279_n98: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t279_n100;
  t279_n99: return 0.09139709174633026f;
  t279_n100: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t279_n102;
  t279_n101: return -0.010173331014811993f;
  t279_n102: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t279_n104;
  t279_n103: return 0.08864784240722656f;
  t279_n104: return 0.16225554049015045f;
  t279_n105: return -0.07029896229505539f;
  t279_n106: return 0.10630036145448685f;
  t279_n107: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t279_n117;
  t279_n108: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t279_n116;
  t279_n109: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t279_n111;
  t279_n110: return -0.08841422945261002f;
  t279_n111: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t279_n115;
  t279_n112: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t279_n114;
  t279_n113: return 0.09437920153141022f;
  t279_n114: return 0.058476462960243225f;
  t279_n115: return -0.013833433389663696f;
  t279_n116: return 0.09483952075242996f;
  t279_n117: if (E.getNumReferences() >= 3275128832 /*182.5*/) goto t279_n119;
  t279_n118: return -0.43834787607192993f;
  t279_n119: return -0.0312344990670681f;
  t279_n120: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t279_n122;
  t279_n121: return -0.0014009708538651466f;
  t279_n122: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t279_n166;
  t279_n123: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t279_n139;
  t279_n124: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t279_n136;
  t279_n125: if (E.getNumReferences() >= 3264872448 /*77.0*/) goto t279_n127;
  t279_n126: return -0.0841573178768158f;
  t279_n127: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t279_n129;
  t279_n128: return 0.1332920640707016f;
  t279_n129: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t279_n135;
  t279_n130: if (E.getNumReferences() >= 3272867840 /*148.0*/) goto t279_n132;
  t279_n131: return -0.000826087431050837f;
  t279_n132: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t279_n134;
  t279_n133: return 0.06809946149587631f;
  t279_n134: return 0.10692090541124344f;
  t279_n135: return -0.11957315355539322f;
  t279_n136: if (E.getNumReferences() >= 3264741376 /*76.0*/) goto t279_n138;
  t279_n137: return 0.1004827693104744f;
  t279_n138: return 0.06019216403365135f;
  t279_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t279_n145;
  t279_n140: if (E.getNumReferences() >= 3301228544 /*1574.0*/) goto t279_n142;
  t279_n141: return -0.04709358513355255f;
  t279_n142: if (E.getNumReferences() >= 3301416960 /*1597.0*/) goto t279_n144;
  t279_n143: return 0.1065712422132492f;
  t279_n144: return 0.01478119008243084f;
  t279_n145: if (E.getNumReferences() >= 3301847040 /*1649.5*/) goto t279_n165;
  t279_n146: if (E.getNumReferences() >= 3277750272 /*222.5*/) goto t279_n148;
  t279_n147: return 0.024988213554024696f;
  t279_n148: if (E.getNumReferences() >= 3277815808 /*223.5*/) goto t279_n154;
  t279_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t279_n153;
  t279_n150: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t279_n152;
  t279_n151: return -0.10249660164117813f;
  t279_n152: return 3.0883753299713135f;
  t279_n153: return 0.1250436156988144f;
  t279_n154: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t279_n164;
  t279_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t279_n157;
  t279_n156: return 0.028168847784399986f;
  t279_n157: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t279_n159;
  t279_n158: return 0.03284112364053726f;
  t279_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t279_n161;
  t279_n160: return 0.07514990121126175f;
  t279_n161: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t279_n163;
  t279_n162: return 0.1122707650065422f;
  t279_n163: return 0.10367385298013687f;
  t279_n164: return 0.03175930306315422f;
  t279_n165: return -0.009090682491660118f;
  t279_n166: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t279_n174;
  t279_n167: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t279_n173;
  t279_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Expression))) goto t279_n170;
  t279_n169: return -0.11036514490842819f;
  t279_n170: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t279_n172;
  t279_n171: return 0.10533293336629868f;
  t279_n172: return -0.021434737369418144f;
  t279_n173: return -0.5050637722015381f;
  t279_n174: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t279_n240;
  t279_n175: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t279_n235;
  t279_n176: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t279_n234;
  t279_n177: if (E.getNumReferences() >= 3313941504 /*4311.5*/) goto t279_n225;
  t279_n178: if (E.getNumReferences() >= 3290079232 /*618.5*/) goto t279_n222;
  t279_n179: if (E.getNumReferences() >= 3290038272 /*616.0*/) goto t279_n221;
  t279_n180: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t279_n212;
  t279_n181: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t279_n211;
  t279_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t279_n188;
  t279_n183: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t279_n185;
  t279_n184: return -0.1886570304632187f;
  t279_n185: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t279_n187;
  t279_n186: return 0.09638898819684982f;
  t279_n187: return 0.04529581964015961f;
  t279_n188: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t279_n210;
  t279_n189: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t279_n191;
  t279_n190: return 0.10879827290773392f;
  t279_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t279_n193;
  t279_n192: return -0.13615921139717102f;
  t279_n193: if (E.getNumReferences() >= 3267297280 /*95.5*/) goto t279_n209;
  t279_n194: if (E.getNumReferences() >= 3266379776 /*88.5*/) goto t279_n208;
  t279_n195: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t279_n207;
  t279_n196: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t279_n198;
  t279_n197: return 0.06414943188428879f;
  t279_n198: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t279_n202;
  t279_n199: if (E.getNumReferences() >= 3263430656 /*66.0*/) goto t279_n201;
  t279_n200: return 0.12767459452152252f;
  t279_n201: return 0.08235250413417816f;
  t279_n202: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t279_n206;
  t279_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t279_n205;
  t279_n204: return -0.11826609820127487f;
  t279_n205: return 0.12195166200399399f;
  t279_n206: return -0.11061357706785202f;
  t279_n207: return -0.04760150983929634f;
  t279_n208: return 0.11583667248487473f;
  t279_n209: return 0.011872630566358566f;
  t279_n210: return 0.10727618634700775f;
  t279_n211: return -0.015980374068021774f;
  t279_n212: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t279_n218;
  t279_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t279_n215;
  t279_n214: return -0.4144437909126282f;
  t279_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t279_n217;
  t279_n216: return -0.3078831136226654f;
  t279_n217: return 0.08859140425920486f;
  t279_n218: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t279_n220;
  t279_n219: return 0.010320114903151989f;
  t279_n220: return -0.09380321204662323f;
  t279_n221: return 0.09463086724281311f;
  t279_n222: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t279_n224;
  t279_n223: return -0.08319052308797836f;
  t279_n224: return 0.010520048439502716f;
  t279_n225: if (E.getNumReferences() >= 3326809600 /*12997.5*/) goto t279_n233;
  t279_n226: if (E.getNumReferences() >= 3318675456 /*6623.0*/) goto t279_n228;
  t279_n227: return 0.0356840081512928f;
  t279_n228: if (E.getNumReferences() >= 3319357440 /*6956.0*/) goto t279_n230;
  t279_n229: return 0.1247696653008461f;
  t279_n230: if (E.getNumReferences() >= 3323836416 /*10094.0*/) goto t279_n232;
  t279_n231: return 0.06104579567909241f;
  t279_n232: return 0.1699139028787613f;
  t279_n233: return 0.018617823719978333f;
  t279_n234: return 0.041300948709249496f;
  t279_n235: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t279_n239;
  t279_n236: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t279_n238;
  t279_n237: return -0.007685762830078602f;
  t279_n238: return 0.11943908780813217f;
  t279_n239: return 0.004379970952868462f;
  t279_n240: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t279_n254;
  t279_n241: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t279_n245;
  t279_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t279_n244;
  t279_n243: return -0.0833214819431305f;
  t279_n244: return 0.12587890028953552f;
  t279_n245: if (E.getNumReferences() >= 3288948736 /*549.5*/) goto t279_n247;
  t279_n246: return 0.05426182225346565f;
  t279_n247: if (E.getNumReferences() >= 3291684864 /*716.5*/) goto t279_n249;
  t279_n248: return 0.12309571355581284f;
  t279_n249: if (E.getNumReferences() >= 3308023808 /*2759.0*/) goto t279_n251;
  t279_n250: return -0.09291550517082214f;
  t279_n251: if (E.getNumReferences() >= 3308718080 /*2928.5*/) goto t279_n253;
  t279_n252: return 0.12465312331914902f;
  t279_n253: return 0.043974872678518295f;
  t279_n254: return 0.03759480267763138f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree280(const Example& E) {
  t280_n0: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t280_n8;
  t280_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t280_n3;
  t280_n2: return -0.029486989602446556f;
  t280_n3: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t280_n7;
  t280_n4: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t280_n6;
  t280_n5: return 5.004979175282642e-05f;
  t280_n6: return 0.007476980332285166f;
  t280_n7: return -0.016226043924689293f;
  t280_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t280_n176;
  t280_n9: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t280_n11;
  t280_n10: return -0.005926317069679499f;
  t280_n11: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t280_n13;
  t280_n12: return -0.003956463187932968f;
  t280_n13: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t280_n175;
  t280_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t280_n88;
  t280_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t280_n53;
  t280_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t280_n18;
  t280_n17: return 0.002162389224395156f;
  t280_n18: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t280_n24;
  t280_n19: if (E.getNumReferences() >= 3297677312 /*1140.5*/) goto t280_n21;
  t280_n20: return 0.012434015981853008f;
  t280_n21: if (E.getNumReferences() >= 3297751040 /*1149.5*/) goto t280_n23;
  t280_n22: return 0.18161848187446594f;
  t280_n23: return 0.050924111157655716f;
  t280_n24: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t280_n52;
  t280_n25: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t280_n27;
  t280_n26: return 0.04647967219352722f;
  t280_n27: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t280_n51;
  t280_n28: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t280_n50;
  t280_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n49;
  t280_n30: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n40;
  t280_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t280_n33;
  t280_n32: return -0.13138209283351898f;
  t280_n33: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t280_n37;
  t280_n34: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t280_n36;
  t280_n35: return 0.0775982066988945f;
  t280_n36: return -0.06718258559703827f;
  t280_n37: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t280_n39;
  t280_n38: return 0.08223174512386322f;
  t280_n39: return 0.08023722469806671f;
  t280_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t280_n42;
  t280_n41: return 0.07151814550161362f;
  t280_n42: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t280_n48;
  t280_n43: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t280_n47;
  t280_n44: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t280_n46;
  t280_n45: return 0.08599992841482162f;
  t280_n46: return -0.03290094435214996f;
  t280_n47: return 0.0942540392279625f;
  t280_n48: return 0.08468686789274216f;
  t280_n49: return 0.07014783471822739f;
  t280_n50: return -0.10135223716497421f;
  t280_n51: return -0.0016945742536336184f;
  t280_n52: return -0.04762644320726395f;
  t280_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t280_n55;
  t280_n54: return -0.020080694928765297f;
  t280_n55: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t280_n73;
  t280_n56: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t280_n72;
  t280_n57: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t280_n59;
  t280_n58: return 0.05378985032439232f;
  t280_n59: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t280_n61;
  t280_n60: return 0.05716373771429062f;
  t280_n61: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t280_n63;
  t280_n62: return 0.11329077929258347f;
  t280_n63: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t280_n71;
  t280_n64: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t280_n70;
  t280_n65: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t280_n67;
  t280_n66: return 0.08379708230495453f;
  t280_n67: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t280_n69;
  t280_n68: return 0.11314165592193604f;
  t280_n69: return 0.06455749273300171f;
  t280_n70: return 0.06810175627470016f;
  t280_n71: return 0.030460244044661522f;
  t280_n72: return -0.11048706620931625f;
  t280_n73: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t280_n75;
  t280_n74: return 0.013632889837026596f;
  t280_n75: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t280_n87;
  t280_n76: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t280_n86;
  t280_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t280_n79;
  t280_n78: return 0.13668292760849f;
  t280_n79: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n85;
  t280_n80: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t280_n82;
  t280_n81: return -0.11837286502122879f;
  t280_n82: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n84;
  t280_n83: return 0.09794830530881882f;
  t280_n84: return -0.10012048482894897f;
  t280_n85: return 0.132518008351326f;
  t280_n86: return -0.10089657455682755f;
  t280_n87: return -0.1197030246257782f;
  t280_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t280_n102;
  t280_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t280_n91;
  t280_n90: return -0.061696361750364304f;
  t280_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t280_n93;
  t280_n92: return -0.10020677000284195f;
  t280_n93: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n97;
  t280_n94: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t280_n96;
  t280_n95: return 0.10431259870529175f;
  t280_n96: return 0.04475861042737961f;
  t280_n97: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t280_n101;
  t280_n98: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t280_n100;
  t280_n99: return 0.013619810342788696f;
  t280_n100: return 0.11767552047967911f;
  t280_n101: return 0.024843985214829445f;
  t280_n102: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t280_n132;
  t280_n103: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t280_n127;
  t280_n104: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t280_n126;
  t280_n105: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t280_n125;
  t280_n106: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t280_n114;
  t280_n107: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t280_n109;
  t280_n108: return 0.032526761293411255f;
  t280_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n111;
  t280_n110: return -0.13233156502246857f;
  t280_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t280_n113;
  t280_n112: return -0.10135441273450851f;
  t280_n113: return 0.10286998748779297f;
  t280_n114: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t280_n124;
  t280_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t280_n121;
  t280_n116: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n118;
  t280_n117: return 0.02187078446149826f;
  t280_n118: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t280_n120;
  t280_n119: return 0.05739439278841019f;
  t280_n120: return -0.009527924470603466f;
  t280_n121: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t280_n123;
  t280_n122: return 0.08740795403718948f;
  t280_n123: return 0.03545296564698219f;
  t280_n124: return -0.10179953277111053f;
  t280_n125: return -0.009994595311582088f;
  t280_n126: return -0.03194443881511688f;
  t280_n127: if (E.getNumReferences() >= 3319326720 /*6941.0*/) goto t280_n129;
  t280_n128: return -0.03117164969444275f;
  t280_n129: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t280_n131;
  t280_n130: return 0.11004376411437988f;
  t280_n131: return 0.04425974562764168f;
  t280_n132: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t280_n170;
  t280_n133: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n169;
  t280_n134: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t280_n168;
  t280_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t280_n143;
  t280_n136: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t280_n138;
  t280_n137: return 0.01437500398606062f;
  t280_n138: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n140;
  t280_n139: return 0.06442292034626007f;
  t280_n140: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t280_n142;
  t280_n141: return 0.08192253112792969f;
  t280_n142: return 0.02443879283964634f;
  t280_n143: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t280_n147;
  t280_n144: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t280_n146;
  t280_n145: return 0.07806071639060974f;
  t280_n146: return 0.02560274302959442f;
  t280_n147: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t280_n149;
  t280_n148: return -0.002004520036280155f;
  t280_n149: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t280_n167;
  t280_n150: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n152;
  t280_n151: return 0.08443323522806168f;
  t280_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t280_n160;
  t280_n153: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t280_n155;
  t280_n154: return 0.04866684228181839f;
  t280_n155: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t280_n159;
  t280_n156: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t280_n158;
  t280_n157: return 0.11509627848863602f;
  t280_n158: return -0.16110585629940033f;
  t280_n159: return -0.07156551629304886f;
  t280_n160: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t280_n166;
  t280_n161: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t280_n165;
  t280_n162: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t280_n164;
  t280_n163: return 0.10541979223489761f;
  t280_n164: return -0.1249484121799469f;
  t280_n165: return 0.08546347171068192f;
  t280_n166: return 0.10966214537620544f;
  t280_n167: return -0.004537058062851429f;
  t280_n168: return -0.10114482790231705f;
  t280_n169: return 0.009672742336988449f;
  t280_n170: if (E.getNumReferences() >= 3312433152 /*3835.5*/) goto t280_n172;
  t280_n171: return 0.020607220008969307f;
  t280_n172: if (E.getNumReferences() >= 3312914432 /*3953.0*/) goto t280_n174;
  t280_n173: return 0.11765507608652115f;
  t280_n174: return 0.07783288508653641f;
  t280_n175: return 0.0012712248135358095f;
  t280_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t280_n210;
  t280_n177: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t280_n199;
  t280_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t280_n180;
  t280_n179: return 0.018805084750056267f;
  t280_n180: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t280_n182;
  t280_n181: return 0.12002699077129364f;
  t280_n182: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t280_n198;
  t280_n183: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t280_n193;
  t280_n184: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t280_n186;
  t280_n185: return 0.03334978595376015f;
  t280_n186: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t280_n192;
  t280_n187: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n191;
  t280_n188: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t280_n190;
  t280_n189: return 0.11955961585044861f;
  t280_n190: return 0.09670330584049225f;
  t280_n191: return 0.06842679530382156f;
  t280_n192: return 0.0905766636133194f;
  t280_n193: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t280_n197;
  t280_n194: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t280_n196;
  t280_n195: return 0.11741691827774048f;
  t280_n196: return -0.4104191064834595f;
  t280_n197: return -0.10856659710407257f;
  t280_n198: return -0.030331268906593323f;
  t280_n199: if (E.getNumReferences() >= 3325698048 /*11912.0*/) goto t280_n201;
  t280_n200: return 0.009383467957377434f;
  t280_n201: if (E.getNumReferences() >= 3325825536 /*12036.5*/) goto t280_n209;
  t280_n202: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t280_n208;
  t280_n203: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t280_n207;
  t280_n204: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t280_n206;
  t280_n205: return -0.10746349394321442f;
  t280_n206: return 0.1331801861524582f;
  t280_n207: return 0.13641153275966644f;
  t280_n208: return 0.0375695638358593f;
  t280_n209: return 0.020366154611110687f;
  t280_n210: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t280_n228;
  t280_n211: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t280_n225;
  t280_n212: if (E.getNumReferences() >= 3300126720 /*1439.5*/) goto t280_n224;
  t280_n213: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t280_n223;
  t280_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t280_n216;
  t280_n215: return 0.013027466833591461f;
  t280_n216: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n222;
  t280_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n221;
  t280_n218: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t280_n220;
  t280_n219: return 0.12468820065259933f;
  t280_n220: return 0.10663352906703949f;
  t280_n221: return 0.09578870981931686f;
  t280_n222: return -0.06803147494792938f;
  t280_n223: return -0.06196935102343559f;
  t280_n224: return 0.1072305291891098f;
  t280_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n227;
  t280_n226: return -0.000640469545032829f;
  t280_n227: return 0.11490827798843384f;
  t280_n228: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t280_n232;
  t280_n229: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t280_n231;
  t280_n230: return 0.0052414159290492535f;
  t280_n231: return 0.07266800105571747f;
  t280_n232: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t280_n250;
  t280_n233: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t280_n249;
  t280_n234: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t280_n248;
  t280_n235: if (E.getNumReferences() >= 3270770688 /*122.0*/) goto t280_n247;
  t280_n236: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t280_n238;
  t280_n237: return 0.02570560947060585f;
  t280_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n246;
  t280_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t280_n241;
  t280_n240: return 0.01501394435763359f;
  t280_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t280_n243;
  t280_n242: return 0.07787970453500748f;
  t280_n243: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t280_n245;
  t280_n244: return 0.03878089040517807f;
  t280_n245: return 0.07440101355314255f;
  t280_n246: return 0.01500410120934248f;
  t280_n247: return 0.12649790942668915f;
  t280_n248: return -0.05850684270262718f;
  t280_n249: return 0.022168787196278572f;
  t280_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t280_n254;
  t280_n251: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t280_n253;
  t280_n252: return -0.1017247810959816f;
  t280_n253: return 0.10207352787256241f;
  t280_n254: return 0.01443571224808693f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree281(const Example& E) {
  t281_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t281_n228;
  t281_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t281_n103;
  t281_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t281_n4;
  t281_n3: return -0.012700523249804974f;
  t281_n4: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t281_n6;
  t281_n5: return -0.0006640683277510107f;
  t281_n6: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t281_n16;
  t281_n7: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t281_n15;
  t281_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t281_n10;
  t281_n9: return 0.1723327338695526f;
  t281_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t281_n14;
  t281_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t281_n13;
  t281_n12: return 0.11399044096469879f;
  t281_n13: return 0.12915624678134918f;
  t281_n14: return 0.033884335309267044f;
  t281_n15: return -0.01339950505644083f;
  t281_n16: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t281_n18;
  t281_n17: return 0.01862248219549656f;
  t281_n18: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t281_n20;
  t281_n19: return 0.02072897180914879f;
  t281_n20: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t281_n30;
  t281_n21: if (E.getNumReferences() >= 3341265408 /*42922.0*/) goto t281_n23;
  t281_n22: return -0.011889494955539703f;
  t281_n23: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t281_n25;
  t281_n24: return 0.01100369542837143f;
  t281_n25: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t281_n29;
  t281_n26: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t281_n28;
  t281_n27: return 0.08305090665817261f;
  t281_n28: return 0.12311321496963501f;
  t281_n29: return 0.02111985720694065f;
  t281_n30: if (E.getNumReferences() >= 3346496384 /*63355.5*/) goto t281_n102;
  t281_n31: if (E.getNumReferences() >= 3336210176 /*27971.5*/) goto t281_n101;
  t281_n32: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t281_n52;
  t281_n33: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t281_n51;
  t281_n34: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t281_n46;
  t281_n35: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t281_n37;
  t281_n36: return 0.015282108448445797f;
  t281_n37: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t281_n45;
  t281_n38: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t281_n42;
  t281_n39: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t281_n41;
  t281_n40: return 0.07827883958816528f;
  t281_n41: return 0.13148722052574158f;
  t281_n42: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t281_n44;
  t281_n43: return -0.15150600671768188f;
  t281_n44: return 0.09903234243392944f;
  t281_n45: return 0.02439621277153492f;
  t281_n46: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t281_n50;
  t281_n47: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t281_n49;
  t281_n48: return 0.11405625939369202f;
  t281_n49: return 0.1224369928240776f;
  t281_n50: return -0.06595123559236526f;
  t281_n51: return -0.1511070877313614f;
  t281_n52: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t281_n62;
  t281_n53: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t281_n57;
  t281_n54: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n56;
  t281_n55: return 0.15763022005558014f;
  t281_n56: return -0.11516313254833221f;
  t281_n57: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t281_n59;
  t281_n58: return -0.6969040036201477f;
  t281_n59: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t281_n61;
  t281_n60: return 0.11318834871053696f;
  t281_n61: return 0.16247455775737762f;
  t281_n62: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t281_n64;
  t281_n63: return -0.012062741443514824f;
  t281_n64: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t281_n76;
  t281_n65: if (E.getNumReferences() >= 3263561728 /*67.0*/) goto t281_n67;
  t281_n66: return 0.11053037643432617f;
  t281_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t281_n69;
  t281_n68: return 0.09356073290109634f;
  t281_n69: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t281_n73;
  t281_n70: if (E.getNumReferences() >= 3272114176 /*136.5*/) goto t281_n72;
  t281_n71: return -0.29788702726364136f;
  t281_n72: return 0.026089457795023918f;
  t281_n73: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n75;
  t281_n74: return 0.07044129818677902f;
  t281_n75: return 0.10091779381036758f;
  t281_n76: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t281_n98;
  t281_n77: if (E.getNumReferences() >= 3290374144 /*636.5*/) goto t281_n97;
  t281_n78: if (E.getNumReferences() >= 3289194496 /*564.5*/) goto t281_n96;
  t281_n79: if (E.getNumReferences() >= 3280404480 /*270.0*/) goto t281_n95;
  t281_n80: if (E.getNumReferences() >= 3278602240 /*235.5*/) goto t281_n94;
  t281_n81: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t281_n87;
  t281_n82: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t281_n86;
  t281_n83: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t281_n85;
  t281_n84: return -0.07303221523761749f;
  t281_n85: return 0.10416959226131439f;
  t281_n86: return -0.011179433204233646f;
  t281_n87: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t281_n93;
  t281_n88: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t281_n92;
  t281_n89: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t281_n91;
  t281_n90: return -0.11567626148462296f;
  t281_n91: return 0.11929811537265778f;
  t281_n92: return 0.116038016974926f;
  t281_n93: return -0.022458795458078384f;
  t281_n94: return 0.13445919752120972f;
  t281_n95: return -0.08988867700099945f;
  t281_n96: return 0.11514178663492203f;
  t281_n97: return -0.18632927536964417f;
  t281_n98: if (E.getNumReferences() >= 3272343552 /*140.0*/) goto t281_n100;
  t281_n99: return -0.33402907848358154f;
  t281_n100: return 0.011084908619523048f;
  t281_n101: return -0.07023199647665024f;
  t281_n102: return 0.09357163310050964f;
  t281_n103: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t281_n225;
  t281_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t281_n112;
  t281_n105: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t281_n109;
  t281_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t281_n108;
  t281_n107: return 0.000738635309971869f;
  t281_n108: return 0.007765098940581083f;
  t281_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t281_n111;
  t281_n110: return -0.03458790108561516f;
  t281_n111: return -0.024100830778479576f;
  t281_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t281_n216;
  t281_n113: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t281_n119;
  t281_n114: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n118;
  t281_n115: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t281_n117;
  t281_n116: return -0.012186783365905285f;
  t281_n117: return 0.005886073689907789f;
  t281_n118: return -0.00508407736197114f;
  t281_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t281_n163;
  t281_n120: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t281_n122;
  t281_n121: return 0.029455194249749184f;
  t281_n122: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t281_n148;
  t281_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t281_n125;
  t281_n124: return 0.01636177860200405f;
  t281_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t281_n127;
  t281_n126: return -0.00397774251177907f;
  t281_n127: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t281_n147;
  t281_n128: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t281_n142;
  t281_n129: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t281_n131;
  t281_n130: return 0.02877935767173767f;
  t281_n131: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t281_n135;
  t281_n132: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t281_n134;
  t281_n133: return 0.1120477020740509f;
  t281_n134: return 0.07965286076068878f;
  t281_n135: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t281_n137;
  t281_n136: return -0.015569481067359447f;
  t281_n137: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t281_n139;
  t281_n138: return 0.09297607839107513f;
  t281_n139: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t281_n141;
  t281_n140: return -0.10865511745214462f;
  t281_n141: return 0.08002417534589767f;
  t281_n142: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t281_n146;
  t281_n143: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t281_n145;
  t281_n144: return 0.06773559004068375f;
  t281_n145: return 0.10544226318597794f;
  t281_n146: return 0.0046228691935539246f;
  t281_n147: return 0.013058406300842762f;
  t281_n148: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t281_n152;
  t281_n149: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t281_n151;
  t281_n150: return -0.01789100095629692f;
  t281_n151: return 0.12237437069416046f;
  t281_n152: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t281_n162;
  t281_n153: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t281_n161;
  t281_n154: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t281_n156;
  t281_n155: return 0.07158965617418289f;
  t281_n156: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t281_n160;
  t281_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n159;
  t281_n158: return 0.09015171229839325f;
  t281_n159: return 0.13385838270187378f;
  t281_n160: return -0.1019558236002922f;
  t281_n161: return 0.02697301283478737f;
  t281_n162: return -0.10739953070878983f;
  t281_n163: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t281_n193;
  t281_n164: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t281_n174;
  t281_n165: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t281_n167;
  t281_n166: return -0.03550180047750473f;
  t281_n167: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t281_n169;
  t281_n168: return 0.0400882251560688f;
  t281_n169: if (E.getNumReferences() >= 3320975360 /*7746.0*/) goto t281_n171;
  t281_n170: return 0.03722105547785759f;
  t281_n171: if (E.getNumReferences() >= 3323093504 /*9368.5*/) goto t281_n173;
  t281_n172: return 0.13185074925422668f;
  t281_n173: return -0.17985674738883972f;
  t281_n174: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t281_n182;
  t281_n175: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t281_n181;
  t281_n176: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t281_n178;
  t281_n177: return -0.15363731980323792f;
  t281_n178: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t281_n180;
  t281_n179: return 0.10023397207260132f;
  t281_n180: return 0.08332086354494095f;
  t281_n181: return 0.001963825663551688f;
  t281_n182: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n188;
  t281_n183: if (E.getNumReferences() >= 3340106752 /*38396.0*/) goto t281_n185;
  t281_n184: return 0.005698068533092737f;
  t281_n185: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t281_n187;
  t281_n186: return 0.06546005606651306f;
  t281_n187: return -0.0011127329198643565f;
  t281_n188: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t281_n192;
  t281_n189: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t281_n191;
  t281_n190: return 0.049940235912799835f;
  t281_n191: return 0.09497156739234924f;
  t281_n192: return 0.05072060972452164f;
  t281_n193: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t281_n205;
  t281_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n196;
  t281_n195: return 0.055292241275310516f;
  t281_n196: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t281_n204;
  t281_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol))) goto t281_n199;
  t281_n198: return 0.0181468166410923f;
  t281_n199: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t281_n201;
  t281_n200: return 0.003505914006382227f;
  t281_n201: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t281_n203;
  t281_n202: return 0.039903730154037476f;
  t281_n203: return 0.13337358832359314f;
  t281_n204: return -2.006385326385498f;
  t281_n205: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t281_n207;
  t281_n206: return 0.04339172691106796f;
  t281_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t281_n209;
  t281_n208: return -0.07610895484685898f;
  t281_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t281_n211;
  t281_n210: return 0.18864630162715912f;
  t281_n211: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t281_n213;
  t281_n212: return 0.001122408895753324f;
  t281_n213: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t281_n215;
  t281_n214: return 0.13828223943710327f;
  t281_n215: return 0.06394296139478683f;
  t281_n216: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t281_n218;
  t281_n217: return 0.006406643893569708f;
  t281_n218: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t281_n224;
  t281_n219: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t281_n221;
  t281_n220: return 0.03417575731873512f;
  t281_n221: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t281_n223;
  t281_n222: return 0.10062868893146515f;
  t281_n223: return 0.019787432625889778f;
  t281_n224: return 0.009088727645576f;
  t281_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t281_n227;
  t281_n226: return -0.1088654100894928f;
  t281_n227: return -0.0005170971853658557f;
  t281_n228: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t281_n254;
  t281_n229: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t281_n231;
  t281_n230: return 0.021403390914201736f;
  t281_n231: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t281_n247;
  t281_n232: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t281_n234;
  t281_n233: return 0.10667290538549423f;
  t281_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t281_n246;
  t281_n235: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t281_n241;
  t281_n236: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t281_n240;
  t281_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n239;
  t281_n238: return -0.10560537129640579f;
  t281_n239: return 2.178177833557129f;
  t281_n240: return -0.06853631883859634f;
  t281_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n243;
  t281_n242: return 0.7834787964820862f;
  t281_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t281_n245;
  t281_n244: return -0.46267056465148926f;
  t281_n245: return 0.1550350934267044f;
  t281_n246: return 1.5666284561157227f;
  t281_n247: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t281_n253;
  t281_n248: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t281_n252;
  t281_n249: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t281_n251;
  t281_n250: return -0.1363552361726761f;
  t281_n251: return 0.47757571935653687f;
  t281_n252: return -0.10085843503475189f;
  t281_n253: return 0.18796013295650482f;
  t281_n254: return -0.042712029069662094f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree282(const Example& E) {
  t282_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t282_n2;
  t282_n1: return -0.00031202565878629684f;
  t282_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t282_n38;
  t282_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t282_n5;
  t282_n4: return 0.00735994940623641f;
  t282_n5: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t282_n37;
  t282_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t282_n10;
  t282_n7: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n9;
  t282_n8: return -0.028485801070928574f;
  t282_n9: return 0.06474091857671738f;
  t282_n10: if (E.getNumReferences() >= 3297521664 /*1121.5*/) goto t282_n36;
  t282_n11: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t282_n13;
  t282_n12: return -0.09474875777959824f;
  t282_n13: if (E.getNumReferences() >= 3292340224 /*756.5*/) goto t282_n27;
  t282_n14: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t282_n26;
  t282_n15: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t282_n25;
  t282_n16: if (E.getNumReferences() >= 3285139456 /*414.5*/) goto t282_n18;
  t282_n17: return 0.011412503197789192f;
  t282_n18: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n24;
  t282_n19: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t282_n21;
  t282_n20: return 0.11019165813922882f;
  t282_n21: if (E.getNumReferences() >= 3286204416 /*447.0*/) goto t282_n23;
  t282_n22: return 0.10615319758653641f;
  t282_n23: return 0.0007531600422225893f;
  t282_n24: return -0.07378876209259033f;
  t282_n25: return -0.1341540813446045f;
  t282_n26: return 0.005361767020076513f;
  t282_n27: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t282_n35;
  t282_n28: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t282_n34;
  t282_n29: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t282_n33;
  t282_n30: if (E.getNumReferences() >= 3293782016 /*844.5*/) goto t282_n32;
  t282_n31: return 0.11284732073545456f;
  t282_n32: return 0.11957701295614243f;
  t282_n33: return 0.0722745954990387f;
  t282_n34: return 0.0614035464823246f;
  t282_n35: return -0.10397736728191376f;
  t282_n36: return 0.010373012162744999f;
  t282_n37: return 0.07786449044942856f;
  t282_n38: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t282_n40;
  t282_n39: return -0.0002560199936851859f;
  t282_n40: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t282_n168;
  t282_n41: if (E.getNumReferences() >= 3284516864 /*395.5*/) goto t282_n45;
  t282_n42: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t282_n44;
  t282_n43: return 0.10776519775390625f;
  t282_n44: return -0.3021254241466522f;
  t282_n45: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t282_n157;
  t282_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t282_n134;
  t282_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t282_n57;
  t282_n48: if (E.getNumReferences() >= 3285467136 /*424.5*/) goto t282_n56;
  t282_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n51;
  t282_n50: return -0.029527295380830765f;
  t282_n51: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t282_n53;
  t282_n52: return -0.018154608085751534f;
  t282_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t282_n55;
  t282_n54: return 0.11058391630649567f;
  t282_n55: return 0.029482614248991013f;
  t282_n56: return -0.004134549759328365f;
  t282_n57: if (E.getNumReferences() >= 3290079232 /*618.5*/) goto t282_n67;
  t282_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t282_n60;
  t282_n59: return -0.45641398429870605f;
  t282_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t282_n66;
  t282_n61: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t282_n63;
  t282_n62: return -0.02207343839108944f;
  t282_n63: if (E.getNumReferences() >= 3290030080 /*615.5*/) goto t282_n65;
  t282_n64: return -0.26651790738105774f;
  t282_n65: return -0.9000018239021301f;
  t282_n66: return 0.10369117558002472f;
  t282_n67: if (E.getNumReferences() >= 3290128384 /*621.5*/) goto t282_n69;
  t282_n68: return 0.09388293325901031f;
  t282_n69: if (E.getNumReferences() >= 3310512128 /*3366.5*/) goto t282_n117;
  t282_n70: if (E.getNumReferences() >= 3309832192 /*3200.5*/) goto t282_n114;
  t282_n71: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t282_n113;
  t282_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n96;
  t282_n73: if (E.getNumReferences() >= 3292413952 /*761.0*/) goto t282_n75;
  t282_n74: return -0.17456009984016418f;
  t282_n75: if (E.getNumReferences() >= 3293192192 /*808.5*/) goto t282_n79;
  t282_n76: if (E.getNumReferences() >= 3292733440 /*780.5*/) goto t282_n78;
  t282_n77: return -0.10469823330640793f;
  t282_n78: return 0.11037324368953705f;
  t282_n79: if (E.getNumReferences() >= 3301113856 /*1560.0*/) goto t282_n85;
  t282_n80: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t282_n84;
  t282_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t282_n83;
  t282_n82: return -0.6032833456993103f;
  t282_n83: return -0.07125187665224075f;
  t282_n84: return 0.008763240650296211f;
  t282_n85: if (E.getNumReferences() >= 3301826560 /*1647.0*/) goto t282_n89;
  t282_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t282_n88;
  t282_n87: return -0.10638564079999924f;
  t282_n88: return 0.15810033679008484f;
  t282_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t282_n91;
  t282_n90: return -0.06223641708493233f;
  t282_n91: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t282_n93;
  t282_n92: return -0.016875866800546646f;
  t282_n93: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t282_n95;
  t282_n94: return 0.14615598320960999f;
  t282_n95: return -0.02092980593442917f;
  t282_n96: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t282_n102;
  t282_n97: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t282_n101;
  t282_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t282_n100;
  t282_n99: return -0.035651061683893204f;
  t282_n100: return 0.1199006512761116f;
  t282_n101: return 0.0881437212228775f;
  t282_n102: if (E.getNumReferences() >= 3292987392 /*796.0*/) goto t282_n106;
  t282_n103: if (E.getNumReferences() >= 3292233728 /*750.0*/) goto t282_n105;
  t282_n104: return 0.06308086961507797f;
  t282_n105: return 0.0893397405743599f;
  t282_n106: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t282_n110;
  t282_n107: if (E.getNumReferences() >= 3299438592 /*1355.5*/) goto t282_n109;
  t282_n108: return 0.10095422714948654f;
  t282_n109: return -0.11985193938016891f;
  t282_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t282_n112;
  t282_n111: return -0.33466246724128723f;
  t282_n112: return 0.08879651874303818f;
  t282_n113: return 0.8031365275382996f;
  t282_n114: if (E.getNumReferences() >= 3310073856 /*3259.5*/) goto t282_n116;
  t282_n115: return 0.10907955467700958f;
  t282_n116: return 0.08588362485170364f;
  t282_n117: if (E.getNumReferences() >= 3320595456 /*7560.5*/) goto t282_n121;
  t282_n118: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n120;
  t282_n119: return -0.028635285794734955f;
  t282_n120: return -0.15169639885425568f;
  t282_n121: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t282_n131;
  t282_n122: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t282_n130;
  t282_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t282_n127;
  t282_n124: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n126;
  t282_n125: return -0.003018096787855029f;
  t282_n126: return 0.08939948678016663f;
  t282_n127: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t282_n129;
  t282_n128: return 0.04856889694929123f;
  t282_n129: return 0.10409124195575714f;
  t282_n130: return 0.13476526737213135f;
  t282_n131: if (E.getNumReferences() >= 3324368896 /*10614.0*/) goto t282_n133;
  t282_n132: return 0.07263099402189255f;
  t282_n133: return 0.013853252865374088f;
  t282_n134: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t282_n148;
  t282_n135: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t282_n137;
  t282_n136: return -0.15526048839092255f;
  t282_n137: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t282_n139;
  t282_n138: return -0.12488272786140442f;
  t282_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t282_n141;
  t282_n140: return -0.2925182580947876f;
  t282_n141: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t282_n147;
  t282_n142: if (E.getNumReferences() >= 3324282368 /*10529.5*/) goto t282_n144;
  t282_n143: return 0.10220542550086975f;
  t282_n144: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t282_n146;
  t282_n145: return 0.07308447360992432f;
  t282_n146: return 0.11491239070892334f;
  t282_n147: return 0.06854967772960663f;
  t282_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n150;
  t282_n149: return 0.056265901774168015f;
  t282_n150: if (E.getNumReferences() >= 3303497728 /*1851.0*/) goto t282_n152;
  t282_n151: return -0.554100751876831f;
  t282_n152: if (E.getNumReferences() >= 3318012928 /*6299.5*/) goto t282_n156;
  t282_n153: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t282_n155;
  t282_n154: return -0.507710874080658f;
  t282_n155: return 0.1379278302192688f;
  t282_n156: return -0.21954381465911865f;
  t282_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t282_n167;
  t282_n158: if (E.getNumReferences() >= 3285516288 /*426.0*/) goto t282_n162;
  t282_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t282_n161;
  t282_n160: return -0.02286510355770588f;
  t282_n161: return 0.09803476184606552f;
  t282_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n164;
  t282_n163: return -0.04443231597542763f;
  t282_n164: if (E.getNumReferences() >= 3358754656 /*182813.5*/) goto t282_n166;
  t282_n165: return -0.2202959656715393f;
  t282_n166: return 0.07741034030914307f;
  t282_n167: return -0.0017174313543364406f;
  t282_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t282_n254;
  t282_n169: if (E.getNumReferences() >= 3286614016 /*459.5*/) goto t282_n181;
  t282_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t282_n176;
  t282_n171: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t282_n175;
  t282_n172: if (E.getNumReferences() >= 3286106112 /*444.0*/) goto t282_n174;
  t282_n173: return -0.12760530412197113f;
  t282_n174: return -0.914707601070404f;
  t282_n175: return -0.04538167268037796f;
  t282_n176: if (E.getNumReferences() >= 3285729280 /*432.5*/) goto t282_n180;
  t282_n177: if (E.getNumReferences() >= 3285499904 /*425.5*/) goto t282_n179;
  t282_n178: return 0.08282921463251114f;
  t282_n179: return -0.7961204648017883f;
  t282_n180: return 0.0944669172167778f;
  t282_n181: if (E.getNumReferences() >= 3286679552 /*461.5*/) goto t282_n183;
  t282_n182: return 0.10593020170927048f;
  t282_n183: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t282_n245;
  t282_n184: if (E.getNumReferences() >= 3287056384 /*473.0*/) goto t282_n188;
  t282_n185: if (E.getNumReferences() >= 3286990848 /*471.0*/) goto t282_n187;
  t282_n186: return 0.0057714395225048065f;
  t282_n187: return 0.09317020326852798f;
  t282_n188: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n240;
  t282_n189: if (E.getNumReferences() >= 3300311040 /*1462.0*/) goto t282_n239;
  t282_n190: if (E.getNumReferences() >= 3300237312 /*1453.0*/) goto t282_n238;
  t282_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t282_n203;
  t282_n192: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t282_n202;
  t282_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t282_n199;
  t282_n194: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t282_n196;
  t282_n195: return -0.08832657337188721f;
  t282_n196: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t282_n198;
  t282_n197: return 0.1090681254863739f;
  t282_n198: return 0.023913446813821793f;
  t282_n199: if (E.getNumReferences() >= 3297816576 /*1157.5*/) goto t282_n201;
  t282_n200: return -0.07927755266427994f;
  t282_n201: return 0.1328626275062561f;
  t282_n202: return 0.0885762944817543f;
  t282_n203: if (E.getNumReferences() >= 3294748672 /*903.5*/) goto t282_n227;
  t282_n204: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t282_n206;
  t282_n205: return 0.10213784873485565f;
  t282_n206: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t282_n224;
  t282_n207: if (E.getNumReferences() >= 3289161728 /*562.5*/) goto t282_n209;
  t282_n208: return -0.15548548102378845f;
  t282_n209: if (E.getNumReferences() >= 3293110272 /*803.5*/) goto t282_n223;
  t282_n210: if (E.getNumReferences() >= 3292405760 /*760.5*/) goto t282_n220;
  t282_n211: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t282_n215;
  t282_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t282_n214;
  t282_n213: return 0.07911912351846695f;
  t282_n214: return 0.09806487709283829f;
  t282_n215: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t282_n217;
  t282_n216: return -0.13492989540100098f;
  t282_n217: if (E.getNumReferences() >= 3289972736 /*612.0*/) goto t282_n219;
  t282_n218: return 0.1342683583498001f;
  t282_n219: return -0.11564911156892776f;
  t282_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t282_n222;
  t282_n221: return 0.04289800673723221f;
  t282_n222: return 0.15287430584430695f;
  t282_n223: return -0.12104400992393494f;
  t282_n224: if (E.getNumReferences() >= 3289456640 /*580.5*/) goto t282_n226;
  t282_n225: return 0.08510316908359528f;
  t282_n226: return 0.018843382596969604f;
  t282_n227: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t282_n233;
  t282_n228: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t282_n232;
  t282_n229: if (E.getNumReferences() >= 3298021376 /*1182.5*/) goto t282_n231;
  t282_n230: return -0.23863543570041656f;
  t282_n231: return 0.10735326260328293f;
  t282_n232: return 0.11444789171218872f;
  t282_n233: if (E.getNumReferences() >= 3295780864 /*966.5*/) goto t282_n237;
  t282_n234: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t282_n236;
  t282_n235: return 0.16641341149806976f;
  t282_n236: return -0.05195186287164688f;
  t282_n237: return 0.0017575661186128855f;
  t282_n238: return 0.11654186993837357f;
  t282_n239: return 0.02009027823805809f;
  t282_n240: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t282_n242;
  t282_n241: return 0.015019840560853481f;
  t282_n242: if (E.getNumReferences() >= 3365715136 /*320998.0*/) goto t282_n244;
  t282_n243: return -0.018412631005048752f;
  t282_n244: return 0.09269475936889648f;
  t282_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t282_n249;
  t282_n246: if (E.getNumReferences() >= 3287924736 /*499.5*/) goto t282_n248;
  t282_n247: return -1.365025281906128f;
  t282_n248: return -0.0019108009291812778f;
  t282_n249: if (E.getNumReferences() >= 3289088000 /*558.0*/) goto t282_n253;
  t282_n250: if (E.getNumReferences() >= 3288530944 /*524.0*/) goto t282_n252;
  t282_n251: return 0.09206531196832657f;
  t282_n252: return 0.15011011064052582f;
  t282_n253: return 0.020402971655130386f;
  t282_n254: return 0.10190942138433456f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree283(const Example& E) {
  t283_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t283_n2;
  t283_n1: return -0.0003101542533840984f;
  t283_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t283_n26;
  t283_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t283_n5;
  t283_n4: return 0.00732892332598567f;
  t283_n5: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t283_n25;
  t283_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t283_n10;
  t283_n7: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t283_n9;
  t283_n8: return -0.029541384428739548f;
  t283_n9: return 0.06265883147716522f;
  t283_n10: if (E.getNumReferences() >= 3297521664 /*1121.5*/) goto t283_n24;
  t283_n11: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t283_n13;
  t283_n12: return -0.08519589900970459f;
  t283_n13: if (E.getNumReferences() >= 3292340224 /*756.5*/) goto t283_n17;
  t283_n14: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t283_n16;
  t283_n15: return 0.06410686671733856f;
  t283_n16: return 0.004721513018012047f;
  t283_n17: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t283_n23;
  t283_n18: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t283_n22;
  t283_n19: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t283_n21;
  t283_n20: return 0.11452153325080872f;
  t283_n21: return 0.07052841782569885f;
  t283_n22: return 0.057397544384002686f;
  t283_n23: return -0.08607739955186844f;
  t283_n24: return 0.006078975275158882f;
  t283_n25: return 0.07338003814220428f;
  t283_n26: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t283_n28;
  t283_n27: return -0.0002326584217371419f;
  t283_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t283_n30;
  t283_n29: return 0.0036472519859671593f;
  t283_n30: if (E.getNumReferences() >= 3284516864 /*395.5*/) goto t283_n34;
  t283_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t283_n33;
  t283_n32: return -0.40184375643730164f;
  t283_n33: return 0.09920252859592438f;
  t283_n34: if (E.getNumReferences() >= 3312803840 /*3926.0*/) goto t283_n178;
  t283_n35: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t283_n41;
  t283_n36: if (E.getNumReferences() >= 3286384640 /*452.5*/) goto t283_n40;
  t283_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t283_n39;
  t283_n38: return 0.06136306747794151f;
  t283_n39: return -0.15349651873111725f;
  t283_n40: return -0.07278098911046982f;
  t283_n41: if (E.getNumReferences() >= 3290112000 /*620.5*/) goto t283_n43;
  t283_n42: return 0.10134243965148926f;
  t283_n43: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t283_n161;
  t283_n44: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t283_n50;
  t283_n45: if (E.getNumReferences() >= 3310151680 /*3278.5*/) goto t283_n47;
  t283_n46: return -0.12186361849308014f;
  t283_n47: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t283_n49;
  t283_n48: return -0.10564660280942917f;
  t283_n49: return 0.11117827147245407f;
  t283_n50: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t283_n78;
  t283_n51: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t283_n75;
  t283_n52: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t283_n74;
  t283_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t283_n63;
  t283_n54: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t283_n56;
  t283_n55: return -0.18744848668575287f;
  t283_n56: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t283_n60;
  t283_n57: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t283_n59;
  t283_n58: return 0.0846262276172638f;
  t283_n59: return -0.9456624388694763f;
  t283_n60: if (E.getNumReferences() >= 3298697216 /*1265.0*/) goto t283_n62;
  t283_n61: return -0.1473608762025833f;
  t283_n62: return 0.10524153709411621f;
  t283_n63: if (E.getNumReferences() >= 3292495872 /*766.0*/) goto t283_n65;
  t283_n64: return -0.3167036175727844f;
  t283_n65: if (E.getNumReferences() >= 3301003264 /*1546.5*/) goto t283_n71;
  t283_n66: if (E.getNumReferences() >= 3297775616 /*1152.5*/) goto t283_n70;
  t283_n67: if (E.getNumReferences() >= 3295903744 /*974.0*/) goto t283_n69;
  t283_n68: return 0.10514377802610397f;
  t283_n69: return -0.1421108841896057f;
  t283_n70: return 0.15548968315124512f;
  t283_n71: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t283_n73;
  t283_n72: return 0.10708440095186234f;
  t283_n73: return -0.18594631552696228f;
  t283_n74: return 0.11418169736862183f;
  t283_n75: if (E.getNumReferences() >= 3294584832 /*893.5*/) goto t283_n77;
  t283_n76: return 0.10621892660856247f;
  t283_n77: return 0.11539904028177261f;
  t283_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace))) goto t283_n160;
  t283_n79: if (E.getNumReferences() >= 3292815360 /*785.5*/) goto t283_n97;
  t283_n80: if (E.getNumReferences() >= 3292684288 /*777.5*/) goto t283_n94;
  t283_n81: if (E.getNumReferences() >= 3291439104 /*701.5*/) goto t283_n93;
  t283_n82: if (E.getNumReferences() >= 3291381760 /*698.0*/) goto t283_n92;
  t283_n83: if (E.getNumReferences() >= 3291021312 /*676.0*/) goto t283_n91;
  t283_n84: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t283_n86;
  t283_n85: return -0.006084693595767021f;
  t283_n86: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t283_n90;
  t283_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t283_n89;
  t283_n88: return 0.11452538520097733f;
  t283_n89: return 0.10131309181451797f;
  t283_n90: return -0.05314777418971062f;
  t283_n91: return -0.27748537063598633f;
  t283_n92: return 0.11148838698863983f;
  t283_n93: return -0.061663318425416946f;
  t283_n94: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t283_n96;
  t283_n95: return 0.09349852800369263f;
  t283_n96: return 0.09846266359090805f;
  t283_n97: if (E.getNumReferences() >= 3306727424 /*2442.5*/) goto t283_n139;
  t283_n98: if (E.getNumReferences() >= 3304943616 /*2027.5*/) goto t283_n136;
  t283_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t283_n103;
  t283_n100: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t283_n102;
  t283_n101: return -0.49843624234199524f;
  t283_n102: return 0.0027054008096456528f;
  t283_n103: if (E.getNumReferences() >= 3295387648 /*942.5*/) goto t283_n105;
  t283_n104: return -0.059421345591545105f;
  t283_n105: if (E.getNumReferences() >= 3295576064 /*954.0*/) goto t283_n107;
  t283_n106: return 0.12354796379804611f;
  t283_n107: if (E.getNumReferences() >= 3296780288 /*1031.0*/) goto t283_n117;
  t283_n108: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t283_n116;
  t283_n109: if (E.getNumReferences() >= 3296256000 /*995.5*/) goto t283_n113;
  t283_n110: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t283_n112;
  t283_n111: return 0.12204813212156296f;
  t283_n112: return 0.014302672818303108f;
  t283_n113: if (E.getNumReferences() >= 3296403456 /*1004.5*/) goto t283_n115;
  t283_n114: return 0.009332239627838135f;
  t283_n115: return 0.10819090902805328f;
  t283_n116: return -0.03571275994181633f;
  t283_n117: if (E.getNumReferences() >= 3303219200 /*1817.0*/) goto t283_n133;
  t283_n118: if (E.getNumReferences() >= 3302764544 /*1761.5*/) goto t283_n132;
  t283_n119: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t283_n125;
  t283_n120: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t283_n124;
  t283_n121: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t283_n123;
  t283_n122: return 0.08520802110433578f;
  t283_n123: return -0.20183517038822174f;
  t283_n124: return -0.037017155438661575f;
  t283_n125: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t283_n131;
  t283_n126: if (E.getNumReferences() >= 3298189312 /*1203.0*/) goto t283_n128;
  t283_n127: return -0.0640546903014183f;
  t283_n128: if (E.getNumReferences() >= 3299315712 /*1340.5*/) goto t283_n130;
  t283_n129: return 0.09964964538812637f;
  t283_n130: return 0.10302131623029709f;
  t283_n131: return -0.03322002664208412f;
  t283_n132: return -1.50899338722229f;
  t283_n133: if (E.getNumReferences() >= 3303272448 /*1823.5*/) goto t283_n135;
  t283_n134: return 0.3126637935638428f;
  t283_n135: return 0.020875919610261917f;
  t283_n136: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t283_n138;
  t283_n137: return -0.2211223691701889f;
  t283_n138: return 0.075968436896801f;
  t283_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t283_n155;
  t283_n140: if (E.getNumReferences() >= 3307331584 /*2590.0*/) goto t283_n144;
  t283_n141: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t283_n143;
  t283_n142: return 0.1054188460111618f;
  t283_n143: return -0.02897805906832218f;
  t283_n144: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t283_n146;
  t283_n145: return -0.022660180926322937f;
  t283_n146: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t283_n154;
  t283_n147: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t283_n151;
  t283_n148: if (E.getNumReferences() >= 3309703168 /*3169.0*/) goto t283_n150;
  t283_n149: return 0.11715209484100342f;
  t283_n150: return 0.09845355898141861f;
  t283_n151: if (E.getNumReferences() >= 3310755840 /*3426.0*/) goto t283_n153;
  t283_n152: return 0.10749383270740509f;
  t283_n153: return -0.28054389357566833f;
  t283_n154: return -0.10203531384468079f;
  t283_n155: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t283_n157;
  t283_n156: return 0.03704938665032387f;
  t283_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t283_n159;
  t283_n158: return 0.10725852847099304f;
  t283_n159: return 0.10456854850053787f;
  t283_n160: return 0.10422050207853317f;
  t283_n161: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t283_n165;
  t283_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t283_n164;
  t283_n163: return -0.22911109030246735f;
  t283_n164: return 0.08638889342546463f;
  t283_n165: if (E.getNumReferences() >= 3291561984 /*709.0*/) goto t283_n169;
  t283_n166: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t283_n168;
  t283_n167: return -0.012004882097244263f;
  t283_n168: return 0.11787456274032593f;
  t283_n169: if (E.getNumReferences() >= 3298562048 /*1248.5*/) goto t283_n171;
  t283_n170: return -0.13467158377170563f;
  t283_n171: if (E.getNumReferences() >= 3298725888 /*1268.5*/) goto t283_n173;
  t283_n172: return 0.09647692739963531f;
  t283_n173: if (E.getNumReferences() >= 3301179392 /*1568.0*/) goto t283_n175;
  t283_n174: return -0.07241597026586533f;
  t283_n175: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t283_n177;
  t283_n176: return 0.17474548518657684f;
  t283_n177: return 0.034753475338220596f;
  t283_n178: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t283_n250;
  t283_n179: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t283_n205;
  t283_n180: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t283_n182;
  t283_n181: return -0.03918677195906639f;
  t283_n182: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t283_n204;
  t283_n183: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t283_n195;
  t283_n184: if (E.getNumReferences() >= 3354468928 /*123460.5*/) goto t283_n186;
  t283_n185: return 0.01035374216735363f;
  t283_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t283_n192;
  t283_n187: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t283_n191;
  t283_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t283_n190;
  t283_n189: return 0.053106147795915604f;
  t283_n190: return 0.040708281099796295f;
  t283_n191: return 1.2266260385513306f;
  t283_n192: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t283_n194;
  t283_n193: return 0.01615307852625847f;
  t283_n194: return 0.09853420406579971f;
  t283_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t283_n203;
  t283_n196: if (E.getNumReferences() >= 3343861504 /*53063.0*/) goto t283_n198;
  t283_n197: return 0.09127653390169144f;
  t283_n198: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t283_n202;
  t283_n199: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t283_n201;
  t283_n200: return 0.007093564607203007f;
  t283_n201: return 0.10060176253318787f;
  t283_n202: return -0.013052895665168762f;
  t283_n203: return 0.1000613197684288f;
  t283_n204: return -0.027184071019291878f;
  t283_n205: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t283_n237;
  t283_n206: if (E.getNumReferences() >= 3315707904 /*5174.0*/) goto t283_n214;
  t283_n207: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t283_n213;
  t283_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t283_n212;
  t283_n209: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t283_n211;
  t283_n210: return -0.7449407577514648f;
  t283_n211: return -0.10577821731567383f;
  t283_n212: return -0.07674729079008102f;
  t283_n213: return -0.035810958594083786f;
  t283_n214: if (E.getNumReferences() >= 3315832832 /*5235.0*/) goto t283_n218;
  t283_n215: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t283_n217;
  t283_n216: return 0.10876250267028809f;
  t283_n217: return -0.8215135931968689f;
  t283_n218: if (E.getNumReferences() >= 3333532160 /*22741.0*/) goto t283_n236;
  t283_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t283_n227;
  t283_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t283_n226;
  t283_n221: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t283_n223;
  t283_n222: return -0.06297680735588074f;
  t283_n223: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t283_n225;
  t283_n224: return 0.11398537456989288f;
  t283_n225: return -0.10535013675689697f;
  t283_n226: return 0.03292534500360489f;
  t283_n227: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t283_n229;
  t283_n228: return -0.05821837857365608f;
  t283_n229: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t283_n231;
  t283_n230: return 0.10199764370918274f;
  t283_n231: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t283_n233;
  t283_n232: return -0.14517387747764587f;
  t283_n233: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t283_n235;
  t283_n234: return 0.11197619885206223f;
  t283_n235: return 0.07863756269216537f;
  t283_n236: return 0.006068825721740723f;
  t283_n237: if (E.getNumReferences() >= 3329272320 /*15402.5*/) goto t283_n249;
  t283_n238: if (E.getNumReferences() >= 3318817792 /*6692.5*/) goto t283_n240;
  t283_n239: return -0.060661930590867996f;
  t283_n240: if (E.getNumReferences() >= 3322330112 /*8623.0*/) goto t283_n244;
  t283_n241: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t283_n243;
  t283_n242: return -0.06507992744445801f;
  t283_n243: return 0.12244711816310883f;
  t283_n244: if (E.getNumReferences() >= 3325912064 /*12121.0*/) goto t283_n246;
  t283_n245: return -0.07987646758556366f;
  t283_n246: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t283_n248;
  t283_n247: return 0.7541830539703369f;
  t283_n248: return 0.139249786734581f;
  t283_n249: return 0.0401856005191803f;
  t283_n250: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t283_n252;
  t283_n251: return -0.05724320188164711f;
  t283_n252: if (E.getNumReferences() >= 3314238464 /*4456.5*/) goto t283_n254;
  t283_n253: return -0.4270537793636322f;
  t283_n254: return 0.03688452020287514f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree284(const Example& E) {
  t284_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t284_n2;
  t284_n1: return -0.000293208344373852f;
  t284_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t284_n98;
  t284_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t284_n7;
  t284_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t284_n6;
  t284_n5: return -0.11580107361078262f;
  t284_n6: return 0.004421899560838938f;
  t284_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t284_n51;
  t284_n8: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t284_n36;
  t284_n9: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t284_n21;
  t284_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t284_n14;
  t284_n11: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t284_n13;
  t284_n12: return 0.05231141299009323f;
  t284_n13: return -0.12960867583751678f;
  t284_n14: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t284_n16;
  t284_n15: return -0.010776110924780369f;
  t284_n16: if (E.getNumReferences() >= 3291176960 /*685.5*/) goto t284_n18;
  t284_n17: return -0.2406335175037384f;
  t284_n18: if (E.getNumReferences() >= 3294339072 /*878.5*/) goto t284_n20;
  t284_n19: return 0.1001439169049263f;
  t284_n20: return 0.05841011181473732f;
  t284_n21: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t284_n31;
  t284_n22: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t284_n30;
  t284_n23: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t284_n25;
  t284_n24: return -0.1049758791923523f;
  t284_n25: if (E.getNumReferences() >= 3289227264 /*566.5*/) goto t284_n27;
  t284_n26: return 0.11441770195960999f;
  t284_n27: if (E.getNumReferences() >= 3295690752 /*961.0*/) goto t284_n29;
  t284_n28: return -0.13594281673431396f;
  t284_n29: return 0.09117726236581802f;
  t284_n30: return -0.24916715919971466f;
  t284_n31: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t284_n33;
  t284_n32: return -0.22909773886203766f;
  t284_n33: if (E.getNumReferences() >= 3291889664 /*729.0*/) goto t284_n35;
  t284_n34: return 0.1133754700422287f;
  t284_n35: return 0.08200542628765106f;
  t284_n36: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t284_n50;
  t284_n37: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t284_n47;
  t284_n38: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t284_n40;
  t284_n39: return 0.01672496646642685f;
  t284_n40: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t284_n46;
  t284_n41: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t284_n43;
  t284_n42: return -0.1308351308107376f;
  t284_n43: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t284_n45;
  t284_n44: return 0.15408658981323242f;
  t284_n45: return 0.08870281279087067f;
  t284_n46: return 0.154104545712471f;
  t284_n47: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t284_n49;
  t284_n48: return 0.0020276394207030535f;
  t284_n49: return 0.05660704895853996f;
  t284_n50: return -0.12898777425289154f;
  t284_n51: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t284_n67;
  t284_n52: if (E.getNumReferences() >= 3287891968 /*498.5*/) goto t284_n66;
  t284_n53: if (E.getNumReferences() >= 3285139456 /*414.5*/) goto t284_n55;
  t284_n54: return -0.04358537867665291f;
  t284_n55: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t284_n65;
  t284_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t284_n64;
  t284_n57: if (E.getNumReferences() >= 3285549056 /*427.0*/) goto t284_n59;
  t284_n58: return 0.09292998909950256f;
  t284_n59: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t284_n63;
  t284_n60: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t284_n62;
  t284_n61: return 0.07983754575252533f;
  t284_n62: return -0.2835056483745575f;
  t284_n63: return 0.1132078468799591f;
  t284_n64: return -0.026648813858628273f;
  t284_n65: return 0.09115895628929138f;
  t284_n66: return 0.10571198910474777f;
  t284_n67: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t284_n69;
  t284_n68: return -0.028748370707035065f;
  t284_n69: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t284_n97;
  t284_n70: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t284_n96;
  t284_n71: if (E.getNumReferences() >= 3292340224 /*756.5*/) goto t284_n77;
  t284_n72: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t284_n74;
  t284_n73: return -0.052326750010252f;
  t284_n74: if (E.getNumReferences() >= 3290718208 /*657.5*/) goto t284_n76;
  t284_n75: return 0.01697167195379734f;
  t284_n76: return 0.09106671810150146f;
  t284_n77: if (E.getNumReferences() >= 3294314496 /*877.0*/) goto t284_n81;
  t284_n78: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t284_n80;
  t284_n79: return 0.11237639933824539f;
  t284_n80: return 0.014332742430269718f;
  t284_n81: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t284_n91;
  t284_n82: if (E.getNumReferences() >= 3301900288 /*1656.0*/) goto t284_n86;
  t284_n83: if (E.getNumReferences() >= 3296133120 /*988.0*/) goto t284_n85;
  t284_n84: return 0.10036862641572952f;
  t284_n85: return -0.2852354943752289f;
  t284_n86: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t284_n90;
  t284_n87: if (E.getNumReferences() >= 3312216064 /*3782.5*/) goto t284_n89;
  t284_n88: return 0.10809610784053802f;
  t284_n89: return 0.06849242001771927f;
  t284_n90: return -0.059140171855688095f;
  t284_n91: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t284_n95;
  t284_n92: if (E.getNumReferences() >= 3316801536 /*5708.0*/) goto t284_n94;
  t284_n93: return -0.028209418058395386f;
  t284_n94: return 0.10275864601135254f;
  t284_n95: return -0.26587679982185364f;
  t284_n96: return 0.10109678655862808f;
  t284_n97: return 0.10423307120800018f;
  t284_n98: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t284_n132;
  t284_n99: if (E.getNumReferences() >= 3284516864 /*395.5*/) goto t284_n103;
  t284_n100: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t284_n102;
  t284_n101: return -0.10540840029716492f;
  t284_n102: return 0.09166263788938522f;
  t284_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t284_n105;
  t284_n104: return 0.023109493777155876f;
  t284_n105: if (E.getNumReferences() >= 3311517696 /*3612.0*/) goto t284_n127;
  t284_n106: if (E.getNumReferences() >= 3306639360 /*2421.0*/) goto t284_n124;
  t284_n107: if (E.getNumReferences() >= 3289849856 /*604.5*/) goto t284_n117;
  t284_n108: if (E.getNumReferences() >= 3289677824 /*594.0*/) goto t284_n116;
  t284_n109: if (E.getNumReferences() >= 3288891392 /*546.0*/) goto t284_n115;
  t284_n110: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t284_n112;
  t284_n111: return -0.12513430416584015f;
  t284_n112: if (E.getNumReferences() >= 3285975040 /*440.0*/) goto t284_n114;
  t284_n113: return 0.10247643291950226f;
  t284_n114: return 0.025807388126850128f;
  t284_n115: return 0.11034126579761505f;
  t284_n116: return 0.10499070584774017f;
  t284_n117: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t284_n119;
  t284_n118: return -0.21788667142391205f;
  t284_n119: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t284_n123;
  t284_n120: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t284_n122;
  t284_n121: return 0.10109201818704605f;
  t284_n122: return 0.056976884603500366f;
  t284_n123: return 0.03337981924414635f;
  t284_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t284_n126;
  t284_n125: return 0.050350889563560486f;
  t284_n126: return 0.11054517328739166f;
  t284_n127: if (E.getNumReferences() >= 3341172352 /*42558.5*/) goto t284_n131;
  t284_n128: if (E.getNumReferences() >= 3338888448 /*33637.0*/) goto t284_n130;
  t284_n129: return -0.054677367210388184f;
  t284_n130: return -1.1913989782333374f;
  t284_n131: return 0.10304208844900131f;
  t284_n132: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t284_n134;
  t284_n133: return -0.0007236163364723325f;
  t284_n134: if (E.getNumReferences() >= 3319569408 /*7059.5*/) goto t284_n254;
  t284_n135: if (E.getNumReferences() >= 3319397376 /*6975.5*/) goto t284_n253;
  t284_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t284_n252;
  t284_n137: if (E.getNumReferences() >= 3318611968 /*6592.0*/) goto t284_n241;
  t284_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t284_n160;
  t284_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t284_n141;
  t284_n140: return -0.00044029977289028466f;
  t284_n141: if (E.getNumReferences() >= 3287498752 /*486.5*/) goto t284_n153;
  t284_n142: if (E.getNumReferences() >= 3286581248 /*458.5*/) goto t284_n148;
  t284_n143: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t284_n145;
  t284_n144: return -0.17104382812976837f;
  t284_n145: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t284_n147;
  t284_n146: return 0.06531007587909698f;
  t284_n147: return -0.09447276592254639f;
  t284_n148: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t284_n150;
  t284_n149: return -0.113828644156456f;
  t284_n150: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t284_n152;
  t284_n151: return 0.09685694426298141f;
  t284_n152: return -0.07454726845026016f;
  t284_n153: if (E.getNumReferences() >= 3296690176 /*1022.0*/) goto t284_n157;
  t284_n154: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t284_n156;
  t284_n155: return -0.12367873638868332f;
  t284_n156: return 0.04243375360965729f;
  t284_n157: if (E.getNumReferences() >= 3297062912 /*1065.5*/) goto t284_n159;
  t284_n158: return 0.10560819506645203f;
  t284_n159: return 0.03779331594705582f;
  t284_n160: if (E.getNumReferences() >= 3290365952 /*636.0*/) goto t284_n174;
  t284_n161: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t284_n173;
  t284_n162: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t284_n164;
  t284_n163: return -0.035955414175987244f;
  t284_n164: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t284_n168;
  t284_n165: if (E.getNumReferences() >= 3285549056 /*427.0*/) goto t284_n167;
  t284_n166: return 0.110667385160923f;
  t284_n167: return -0.2874946892261505f;
  t284_n168: if (E.getNumReferences() >= 3289071616 /*557.0*/) goto t284_n172;
  t284_n169: if (E.getNumReferences() >= 3288506368 /*522.5*/) goto t284_n171;
  t284_n170: return 0.07902505993843079f;
  t284_n171: return 0.15036581456661224f;
  t284_n172: return -0.14462575316429138f;
  t284_n173: return -0.9662525057792664f;
  t284_n174: if (E.getNumReferences() >= 3293151232 /*806.0*/) goto t284_n198;
  t284_n175: if (E.getNumReferences() >= 3292684288 /*777.5*/) goto t284_n189;
  t284_n176: if (E.getNumReferences() >= 3291660288 /*715.0*/) goto t284_n188;
  t284_n177: if (E.getNumReferences() >= 3291521024 /*706.5*/) goto t284_n187;
  t284_n178: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t284_n184;
  t284_n179: if (E.getNumReferences() >= 3290972160 /*673.0*/) goto t284_n183;
  t284_n180: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t284_n182;
  t284_n181: return 0.029001938179135323f;
  t284_n182: return 0.09638265520334244f;
  t284_n183: return -0.2363768219947815f;
  t284_n184: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t284_n186;
  t284_n185: return 0.08599825948476791f;
  t284_n186: return 0.014685327187180519f;
  t284_n187: return 0.12714150547981262f;
  t284_n188: return -0.08907788246870041f;
  t284_n189: if (E.getNumReferences() >= 3292782592 /*783.5*/) goto t284_n193;
  t284_n190: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t284_n192;
  t284_n191: return 0.09831973165273666f;
  t284_n192: return 0.1013672798871994f;
  t284_n193: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t284_n197;
  t284_n194: if (E.getNumReferences() >= 3292880896 /*789.5*/) goto t284_n196;
  t284_n195: return -0.037148136645555496f;
  t284_n196: return 0.10868088901042938f;
  t284_n197: return -0.48110005259513855f;
  t284_n198: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t284_n232;
  t284_n199: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t284_n201;
  t284_n200: return -0.34481531381607056f;
  t284_n201: if (E.getNumReferences() >= 3295535104 /*951.5*/) goto t284_n203;
  t284_n202: return -0.2005741447210312f;
  t284_n203: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t284_n205;
  t284_n204: return 0.01711219735443592f;
  t284_n205: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t284_n213;
  t284_n206: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t284_n212;
  t284_n207: if (E.getNumReferences() >= 3297787904 /*1154.0*/) goto t284_n211;
  t284_n208: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t284_n210;
  t284_n209: return -0.12012318521738052f;
  t284_n210: return 0.8177352547645569f;
  t284_n211: return -0.17224536836147308f;
  t284_n212: return 0.17005771398544312f;
  t284_n213: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t284_n227;
  t284_n214: if (E.getNumReferences() >= 3300458496 /*1480.0*/) goto t284_n220;
  t284_n215: if (E.getNumReferences() >= 3297886208 /*1166.0*/) goto t284_n219;
  t284_n216: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t284_n218;
  t284_n217: return 0.0837307870388031f;
  t284_n218: return -0.1545955240726471f;
  t284_n219: return 0.12898553907871246f;
  t284_n220: if (E.getNumReferences() >= 3306293248 /*2336.5*/) goto t284_n222;
  t284_n221: return -0.1571582853794098f;
  t284_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t284_n224;
  t284_n223: return -0.15441571176052094f;
  t284_n224: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t284_n226;
  t284_n225: return 0.08601412922143936f;
  t284_n226: return 0.14660537242889404f;
  t284_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t284_n231;
  t284_n228: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t284_n230;
  t284_n229: return -0.046445202082395554f;
  t284_n230: return 0.09809103608131409f;
  t284_n231: return 0.10120803117752075f;
  t284_n232: if (E.getNumReferences() >= 3318055936 /*6320.5*/) goto t284_n236;
  t284_n233: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t284_n235;
  t284_n234: return -0.02186264656484127f;
  t284_n235: return 0.02779659815132618f;
  t284_n236: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t284_n238;
  t284_n237: return -0.013022946193814278f;
  t284_n238: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t284_n240;
  t284_n239: return -1.217344045639038f;
  t284_n240: return -0.3018433749675751f;
  t284_n241: if (E.getNumReferences() >= 3318784000 /*6676.0*/) goto t284_n251;
  t284_n242: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t284_n246;
  t284_n243: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t284_n245;
  t284_n244: return -0.28168749809265137f;
  t284_n245: return 0.12059376388788223f;
  t284_n246: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t284_n250;
  t284_n247: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t284_n249;
  t284_n248: return 0.10045457631349564f;
  t284_n249: return 0.06603001803159714f;
  t284_n250: return -0.14248716831207275f;
  t284_n251: return 0.018570873886346817f;
  t284_n252: return 0.09975786507129669f;
  t284_n253: return 0.10914259403944016f;
  t284_n254: return 0.0037214960902929306f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree285(const Example& E) {
  t285_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t285_n2;
  t285_n1: return -0.00027685044915415347f;
  t285_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t285_n34;
  t285_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t285_n15;
  t285_n4: if (E.getNumReferences() >= 3317489664 /*6044.0*/) goto t285_n14;
  t285_n5: if (E.getNumReferences() >= 3300917248 /*1536.0*/) goto t285_n7;
  t285_n6: return -0.004306808114051819f;
  t285_n7: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t285_n9;
  t285_n8: return 0.1360553652048111f;
  t285_n9: if (E.getNumReferences() >= 3301826560 /*1647.0*/) goto t285_n11;
  t285_n10: return 0.15802070498466492f;
  t285_n11: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t285_n13;
  t285_n12: return 0.012312822043895721f;
  t285_n13: return 0.1065576896071434f;
  t285_n14: return -0.11739646643400192f;
  t285_n15: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t285_n17;
  t285_n16: return 0.09608727693557739f;
  t285_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t285_n29;
  t285_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t285_n20;
  t285_n19: return -0.025843998417258263f;
  t285_n20: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t285_n26;
  t285_n21: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t285_n23;
  t285_n22: return -0.10510219633579254f;
  t285_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t285_n25;
  t285_n24: return -0.0018059361027553678f;
  t285_n25: return 0.08998598903417587f;
  t285_n26: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t285_n28;
  t285_n27: return -0.013504080474376678f;
  t285_n28: return -0.25199639797210693f;
  t285_n29: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t285_n31;
  t285_n30: return 0.009207721799612045f;
  t285_n31: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t285_n33;
  t285_n32: return 0.056249864399433136f;
  t285_n33: return -0.0653035044670105f;
  t285_n34: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t285_n254;
  t285_n35: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t285_n37;
  t285_n36: return 0.007049051579087973f;
  t285_n37: if (E.getNumReferences() >= 3290374144 /*636.5*/) goto t285_n199;
  t285_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t285_n86;
  t285_n39: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t285_n73;
  t285_n40: if (E.getNumReferences() >= 3289948160 /*610.5*/) goto t285_n72;
  t285_n41: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t285_n61;
  t285_n42: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t285_n46;
  t285_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t285_n45;
  t285_n44: return 0.044115811586380005f;
  t285_n45: return -0.7690717577934265f;
  t285_n46: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t285_n48;
  t285_n47: return 0.05730368196964264f;
  t285_n48: if (E.getNumReferences() >= 3280601088 /*276.0*/) goto t285_n60;
  t285_n49: if (E.getNumReferences() >= 3277357056 /*216.5*/) goto t285_n59;
  t285_n50: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t285_n56;
  t285_n51: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t285_n55;
  t285_n52: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t285_n54;
  t285_n53: return 0.1387208253145218f;
  t285_n54: return 0.07770140469074249f;
  t285_n55: return -0.005552884191274643f;
  t285_n56: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t285_n58;
  t285_n57: return -0.07524048537015915f;
  t285_n58: return 0.11294630169868469f;
  t285_n59: return 0.15435722470283508f;
  t285_n60: return -0.08354903012514114f;
  t285_n61: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t285_n69;
  t285_n62: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t285_n66;
  t285_n63: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t285_n65;
  t285_n64: return 0.14267420768737793f;
  t285_n65: return -0.0010256090899929404f;
  t285_n66: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t285_n68;
  t285_n67: return 0.12618765234947205f;
  t285_n68: return 0.43126416206359863f;
  t285_n69: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t285_n71;
  t285_n70: return 0.040497925132513046f;
  t285_n71: return -0.8257911801338196f;
  t285_n72: return 0.11646075546741486f;
  t285_n73: if (E.getNumReferences() >= 3276308480 /*200.5*/) goto t285_n83;
  t285_n74: if (E.getNumReferences() >= 3275522048 /*188.5*/) goto t285_n82;
  t285_n75: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t285_n81;
  t285_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t285_n80;
  t285_n77: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t285_n79;
  t285_n78: return -0.7015922665596008f;
  t285_n79: return 0.13757175207138062f;
  t285_n80: return 0.10803738981485367f;
  t285_n81: return -0.08436799049377441f;
  t285_n82: return 0.1321702003479004f;
  t285_n83: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t285_n85;
  t285_n84: return -0.15047450363636017f;
  t285_n85: return 0.9602012038230896f;
  t285_n86: if (E.getNumReferences() >= 3290267648 /*630.0*/) goto t285_n196;
  t285_n87: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t285_n123;
  t285_n88: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t285_n118;
  t285_n89: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t285_n101;
  t285_n90: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t285_n96;
  t285_n91: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t285_n93;
  t285_n92: return -1.0605086088180542f;
  t285_n93: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t285_n95;
  t285_n94: return 0.25906750559806824f;
  t285_n95: return -0.10972587019205093f;
  t285_n96: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t285_n100;
  t285_n97: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t285_n99;
  t285_n98: return 0.10066276043653488f;
  t285_n99: return 0.10184939950704575f;
  t285_n100: return -0.10185706615447998f;
  t285_n101: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t285_n111;
  t285_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t285_n110;
  t285_n103: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t285_n107;
  t285_n104: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t285_n106;
  t285_n105: return -0.879972517490387f;
  t285_n106: return -0.15921558439731598f;
  t285_n107: if (E.getNumReferences() >= 3278045184 /*227.0*/) goto t285_n109;
  t285_n108: return -0.13296951353549957f;
  t285_n109: return 0.11055203527212143f;
  t285_n110: return 0.0582372285425663f;
  t285_n111: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t285_n117;
  t285_n112: if (E.getNumReferences() >= 3281616896 /*307.0*/) goto t285_n116;
  t285_n113: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t285_n115;
  t285_n114: return -0.08876724541187286f;
  t285_n115: return 0.08191868662834167f;
  t285_n116: return 0.10602972656488419f;
  t285_n117: return 0.025963537395000458f;
  t285_n118: if (E.getNumReferences() >= 3277750272 /*222.5*/) goto t285_n120;
  t285_n119: return -0.027201607823371887f;
  t285_n120: if (E.getNumReferences() >= 3277815808 /*223.5*/) goto t285_n122;
  t285_n121: return 0.12823866307735443f;
  t285_n122: return 0.02314002998173237f;
  t285_n123: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t285_n193;
  t285_n124: if (E.getNumReferences() >= 3279994880 /*257.5*/) goto t285_n184;
  t285_n125: if (E.getNumReferences() >= 3279683584 /*252.0*/) goto t285_n183;
  t285_n126: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t285_n140;
  t285_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t285_n129;
  t285_n128: return -0.09178753942251205f;
  t285_n129: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t285_n139;
  t285_n130: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t285_n138;
  t285_n131: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t285_n137;
  t285_n132: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t285_n136;
  t285_n133: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t285_n135;
  t285_n134: return -0.1644829362630844f;
  t285_n135: return 0.12376817315816879f;
  t285_n136: return -0.375501811504364f;
  t285_n137: return 0.12216120958328247f;
  t285_n138: return 0.07481014728546143f;
  t285_n139: return -0.040564537048339844f;
  t285_n140: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t285_n180;
  t285_n141: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t285_n149;
  t285_n142: if (E.getNumReferences() >= 3271720960 /*130.5*/) goto t285_n148;
  t285_n143: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t285_n145;
  t285_n144: return 0.05229447782039642f;
  t285_n145: if (E.getNumReferences() >= 3270639616 /*121.0*/) goto t285_n147;
  t285_n146: return -0.12270668148994446f;
  t285_n147: return 0.21200445294380188f;
  t285_n148: return 0.1072971299290657f;
  t285_n149: if (E.getNumReferences() >= 3274735616 /*176.5*/) goto t285_n159;
  t285_n150: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t285_n152;
  t285_n151: return -0.03189234063029289f;
  t285_n152: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t285_n158;
  t285_n153: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t285_n157;
  t285_n154: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t285_n156;
  t285_n155: return -0.10342882573604584f;
  t285_n156: return 0.12823888659477234f;
  t285_n157: return -0.3105246126651764f;
  t285_n158: return 0.09155721217393875f;
  t285_n159: if (E.getNumReferences() >= 3275063296 /*181.5*/) goto t285_n165;
  t285_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t285_n164;
  t285_n161: if (E.getNumReferences() >= 3274801152 /*177.5*/) goto t285_n163;
  t285_n162: return 0.20706842839717865f;
  t285_n163: return -0.1597525030374527f;
  t285_n164: return 0.1043190136551857f;
  t285_n165: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t285_n167;
  t285_n166: return -0.0019793843384832144f;
  t285_n167: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t285_n175;
  t285_n168: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t285_n172;
  t285_n169: if (E.getNumReferences() >= 3275554816 /*189.0*/) goto t285_n171;
  t285_n170: return 0.11328506469726562f;
  t285_n171: return -0.028953013941645622f;
  t285_n172: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t285_n174;
  t285_n173: return 0.16564035415649414f;
  t285_n174: return -0.10044564306735992f;
  t285_n175: if (E.getNumReferences() >= 3278667776 /*236.5*/) goto t285_n177;
  t285_n176: return -0.15675204992294312f;
  t285_n177: if (E.getNumReferences() >= 3278864384 /*239.5*/) goto t285_n179;
  t285_n178: return 0.10889805108308792f;
  t285_n179: return -0.11091241985559464f;
  t285_n180: if (E.getNumReferences() >= 3271098368 /*124.5*/) goto t285_n182;
  t285_n181: return 0.12532341480255127f;
  t285_n182: return 0.13569827377796173f;
  t285_n183: return 0.10914907604455948f;
  t285_n184: if (E.getNumReferences() >= 3287662592 /*491.5*/) goto t285_n190;
  t285_n185: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t285_n187;
  t285_n186: return -0.14398494362831116f;
  t285_n187: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t285_n189;
  t285_n188: return -0.08701593428850174f;
  t285_n189: return 0.0376657173037529f;
  t285_n190: if (E.getNumReferences() >= 3287924736 /*499.5*/) goto t285_n192;
  t285_n191: return 0.08070552349090576f;
  t285_n192: return 0.03728087246417999f;
  t285_n193: if (E.getNumReferences() >= 3266379776 /*88.5*/) goto t285_n195;
  t285_n194: return 0.10914114862680435f;
  t285_n195: return 0.09649910032749176f;
  t285_n196: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t285_n198;
  t285_n197: return 0.10048885643482208f;
  t285_n198: return -0.126892551779747f;
  t285_n199: if (E.getNumReferences() >= 3293290496 /*814.5*/) goto t285_n205;
  t285_n200: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t285_n202;
  t285_n201: return -0.07722406834363937f;
  t285_n202: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t285_n204;
  t285_n203: return -0.13375425338745117f;
  t285_n204: return -1.3035396337509155f;
  t285_n205: if (E.getNumReferences() >= 3293315072 /*816.0*/) goto t285_n207;
  t285_n206: return 0.08472920209169388f;
  t285_n207: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t285_n215;
  t285_n208: if (E.getNumReferences() >= 3319490560 /*7021.0*/) goto t285_n212;
  t285_n209: if (E.getNumReferences() >= 3293913088 /*852.5*/) goto t285_n211;
  t285_n210: return 0.0987725630402565f;
  t285_n211: return -0.09313010424375534f;
  t285_n212: if (E.getNumReferences() >= 3319629824 /*7089.0*/) goto t285_n214;
  t285_n213: return 0.11110108345746994f;
  t285_n214: return -0.006799082737416029f;
  t285_n215: if (E.getNumReferences() >= 3293495296 /*827.0*/) goto t285_n221;
  t285_n216: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t285_n218;
  t285_n217: return -0.13074567914009094f;
  t285_n218: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t285_n220;
  t285_n219: return 0.15179823338985443f;
  t285_n220: return -0.12967830896377563f;
  t285_n221: if (E.getNumReferences() >= 3295453184 /*946.5*/) goto t285_n223;
  t285_n222: return -0.13924144208431244f;
  t285_n223: if (E.getNumReferences() >= 3295698944 /*961.5*/) goto t285_n227;
  t285_n224: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t285_n226;
  t285_n225: return 0.11375366896390915f;
  t285_n226: return 0.0597112812101841f;
  t285_n227: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t285_n229;
  t285_n228: return 0.09970507770776749f;
  t285_n229: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t285_n231;
  t285_n230: return -0.47748181223869324f;
  t285_n231: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t285_n253;
  t285_n232: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t285_n240;
  t285_n233: if (E.getNumReferences() >= 3347438016 /*68531.5*/) goto t285_n239;
  t285_n234: if (E.getNumReferences() >= 3343006592 /*49723.5*/) goto t285_n238;
  t285_n235: if (E.getNumReferences() >= 3334924800 /*25461.0*/) goto t285_n237;
  t285_n236: return 0.007808004040271044f;
  t285_n237: return 0.034993983805179596f;
  t285_n238: return -0.06027071177959442f;
  t285_n239: return -0.6127010583877563f;
  t285_n240: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t285_n252;
  t285_n241: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t285_n251;
  t285_n242: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t285_n250;
  t285_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t285_n245;
  t285_n244: return 0.07338724285364151f;
  t285_n245: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t285_n247;
  t285_n246: return 0.09835419058799744f;
  t285_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t285_n249;
  t285_n248: return 0.03691338747739792f;
  t285_n249: return 0.10791032761335373f;
  t285_n250: return 0.13360120356082916f;
  t285_n251: return 0.04714198410511017f;
  t285_n252: return 0.0026158231776207685f;
  t285_n253: return -0.25632941722869873f;
  t285_n254: return -1.2111814612580929e-05f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree286(const Example& E) {
  t286_n0: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t286_n26;
  t286_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t286_n3;
  t286_n2: return -0.027640795335173607f;
  t286_n3: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t286_n5;
  t286_n4: return 0.0037766355089843273f;
  t286_n5: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t286_n7;
  t286_n6: return -0.000159332063049078f;
  t286_n7: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t286_n11;
  t286_n8: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t286_n10;
  t286_n9: return -0.020967500284314156f;
  t286_n10: return -0.05218067765235901f;
  t286_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t286_n13;
  t286_n12: return 0.02793486788868904f;
  t286_n13: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t286_n19;
  t286_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t286_n18;
  t286_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t286_n17;
  t286_n16: return 0.013917871750891209f;
  t286_n17: return 0.08833912760019302f;
  t286_n18: return 0.14382237195968628f;
  t286_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t286_n21;
  t286_n20: return 0.061350543051958084f;
  t286_n21: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t286_n23;
  t286_n22: return 0.11011804640293121f;
  t286_n23: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t286_n25;
  t286_n24: return -0.28885096311569214f;
  t286_n25: return 0.1254620999097824f;
  t286_n26: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t286_n254;
  t286_n27: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t286_n97;
  t286_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t286_n62;
  t286_n29: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t286_n61;
  t286_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t286_n52;
  t286_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t286_n33;
  t286_n32: return 0.0011279820464551449f;
  t286_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t286_n35;
  t286_n34: return 0.07844597101211548f;
  t286_n35: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t286_n45;
  t286_n36: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t286_n38;
  t286_n37: return 0.03274885565042496f;
  t286_n38: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t286_n44;
  t286_n39: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t286_n41;
  t286_n40: return 0.06416144967079163f;
  t286_n41: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t286_n43;
  t286_n42: return 0.09739222377538681f;
  t286_n43: return 0.06273659318685532f;
  t286_n44: return 0.0003498863079585135f;
  t286_n45: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t286_n49;
  t286_n46: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t286_n48;
  t286_n47: return 0.13868224620819092f;
  t286_n48: return -0.010730862617492676f;
  t286_n49: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t286_n51;
  t286_n50: return 0.12056254595518112f;
  t286_n51: return -0.18404386937618256f;
  t286_n52: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t286_n54;
  t286_n53: return 0.10353568941354752f;
  t286_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t286_n56;
  t286_n55: return 0.046095412224531174f;
  t286_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t286_n58;
  t286_n57: return 0.050532400608062744f;
  t286_n58: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t286_n60;
  t286_n59: return 0.11808845400810242f;
  t286_n60: return -0.06193391978740692f;
  t286_n61: return -0.003245669649913907f;
  t286_n62: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t286_n96;
  t286_n63: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t286_n87;
  t286_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t286_n66;
  t286_n65: return 0.017559293657541275f;
  t286_n66: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t286_n68;
  t286_n67: return 0.08762554079294205f;
  t286_n68: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n86;
  t286_n69: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t286_n81;
  t286_n70: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t286_n78;
  t286_n71: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t286_n73;
  t286_n72: return 0.05994492024183273f;
  t286_n73: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t286_n77;
  t286_n74: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t286_n76;
  t286_n75: return 0.11547673493623734f;
  t286_n76: return 0.09376700967550278f;
  t286_n77: return 0.0662200003862381f;
  t286_n78: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t286_n80;
  t286_n79: return -0.21107839047908783f;
  t286_n80: return 0.08109308034181595f;
  t286_n81: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t286_n85;
  t286_n82: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t286_n84;
  t286_n83: return 0.11395778506994247f;
  t286_n84: return -0.12081696093082428f;
  t286_n85: return -0.09101632982492447f;
  t286_n86: return -0.017043383792042732f;
  t286_n87: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t286_n95;
  t286_n88: if (E.getNumReferences() >= 3325698048 /*11912.0*/) goto t286_n90;
  t286_n89: return 0.013889669440686703f;
  t286_n90: if (E.getNumReferences() >= 3325825536 /*12036.5*/) goto t286_n94;
  t286_n91: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t286_n93;
  t286_n92: return 0.12657904624938965f;
  t286_n93: return -0.055555764585733414f;
  t286_n94: return 0.020419107750058174f;
  t286_n95: return -0.19928662478923798f;
  t286_n96: return 0.013433392159640789f;
  t286_n97: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t286_n105;
  t286_n98: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t286_n100;
  t286_n99: return 0.001141635701060295f;
  t286_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t286_n102;
  t286_n101: return 0.0064758858643472195f;
  t286_n102: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t286_n104;
  t286_n103: return 0.02488834224641323f;
  t286_n104: return -0.12950974702835083f;
  t286_n105: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t286_n253;
  t286_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t286_n146;
  t286_n107: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t286_n119;
  t286_n108: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t286_n112;
  t286_n109: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t286_n111;
  t286_n110: return 0.023344721645116806f;
  t286_n111: return -0.03974998742341995f;
  t286_n112: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n116;
  t286_n113: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t286_n115;
  t286_n114: return -0.15785697102546692f;
  t286_n115: return 0.09330374747514725f;
  t286_n116: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t286_n118;
  t286_n117: return 0.14863519370555878f;
  t286_n118: return -0.01598377153277397f;
  t286_n119: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t286_n127;
  t286_n120: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t286_n122;
  t286_n121: return 0.10876227915287018f;
  t286_n122: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t286_n126;
  t286_n123: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t286_n125;
  t286_n124: return 0.024586116895079613f;
  t286_n125: return -0.020505497232079506f;
  t286_n126: return 0.15445604920387268f;
  t286_n127: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t286_n145;
  t286_n128: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t286_n144;
  t286_n129: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t286_n143;
  t286_n130: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t286_n134;
  t286_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t286_n133;
  t286_n132: return -0.00813473854213953f;
  t286_n133: return 0.07639884948730469f;
  t286_n134: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n142;
  t286_n135: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n137;
  t286_n136: return 0.09765497595071793f;
  t286_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t286_n139;
  t286_n138: return 0.08840020000934601f;
  t286_n139: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t286_n141;
  t286_n140: return -0.31973445415496826f;
  t286_n141: return 0.1202089786529541f;
  t286_n142: return 0.02543638087809086f;
  t286_n143: return 0.05545240640640259f;
  t286_n144: return 0.02818628028035164f;
  t286_n145: return -0.10659874975681305f;
  t286_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t286_n148;
  t286_n147: return -0.06020186096429825f;
  t286_n148: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t286_n238;
  t286_n149: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t286_n237;
  t286_n150: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t286_n220;
  t286_n151: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t286_n179;
  t286_n152: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t286_n164;
  t286_n153: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t286_n163;
  t286_n154: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n156;
  t286_n155: return 0.05034222826361656f;
  t286_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t286_n160;
  t286_n157: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n159;
  t286_n158: return 0.05291450023651123f;
  t286_n159: return 0.006963761989027262f;
  t286_n160: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n162;
  t286_n161: return 0.0755922868847847f;
  t286_n162: return 0.08720005303621292f;
  t286_n163: return -0.020525451749563217f;
  t286_n164: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t286_n166;
  t286_n165: return -0.011126159690320492f;
  t286_n166: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t286_n178;
  t286_n167: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n177;
  t286_n168: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n172;
  t286_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t286_n171;
  t286_n170: return 0.036479294300079346f;
  t286_n171: return 0.06612168252468109f;
  t286_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t286_n174;
  t286_n173: return 0.027157247066497803f;
  t286_n174: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n176;
  t286_n175: return 0.08544675260782242f;
  t286_n176: return 0.08967353403568268f;
  t286_n177: return 0.024487411603331566f;
  t286_n178: return -0.012018010020256042f;
  t286_n179: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t286_n219;
  t286_n180: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t286_n196;
  t286_n181: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t286_n195;
  t286_n182: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n194;
  t286_n183: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n189;
  t286_n184: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n188;
  t286_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t286_n187;
  t286_n186: return 0.08503039926290512f;
  t286_n187: return 0.09935874491930008f;
  t286_n188: return 0.046408649533987045f;
  t286_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t286_n191;
  t286_n190: return -0.0016361649613827467f;
  t286_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t286_n193;
  t286_n192: return 0.08593548834323883f;
  t286_n193: return 0.10961548238992691f;
  t286_n194: return 0.011310802772641182f;
  t286_n195: return -0.043197132647037506f;
  t286_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t286_n206;
  t286_n197: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n199;
  t286_n198: return 0.002056750236079097f;
  t286_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t286_n201;
  t286_n200: return 0.04266922548413277f;
  t286_n201: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n205;
  t286_n202: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n204;
  t286_n203: return 0.0806875005364418f;
  t286_n204: return 0.09688523411750793f;
  t286_n205: return -0.17715948820114136f;
  t286_n206: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n218;
  t286_n207: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n211;
  t286_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t286_n210;
  t286_n209: return 0.12150898575782776f;
  t286_n210: return 0.1517508327960968f;
  t286_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t286_n215;
  t286_n212: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n214;
  t286_n213: return 0.12907689809799194f;
  t286_n214: return 0.08277402818202972f;
  t286_n215: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n217;
  t286_n216: return 0.08863648772239685f;
  t286_n217: return 0.09920220822095871f;
  t286_n218: return -0.0013987226411700249f;
  t286_n219: return 0.0456383153796196f;
  t286_n220: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n236;
  t286_n221: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n227;
  t286_n222: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t286_n226;
  t286_n223: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t286_n225;
  t286_n224: return 0.013566164299845695f;
  t286_n225: return 0.07266387343406677f;
  t286_n226: return -0.06387076526880264f;
  t286_n227: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t286_n231;
  t286_n228: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t286_n230;
  t286_n229: return 0.06866560131311417f;
  t286_n230: return -0.0223728995770216f;
  t286_n231: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t286_n235;
  t286_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t286_n234;
  t286_n233: return 0.09904742985963821f;
  t286_n234: return 0.11758437007665634f;
  t286_n235: return 0.01828927733004093f;
  t286_n236: return -0.07853634655475616f;
  t286_n237: return -0.10109958797693253f;
  t286_n238: if (E.getNumReferences() >= 3312652288 /*3889.0*/) goto t286_n240;
  t286_n239: return -0.021888338029384613f;
  t286_n240: if (E.getNumReferences() >= 3312812032 /*3928.0*/) goto t286_n242;
  t286_n241: return 0.1058933436870575f;
  t286_n242: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n244;
  t286_n243: return -0.053474050015211105f;
  t286_n244: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n252;
  t286_n245: if (E.getNumReferences() >= 3331624192 /*19014.5*/) goto t286_n251;
  t286_n246: if (E.getNumReferences() >= 3316534272 /*5577.5*/) goto t286_n248;
  t286_n247: return -0.2022964507341385f;
  t286_n248: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t286_n250;
  t286_n249: return 0.09019777178764343f;
  t286_n250: return 0.11286123096942902f;
  t286_n251: return 0.0844651535153389f;
  t286_n252: return 0.041705306619405746f;
  t286_n253: return -0.006200931500643492f;
  t286_n254: return -0.04460381343960762f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree287(const Example& E) {
  t287_n0: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t287_n2;
  t287_n1: return -0.0004134258779231459f;
  t287_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t287_n190;
  t287_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t287_n121;
  t287_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t287_n30;
  t287_n5: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t287_n15;
  t287_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n8;
  t287_n7: return -0.02655639313161373f;
  t287_n8: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t287_n12;
  t287_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t287_n11;
  t287_n10: return 0.03750964626669884f;
  t287_n11: return 0.1297018676996231f;
  t287_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t287_n14;
  t287_n13: return 0.11096359044313431f;
  t287_n14: return -0.29158496856689453f;
  t287_n15: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n17;
  t287_n16: return -0.014811288565397263f;
  t287_n17: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t287_n19;
  t287_n18: return -0.037391871213912964f;
  t287_n19: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t287_n21;
  t287_n20: return -0.1440250426530838f;
  t287_n21: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t287_n23;
  t287_n22: return -0.2455744594335556f;
  t287_n23: if (E.getNumReferences() >= 3280568320 /*275.0*/) goto t287_n29;
  t287_n24: if (E.getNumReferences() >= 3273424896 /*156.5*/) goto t287_n28;
  t287_n25: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t287_n27;
  t287_n26: return 0.15728843212127686f;
  t287_n27: return -0.08770938217639923f;
  t287_n28: return 0.11379610747098923f;
  t287_n29: return 0.039345528930425644f;
  t287_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t287_n32;
  t287_n31: return 0.003781162900850177f;
  t287_n32: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t287_n102;
  t287_n33: if (E.getNumReferences() >= 3281027072 /*289.0*/) goto t287_n81;
  t287_n34: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t287_n46;
  t287_n35: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t287_n41;
  t287_n36: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t287_n38;
  t287_n37: return -0.06550656259059906f;
  t287_n38: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t287_n40;
  t287_n39: return 0.07084105908870697f;
  t287_n40: return 0.1065715029835701f;
  t287_n41: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t287_n43;
  t287_n42: return -0.12095960974693298f;
  t287_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t287_n45;
  t287_n44: return 0.12269030511379242f;
  t287_n45: return 0.11232214421033859f;
  t287_n46: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t287_n80;
  t287_n47: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t287_n57;
  t287_n48: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n50;
  t287_n49: return -0.11289287358522415f;
  t287_n50: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t287_n52;
  t287_n51: return -0.1859954446554184f;
  t287_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t287_n54;
  t287_n53: return -0.0709809884428978f;
  t287_n54: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t287_n56;
  t287_n55: return 0.057397905737161636f;
  t287_n56: return -0.09166199713945389f;
  t287_n57: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t287_n67;
  t287_n58: if (E.getNumReferences() >= 3265986560 /*85.5*/) goto t287_n64;
  t287_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t287_n61;
  t287_n60: return -0.03838469460606575f;
  t287_n61: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t287_n63;
  t287_n62: return 0.12016778439283371f;
  t287_n63: return 0.012968306429684162f;
  t287_n64: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t287_n66;
  t287_n65: return -0.27685439586639404f;
  t287_n66: return 0.12629280984401703f;
  t287_n67: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n69;
  t287_n68: return -0.03568573296070099f;
  t287_n69: if (E.getNumReferences() >= 3268214784 /*102.5*/) goto t287_n79;
  t287_n70: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t287_n76;
  t287_n71: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t287_n75;
  t287_n72: if (E.getNumReferences() >= 3267362816 /*96.0*/) goto t287_n74;
  t287_n73: return 0.11408285796642303f;
  t287_n74: return 0.08927181363105774f;
  t287_n75: return 0.04760312661528587f;
  t287_n76: if (E.getNumReferences() >= 3267756032 /*99.0*/) goto t287_n78;
  t287_n77: return -0.18046027421951294f;
  t287_n78: return 0.09312333166599274f;
  t287_n79: return 0.01294466108083725f;
  t287_n80: return -0.036308594048023224f;
  t287_n81: if (E.getNumReferences() >= 3281747968 /*311.0*/) goto t287_n85;
  t287_n82: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t287_n84;
  t287_n83: return 0.08723147213459015f;
  t287_n84: return 0.12016530334949493f;
  t287_n85: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t287_n87;
  t287_n86: return 0.010422907769680023f;
  t287_n87: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t287_n99;
  t287_n88: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t287_n90;
  t287_n89: return 0.055432237684726715f;
  t287_n90: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t287_n98;
  t287_n91: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t287_n95;
  t287_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t287_n94;
  t287_n93: return 0.10957035422325134f;
  t287_n94: return -0.107404924929142f;
  t287_n95: if (E.getNumReferences() >= 3294699520 /*900.5*/) goto t287_n97;
  t287_n96: return 0.11229591071605682f;
  t287_n97: return 0.09847649931907654f;
  t287_n98: return 0.020680274814367294f;
  t287_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t287_n101;
  t287_n100: return -0.09571971744298935f;
  t287_n101: return 0.057889629155397415f;
  t287_n102: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t287_n112;
  t287_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t287_n105;
  t287_n104: return 0.016176914796233177f;
  t287_n105: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t287_n109;
  t287_n106: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t287_n108;
  t287_n107: return -0.39031797647476196f;
  t287_n108: return 0.035451166331768036f;
  t287_n109: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t287_n111;
  t287_n110: return -0.131337508559227f;
  t287_n111: return 0.11081799119710922f;
  t287_n112: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t287_n120;
  t287_n113: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t287_n115;
  t287_n114: return -0.004038703162223101f;
  t287_n115: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t287_n119;
  t287_n116: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t287_n118;
  t287_n117: return 0.10590590536594391f;
  t287_n118: return -0.05624571442604065f;
  t287_n119: return 0.016914140433073044f;
  t287_n120: return 0.05345524474978447f;
  t287_n121: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t287_n161;
  t287_n122: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t287_n158;
  t287_n123: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t287_n157;
  t287_n124: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t287_n136;
  t287_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t287_n127;
  t287_n126: return 0.009126214310526848f;
  t287_n127: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t287_n133;
  t287_n128: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t287_n132;
  t287_n129: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t287_n131;
  t287_n130: return -0.039548151195049286f;
  t287_n131: return 0.09815295785665512f;
  t287_n132: return 0.12371478229761124f;
  t287_n133: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t287_n135;
  t287_n134: return -0.18709465861320496f;
  t287_n135: return 0.08894715458154678f;
  t287_n136: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t287_n138;
  t287_n137: return -0.02642485685646534f;
  t287_n138: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t287_n142;
  t287_n139: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t287_n141;
  t287_n140: return 0.107771135866642f;
  t287_n141: return -0.26030850410461426f;
  t287_n142: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t287_n156;
  t287_n143: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t287_n153;
  t287_n144: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n152;
  t287_n145: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t287_n151;
  t287_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t287_n148;
  t287_n147: return 0.13226905465126038f;
  t287_n148: if (E.getNumReferences() >= 3271098368 /*124.5*/) goto t287_n150;
  t287_n149: return 0.1159411147236824f;
  t287_n150: return -0.13012631237506866f;
  t287_n151: return 0.056612495332956314f;
  t287_n152: return -0.13106408715248108f;
  t287_n153: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t287_n155;
  t287_n154: return 0.10771477222442627f;
  t287_n155: return 0.045900896191596985f;
  t287_n156: return 0.006253836676478386f;
  t287_n157: return 0.09378720819950104f;
  t287_n158: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t287_n160;
  t287_n159: return 0.0077407206408679485f;
  t287_n160: return 0.1011209487915039f;
  t287_n161: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t287_n185;
  t287_n162: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t287_n184;
  t287_n163: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t287_n167;
  t287_n164: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t287_n166;
  t287_n165: return -0.16276311874389648f;
  t287_n166: return 0.10467150807380676f;
  t287_n167: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t287_n169;
  t287_n168: return -0.025194693356752396f;
  t287_n169: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t287_n183;
  t287_n170: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t287_n176;
  t287_n171: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t287_n173;
  t287_n172: return -0.24486178159713745f;
  t287_n173: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t287_n175;
  t287_n174: return -0.4019053280353546f;
  t287_n175: return 0.10758465528488159f;
  t287_n176: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t287_n178;
  t287_n177: return 0.08964934200048447f;
  t287_n178: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t287_n180;
  t287_n179: return 0.003019560594111681f;
  t287_n180: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n182;
  t287_n181: return 0.08273269981145859f;
  t287_n182: return 0.16581952571868896f;
  t287_n183: return -0.06082620844244957f;
  t287_n184: return 0.10426879674196243f;
  t287_n185: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t287_n189;
  t287_n186: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t287_n188;
  t287_n187: return 0.021087199449539185f;
  t287_n188: return 0.08528076857328415f;
  t287_n189: return -0.04121294245123863f;
  t287_n190: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t287_n252;
  t287_n191: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t287_n193;
  t287_n192: return -0.0024592748377472162f;
  t287_n193: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t287_n233;
  t287_n194: if (E.getNumReferences() >= 3266772992 /*91.5*/) goto t287_n232;
  t287_n195: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t287_n203;
  t287_n196: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t287_n200;
  t287_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t287_n199;
  t287_n198: return -0.1038866713643074f;
  t287_n199: return -0.00047307030763477087f;
  t287_n200: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t287_n202;
  t287_n201: return 0.0791323259472847f;
  t287_n202: return 0.10440223664045334f;
  t287_n203: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t287_n207;
  t287_n204: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t287_n206;
  t287_n205: return 0.11460692435503006f;
  t287_n206: return -0.014477663673460484f;
  t287_n207: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t287_n223;
  t287_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t287_n210;
  t287_n209: return -0.06694120913743973f;
  t287_n210: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t287_n222;
  t287_n211: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t287_n221;
  t287_n212: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t287_n214;
  t287_n213: return -0.2635612189769745f;
  t287_n214: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t287_n218;
  t287_n215: if (E.getNumReferences() >= 3264872448 /*77.0*/) goto t287_n217;
  t287_n216: return -0.1380675584077835f;
  t287_n217: return 0.108941949903965f;
  t287_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t287_n220;
  t287_n219: return -0.44273510575294495f;
  t287_n220: return 0.08268345147371292f;
  t287_n221: return 0.1183377355337143f;
  t287_n222: return -0.059417497366666794f;
  t287_n223: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t287_n231;
  t287_n224: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t287_n230;
  t287_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t287_n229;
  t287_n226: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t287_n228;
  t287_n227: return 0.15823817253112793f;
  t287_n228: return -0.00967510137706995f;
  t287_n229: return 0.12193107604980469f;
  t287_n230: return 0.06837449967861176f;
  t287_n231: return -0.006598532199859619f;
  t287_n232: return 0.0041308170184493065f;
  t287_n233: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t287_n235;
  t287_n234: return -0.0064896452240645885f;
  t287_n235: if (E.getNumReferences() >= 3276242944 /*199.5*/) goto t287_n239;
  t287_n236: if (E.getNumReferences() >= 3275030528 /*181.0*/) goto t287_n238;
  t287_n237: return -0.009193282574415207f;
  t287_n238: return 0.12743543088436127f;
  t287_n239: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t287_n245;
  t287_n240: if (E.getNumReferences() >= 3294609408 /*895.0*/) goto t287_n242;
  t287_n241: return -0.1564009189605713f;
  t287_n242: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t287_n244;
  t287_n243: return 0.11329237371683121f;
  t287_n244: return -0.09562452137470245f;
  t287_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n247;
  t287_n246: return 0.025860393419861794f;
  t287_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t287_n251;
  t287_n248: if (E.getNumReferences() >= 3280650240 /*277.5*/) goto t287_n250;
  t287_n249: return 0.09657605737447739f;
  t287_n250: return 0.01566111482679844f;
  t287_n251: return 0.10842527449131012f;
  t287_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t287_n254;
  t287_n253: return 0.015237560495734215f;
  t287_n254: return 0.025560559704899788f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree288(const Example& E) {
  t288_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t288_n2;
  t288_n1: return -0.0003132911224383861f;
  t288_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t288_n64;
  t288_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t288_n5;
  t288_n4: return 0.002919575432315469f;
  t288_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t288_n33;
  t288_n6: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t288_n32;
  t288_n7: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t288_n19;
  t288_n8: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t288_n10;
  t288_n9: return -0.05074351653456688f;
  t288_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t288_n12;
  t288_n11: return -0.04457610845565796f;
  t288_n12: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t288_n16;
  t288_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t288_n15;
  t288_n14: return 0.04811244085431099f;
  t288_n15: return 0.10016925632953644f;
  t288_n16: if (E.getNumReferences() >= 3298197504 /*1204.0*/) goto t288_n18;
  t288_n17: return -0.1308092325925827f;
  t288_n18: return 0.08573022484779358f;
  t288_n19: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t288_n27;
  t288_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t288_n22;
  t288_n21: return -0.0010911333374679089f;
  t288_n22: if (E.getNumReferences() >= 3295059968 /*922.5*/) goto t288_n26;
  t288_n23: if (E.getNumReferences() >= 3288489984 /*521.5*/) goto t288_n25;
  t288_n24: return 0.11264708638191223f;
  t288_n25: return -0.1326747089624405f;
  t288_n26: return 0.08705134689807892f;
  t288_n27: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t288_n29;
  t288_n28: return -0.20437796413898468f;
  t288_n29: if (E.getNumReferences() >= 3291889664 /*729.0*/) goto t288_n31;
  t288_n30: return 0.10963127017021179f;
  t288_n31: return 0.08430742472410202f;
  t288_n32: return 0.012081116437911987f;
  t288_n33: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t288_n43;
  t288_n34: if (E.getNumReferences() >= 3287891968 /*498.5*/) goto t288_n42;
  t288_n35: if (E.getNumReferences() >= 3285073920 /*412.5*/) goto t288_n37;
  t288_n36: return -0.04650748893618584f;
  t288_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t288_n41;
  t288_n38: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t288_n40;
  t288_n39: return 0.07133546471595764f;
  t288_n40: return -0.02451709657907486f;
  t288_n41: return 0.08616013079881668f;
  t288_n42: return 0.10256737470626831f;
  t288_n43: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t288_n45;
  t288_n44: return -0.024533092975616455f;
  t288_n45: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t288_n63;
  t288_n46: if (E.getNumReferences() >= 3292340224 /*756.5*/) goto t288_n48;
  t288_n47: return -0.011429209262132645f;
  t288_n48: if (E.getNumReferences() >= 3294167040 /*868.0*/) goto t288_n52;
  t288_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t288_n51;
  t288_n50: return 0.10649380832910538f;
  t288_n51: return 0.04679858684539795f;
  t288_n52: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t288_n60;
  t288_n53: if (E.getNumReferences() >= 3301900288 /*1656.0*/) goto t288_n55;
  t288_n54: return -0.00011701409675879404f;
  t288_n55: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t288_n59;
  t288_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t288_n58;
  t288_n57: return -0.19563470780849457f;
  t288_n58: return 0.0960947722196579f;
  t288_n59: return -0.07813651859760284f;
  t288_n60: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t288_n62;
  t288_n61: return -0.2376917004585266f;
  t288_n62: return 0.08308116346597672f;
  t288_n63: return 0.09493547677993774f;
  t288_n64: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t288_n66;
  t288_n65: return 0.00018143832858186215f;
  t288_n66: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t288_n72;
  t288_n67: if (E.getNumReferences() >= 3284516864 /*395.5*/) goto t288_n71;
  t288_n68: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t288_n70;
  t288_n69: return 0.10597789287567139f;
  t288_n70: return -0.19465714693069458f;
  t288_n71: return 0.004652274306863546f;
  t288_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t288_n254;
  t288_n73: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t288_n209;
  t288_n74: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t288_n150;
  t288_n75: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t288_n103;
  t288_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t288_n86;
  t288_n77: if (E.getNumReferences() >= 3297996800 /*1179.5*/) goto t288_n79;
  t288_n78: return -0.1930975764989853f;
  t288_n79: if (E.getNumReferences() >= 3298541568 /*1246.0*/) goto t288_n81;
  t288_n80: return 0.09595560282468796f;
  t288_n81: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t288_n85;
  t288_n82: if (E.getNumReferences() >= 3330556416 /*16929.0*/) goto t288_n84;
  t288_n83: return -0.015515612438321114f;
  t288_n84: return 0.0880889743566513f;
  t288_n85: return -3.1118528842926025f;
  t288_n86: if (E.getNumReferences() >= 3288539136 /*524.5*/) goto t288_n96;
  t288_n87: if (E.getNumReferences() >= 3287695360 /*492.5*/) goto t288_n95;
  t288_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t288_n90;
  t288_n89: return -0.43039628863334656f;
  t288_n90: if (E.getNumReferences() >= 3286155264 /*445.5*/) goto t288_n94;
  t288_n91: if (E.getNumReferences() >= 3285155840 /*415.0*/) goto t288_n93;
  t288_n92: return 0.11305121332406998f;
  t288_n93: return -0.3642145097255707f;
  t288_n94: return 0.10846338421106339f;
  t288_n95: return 0.09740510582923889f;
  t288_n96: if (E.getNumReferences() >= 3331719680 /*19201.0*/) goto t288_n102;
  t288_n97: if (E.getNumReferences() >= 3323767808 /*10027.0*/) goto t288_n99;
  t288_n98: return -0.005213716067373753f;
  t288_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t288_n101;
  t288_n100: return -0.9408723711967468f;
  t288_n101: return 0.03224997967481613f;
  t288_n102: return 0.07674149423837662f;
  t288_n103: if (E.getNumReferences() >= 3300311040 /*1462.0*/) goto t288_n129;
  t288_n104: if (E.getNumReferences() >= 3299737600 /*1392.0*/) goto t288_n128;
  t288_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t288_n113;
  t288_n106: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t288_n112;
  t288_n107: if (E.getNumReferences() >= 3294748672 /*903.5*/) goto t288_n109;
  t288_n108: return -0.12064561992883682f;
  t288_n109: if (E.getNumReferences() >= 3296817152 /*1035.5*/) goto t288_n111;
  t288_n110: return 0.09610350430011749f;
  t288_n111: return 0.011242326349020004f;
  t288_n112: return 0.07463329285383224f;
  t288_n113: if (E.getNumReferences() >= 3291308032 /*693.5*/) goto t288_n117;
  t288_n114: if (E.getNumReferences() >= 3285532672 /*426.5*/) goto t288_n116;
  t288_n115: return 0.22299738228321075f;
  t288_n116: return -0.027171533554792404f;
  t288_n117: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t288_n121;
  t288_n118: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t288_n120;
  t288_n119: return -0.10116846114397049f;
  t288_n120: return 0.1456785649061203f;
  t288_n121: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t288_n123;
  t288_n122: return 0.1156134083867073f;
  t288_n123: if (E.getNumReferences() >= 3292880896 /*789.5*/) goto t288_n125;
  t288_n124: return 0.04449556767940521f;
  t288_n125: if (E.getNumReferences() >= 3295805440 /*968.0*/) goto t288_n127;
  t288_n126: return 0.2920297682285309f;
  t288_n127: return 0.12289079278707504f;
  t288_n128: return 0.10413013398647308f;
  t288_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t288_n131;
  t288_n130: return 0.014544793404638767f;
  t288_n131: if (E.getNumReferences() >= 3330181632 /*16290.5*/) goto t288_n141;
  t288_n132: if (E.getNumReferences() >= 3305365504 /*2110.0*/) goto t288_n134;
  t288_n133: return -0.27944415807724f;
  t288_n134: if (E.getNumReferences() >= 3307837440 /*2713.5*/) goto t288_n136;
  t288_n135: return 0.1097777709364891f;
  t288_n136: if (E.getNumReferences() >= 3319662592 /*7105.0*/) goto t288_n138;
  t288_n137: return 0.022564779967069626f;
  t288_n138: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t288_n140;
  t288_n139: return 0.0916372537612915f;
  t288_n140: return 0.023473143577575684f;
  t288_n141: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t288_n143;
  t288_n142: return 0.02945922128856182f;
  t288_n143: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t288_n149;
  t288_n144: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t288_n148;
  t288_n145: if (E.getNumReferences() >= 3343170304 /*50363.0*/) goto t288_n147;
  t288_n146: return -0.16909213364124298f;
  t288_n147: return 0.050878025591373444f;
  t288_n148: return -0.4178772568702698f;
  t288_n149: return 0.09163392335176468f;
  t288_n150: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t288_n206;
  t288_n151: if (E.getNumReferences() >= 3287056384 /*473.0*/) goto t288_n155;
  t288_n152: if (E.getNumReferences() >= 3286646784 /*460.5*/) goto t288_n154;
  t288_n153: return -0.16580475866794586f;
  t288_n154: return 0.0991806909441948f;
  t288_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t288_n163;
  t288_n156: if (E.getNumReferences() >= 3348635904 /*77890.0*/) goto t288_n162;
  t288_n157: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t288_n159;
  t288_n158: return 0.0813322439789772f;
  t288_n159: if (E.getNumReferences() >= 3330147328 /*16257.0*/) goto t288_n161;
  t288_n160: return -0.31147778034210205f;
  t288_n161: return 0.0719214677810669f;
  t288_n162: return -1.7902312278747559f;
  t288_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t288_n165;
  t288_n164: return -0.08960284292697906f;
  t288_n165: if (E.getNumReferences() >= 3290718208 /*657.5*/) goto t288_n169;
  t288_n166: if (E.getNumReferences() >= 3290267648 /*630.0*/) goto t288_n168;
  t288_n167: return 0.00991644524037838f;
  t288_n168: return 0.11301405727863312f;
  t288_n169: if (E.getNumReferences() >= 3313736704 /*4211.5*/) goto t288_n175;
  t288_n170: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t288_n172;
  t288_n171: return -0.03942946344614029f;
  t288_n172: if (E.getNumReferences() >= 3296833536 /*1037.5*/) goto t288_n174;
  t288_n173: return 0.0878203809261322f;
  t288_n174: return 0.025587575510144234f;
  t288_n175: if (E.getNumReferences() >= 3315866624 /*5251.5*/) goto t288_n181;
  t288_n176: if (E.getNumReferences() >= 3315571712 /*5107.5*/) goto t288_n180;
  t288_n177: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t288_n179;
  t288_n178: return -0.2668737471103668f;
  t288_n179: return 0.11986664682626724f;
  t288_n180: return 0.10675318539142609f;
  t288_n181: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t288_n195;
  t288_n182: if (E.getNumReferences() >= 3330498816 /*16816.5*/) goto t288_n186;
  t288_n183: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t288_n185;
  t288_n184: return -0.08687996864318848f;
  t288_n185: return 0.09912408143281937f;
  t288_n186: if (E.getNumReferences() >= 3339076992 /*34373.5*/) goto t288_n190;
  t288_n187: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t288_n189;
  t288_n188: return 0.0017612994415685534f;
  t288_n189: return -0.560341477394104f;
  t288_n190: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t288_n192;
  t288_n191: return 0.08981620520353317f;
  t288_n192: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t288_n194;
  t288_n193: return -0.5044015645980835f;
  t288_n194: return -0.00901057105511427f;
  t288_n195: if (E.getNumReferences() >= 3336247808 /*28045.0*/) goto t288_n205;
  t288_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t288_n198;
  t288_n197: return -0.5618304014205933f;
  t288_n198: if (E.getNumReferences() >= 3329812480 /*15930.0*/) goto t288_n204;
  t288_n199: if (E.getNumReferences() >= 3324910592 /*11143.0*/) goto t288_n203;
  t288_n200: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t288_n202;
  t288_n201: return -0.07351113855838776f;
  t288_n202: return 0.11252646893262863f;
  t288_n203: return 0.1084408164024353f;
  t288_n204: return -0.11194998770952225f;
  t288_n205: return 0.07224563509225845f;
  t288_n206: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t288_n208;
  t288_n207: return -0.020894482731819153f;
  t288_n208: return 0.09595518559217453f;
  t288_n209: if (E.getNumReferences() >= 3286286336 /*449.5*/) goto t288_n211;
  t288_n210: return -0.17878711223602295f;
  t288_n211: if (E.getNumReferences() >= 3286417408 /*453.5*/) goto t288_n213;
  t288_n212: return 0.086934894323349f;
  t288_n213: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t288_n215;
  t288_n214: return -0.26529887318611145f;
  t288_n215: if (E.getNumReferences() >= 3291062272 /*678.5*/) goto t288_n233;
  t288_n216: if (E.getNumReferences() >= 3290906624 /*669.0*/) goto t288_n232;
  t288_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t288_n225;
  t288_n218: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t288_n224;
  t288_n219: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t288_n223;
  t288_n220: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t288_n222;
  t288_n221: return 0.0983564555644989f;
  t288_n222: return -0.017832353711128235f;
  t288_n223: return 0.08631705492734909f;
  t288_n224: return -0.07509146630764008f;
  t288_n225: if (E.getNumReferences() >= 3289063424 /*556.5*/) goto t288_n229;
  t288_n226: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t288_n228;
  t288_n227: return 0.04340744763612747f;
  t288_n228: return 0.1551373451948166f;
  t288_n229: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t288_n231;
  t288_n230: return -0.17158547043800354f;
  t288_n231: return 0.11021605879068375f;
  t288_n232: return 0.11915798485279083f;
  t288_n233: if (E.getNumReferences() >= 3319629824 /*7089.0*/) goto t288_n251;
  t288_n234: if (E.getNumReferences() >= 3311720448 /*3661.5*/) goto t288_n248;
  t288_n235: if (E.getNumReferences() >= 3311081472 /*3505.5*/) goto t288_n245;
  t288_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t288_n238;
  t288_n237: return -0.0037791819777339697f;
  t288_n238: if (E.getNumReferences() >= 3309152256 /*3034.5*/) goto t288_n244;
  t288_n239: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t288_n243;
  t288_n240: if (E.getNumReferences() >= 3298500608 /*1241.0*/) goto t288_n242;
  t288_n241: return -0.028492985293269157f;
  t288_n242: return 0.09736252576112747f;
  t288_n243: return -0.13905680179595947f;
  t288_n244: return 0.10415805876255035f;
  t288_n245: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t288_n247;
  t288_n246: return 0.12017494440078735f;
  t288_n247: return 0.02087404392659664f;
  t288_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t288_n250;
  t288_n249: return -0.10208377987146378f;
  t288_n250: return 0.04515538364648819f;
  t288_n251: if (E.getNumReferences() >= 3319669760 /*7108.5*/) goto t288_n253;
  t288_n252: return 0.11247412115335464f;
  t288_n253: return 0.014366996474564075f;
  t288_n254: return 0.10082046687602997f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree289(const Example& E) {
  t289_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t289_n2;
  t289_n1: return -0.00027510637301020324f;
  t289_n2: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t289_n4;
  t289_n3: return 0.0018796513322740793f;
  t289_n4: if (E.getNumReferences() >= 3290374144 /*636.5*/) goto t289_n100;
  t289_n5: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n45;
  t289_n6: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t289_n36;
  t289_n7: if (E.getNumReferences() >= 3289948160 /*610.5*/) goto t289_n35;
  t289_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t289_n12;
  t289_n9: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t289_n11;
  t289_n10: return 0.12354940921068192f;
  t289_n11: return 0.0027867748867720366f;
  t289_n12: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t289_n14;
  t289_n13: return -0.013259944505989552f;
  t289_n14: if (E.getNumReferences() >= 3274801152 /*177.5*/) goto t289_n22;
  t289_n15: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t289_n21;
  t289_n16: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t289_n20;
  t289_n17: if (E.getNumReferences() >= 3272179712 /*137.5*/) goto t289_n19;
  t289_n18: return 0.07546305656433105f;
  t289_n19: return -0.42607197165489197f;
  t289_n20: return 0.10737130790948868f;
  t289_n21: return -0.16086989641189575f;
  t289_n22: if (E.getNumReferences() >= 3275096064 /*182.0*/) goto t289_n24;
  t289_n23: return 0.18700164556503296f;
  t289_n24: if (E.getNumReferences() >= 3283042304 /*350.5*/) goto t289_n34;
  t289_n25: if (E.getNumReferences() >= 3278438400 /*233.0*/) goto t289_n27;
  t289_n26: return 0.04346504807472229f;
  t289_n27: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t289_n33;
  t289_n28: if (E.getNumReferences() >= 3280502784 /*273.0*/) goto t289_n30;
  t289_n29: return 0.14826257526874542f;
  t289_n30: if (E.getNumReferences() >= 3281371136 /*299.5*/) goto t289_n32;
  t289_n31: return -0.10242854058742523f;
  t289_n32: return 0.39577871561050415f;
  t289_n33: return -0.6376256346702576f;
  t289_n34: return -0.10692444443702698f;
  t289_n35: return 0.11153948307037354f;
  t289_n36: if (E.getNumReferences() >= 3276308480 /*200.5*/) goto t289_n42;
  t289_n37: if (E.getNumReferences() >= 3274833920 /*178.0*/) goto t289_n41;
  t289_n38: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t289_n40;
  t289_n39: return 0.11207876354455948f;
  t289_n40: return -0.03289482370018959f;
  t289_n41: return 0.12166319042444229f;
  t289_n42: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t289_n44;
  t289_n43: return -0.1428653597831726f;
  t289_n44: return 0.38592007756233215f;
  t289_n45: if (E.getNumReferences() >= 3290267648 /*630.0*/) goto t289_n97;
  t289_n46: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t289_n62;
  t289_n47: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t289_n51;
  t289_n48: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t289_n50;
  t289_n49: return 0.12400101125240326f;
  t289_n50: return 0.0007481181528419256f;
  t289_n51: if (E.getNumReferences() >= 3277750272 /*222.5*/) goto t289_n53;
  t289_n52: return -0.01932513527572155f;
  t289_n53: if (E.getNumReferences() >= 3277815808 /*223.5*/) goto t289_n55;
  t289_n54: return 0.1841798573732376f;
  t289_n55: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t289_n61;
  t289_n56: if (E.getNumReferences() >= 3281616896 /*307.0*/) goto t289_n58;
  t289_n57: return -0.011186775751411915f;
  t289_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t289_n60;
  t289_n59: return 0.11381349712610245f;
  t289_n60: return 0.04450225457549095f;
  t289_n61: return 0.016367992386221886f;
  t289_n62: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t289_n94;
  t289_n63: if (E.getNumReferences() >= 3279994880 /*257.5*/) goto t289_n89;
  t289_n64: if (E.getNumReferences() >= 3274735616 /*176.5*/) goto t289_n66;
  t289_n65: return 0.028929712250828743f;
  t289_n66: if (E.getNumReferences() >= 3274801152 /*177.5*/) goto t289_n68;
  t289_n67: return 0.13267108798027039f;
  t289_n68: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t289_n72;
  t289_n69: if (E.getNumReferences() >= 3279224832 /*245.0*/) goto t289_n71;
  t289_n70: return -0.1299150437116623f;
  t289_n71: return 0.13002042472362518f;
  t289_n72: if (E.getNumReferences() >= 3275063296 /*181.5*/) goto t289_n76;
  t289_n73: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t289_n75;
  t289_n74: return -0.16080453991889954f;
  t289_n75: return 0.10668914020061493f;
  t289_n76: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t289_n86;
  t289_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t289_n81;
  t289_n78: if (E.getNumReferences() >= 3275390976 /*186.5*/) goto t289_n80;
  t289_n79: return 0.10782270133495331f;
  t289_n80: return -0.053348615765571594f;
  t289_n81: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t289_n83;
  t289_n82: return 0.14638495445251465f;
  t289_n83: if (E.getNumReferences() >= 3278307328 /*231.0*/) goto t289_n85;
  t289_n84: return -0.5711079239845276f;
  t289_n85: return 0.11064489185810089f;
  t289_n86: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t289_n88;
  t289_n87: return 0.028625058010220528f;
  t289_n88: return 0.10306449979543686f;
  t289_n89: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t289_n91;
  t289_n90: return -0.011279995553195477f;
  t289_n91: if (E.getNumReferences() >= 3283877888 /*376.0*/) goto t289_n93;
  t289_n92: return -0.15671876072883606f;
  t289_n93: return 0.12699569761753082f;
  t289_n94: if (E.getNumReferences() >= 3265921024 /*85.0*/) goto t289_n96;
  t289_n95: return 0.10836495459079742f;
  t289_n96: return 0.0709943026304245f;
  t289_n97: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t289_n99;
  t289_n98: return 0.09655823558568954f;
  t289_n99: return -0.1135186105966568f;
  t289_n100: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t289_n254;
  t289_n101: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t289_n103;
  t289_n102: return -0.012246442027390003f;
  t289_n103: if (E.getNumReferences() >= 3300196352 /*1448.0*/) goto t289_n105;
  t289_n104: return -0.03214314952492714f;
  t289_n105: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t289_n235;
  t289_n106: if (E.getNumReferences() >= 3328776192 /*14918.0*/) goto t289_n160;
  t289_n107: if (E.getNumReferences() >= 3323748864 /*10008.5*/) goto t289_n153;
  t289_n108: if (E.getNumReferences() >= 3322603520 /*8890.0*/) goto t289_n134;
  t289_n109: if (E.getNumReferences() >= 3307966464 /*2745.0*/) goto t289_n125;
  t289_n110: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t289_n116;
  t289_n111: if (E.getNumReferences() >= 3306926080 /*2491.0*/) goto t289_n113;
  t289_n112: return -0.008130716159939766f;
  t289_n113: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n115;
  t289_n114: return 0.09892742335796356f;
  t289_n115: return 0.15533828735351562f;
  t289_n116: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t289_n124;
  t289_n117: if (E.getNumReferences() >= 3300925440 /*1537.0*/) goto t289_n119;
  t289_n118: return 0.13048657774925232f;
  t289_n119: if (E.getNumReferences() >= 3305877504 /*2235.0*/) goto t289_n123;
  t289_n120: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t289_n122;
  t289_n121: return 0.10294357687234879f;
  t289_n122: return -0.4637068212032318f;
  t289_n123: return 0.11216627061367035f;
  t289_n124: return 0.12664629518985748f;
  t289_n125: if (E.getNumReferences() >= 3309840384 /*3202.5*/) goto t289_n129;
  t289_n126: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t289_n128;
  t289_n127: return 0.0843270942568779f;
  t289_n128: return -0.20153436064720154f;
  t289_n129: if (E.getNumReferences() >= 3313057792 /*3988.0*/) goto t289_n133;
  t289_n130: if (E.getNumReferences() >= 3312498688 /*3851.5*/) goto t289_n132;
  t289_n131: return 0.011364971287548542f;
  t289_n132: return 0.10597792267799377f;
  t289_n133: return -0.02888667583465576f;
  t289_n134: if (E.getNumReferences() >= 3322671104 /*8956.0*/) goto t289_n136;
  t289_n135: return 0.10611758381128311f;
  t289_n136: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t289_n138;
  t289_n137: return -0.015315935015678406f;
  t289_n138: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t289_n140;
  t289_n139: return -0.10560082644224167f;
  t289_n140: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t289_n152;
  t289_n141: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t289_n151;
  t289_n142: if (E.getNumReferences() >= 3323686912 /*9948.0*/) goto t289_n148;
  t289_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n145;
  t289_n144: return -0.1178637146949768f;
  t289_n145: if (E.getNumReferences() >= 3322915840 /*9195.0*/) goto t289_n147;
  t289_n146: return 0.09186505526304245f;
  t289_n147: return 0.05868442729115486f;
  t289_n148: if (E.getNumReferences() >= 3323708928 /*9969.5*/) goto t289_n150;
  t289_n149: return 0.1090879887342453f;
  t289_n150: return -0.1243891716003418f;
  t289_n151: return 0.10475564002990723f;
  t289_n152: return 0.041863422840833664f;
  t289_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t289_n155;
  t289_n154: return -0.08100289851427078f;
  t289_n155: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t289_n157;
  t289_n156: return -0.06754998117685318f;
  t289_n157: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n159;
  t289_n158: return 0.13532845675945282f;
  t289_n159: return 0.12628333270549774f;
  t289_n160: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t289_n164;
  t289_n161: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t289_n163;
  t289_n162: return -0.3960946500301361f;
  t289_n163: return 0.11719752848148346f;
  t289_n164: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t289_n232;
  t289_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t289_n167;
  t289_n166: return -0.2263496071100235f;
  t289_n167: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t289_n203;
  t289_n168: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t289_n190;
  t289_n169: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t289_n189;
  t289_n170: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t289_n186;
  t289_n171: if (E.getNumReferences() >= 3334924800 /*25461.0*/) goto t289_n177;
  t289_n172: if (E.getNumReferences() >= 3333992192 /*23639.5*/) goto t289_n174;
  t289_n173: return -0.0002586705959402025f;
  t289_n174: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n176;
  t289_n175: return -0.05397212877869606f;
  t289_n176: return -1.1952238082885742f;
  t289_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t289_n179;
  t289_n178: return 0.1032504141330719f;
  t289_n179: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t289_n183;
  t289_n180: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n182;
  t289_n181: return 0.10250832885503769f;
  t289_n182: return 0.06813456118106842f;
  t289_n183: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t289_n185;
  t289_n184: return -0.3354724943637848f;
  t289_n185: return 0.08801015466451645f;
  t289_n186: if (E.getNumReferences() >= 3331945984 /*19643.0*/) goto t289_n188;
  t289_n187: return 0.120332732796669f;
  t289_n188: return -0.0376567617058754f;
  t289_n189: return -0.41635778546333313f;
  t289_n190: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t289_n192;
  t289_n191: return -0.07014243304729462f;
  t289_n192: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t289_n194;
  t289_n193: return 0.01990444026887417f;
  t289_n194: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t289_n200;
  t289_n195: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t289_n197;
  t289_n196: return 0.06643463671207428f;
  t289_n197: if (E.getNumReferences() >= 3337883136 /*31239.0*/) goto t289_n199;
  t289_n198: return 0.09741741418838501f;
  t289_n199: return 0.07233966141939163f;
  t289_n200: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t289_n202;
  t289_n201: return 0.07794549316167831f;
  t289_n202: return -0.4676990807056427f;
  t289_n203: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t289_n215;
  t289_n204: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t289_n212;
  t289_n205: if (E.getNumReferences() >= 3340675072 /*40616.0*/) goto t289_n211;
  t289_n206: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t289_n208;
  t289_n207: return -0.11226267367601395f;
  t289_n208: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t289_n210;
  t289_n209: return 0.11892321705818176f;
  t289_n210: return 0.13651143014431f;
  t289_n211: return -0.07098108530044556f;
  t289_n212: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t289_n214;
  t289_n213: return 0.03260913863778114f;
  t289_n214: return -0.07004256546497345f;
  t289_n215: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t289_n231;
  t289_n216: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t289_n228;
  t289_n217: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n227;
  t289_n218: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t289_n220;
  t289_n219: return 0.0955287292599678f;
  t289_n220: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t289_n222;
  t289_n221: return -0.024689797312021255f;
  t289_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t289_n224;
  t289_n223: return -0.11634846031665802f;
  t289_n224: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t289_n226;
  t289_n225: return 0.12338106334209442f;
  t289_n226: return 0.10640160739421844f;
  t289_n227: return -0.07471296191215515f;
  t289_n228: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t289_n230;
  t289_n229: return 0.05706724151968956f;
  t289_n230: return 0.1253245621919632f;
  t289_n231: return 0.0003374289080966264f;
  t289_n232: if (E.getNumReferences() >= 3335962112 /*27487.0*/) goto t289_n234;
  t289_n233: return -1.3280909061431885f;
  t289_n234: return -0.021539997309446335f;
  t289_n235: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t289_n249;
  t289_n236: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t289_n238;
  t289_n237: return -0.3475241959095001f;
  t289_n238: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t289_n248;
  t289_n239: if (E.getNumReferences() >= 3327475712 /*13648.0*/) goto t289_n241;
  t289_n240: return 0.029453538358211517f;
  t289_n241: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t289_n247;
  t289_n242: if (E.getNumReferences() >= 3328385536 /*14536.5*/) goto t289_n246;
  t289_n243: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t289_n245;
  t289_n244: return -0.1913495510816574f;
  t289_n245: return 0.10785527527332306f;
  t289_n246: return 0.12398608773946762f;
  t289_n247: return 0.05192354694008827f;
  t289_n248: return 0.010750741697847843f;
  t289_n249: if (E.getNumReferences() >= 3311716352 /*3660.5*/) goto t289_n251;
  t289_n250: return -0.18607006967067719f;
  t289_n251: if (E.getNumReferences() >= 3315241984 /*4946.5*/) goto t289_n253;
  t289_n252: return 0.11119701713323593f;
  t289_n253: return -0.014623434282839298f;
  t289_n254: return -0.10681876540184021f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree290(const Example& E) {
  t290_n0: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t290_n2;
  t290_n1: return -0.0003758746897801757f;
  t290_n2: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t290_n254;
  t290_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function))) goto t290_n149;
  t290_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag))) goto t290_n40;
  t290_n5: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t290_n39;
  t290_n6: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t290_n24;
  t290_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t290_n9;
  t290_n8: return -0.05049802362918854f;
  t290_n9: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t290_n23;
  t290_n10: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t290_n12;
  t290_n11: return 0.04599408060312271f;
  t290_n12: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t290_n14;
  t290_n13: return 0.05740176513791084f;
  t290_n14: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t290_n18;
  t290_n15: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t290_n17;
  t290_n16: return 0.07672283053398132f;
  t290_n17: return 0.12331335991621017f;
  t290_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t290_n22;
  t290_n19: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t290_n21;
  t290_n20: return -0.17073792219161987f;
  t290_n21: return 0.10402515530586243f;
  t290_n22: return -0.09665005654096603f;
  t290_n23: return 0.003406872507184744f;
  t290_n24: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t290_n38;
  t290_n25: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t290_n29;
  t290_n26: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t290_n28;
  t290_n27: return 0.04973358288407326f;
  t290_n28: return -0.3226686716079712f;
  t290_n29: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t290_n37;
  t290_n30: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t290_n34;
  t290_n31: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t290_n33;
  t290_n32: return 0.11611749976873398f;
  t290_n33: return -0.41952845454216003f;
  t290_n34: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t290_n36;
  t290_n35: return -0.03798479214310646f;
  t290_n36: return 0.1066734567284584f;
  t290_n37: return -0.19943587481975555f;
  t290_n38: return 0.10114555060863495f;
  t290_n39: return -0.001652680803090334f;
  t290_n40: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t290_n64;
  t290_n41: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t290_n61;
  t290_n42: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t290_n44;
  t290_n43: return 0.023166973143815994f;
  t290_n44: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t290_n48;
  t290_n45: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t290_n47;
  t290_n46: return 0.10901664942502975f;
  t290_n47: return -0.8027737140655518f;
  t290_n48: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t290_n52;
  t290_n49: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t290_n51;
  t290_n50: return 0.03505120053887367f;
  t290_n51: return 0.08347970992326736f;
  t290_n52: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t290_n58;
  t290_n53: if (E.getNumReferences() >= 3280519168 /*273.5*/) goto t290_n55;
  t290_n54: return -0.311857134103775f;
  t290_n55: if (E.getNumReferences() >= 3281174528 /*293.5*/) goto t290_n57;
  t290_n56: return 0.09245357662439346f;
  t290_n57: return -0.03966231271624565f;
  t290_n58: if (E.getNumReferences() >= 3281731584 /*310.5*/) goto t290_n60;
  t290_n59: return 0.09001092612743378f;
  t290_n60: return -0.007049118168652058f;
  t290_n61: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t290_n63;
  t290_n62: return -0.09704254567623138f;
  t290_n63: return 0.09405358135700226f;
  t290_n64: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t290_n76;
  t290_n65: if (E.getNumReferences() >= 3275980800 /*195.5*/) goto t290_n67;
  t290_n66: return -0.10489563643932343f;
  t290_n67: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t290_n75;
  t290_n68: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t290_n74;
  t290_n69: if (E.getNumReferences() >= 3284746240 /*402.5*/) goto t290_n73;
  t290_n70: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t290_n72;
  t290_n71: return 0.07320809364318848f;
  t290_n72: return 0.10720673948526382f;
  t290_n73: return -0.32160428166389465f;
  t290_n74: return 0.09699583053588867f;
  t290_n75: return 0.004766733385622501f;
  t290_n76: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t290_n100;
  t290_n77: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t290_n97;
  t290_n78: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t290_n96;
  t290_n79: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t290_n81;
  t290_n80: return 0.0028896171133965254f;
  t290_n81: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t290_n83;
  t290_n82: return 0.13443557918071747f;
  t290_n83: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t290_n95;
  t290_n84: if (E.getNumReferences() >= 3266904064 /*92.5*/) goto t290_n90;
  t290_n85: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t290_n89;
  t290_n86: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t290_n88;
  t290_n87: return -0.33114394545555115f;
  t290_n88: return 0.1446443349123001f;
  t290_n89: return -0.07533645629882812f;
  t290_n90: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t290_n94;
  t290_n91: if (E.getNumReferences() >= 3267297280 /*95.5*/) goto t290_n93;
  t290_n92: return 0.11599748581647873f;
  t290_n93: return -0.12538479268550873f;
  t290_n94: return 0.2008715271949768f;
  t290_n95: return -0.11972928792238235f;
  t290_n96: return -0.12260166555643082f;
  t290_n97: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t290_n99;
  t290_n98: return 0.10790261626243591f;
  t290_n99: return -0.13314348459243774f;
  t290_n100: if (E.getNumReferences() >= 3282305024 /*328.0*/) goto t290_n102;
  t290_n101: return -0.0162455216050148f;
  t290_n102: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t290_n114;
  t290_n103: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t290_n107;
  t290_n104: if (E.getNumReferences() >= 3293462528 /*825.0*/) goto t290_n106;
  t290_n105: return -0.04712297394871712f;
  t290_n106: return 0.1867280900478363f;
  t290_n107: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t290_n113;
  t290_n108: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t290_n110;
  t290_n109: return -0.125138059258461f;
  t290_n110: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t290_n112;
  t290_n111: return 0.09987690299749374f;
  t290_n112: return 0.01093680877238512f;
  t290_n113: return -0.04189309477806091f;
  t290_n114: if (E.getNumReferences() >= 3282567168 /*336.0*/) goto t290_n116;
  t290_n115: return 0.1255251169204712f;
  t290_n116: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t290_n120;
  t290_n117: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t290_n119;
  t290_n118: return -0.15616559982299805f;
  t290_n119: return 0.0624343603849411f;
  t290_n120: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t290_n138;
  t290_n121: if (E.getNumReferences() >= 3312984064 /*3970.0*/) goto t290_n137;
  t290_n122: if (E.getNumReferences() >= 3309117440 /*3026.0*/) goto t290_n136;
  t290_n123: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t290_n135;
  t290_n124: if (E.getNumReferences() >= 3288530944 /*524.0*/) goto t290_n132;
  t290_n125: if (E.getNumReferences() >= 3288203264 /*508.0*/) goto t290_n131;
  t290_n126: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t290_n128;
  t290_n127: return 0.0569983646273613f;
  t290_n128: if (E.getNumReferences() >= 3283795968 /*373.5*/) goto t290_n130;
  t290_n129: return -0.10067674517631531f;
  t290_n130: return 0.23707441985607147f;
  t290_n131: return 0.11349070817232132f;
  t290_n132: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t290_n134;
  t290_n133: return 0.08844281733036041f;
  t290_n134: return 0.021830523386597633f;
  t290_n135: return 0.09385515749454498f;
  t290_n136: return 0.11362159997224808f;
  t290_n137: return 0.012716706842184067f;
  t290_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t290_n146;
  t290_n139: if (E.getNumReferences() >= 3324868096 /*11101.5*/) goto t290_n141;
  t290_n140: return -0.0605824738740921f;
  t290_n141: if (E.getNumReferences() >= 3333739264 /*23145.5*/) goto t290_n145;
  t290_n142: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t290_n144;
  t290_n143: return 0.11503738164901733f;
  t290_n144: return -0.04729185625910759f;
  t290_n145: return 0.0067432476207613945f;
  t290_n146: if (E.getNumReferences() >= 3293175808 /*807.5*/) goto t290_n148;
  t290_n147: return -0.026720041409134865f;
  t290_n148: return 0.12275461107492447f;
  t290_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t290_n167;
  t290_n150: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t290_n166;
  t290_n151: if (E.getNumReferences() >= 3285319680 /*420.0*/) goto t290_n159;
  t290_n152: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t290_n158;
  t290_n153: if (E.getNumReferences() >= 3276898304 /*209.5*/) goto t290_n157;
  t290_n154: if (E.getNumReferences() >= 3275653120 /*190.5*/) goto t290_n156;
  t290_n155: return -0.2556565999984741f;
  t290_n156: return 0.11475642770528793f;
  t290_n157: return -0.4600152373313904f;
  t290_n158: return -0.04402404651045799f;
  t290_n159: if (E.getNumReferences() >= 3287465984 /*485.5*/) goto t290_n165;
  t290_n160: if (E.getNumReferences() >= 3286941696 /*469.5*/) goto t290_n162;
  t290_n161: return 0.02182997763156891f;
  t290_n162: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t290_n164;
  t290_n163: return 0.08554001152515411f;
  t290_n164: return -0.5063996911048889f;
  t290_n165: return -0.03576888144016266f;
  t290_n166: return 0.01639370433986187f;
  t290_n167: if (E.getNumReferences() >= 3353595776 /*116639.0*/) goto t290_n239;
  t290_n168: if (E.getNumReferences() >= 3282223104 /*325.5*/) goto t290_n170;
  t290_n169: return 0.019620178267359734f;
  t290_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t290_n174;
  t290_n171: if (E.getNumReferences() >= 3282321408 /*328.5*/) goto t290_n173;
  t290_n172: return 0.26385998725891113f;
  t290_n173: return 0.02000170759856701f;
  t290_n174: if (E.getNumReferences() >= 3297275904 /*1091.5*/) goto t290_n196;
  t290_n175: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t290_n185;
  t290_n176: if (E.getNumReferences() >= 3282419712 /*331.5*/) goto t290_n182;
  t290_n177: if (E.getNumReferences() >= 3282386944 /*330.5*/) goto t290_n179;
  t290_n178: return -0.05552729591727257f;
  t290_n179: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t290_n181;
  t290_n180: return -0.10022664070129395f;
  t290_n181: return 0.15996935963630676f;
  t290_n182: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t290_n184;
  t290_n183: return 0.05623670667409897f;
  t290_n184: return 0.06677538901567459f;
  t290_n185: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t290_n187;
  t290_n186: return 0.04446323588490486f;
  t290_n187: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t290_n193;
  t290_n188: if (E.getNumReferences() >= 3289186304 /*564.0*/) goto t290_n190;
  t290_n189: return -0.1041627749800682f;
  t290_n190: if (E.getNumReferences() >= 3291136000 /*683.0*/) goto t290_n192;
  t290_n191: return 0.10107025504112244f;
  t290_n192: return 0.09642034024000168f;
  t290_n193: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t290_n195;
  t290_n194: return 0.10886148363351822f;
  t290_n195: return 0.11521400511264801f;
  t290_n196: if (E.getNumReferences() >= 3299151872 /*1320.5*/) goto t290_n218;
  t290_n197: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t290_n207;
  t290_n198: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t290_n206;
  t290_n199: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t290_n201;
  t290_n200: return -0.16536463797092438f;
  t290_n201: if (E.getNumReferences() >= 3298168832 /*1200.5*/) goto t290_n205;
  t290_n202: if (E.getNumReferences() >= 3297943552 /*1173.0*/) goto t290_n204;
  t290_n203: return -0.10223404318094254f;
  t290_n204: return 0.13851742446422577f;
  t290_n205: return 0.03494250029325485f;
  t290_n206: return 0.117310531437397f;
  t290_n207: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t290_n217;
  t290_n208: if (E.getNumReferences() >= 3298639872 /*1258.0*/) goto t290_n216;
  t290_n209: if (E.getNumReferences() >= 3298324480 /*1219.5*/) goto t290_n213;
  t290_n210: if (E.getNumReferences() >= 3297902592 /*1168.0*/) goto t290_n212;
  t290_n211: return 0.10739216208457947f;
  t290_n212: return -0.10190899670124054f;
  t290_n213: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t290_n215;
  t290_n214: return 0.12147931009531021f;
  t290_n215: return -0.10016652196645737f;
  t290_n216: return -0.1135624572634697f;
  t290_n217: return -0.10880928486585617f;
  t290_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t290_n238;
  t290_n219: if (E.getNumReferences() >= 3313839104 /*4261.5*/) goto t290_n221;
  t290_n220: return 0.06175487861037254f;
  t290_n221: if (E.getNumReferences() >= 3313898496 /*4290.5*/) goto t290_n223;
  t290_n222: return 0.14519108831882477f;
  t290_n223: if (E.getNumReferences() >= 3317490688 /*6044.5*/) goto t290_n225;
  t290_n224: return -0.04215676710009575f;
  t290_n225: if (E.getNumReferences() >= 3317757952 /*6175.0*/) goto t290_n227;
  t290_n226: return 0.11443211883306503f;
  t290_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t290_n237;
  t290_n228: if (E.getNumReferences() >= 3322947584 /*9226.0*/) goto t290_n230;
  t290_n229: return 0.056423626840114594f;
  t290_n230: if (E.getNumReferences() >= 3324085248 /*10337.0*/) goto t290_n232;
  t290_n231: return 0.12380901724100113f;
  t290_n232: if (E.getNumReferences() >= 3328163328 /*14319.5*/) goto t290_n236;
  t290_n233: if (E.getNumReferences() >= 3326885888 /*13072.0*/) goto t290_n235;
  t290_n234: return -0.027981910854578018f;
  t290_n235: return 0.1140306144952774f;
  t290_n236: return -0.11132889240980148f;
  t290_n237: return -0.07558123022317886f;
  t290_n238: return -0.10021202266216278f;
  t290_n239: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t290_n253;
  t290_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t290_n252;
  t290_n241: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t290_n251;
  t290_n242: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t290_n250;
  t290_n243: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t290_n245;
  t290_n244: return 0.08465901017189026f;
  t290_n245: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t290_n247;
  t290_n246: return 0.11695220321416855f;
  t290_n247: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t290_n249;
  t290_n248: return 0.10688968747854233f;
  t290_n249: return 0.10934565216302872f;
  t290_n250: return -0.4023343026638031f;
  t290_n251: return 0.0907929539680481f;
  t290_n252: return 0.020408596843481064f;
  t290_n253: return -0.006540196947753429f;
  t290_n254: return -0.0005379684153012931f;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree291(const Example& E) {
  t291_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t291_n206;
  t291_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t291_n3;
  t291_n2: return -9.381832205690444e-05f;
  t291_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t291_n17;
  t291_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t291_n6;
  t291_n5: return -0.013474937528371811f;
  t291_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t291_n8;
  t291_n7: return -0.018641190603375435f;
  t291_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t291_n10;
  t291_n9: return 0.012510438449680805f;
  t291_n10: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t291_n12;
  t291_n11: return 0.004396921955049038f;
  t291_n12: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t291_n16;
  t291_n13: if (E.getNumReferences() >= 3322085376 /*8384.0*/) goto t291_n15;
  t291_n14: return 0.0703975260257721f;
  t291_n15: return -0.2107551097869873f;
  t291_n16: return 0.03427647054195404f;
  t291_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t291_n163;
  t291_n18: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t291_n46;
  t291_n19: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t291_n41;
  t291_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n22;
  t291_n21: return -0.0038289958611130714f;
  t291_n22: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t291_n24;
  t291_n23: return 0.0006883793976157904f;
  t291_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t291_n28;
  t291_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n27;
  t291_n26: return -0.05213822424411774f;
  t291_n27: return 0.02935420349240303f;
  t291_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t291_n40;
  t291_n29: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t291_n31;
  t291_n30: return 0.04694046452641487f;
  t291_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t291_n33;
  t291_n32: return 0.062120962888002396f;
  t291_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t291_n39;
  t291_n34: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t291_n38;
  t291_n35: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t291_n37;
  t291_n36: return -0.1044471263885498f;
  t291_n37: return 0.08697892725467682f;
  t291_n38: return -0.12165842950344086f;
  t291_n39: return 0.013998414389789104f;
  t291_n40: return 0.007093135733157396f;
  t291_n41: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t291_n45;
  t291_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n44;
  t291_n43: return -0.02991998754441738f;
  t291_n44: return -0.00857355073094368f;
  t291_n45: return 0.007957075722515583f;
  t291_n46: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t291_n50;
  t291_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t291_n49;
  t291_n48: return -0.012319260276854038f;
  t291_n49: return 0.02449943497776985f;
  t291_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t291_n162;
  t291_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t291_n65;
  t291_n52: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t291_n54;
  t291_n53: return 0.007462368346750736f;
  t291_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t291_n62;
  t291_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n61;
  t291_n56: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t291_n60;
  t291_n57: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t291_n59;
  t291_n58: return -0.025752069428563118f;
  t291_n59: return -0.14532820880413055f;
  t291_n60: return 0.0008486551814712584f;
  t291_n61: return -0.014614921994507313f;
  t291_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n64;
  t291_n63: return -0.0013415239518508315f;
  t291_n64: return 0.05546329915523529f;
  t291_n65: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t291_n85;
  t291_n66: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t291_n70;
  t291_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t291_n69;
  t291_n68: return -0.11501562595367432f;
  t291_n69: return -0.03132624924182892f;
  t291_n70: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t291_n84;
  t291_n71: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t291_n73;
  t291_n72: return -0.01514025405049324f;
  t291_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n75;
  t291_n74: return -0.009807078167796135f;
  t291_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t291_n77;
  t291_n76: return -0.008678650483489037f;
  t291_n77: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t291_n83;
  t291_n78: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t291_n80;
  t291_n79: return 0.029170794412493706f;
  t291_n80: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t291_n82;
  t291_n81: return 0.07262790203094482f;
  t291_n82: return 0.03584323078393936f;
  t291_n83: return -0.003367809811607003f;
  t291_n84: return 0.060701627284288406f;
  t291_n85: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t291_n157;
  t291_n86: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t291_n110;
  t291_n87: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t291_n109;
  t291_n88: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t291_n96;
  t291_n89: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t291_n91;
  t291_n90: return -0.132868230342865f;
  t291_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t291_n95;
  t291_n92: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t291_n94;
  t291_n93: return 0.07100047171115875f;
  t291_n94: return 0.007504635490477085f;
  t291_n95: return 0.10686545073986053f;
  t291_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t291_n98;
  t291_n97: return 0.019836949184536934f;
  t291_n98: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t291_n102;
  t291_n99: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t291_n101;
  t291_n100: return 0.06299348920583725f;
  t291_n101: return 0.11295817047357559f;
  t291_n102: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t291_n104;
  t291_n103: return 0.12733562290668488f;
  t291_n104: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t291_n106;
  t291_n105: return -0.06366676092147827f;
  t291_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t291_n108;
  t291_n107: return 0.05008697882294655f;
  t291_n108: return 0.10794111341238022f;
  t291_n109: return -0.13502247631549835f;
  t291_n110: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t291_n132;
  t291_n111: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t291_n121;
  t291_n112: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t291_n114;
  t291_n113: return 0.05835979804396629f;
  t291_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t291_n116;
  t291_n115: return 0.10448310524225235f;
  t291_n116: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t291_n118;
  t291_n117: return -0.12638165056705475f;
  t291_n118: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t291_n120;
  t291_n119: return 0.1145688146352768f;
  t291_n120: return 0.05274040251970291f;
  t291_n121: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t291_n131;
  t291_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t291_n124;
  t291_n123: return 0.12794198095798492f;
  t291_n124: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t291_n126;
  t291_n125: return 0.026235757395625114f;
  t291_n126: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t291_n130;
  t291_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t291_n129;
  t291_n128: return 0.0f;
  t291_n129: return 0.1045181155204773f;
  t291_n130: return -0.00766731658950448f;
  t291_n131: return -0.15436714887619019f;
  t291_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t291_n152;
  t291_n133: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t291_n151;
  t291_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t291_n136;
  t291_n135: return 0.009993339888751507f;
  t291_n136: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t291_n138;
  t291_n137: return -0.17515695095062256f;
  t291_n138: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t291_n146;
  t291_n139: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t291_n143;
  t291_n140: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t291_n142;
  t291_n141: return 0.04061681032180786f;
  t291_n142: return 0.0732160359621048f;
  t291_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t291_n145;
  t291_n144: return 0.06755934655666351f;
  t291_n145: return 0.13326673209667206f;
  t291_n146: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t291_n148;
  t291_n147: return -0.2224569022655487f;
  t291_n148: if (E.getNumReferences() >= 3249537024 /*22.0*/) goto t291_n150;
  t291_n149: return 0.10381709039211273f;
  t291_n150: return 0.026838945224881172f;
  t291_n151: return 0.1099848747253418f;
  t291_n152: if (E.getNumReferences() >= 3338667520 /*32774.0*/) goto t291_n154;
  t291_n153: return -0.048518288880586624f;
  t291_n154: if (E.getNumReferences() >= 3338968320 /*33949.0*/) goto t291_n156;
  t291_n155: return 0.11126405000686646f;
  t291_n156: return 0.00275589432567358f;
  t291_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t291_n161;
  t291_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n160;
  t291_n159: return -0.06327354162931442f;
  t291_n160: return 0.34912800788879395f;
  t291_n161: return 0.11177556961774826f;
  t291_n162: return 0.2065284699201584f;
  t291_n163: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t291_n205;
  t291_n164: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t291_n202;
  t291_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t291_n177;
  t291_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t291_n176;
  t291_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t291_n169;
  t291_n168: return 0.007292652502655983f;
  t291_n169: if (E.getNumReferences() >= 3239051264 /*9.0*/) goto t291_n175;
  t291_n170: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t291_n174;
  t291_n171: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t291_n173;
  t291_n172: return 0.07703229784965515f;
  t291_n173: return -0.4369247555732727f;
  t291_n174: return -0.7921183705329895f;
  t291_n175: return 0.09365657716989517f;
  t291_n176: return 0.048378899693489075f;
  t291_n177: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t291_n187;
  t291_n178: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t291_n186;
  t291_n179: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t291_n185;
  t291_n180: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t291_n184;
  t291_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t291_n183;
  t291_n182: return -0.11597326397895813f;
  t291_n183: return 0.1407659649848938f;
  t291_n184: return 0.16911838948726654f;
  t291_n185: return -0.019939839839935303f;
  t291_n186: return -0.006651789415627718f;
  t291_n187: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t291_n195;
  t291_n188: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t291_n194;
  t291_n189: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t291_n191;
  t291_n190: return 0.11188633739948273f;
  t291_n191: if (E.getNumReferences() >= 3233808384 /*6.0*/) goto t291_n193;
  t291_n192: return -0.011203131638467312f;
  t291_n193: return 0.11498082429170609f;
  t291_n194: return 0.04957350715994835f;
  t291_n195: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t291_n197;
  t291_n196: return 0.15181151032447815f;
  t291_n197: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t291_n199;
  t291_n198: return 0.020545735955238342f;
  t291_n199: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t291_n201;
  t291_n200: return 0.11003991961479187f;
  t291_n201: return -0.11045662313699722f;
  t291_n202: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t291_n204;
  t291_n203: return 0.014450003392994404f;
  t291_n204: return 0.011388398706912994f;
  t291_n205: return -0.006853652652353048f;
  t291_n206: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t291_n208;
  t291_n207: return -0.011584019288420677f;
  t291_n208: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t291_n218;
  t291_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t291_n211;
  t291_n210: return 0.05120832100510597f;
  t291_n211: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t291_n213;
  t291_n212: return 0.013165966607630253f;
  t291_n213: if (E.getNumReferences() >= 3244294144 /*14.0*/) goto t291_n215;
  t291_n214: return 0.1577499955892563f;
  t291_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t291_n217;
  t291_n216: return -0.2396327704191208f;
  t291_n217: return 0.17706002295017242f;
  t291_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t291_n220;
  t291_n219: return -0.02430008165538311f;
  t291_n220: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t291_n236;
  t291_n221: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t291_n229;
  t291_n222: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t291_n224;
  t291_n223: return 0.0021503656171262264f;
  t291_n224: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t291_n228;
  t291_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t291_n227;
  t291_n226: return 0.10209590941667557f;
  t291_n227: return -0.10094248503446579f;
  t291_n228: return 0.0565190315246582f;
  t291_n229: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t291_n231;
  t291_n230: return 0.07504937052726746f;
  t291_n231: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t291_n235;
  t291_n232: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t291_n234;
  t291_n233: return 0.09303239732980728f;
  t291_n234: return 0.1220465898513794f;
  t291_n235: return -0.0552414134144783f;
  t291_n236: if (E.getNumReferences() >= 3317581824 /*6089.0*/) goto t291_n238;
  t291_n237: return 0.02017456479370594f;
  t291_n238: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t291_n252;
  t291_n239: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t291_n247;
  t291_n240: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t291_n242;
  t291_n241: return -0.5523847341537476f;
  t291_n242: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t291_n244;
  t291_n243: return 0.135552316904068f;
  t291_n244: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t291_n246;
  t291_n245: return -0.10694114863872528f;
  t291_n246: return 0.1076260507106781f;
  t291_n247: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t291_n249;
  t291_n248: return -0.16570794582366943f;
  t291_n249: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t291_n251;
  t291_n250: return 0.08825422823429108f;
  t291_n251: return -0.18362212181091309f;
  t291_n252: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t291_n254;
  t291_n253: return 0.027011949568986893f;
  t291_n254: return -0.6367723941802979f;
}

} // namespace

float Evaluate(const Example& E) {
  float Score = 0;
  Score += EvaluateTree0(E);
  Score += EvaluateTree1(E);
  Score += EvaluateTree2(E);
  Score += EvaluateTree3(E);
  Score += EvaluateTree4(E);
  Score += EvaluateTree5(E);
  Score += EvaluateTree6(E);
  Score += EvaluateTree7(E);
  Score += EvaluateTree8(E);
  Score += EvaluateTree9(E);
  Score += EvaluateTree10(E);
  Score += EvaluateTree11(E);
  Score += EvaluateTree12(E);
  Score += EvaluateTree13(E);
  Score += EvaluateTree14(E);
  Score += EvaluateTree15(E);
  Score += EvaluateTree16(E);
  Score += EvaluateTree17(E);
  Score += EvaluateTree18(E);
  Score += EvaluateTree19(E);
  Score += EvaluateTree20(E);
  Score += EvaluateTree21(E);
  Score += EvaluateTree22(E);
  Score += EvaluateTree23(E);
  Score += EvaluateTree24(E);
  Score += EvaluateTree25(E);
  Score += EvaluateTree26(E);
  Score += EvaluateTree27(E);
  Score += EvaluateTree28(E);
  Score += EvaluateTree29(E);
  Score += EvaluateTree30(E);
  Score += EvaluateTree31(E);
  Score += EvaluateTree32(E);
  Score += EvaluateTree33(E);
  Score += EvaluateTree34(E);
  Score += EvaluateTree35(E);
  Score += EvaluateTree36(E);
  Score += EvaluateTree37(E);
  Score += EvaluateTree38(E);
  Score += EvaluateTree39(E);
  Score += EvaluateTree40(E);
  Score += EvaluateTree41(E);
  Score += EvaluateTree42(E);
  Score += EvaluateTree43(E);
  Score += EvaluateTree44(E);
  Score += EvaluateTree45(E);
  Score += EvaluateTree46(E);
  Score += EvaluateTree47(E);
  Score += EvaluateTree48(E);
  Score += EvaluateTree49(E);
  Score += EvaluateTree50(E);
  Score += EvaluateTree51(E);
  Score += EvaluateTree52(E);
  Score += EvaluateTree53(E);
  Score += EvaluateTree54(E);
  Score += EvaluateTree55(E);
  Score += EvaluateTree56(E);
  Score += EvaluateTree57(E);
  Score += EvaluateTree58(E);
  Score += EvaluateTree59(E);
  Score += EvaluateTree60(E);
  Score += EvaluateTree61(E);
  Score += EvaluateTree62(E);
  Score += EvaluateTree63(E);
  Score += EvaluateTree64(E);
  Score += EvaluateTree65(E);
  Score += EvaluateTree66(E);
  Score += EvaluateTree67(E);
  Score += EvaluateTree68(E);
  Score += EvaluateTree69(E);
  Score += EvaluateTree70(E);
  Score += EvaluateTree71(E);
  Score += EvaluateTree72(E);
  Score += EvaluateTree73(E);
  Score += EvaluateTree74(E);
  Score += EvaluateTree75(E);
  Score += EvaluateTree76(E);
  Score += EvaluateTree77(E);
  Score += EvaluateTree78(E);
  Score += EvaluateTree79(E);
  Score += EvaluateTree80(E);
  Score += EvaluateTree81(E);
  Score += EvaluateTree82(E);
  Score += EvaluateTree83(E);
  Score += EvaluateTree84(E);
  Score += EvaluateTree85(E);
  Score += EvaluateTree86(E);
  Score += EvaluateTree87(E);
  Score += EvaluateTree88(E);
  Score += EvaluateTree89(E);
  Score += EvaluateTree90(E);
  Score += EvaluateTree91(E);
  Score += EvaluateTree92(E);
  Score += EvaluateTree93(E);
  Score += EvaluateTree94(E);
  Score += EvaluateTree95(E);
  Score += EvaluateTree96(E);
  Score += EvaluateTree97(E);
  Score += EvaluateTree98(E);
  Score += EvaluateTree99(E);
  Score += EvaluateTree100(E);
  Score += EvaluateTree101(E);
  Score += EvaluateTree102(E);
  Score += EvaluateTree103(E);
  Score += EvaluateTree104(E);
  Score += EvaluateTree105(E);
  Score += EvaluateTree106(E);
  Score += EvaluateTree107(E);
  Score += EvaluateTree108(E);
  Score += EvaluateTree109(E);
  Score += EvaluateTree110(E);
  Score += EvaluateTree111(E);
  Score += EvaluateTree112(E);
  Score += EvaluateTree113(E);
  Score += EvaluateTree114(E);
  Score += EvaluateTree115(E);
  Score += EvaluateTree116(E);
  Score += EvaluateTree117(E);
  Score += EvaluateTree118(E);
  Score += EvaluateTree119(E);
  Score += EvaluateTree120(E);
  Score += EvaluateTree121(E);
  Score += EvaluateTree122(E);
  Score += EvaluateTree123(E);
  Score += EvaluateTree124(E);
  Score += EvaluateTree125(E);
  Score += EvaluateTree126(E);
  Score += EvaluateTree127(E);
  Score += EvaluateTree128(E);
  Score += EvaluateTree129(E);
  Score += EvaluateTree130(E);
  Score += EvaluateTree131(E);
  Score += EvaluateTree132(E);
  Score += EvaluateTree133(E);
  Score += EvaluateTree134(E);
  Score += EvaluateTree135(E);
  Score += EvaluateTree136(E);
  Score += EvaluateTree137(E);
  Score += EvaluateTree138(E);
  Score += EvaluateTree139(E);
  Score += EvaluateTree140(E);
  Score += EvaluateTree141(E);
  Score += EvaluateTree142(E);
  Score += EvaluateTree143(E);
  Score += EvaluateTree144(E);
  Score += EvaluateTree145(E);
  Score += EvaluateTree146(E);
  Score += EvaluateTree147(E);
  Score += EvaluateTree148(E);
  Score += EvaluateTree149(E);
  Score += EvaluateTree150(E);
  Score += EvaluateTree151(E);
  Score += EvaluateTree152(E);
  Score += EvaluateTree153(E);
  Score += EvaluateTree154(E);
  Score += EvaluateTree155(E);
  Score += EvaluateTree156(E);
  Score += EvaluateTree157(E);
  Score += EvaluateTree158(E);
  Score += EvaluateTree159(E);
  Score += EvaluateTree160(E);
  Score += EvaluateTree161(E);
  Score += EvaluateTree162(E);
  Score += EvaluateTree163(E);
  Score += EvaluateTree164(E);
  Score += EvaluateTree165(E);
  Score += EvaluateTree166(E);
  Score += EvaluateTree167(E);
  Score += EvaluateTree168(E);
  Score += EvaluateTree169(E);
  Score += EvaluateTree170(E);
  Score += EvaluateTree171(E);
  Score += EvaluateTree172(E);
  Score += EvaluateTree173(E);
  Score += EvaluateTree174(E);
  Score += EvaluateTree175(E);
  Score += EvaluateTree176(E);
  Score += EvaluateTree177(E);
  Score += EvaluateTree178(E);
  Score += EvaluateTree179(E);
  Score += EvaluateTree180(E);
  Score += EvaluateTree181(E);
  Score += EvaluateTree182(E);
  Score += EvaluateTree183(E);
  Score += EvaluateTree184(E);
  Score += EvaluateTree185(E);
  Score += EvaluateTree186(E);
  Score += EvaluateTree187(E);
  Score += EvaluateTree188(E);
  Score += EvaluateTree189(E);
  Score += EvaluateTree190(E);
  Score += EvaluateTree191(E);
  Score += EvaluateTree192(E);
  Score += EvaluateTree193(E);
  Score += EvaluateTree194(E);
  Score += EvaluateTree195(E);
  Score += EvaluateTree196(E);
  Score += EvaluateTree197(E);
  Score += EvaluateTree198(E);
  Score += EvaluateTree199(E);
  Score += EvaluateTree200(E);
  Score += EvaluateTree201(E);
  Score += EvaluateTree202(E);
  Score += EvaluateTree203(E);
  Score += EvaluateTree204(E);
  Score += EvaluateTree205(E);
  Score += EvaluateTree206(E);
  Score += EvaluateTree207(E);
  Score += EvaluateTree208(E);
  Score += EvaluateTree209(E);
  Score += EvaluateTree210(E);
  Score += EvaluateTree211(E);
  Score += EvaluateTree212(E);
  Score += EvaluateTree213(E);
  Score += EvaluateTree214(E);
  Score += EvaluateTree215(E);
  Score += EvaluateTree216(E);
  Score += EvaluateTree217(E);
  Score += EvaluateTree218(E);
  Score += EvaluateTree219(E);
  Score += EvaluateTree220(E);
  Score += EvaluateTree221(E);
  Score += EvaluateTree222(E);
  Score += EvaluateTree223(E);
  Score += EvaluateTree224(E);
  Score += EvaluateTree225(E);
  Score += EvaluateTree226(E);
  Score += EvaluateTree227(E);
  Score += EvaluateTree228(E);
  Score += EvaluateTree229(E);
  Score += EvaluateTree230(E);
  Score += EvaluateTree231(E);
  Score += EvaluateTree232(E);
  Score += EvaluateTree233(E);
  Score += EvaluateTree234(E);
  Score += EvaluateTree235(E);
  Score += EvaluateTree236(E);
  Score += EvaluateTree237(E);
  Score += EvaluateTree238(E);
  Score += EvaluateTree239(E);
  Score += EvaluateTree240(E);
  Score += EvaluateTree241(E);
  Score += EvaluateTree242(E);
  Score += EvaluateTree243(E);
  Score += EvaluateTree244(E);
  Score += EvaluateTree245(E);
  Score += EvaluateTree246(E);
  Score += EvaluateTree247(E);
  Score += EvaluateTree248(E);
  Score += EvaluateTree249(E);
  Score += EvaluateTree250(E);
  Score += EvaluateTree251(E);
  Score += EvaluateTree252(E);
  Score += EvaluateTree253(E);
  Score += EvaluateTree254(E);
  Score += EvaluateTree255(E);
  Score += EvaluateTree256(E);
  Score += EvaluateTree257(E);
  Score += EvaluateTree258(E);
  Score += EvaluateTree259(E);
  Score += EvaluateTree260(E);
  Score += EvaluateTree261(E);
  Score += EvaluateTree262(E);
  Score += EvaluateTree263(E);
  Score += EvaluateTree264(E);
  Score += EvaluateTree265(E);
  Score += EvaluateTree266(E);
  Score += EvaluateTree267(E);
  Score += EvaluateTree268(E);
  Score += EvaluateTree269(E);
  Score += EvaluateTree270(E);
  Score += EvaluateTree271(E);
  Score += EvaluateTree272(E);
  Score += EvaluateTree273(E);
  Score += EvaluateTree274(E);
  Score += EvaluateTree275(E);
  Score += EvaluateTree276(E);
  Score += EvaluateTree277(E);
  Score += EvaluateTree278(E);
  Score += EvaluateTree279(E);
  Score += EvaluateTree280(E);
  Score += EvaluateTree281(E);
  Score += EvaluateTree282(E);
  Score += EvaluateTree283(E);
  Score += EvaluateTree284(E);
  Score += EvaluateTree285(E);
  Score += EvaluateTree286(E);
  Score += EvaluateTree287(E);
  Score += EvaluateTree288(E);
  Score += EvaluateTree289(E);
  Score += EvaluateTree290(E);
  Score += EvaluateTree291(E);
  return Score;
}

} // namespace clangd
} // namespace clang
